{
 "cells": [
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [],
   "source": [
    "import numpy as np\n",
    "import matplotlib.pyplot as plt\n",
    "%matplotlib inline\n",
    "import matplotlib_inline\n",
    "matplotlib_inline.backend_inline.set_matplotlib_formats('svg')\n",
    "import seaborn as sns\n",
    "sns.set_context(\"paper\")\n",
    "sns.set_style(\"ticks\")\n",
    "\n",
    "import torch\n",
    "import gpytorch\n",
    "from gpytorch.kernels import RBFKernel, ScaleKernel\n",
    "\n",
    "\n",
    "class ExactGP(gpytorch.models.ExactGP):\n",
    "    def __init__(self,\n",
    "                 train_x,\n",
    "                 train_y,\n",
    "                 likelihood=gpytorch.likelihoods.GaussianLikelihood(\n",
    "                     noise_constraint=gpytorch.constraints.GreaterThan(0.0)\n",
    "                ),\n",
    "                mean_module=gpytorch.means.ConstantMean(),\n",
    "                covar_module=ScaleKernel(RBFKernel())\n",
    "        ):\n",
    "        super().__init__(train_x, train_y, likelihood)\n",
    "        self.mean_module = mean_module\n",
    "        self.covar_module = covar_module\n",
    "\n",
    "    def forward(self, x):\n",
    "        mean_x = self.mean_module(x)\n",
    "        covar_x = self.covar_module(x)\n",
    "        return gpytorch.distributions.MultivariateNormal(mean_x, covar_x)\n",
    "\n",
    "\n",
    "def plot_1d_regression(\n",
    "    x_star,\n",
    "    model,\n",
    "    ax=None,\n",
    "    f_true=None,\n",
    "    num_samples=10\n",
    "):\n",
    "    \"\"\"Plot the posterior predictive.\n",
    "    \n",
    "    Arguments\n",
    "    x_start  --  The test points on which to evaluate.\n",
    "    model    --  The trained model.\n",
    "    \n",
    "    Keyword Arguments\n",
    "    ax          --  An axes object to write on.\n",
    "    f_true      --  The true function.\n",
    "    num_samples --  The number of samples.\n",
    "    \"\"\"\n",
    "    f_star = model(x_star)\n",
    "    m_star = f_star.mean\n",
    "    v_star = f_star.variance\n",
    "    y_star = model.likelihood(f_star)\n",
    "    yv_star = y_star.variance\n",
    "\n",
    "    f_lower = (\n",
    "        m_star - 2.0 * torch.sqrt(v_star)\n",
    "    )\n",
    "    f_upper = (\n",
    "        m_star + 2.0 * torch.sqrt(v_star)\n",
    "    )\n",
    "    \n",
    "    y_lower = m_star - 2.0 * torch.sqrt(yv_star)\n",
    "    y_upper = m_star + 2.0 * torch.sqrt(yv_star)\n",
    "\n",
    "    if ax is None:\n",
    "        fig, ax = plt.subplots()\n",
    "    \n",
    "    ax.plot(model.train_inputs[0].flatten().detach(),\n",
    "            model.train_targets.detach(),\n",
    "            'kx',\n",
    "            markersize=10,\n",
    "            markeredgewidth=2,\n",
    "            label='Observations'\n",
    "    )\n",
    "\n",
    "    ax.plot(\n",
    "        x_star,\n",
    "        m_star.detach(),\n",
    "        lw=2,\n",
    "        label='$m_n(x)$',\n",
    "        color=sns.color_palette()[0]\n",
    "    )\n",
    "    \n",
    "    ax.fill_between(\n",
    "        x_star.flatten().detach(),\n",
    "        f_lower.flatten().detach(),\n",
    "        f_upper.flatten().detach(),\n",
    "        alpha=0.5,\n",
    "        label='$f(\\mathbf{x}^*)$ 95% pred.',\n",
    "        color=sns.color_palette()[0]\n",
    "    )\n",
    "\n",
    "    ax.fill_between(\n",
    "        x_star.detach().flatten(),\n",
    "        y_lower.detach().flatten(),\n",
    "        f_lower.detach().flatten(),\n",
    "        color=sns.color_palette()[1],\n",
    "        alpha=0.5,\n",
    "        label='$y^*$ 95% pred.'\n",
    "    )\n",
    "    ax.fill_between(\n",
    "        x_star.detach().flatten(),\n",
    "        f_upper.detach().flatten(),\n",
    "        y_upper.detach().flatten(),\n",
    "        color=sns.color_palette()[1],\n",
    "        alpha=0.5,\n",
    "        label=None\n",
    "    )\n",
    "\n",
    "    \n",
    "    if f_true is not None:\n",
    "        ax.plot(\n",
    "            x_star,\n",
    "            f_true(x_star),\n",
    "            'm-.',\n",
    "            label='True function'\n",
    "        )\n",
    "        \n",
    "    if num_samples > 0:\n",
    "        f_post_samples = f_star.sample(\n",
    "            sample_shape=torch.Size([10])\n",
    "        )\n",
    "        ax.plot(\n",
    "            x_star.numpy(),\n",
    "            f_post_samples.T.detach().numpy(),\n",
    "            color=\"red\",\n",
    "            lw=0.5\n",
    "        )\n",
    "        # This is just to add the legend entry\n",
    "        ax.plot(\n",
    "            [],\n",
    "            [],\n",
    "            color=\"red\",\n",
    "            lw=0.5,\n",
    "            label=\"Posterior samples\"\n",
    "        )\n",
    "        \n",
    "    ax.set_xlabel('$x$')\n",
    "    ax.set_ylabel('$y$')\n",
    "\n",
    "    plt.legend(loc='best', frameon=False)\n",
    "    sns.despine(trim=True)\n",
    "    \n",
    "    return m_star, v_star\n",
    "\n",
    "\n",
    "def train(model, train_x, train_y, n_iter=10, lr=0.1):\n",
    "    \"\"\"Train the model.\n",
    "\n",
    "    Arguments\n",
    "    model   --  The model to train.\n",
    "    train_x --  The training inputs.\n",
    "    train_y --  The training labels.\n",
    "    n_iter  --  The number of iterations.\n",
    "    \"\"\"\n",
    "    model.train()\n",
    "    optimizer = torch.optim.LBFGS(model.parameters(), line_search_fn='strong_wolfe')\n",
    "    likelihood = model.likelihood\n",
    "    mll = gpytorch.mlls.ExactMarginalLogLikelihood(likelihood, model)\n",
    "    def closure():\n",
    "        optimizer.zero_grad()\n",
    "        output = model(train_x)\n",
    "        loss = -mll(output, train_y)\n",
    "        loss.backward()\n",
    "        return loss\n",
    "    for i in range(n_iter):\n",
    "        loss = optimizer.step(closure)\n",
    "        if (i + 1) % 1 == 0:\n",
    "            print(f'Iter {i + 1:3d}/{n_iter} - Loss: {loss.item():.3f}')\n",
    "    model.eval()\n",
    "\n",
    "\n",
    "def plot_iaf(\n",
    "    x_star,\n",
    "    gpr,\n",
    "    alpha,\n",
    "    alpha_params={},\n",
    "    ax=None,\n",
    "    f_true=None,\n",
    "    iaf_label=\"Information Acquisition Function\"\n",
    "):\n",
    "    \"\"\"Plot the information acquisition function.\n",
    "    \n",
    "    Arguments\n",
    "    x_star       -- A set of points to plot on.\n",
    "    gpr          -- A rained Gaussian process regression\n",
    "                    object.\n",
    "    alpha        -- The information acquisition function.\n",
    "                    This assumed to be a function of the\n",
    "                    posterior mean and standard deviation.\n",
    "              \n",
    "    Keyword Arguments\n",
    "    ax           -- An axes object to plot on.\n",
    "    f_true       -- The true function - if available.\n",
    "    alpha_params -- Extra parameters to the information\n",
    "                    acquisition function.\n",
    "    ax           -- An axes object to plot on.\n",
    "    f_true       -- The true function - if available.\n",
    "    iaf_label    -- The label for the information acquisition\n",
    "                    function. Default is \"Information Acquisition\".\n",
    "    \n",
    "    The evaluation of the information acquisition function\n",
    "    is as follows:\n",
    "    \n",
    "        af_values = alpha(mu, sigma, y_max, **alpha_params)\n",
    "\n",
    "    \"\"\"\n",
    "    if ax is None:\n",
    "        fig, ax = plt.subplots()\n",
    "    \n",
    "    ax.set_title(\n",
    "        \", \".join(\n",
    "            f\"{n}={k:.2f}\"\n",
    "            for n, k in alpha_params.items()\n",
    "            )\n",
    "    )\n",
    "    \n",
    "    m, v = plot_1d_regression(\n",
    "        x_star,\n",
    "        gpr,\n",
    "        ax=ax,\n",
    "        f_true=f_true,\n",
    "        num_samples=0\n",
    "    )\n",
    "    \n",
    "    sigma = torch.sqrt(v)\n",
    "    af_values = alpha(m, sigma, gpr.train_targets.numpy().max(), **alpha_params)\n",
    "    next_id = torch.argmax(af_values)\n",
    "    next_x = x_star[next_id]\n",
    "    af_max = af_values[next_id]\n",
    "    \n",
    "    ax2 = ax.twinx()\n",
    "    ax2.plot(x_star, af_values.detach(), color=sns.color_palette()[1])\n",
    "    ax2.set_ylabel(\n",
    "        iaf_label,\n",
    "        color=sns.color_palette()[1]\n",
    "    )\n",
    "    plt.setp(\n",
    "        ax2.get_yticklabels(),\n",
    "        color=sns.color_palette()[1]\n",
    "    )\n",
    "    ax2.plot(\n",
    "        next_x * np.ones(100),\n",
    "        torch.linspace(0, af_max.item(), 100),\n",
    "        color=sns.color_palette()[1],\n",
    "        linewidth=1\n",
    "    )\n",
    "\n",
    "\n",
    "def maximize(\n",
    "    f,\n",
    "    model,\n",
    "    X_design,\n",
    "    alpha,\n",
    "    alpha_params={},\n",
    "    max_it=10,\n",
    "    optimize=False,\n",
    "    plot=False,\n",
    "    **kwargs\n",
    "):\n",
    "    \"\"\"Optimize a function using a limited number of evaluations.\n",
    "    \n",
    "    Arguments\n",
    "    f            -- The function to optimize.\n",
    "    gpr          -- A Gaussian process model to use for representing\n",
    "                    our state of knowledge.\n",
    "    X_design     -- The set of candidate points for identifying the\n",
    "                    maximum.\n",
    "    alpha        -- The information acquisition function.\n",
    "                    This assumed to be a function of the\n",
    "                    posterior mean and standard deviation.\n",
    "    \n",
    "    Keyword Arguments\n",
    "    alpha_params -- Extra parameters to the information\n",
    "                    acquisition function.\n",
    "    max_it       -- The maximum number of iterations.\n",
    "    optimize     -- Whether or not to optimize the hyper-parameters.\n",
    "    plot         -- Determines how often to plot. Make it one\n",
    "                    to plot at each iteration. Make it max_it\n",
    "                    to plot at the last iteration.\n",
    "                    \n",
    "    The rest of the keyword arguments are passed to plot_iaf().\n",
    "    \"\"\"\n",
    "    af_all = []\n",
    "    for count in range(max_it):\n",
    "        # Predict\n",
    "        f_design = model(X_design)\n",
    "        m = f_design.mean\n",
    "        sigma2 = f_design.variance\n",
    "        sigma = torch.sqrt(sigma2)\n",
    "        \n",
    "        # Evaluate information acquisition function\n",
    "        y_train = model.train_targets.numpy()\n",
    "        af_values = alpha(\n",
    "            m,\n",
    "            sigma,\n",
    "            y_train.max(),\n",
    "            **alpha_params\n",
    "        )\n",
    "        \n",
    "        # Find best point to include\n",
    "        i = torch.argmax(af_values)\n",
    "        af_all.append(af_values[i])\n",
    "        \n",
    "        new_x = X_design[i:(i+1)].float()\n",
    "        new_y = f(new_x)\n",
    "        train_x = torch.cat([model.train_inputs[0], new_x[:, None]])\n",
    "        train_y = torch.cat([model.train_targets, new_y])\n",
    "        model.set_train_data(train_x, train_y, strict=False)\n",
    "        \n",
    "        if optimize:\n",
    "            train(model, train_x, train_y, n_iter=100, lr=0.1)\n",
    "        else:\n",
    "            model.train()\n",
    "            model.eval()\n",
    "        \n",
    "        # Plot if required\n",
    "        if count % plot == 0:\n",
    "            if \"ax\" in kwargs:\n",
    "                ax = kwargs[ax]\n",
    "            else:\n",
    "                fig, ax = plt.subplots()\n",
    "            plot_iaf(\n",
    "                X_design,\n",
    "                model,\n",
    "                alpha,\n",
    "                alpha_params=alpha_params,\n",
    "                f_true=f,\n",
    "                ax=ax,\n",
    "                **kwargs\n",
    "            )\n",
    "            ax.set_title(\n",
    "                f\"N={count}, \" + ax.get_title()\n",
    "            )\n",
    "    return af_all"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [],
   "source": [
    "!pip install gpytorch"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# Expected Improvement\n",
    "\n",
    "We develop intuition about the expected improvement, the most popular acquisition function for Bayesian optimization.\n",
    "Let's reintroduce the same running example as the previous hands-on activity."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"414.864875pt\" height=\"309.639375pt\" viewBox=\"0 0 414.864875 309.639375\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2023-10-23T15:18:57.649001</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.8.0, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 309.639375 \n",
       "L 414.864875 309.639375 \n",
       "L 414.864875 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 50.544875 273.312 \n",
       "L 407.664875 273.312 \n",
       "L 407.664875 7.2 \n",
       "L 50.544875 7.2 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"m5c66fbf076\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m5c66fbf076\" x=\"73.778876\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(67.662876 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m5c66fbf076\" x=\"117.315919\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0.3 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(111.199919 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-33\" d=\"M 269 1209 \n",
       "L 831 1284 \n",
       "Q 928 806 1161 595 \n",
       "Q 1394 384 1728 384 \n",
       "Q 2125 384 2398 659 \n",
       "Q 2672 934 2672 1341 \n",
       "Q 2672 1728 2419 1979 \n",
       "Q 2166 2231 1775 2231 \n",
       "Q 1616 2231 1378 2169 \n",
       "L 1441 2663 \n",
       "Q 1497 2656 1531 2656 \n",
       "Q 1891 2656 2178 2843 \n",
       "Q 2466 3031 2466 3422 \n",
       "Q 2466 3731 2256 3934 \n",
       "Q 2047 4138 1716 4138 \n",
       "Q 1388 4138 1169 3931 \n",
       "Q 950 3725 888 3313 \n",
       "L 325 3413 \n",
       "Q 428 3978 793 4289 \n",
       "Q 1159 4600 1703 4600 \n",
       "Q 2078 4600 2393 4439 \n",
       "Q 2709 4278 2876 4000 \n",
       "Q 3044 3722 3044 3409 \n",
       "Q 3044 3113 2884 2869 \n",
       "Q 2725 2625 2413 2481 \n",
       "Q 2819 2388 3044 2092 \n",
       "Q 3269 1797 3269 1353 \n",
       "Q 3269 753 2831 336 \n",
       "Q 2394 -81 1725 -81 \n",
       "Q 1122 -81 723 278 \n",
       "Q 325 638 269 1209 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m5c66fbf076\" x=\"160.852962\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(154.736962 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m5c66fbf076\" x=\"204.390005\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 0.5 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(198.274005 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m5c66fbf076\" x=\"247.927048\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(241.811048 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m5c66fbf076\" x=\"291.464091\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 0.7 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(285.348091 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-37\" d=\"M 303 3981 \n",
       "L 303 4522 \n",
       "L 3269 4522 \n",
       "L 3269 4084 \n",
       "Q 2831 3619 2401 2847 \n",
       "Q 1972 2075 1738 1259 \n",
       "Q 1569 684 1522 0 \n",
       "L 944 0 \n",
       "Q 953 541 1156 1306 \n",
       "Q 1359 2072 1739 2783 \n",
       "Q 2119 3494 2547 3981 \n",
       "L 303 3981 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-37\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_7\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m5c66fbf076\" x=\"335.001134\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_7\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(328.885134 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_8\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m5c66fbf076\" x=\"378.538177\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- 0.9 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(372.422177 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-39\" d=\"M 350 1059 \n",
       "L 891 1109 \n",
       "Q 959 728 1153 556 \n",
       "Q 1347 384 1650 384 \n",
       "Q 1909 384 2104 503 \n",
       "Q 2300 622 2425 820 \n",
       "Q 2550 1019 2634 1356 \n",
       "Q 2719 1694 2719 2044 \n",
       "Q 2719 2081 2716 2156 \n",
       "Q 2547 1888 2255 1720 \n",
       "Q 1963 1553 1622 1553 \n",
       "Q 1053 1553 659 1965 \n",
       "Q 266 2378 266 3053 \n",
       "Q 266 3750 677 4175 \n",
       "Q 1088 4600 1706 4600 \n",
       "Q 2153 4600 2523 4359 \n",
       "Q 2894 4119 3086 3673 \n",
       "Q 3278 3228 3278 2384 \n",
       "Q 3278 1506 3087 986 \n",
       "Q 2897 466 2520 194 \n",
       "Q 2144 -78 1638 -78 \n",
       "Q 1100 -78 759 220 \n",
       "Q 419 519 350 1059 \n",
       "z\n",
       "M 2653 3081 \n",
       "Q 2653 3566 2395 3850 \n",
       "Q 2138 4134 1775 4134 \n",
       "Q 1400 4134 1122 3828 \n",
       "Q 844 3522 844 3034 \n",
       "Q 844 2597 1108 2323 \n",
       "Q 1372 2050 1759 2050 \n",
       "Q 2150 2050 2401 2323 \n",
       "Q 2653 2597 2653 3081 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-39\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_9\">\n",
       "     <!-- $x$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(226.224875 300.531375) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-78\" d=\"M 3841 3500 \n",
       "L 2234 1784 \n",
       "L 3219 0 \n",
       "L 2559 0 \n",
       "L 1819 1388 \n",
       "L 531 0 \n",
       "L -166 0 \n",
       "L 1556 1844 \n",
       "L 641 3500 \n",
       "L 1300 3500 \n",
       "L 1972 2234 \n",
       "L 3144 3500 \n",
       "L 3841 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <defs>\n",
       "       <path id=\"mb9d54a06c8\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb9d54a06c8\" x=\"50.544875\" y=\"245.1672\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- −0.38 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 248.316637) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb9d54a06c8\" x=\"50.544875\" y=\"213.255195\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- −0.36 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 216.404633) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb9d54a06c8\" x=\"50.544875\" y=\"181.343191\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- −0.34 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 184.492628) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb9d54a06c8\" x=\"50.544875\" y=\"149.431186\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- −0.32 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 152.580624) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_13\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb9d54a06c8\" x=\"50.544875\" y=\"117.519182\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_14\">\n",
       "      <!-- −0.30 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 120.668619) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_14\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb9d54a06c8\" x=\"50.544875\" y=\"85.607177\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_15\">\n",
       "      <!-- −0.28 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 88.756615) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_15\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb9d54a06c8\" x=\"50.544875\" y=\"53.695173\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_16\">\n",
       "      <!-- −0.26 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 56.84461) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_16\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb9d54a06c8\" x=\"50.544875\" y=\"21.783168\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_17\">\n",
       "      <!-- −0.24 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 24.932606) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"114.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"141.796875\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"197.412109\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_18\">\n",
       "     <!-- $y$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(13.9635 143.136) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-79\" d=\"M 1588 -325 \n",
       "Q 1188 -997 936 -1164 \n",
       "Q 684 -1331 294 -1331 \n",
       "L -159 -1331 \n",
       "L -63 -850 \n",
       "L 269 -850 \n",
       "Q 509 -850 678 -719 \n",
       "Q 847 -588 1056 -206 \n",
       "L 1234 128 \n",
       "L 459 3500 \n",
       "L 1069 3500 \n",
       "L 1650 819 \n",
       "L 3256 3500 \n",
       "L 3859 3500 \n",
       "L 1588 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_17\">\n",
       "    <defs>\n",
       "     <path id=\"m6ef752258b\" d=\"M -5 5 \n",
       "L 5 -5 \n",
       "M -5 -5 \n",
       "L 5 5 \n",
       "\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pb5f05e0561)\">\n",
       "     <use xlink:href=\"#m6ef752258b\" x=\"391.432148\" y=\"19.296\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m6ef752258b\" x=\"124.445351\" y=\"85.049893\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m6ef752258b\" x=\"66.777602\" y=\"261.216\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 50.544875 245.1672 \n",
       "L 50.544875 21.783168 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 73.778876 273.312 \n",
       "L 378.538177 273.312 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"pb5f05e0561\">\n",
       "   <rect x=\"50.544875\" y=\"7.2\" width=\"357.12\" height=\"266.112\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 640x480 with 1 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "def f(x):\n",
    "    \"\"\"A function to optimize.\"\"\"\n",
    "    return -4 * (1. - np.sin(6 * x + 8 * np.exp(6 * x - 7.))) \n",
    "\n",
    "np.random.seed(12345)\n",
    "\n",
    "n_init = 3\n",
    "\n",
    "X = np.random.rand(n_init)\n",
    "Y = f(X)\n",
    "\n",
    "plt.plot(X, Y, 'kx', markersize=10, markeredgewidth=2)\n",
    "plt.xlabel('$x$')\n",
    "plt.ylabel('$y$')\n",
    "sns.despine(trim=True);"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Just like in the previous hands-on activity, assume that we have made some observations and that we have used them to do Gaussian process regression, resulting in the point-predictive distribution:\n",
    "\n",
    "$$\n",
    "p(y|\\mathbf{x},\\mathcal{D}_{n}) = \\mathcal{N}\\left(y|m_{n}(\\mathbf{x}), \\sigma^2_{n}(\\mathbf{x})\\right),\n",
    "$$\n",
    "\n",
    "where $m_{n}(\\mathbf{x})$ and $\\sigma^2_{n}(\\mathbf{x})$ are the predictive mean and variance respectively.\n",
    "Here is the code for this:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {},
   "outputs": [
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "/Users/ibilion/.pyenv/versions/3.11.6/lib/python3.11/site-packages/linear_operator/utils/cholesky.py:40: NumericalWarning: A not p.d., added jitter of 1.0e-06 to the diagonal\n",
      "  warnings.warn(\n",
      "/Users/ibilion/.pyenv/versions/3.11.6/lib/python3.11/site-packages/linear_operator/utils/cholesky.py:40: NumericalWarning: A not p.d., added jitter of 1.0e-05 to the diagonal\n",
      "  warnings.warn(\n",
      "/Users/ibilion/.pyenv/versions/3.11.6/lib/python3.11/site-packages/linear_operator/utils/cholesky.py:40: NumericalWarning: A not p.d., added jitter of 1.0e-04 to the diagonal\n",
      "  warnings.warn(\n"
     ]
    },
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"402.632875pt\" height=\"309.639375pt\" viewBox=\"0 0 402.632875 309.639375\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2023-10-23T15:18:57.825918</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.8.0, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 309.639375 \n",
       "L 402.632875 309.639375 \n",
       "L 402.632875 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 38.312875 273.312 \n",
       "L 395.432875 273.312 \n",
       "L 395.432875 7.2 \n",
       "L 38.312875 7.2 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"m6583a5013c\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m6583a5013c\" x=\"54.545602\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(48.429602 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m6583a5013c\" x=\"119.476511\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(113.360511 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m6583a5013c\" x=\"184.40742\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(178.29142 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m6583a5013c\" x=\"249.33833\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(243.22233 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m6583a5013c\" x=\"314.269239\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(308.153239 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m6583a5013c\" x=\"379.200148\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 1.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(373.084148 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_7\">\n",
       "     <!-- $x$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(213.992875 300.531375) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-78\" d=\"M 3841 3500 \n",
       "L 2234 1784 \n",
       "L 3219 0 \n",
       "L 2559 0 \n",
       "L 1819 1388 \n",
       "L 531 0 \n",
       "L -166 0 \n",
       "L 1556 1844 \n",
       "L 641 3500 \n",
       "L 1300 3500 \n",
       "L 1972 2234 \n",
       "L 3144 3500 \n",
       "L 3841 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <defs>\n",
       "       <path id=\"m696e291297\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m696e291297\" x=\"38.312875\" y=\"261.273566\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- −8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 264.423003) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m696e291297\" x=\"38.312875\" y=\"220.543566\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- −6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 223.693004) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m696e291297\" x=\"38.312875\" y=\"179.813567\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 182.963005) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m696e291297\" x=\"38.312875\" y=\"139.083568\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 142.233005) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m696e291297\" x=\"38.312875\" y=\"98.353569\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 101.503006) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m696e291297\" x=\"38.312875\" y=\"57.62357\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 60.773007) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_13\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m696e291297\" x=\"38.312875\" y=\"16.89357\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_14\">\n",
       "      <!-- 4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 20.043008) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-34\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_15\">\n",
       "     <!-- $y$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(13.9635 143.136) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-79\" d=\"M 1588 -325 \n",
       "Q 1188 -997 936 -1164 \n",
       "Q 684 -1331 294 -1331 \n",
       "L -159 -1331 \n",
       "L -63 -850 \n",
       "L 269 -850 \n",
       "Q 509 -850 678 -719 \n",
       "Q 847 -588 1056 -206 \n",
       "L 1234 128 \n",
       "L 459 3500 \n",
       "L 1069 3500 \n",
       "L 1650 819 \n",
       "L 3256 3500 \n",
       "L 3859 3500 \n",
       "L 1588 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_1\">\n",
       "    <defs>\n",
       "     <path id=\"mbce84e3f81\" d=\"M 54.545602 -275.586429 \n",
       "L 54.545602 -139.739149 \n",
       "L 57.824941 -141.773884 \n",
       "L 61.10428 -144.062902 \n",
       "L 64.383619 -146.610838 \n",
       "L 67.662958 -149.417649 \n",
       "L 70.942296 -152.478053 \n",
       "L 74.221636 -155.7811 \n",
       "L 77.500973 -159.309947 \n",
       "L 80.780313 -163.04156 \n",
       "L 84.059653 -166.94703 \n",
       "L 87.33899 -170.991411 \n",
       "L 90.61833 -175.13431 \n",
       "L 93.89767 -179.330388 \n",
       "L 97.177007 -183.529867 \n",
       "L 100.456344 -187.680185 \n",
       "L 103.735686 -191.726054 \n",
       "L 107.015024 -195.611041 \n",
       "L 110.294361 -199.279301 \n",
       "L 113.573703 -202.673183 \n",
       "L 116.853041 -200.922203 \n",
       "L 120.132378 -198.265433 \n",
       "L 123.41172 -196.092809 \n",
       "L 126.691057 -194.439612 \n",
       "L 129.970395 -193.333729 \n",
       "L 133.249737 -192.79343 \n",
       "L 136.529069 -192.828627 \n",
       "L 139.808412 -193.439273 \n",
       "L 143.087754 -194.616015 \n",
       "L 146.367086 -196.340346 \n",
       "L 149.646428 -198.585042 \n",
       "L 152.92577 -201.314285 \n",
       "L 156.205103 -204.486126 \n",
       "L 159.484445 -203.545524 \n",
       "L 162.763787 -200.261499 \n",
       "L 166.04312 -196.699932 \n",
       "L 169.322462 -192.915284 \n",
       "L 172.601804 -188.962784 \n",
       "L 175.881137 -184.8981 \n",
       "L 179.160479 -180.775548 \n",
       "L 182.439821 -176.647176 \n",
       "L 185.719153 -172.561918 \n",
       "L 188.998496 -168.564411 \n",
       "L 192.277838 -164.694545 \n",
       "L 195.55717 -160.986757 \n",
       "L 198.836512 -157.469762 \n",
       "L 202.115855 -154.166336 \n",
       "L 205.395187 -151.093348 \n",
       "L 208.674529 -148.261876 \n",
       "L 211.953871 -145.677568 \n",
       "L 215.233204 -143.341041 \n",
       "L 218.512556 -141.248429 \n",
       "L 221.791879 -139.392085 \n",
       "L 225.071221 -137.761139 \n",
       "L 228.350563 -136.342364 \n",
       "L 231.629886 -135.120824 \n",
       "L 234.909247 -134.080624 \n",
       "L 238.18857 -133.205633 \n",
       "L 241.467912 -132.480087 \n",
       "L 244.747254 -131.889234 \n",
       "L 248.026597 -131.419795 \n",
       "L 251.305939 -131.060476 \n",
       "L 254.585262 -130.802262 \n",
       "L 257.864623 -130.638737 \n",
       "L 261.143946 -130.566251 \n",
       "L 264.423288 -130.584036 \n",
       "L 267.70263 -130.694224 \n",
       "L 270.981953 -130.901787 \n",
       "L 274.261315 -131.214426 \n",
       "L 277.540637 -131.642323 \n",
       "L 280.81998 -132.197901 \n",
       "L 284.099322 -132.895505 \n",
       "L 287.378664 -133.750938 \n",
       "L 290.658006 -134.781092 \n",
       "L 293.937329 -136.003379 \n",
       "L 297.21669 -137.435308 \n",
       "L 300.496013 -139.093765 \n",
       "L 303.775355 -140.994696 \n",
       "L 307.054697 -143.152277 \n",
       "L 310.33402 -145.578591 \n",
       "L 313.613382 -148.283016 \n",
       "L 316.892705 -151.271759 \n",
       "L 320.172047 -154.547519 \n",
       "L 323.451389 -158.10914 \n",
       "L 326.730731 -161.951291 \n",
       "L 330.010073 -166.064441 \n",
       "L 333.289396 -170.434801 \n",
       "L 336.568738 -175.044347 \n",
       "L 339.84808 -179.871197 \n",
       "L 343.127423 -184.889273 \n",
       "L 346.406765 -190.069554 \n",
       "L 349.686088 -195.380581 \n",
       "L 352.96543 -200.788012 \n",
       "L 356.244772 -206.252096 \n",
       "L 359.524114 -201.136253 \n",
       "L 362.803456 -195.723942 \n",
       "L 366.082798 -190.406208 \n",
       "L 369.362141 -185.216626 \n",
       "L 372.641463 -180.187249 \n",
       "L 375.920806 -175.347722 \n",
       "L 379.200148 -170.723609 \n",
       "L 379.200148 -243.148938 \n",
       "L 379.200148 -243.148938 \n",
       "L 375.920806 -238.265878 \n",
       "L 372.641463 -233.201444 \n",
       "L 369.362141 -227.984084 \n",
       "L 366.082798 -222.645935 \n",
       "L 362.803456 -217.221017 \n",
       "L 359.524114 -211.744339 \n",
       "L 356.244772 -206.607825 \n",
       "L 352.96543 -212.095191 \n",
       "L 349.686088 -217.56955 \n",
       "L 346.406765 -222.990222 \n",
       "L 343.127423 -228.321369 \n",
       "L 339.84808 -233.529518 \n",
       "L 336.568738 -238.583119 \n",
       "L 333.289396 -243.453133 \n",
       "L 330.010073 -248.114321 \n",
       "L 326.730731 -252.545014 \n",
       "L 323.451389 -256.727529 \n",
       "L 320.172047 -260.648284 \n",
       "L 316.892705 -264.297792 \n",
       "L 313.613382 -267.670752 \n",
       "L 310.33402 -270.765765 \n",
       "L 307.054697 -273.585045 \n",
       "L 303.775355 -276.134175 \n",
       "L 300.496013 -278.421644 \n",
       "L 297.21669 -280.458317 \n",
       "L 293.937329 -282.257099 \n",
       "L 290.658006 -283.83215 \n",
       "L 287.378664 -285.19859 \n",
       "L 284.099322 -286.37174 \n",
       "L 280.81998 -287.366708 \n",
       "L 277.540637 -288.19783 \n",
       "L 274.261315 -288.878226 \n",
       "L 270.981953 -289.41935 \n",
       "L 267.70263 -289.830626 \n",
       "L 264.423288 -290.119172 \n",
       "L 261.143946 -290.289495 \n",
       "L 257.864623 -290.343375 \n",
       "L 254.585262 -290.279755 \n",
       "L 251.305939 -290.09474 \n",
       "L 248.026597 -289.781635 \n",
       "L 244.747254 -289.331161 \n",
       "L 241.467912 -288.731705 \n",
       "L 238.18857 -287.969597 \n",
       "L 234.909247 -287.029661 \n",
       "L 231.629886 -285.895625 \n",
       "L 228.350563 -284.550807 \n",
       "L 225.071221 -282.978708 \n",
       "L 221.791879 -281.163791 \n",
       "L 218.512556 -279.092217 \n",
       "L 215.233204 -276.752563 \n",
       "L 211.953871 -274.136705 \n",
       "L 208.674529 -271.240438 \n",
       "L 205.395187 -268.064204 \n",
       "L 202.115855 -264.613709 \n",
       "L 198.836512 -260.900352 \n",
       "L 195.55717 -256.941681 \n",
       "L 192.277838 -252.761482 \n",
       "L 188.998496 -248.389918 \n",
       "L 185.719153 -243.863329 \n",
       "L 182.439821 -239.223983 \n",
       "L 179.160479 -234.519392 \n",
       "L 175.881137 -229.80188 \n",
       "L 172.601804 -225.127394 \n",
       "L 169.322462 -220.554636 \n",
       "L 166.04312 -216.144121 \n",
       "L 162.763787 -211.956346 \n",
       "L 159.484445 -208.051399 \n",
       "L 156.205103 -206.501072 \n",
       "L 152.92577 -209.080513 \n",
       "L 149.646428 -211.240908 \n",
       "L 146.367086 -212.94655 \n",
       "L 143.087754 -214.167767 \n",
       "L 139.808412 -214.883262 \n",
       "L 136.529069 -215.080134 \n",
       "L 133.249737 -214.754195 \n",
       "L 129.970395 -213.910016 \n",
       "L 126.691057 -212.561503 \n",
       "L 123.41172 -210.730165 \n",
       "L 120.132378 -208.446358 \n",
       "L 116.853041 -205.746958 \n",
       "L 113.573703 -204.02261 \n",
       "L 110.294361 -207.512173 \n",
       "L 107.015024 -211.34407 \n",
       "L 103.735686 -215.458636 \n",
       "L 100.456344 -219.797185 \n",
       "L 97.177007 -224.299655 \n",
       "L 93.89767 -228.906405 \n",
       "L 90.61833 -233.55992 \n",
       "L 87.33899 -238.20494 \n",
       "L 84.059653 -242.790231 \n",
       "L 80.780313 -247.269228 \n",
       "L 77.500973 -251.600611 \n",
       "L 74.221636 -255.749084 \n",
       "L 70.942296 -259.685255 \n",
       "L 67.662958 -263.386076 \n",
       "L 64.383619 -266.834692 \n",
       "L 61.10428 -270.020219 \n",
       "L 57.824941 -272.937476 \n",
       "L 54.545602 -275.586429 \n",
       "z\n",
       "\" style=\"stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p903a380801)\">\n",
       "     <use xlink:href=\"#mbce84e3f81\" x=\"0\" y=\"309.639375\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_2\">\n",
       "    <defs>\n",
       "     <path id=\"md974d39526\" d=\"M 54.545602 -139.739149 \n",
       "L 54.545602 -139.739149 \n",
       "L 57.824941 -141.773884 \n",
       "L 61.10428 -144.062902 \n",
       "L 64.383619 -146.610838 \n",
       "L 67.662958 -149.417649 \n",
       "L 70.942296 -152.478053 \n",
       "L 74.221636 -155.7811 \n",
       "L 77.500973 -159.309947 \n",
       "L 80.780313 -163.04156 \n",
       "L 84.059653 -166.94703 \n",
       "L 87.33899 -170.991411 \n",
       "L 90.61833 -175.13431 \n",
       "L 93.89767 -179.330388 \n",
       "L 97.177007 -183.529867 \n",
       "L 100.456344 -187.680185 \n",
       "L 103.735686 -191.726054 \n",
       "L 107.015024 -195.611041 \n",
       "L 110.294361 -199.279301 \n",
       "L 113.573703 -202.673183 \n",
       "L 116.853041 -200.922203 \n",
       "L 120.132378 -198.265433 \n",
       "L 123.41172 -196.092809 \n",
       "L 126.691057 -194.439612 \n",
       "L 129.970395 -193.333729 \n",
       "L 133.249737 -192.79343 \n",
       "L 136.529069 -192.828627 \n",
       "L 139.808412 -193.439273 \n",
       "L 143.087754 -194.616015 \n",
       "L 146.367086 -196.340346 \n",
       "L 149.646428 -198.585042 \n",
       "L 152.92577 -201.314285 \n",
       "L 156.205103 -204.486126 \n",
       "L 159.484445 -203.545524 \n",
       "L 162.763787 -200.261499 \n",
       "L 166.04312 -196.699932 \n",
       "L 169.322462 -192.915284 \n",
       "L 172.601804 -188.962784 \n",
       "L 175.881137 -184.8981 \n",
       "L 179.160479 -180.775548 \n",
       "L 182.439821 -176.647176 \n",
       "L 185.719153 -172.561918 \n",
       "L 188.998496 -168.564411 \n",
       "L 192.277838 -164.694545 \n",
       "L 195.55717 -160.986757 \n",
       "L 198.836512 -157.469762 \n",
       "L 202.115855 -154.166336 \n",
       "L 205.395187 -151.093348 \n",
       "L 208.674529 -148.261876 \n",
       "L 211.953871 -145.677568 \n",
       "L 215.233204 -143.341041 \n",
       "L 218.512556 -141.248429 \n",
       "L 221.791879 -139.392085 \n",
       "L 225.071221 -137.761139 \n",
       "L 228.350563 -136.342364 \n",
       "L 231.629886 -135.120824 \n",
       "L 234.909247 -134.080624 \n",
       "L 238.18857 -133.205633 \n",
       "L 241.467912 -132.480087 \n",
       "L 244.747254 -131.889234 \n",
       "L 248.026597 -131.419795 \n",
       "L 251.305939 -131.060476 \n",
       "L 254.585262 -130.802262 \n",
       "L 257.864623 -130.638737 \n",
       "L 261.143946 -130.566251 \n",
       "L 264.423288 -130.584036 \n",
       "L 267.70263 -130.694224 \n",
       "L 270.981953 -130.901787 \n",
       "L 274.261315 -131.214426 \n",
       "L 277.540637 -131.642323 \n",
       "L 280.81998 -132.197901 \n",
       "L 284.099322 -132.895505 \n",
       "L 287.378664 -133.750938 \n",
       "L 290.658006 -134.781092 \n",
       "L 293.937329 -136.003379 \n",
       "L 297.21669 -137.435308 \n",
       "L 300.496013 -139.093765 \n",
       "L 303.775355 -140.994696 \n",
       "L 307.054697 -143.152277 \n",
       "L 310.33402 -145.578591 \n",
       "L 313.613382 -148.283016 \n",
       "L 316.892705 -151.271759 \n",
       "L 320.172047 -154.547519 \n",
       "L 323.451389 -158.10914 \n",
       "L 326.730731 -161.951291 \n",
       "L 330.010073 -166.064441 \n",
       "L 333.289396 -170.434801 \n",
       "L 336.568738 -175.044347 \n",
       "L 339.84808 -179.871197 \n",
       "L 343.127423 -184.889273 \n",
       "L 346.406765 -190.069554 \n",
       "L 349.686088 -195.380581 \n",
       "L 352.96543 -200.788012 \n",
       "L 356.244772 -206.252096 \n",
       "L 359.524114 -201.136253 \n",
       "L 362.803456 -195.723942 \n",
       "L 366.082798 -190.406208 \n",
       "L 369.362141 -185.216626 \n",
       "L 372.641463 -180.187249 \n",
       "L 375.920806 -175.347722 \n",
       "L 379.200148 -170.723609 \n",
       "L 379.200148 -170.723609 \n",
       "L 379.200148 -170.723609 \n",
       "L 375.920806 -175.347722 \n",
       "L 372.641463 -180.187249 \n",
       "L 369.362141 -185.216626 \n",
       "L 366.082798 -190.406208 \n",
       "L 362.803456 -195.723942 \n",
       "L 359.524114 -201.136253 \n",
       "L 356.244772 -206.252096 \n",
       "L 352.96543 -200.788012 \n",
       "L 349.686088 -195.380581 \n",
       "L 346.406765 -190.069554 \n",
       "L 343.127423 -184.889273 \n",
       "L 339.84808 -179.871197 \n",
       "L 336.568738 -175.044347 \n",
       "L 333.289396 -170.434801 \n",
       "L 330.010073 -166.064441 \n",
       "L 326.730731 -161.951291 \n",
       "L 323.451389 -158.10914 \n",
       "L 320.172047 -154.547519 \n",
       "L 316.892705 -151.271759 \n",
       "L 313.613382 -148.283016 \n",
       "L 310.33402 -145.578591 \n",
       "L 307.054697 -143.152277 \n",
       "L 303.775355 -140.994696 \n",
       "L 300.496013 -139.093765 \n",
       "L 297.21669 -137.435308 \n",
       "L 293.937329 -136.003379 \n",
       "L 290.658006 -134.781092 \n",
       "L 287.378664 -133.750938 \n",
       "L 284.099322 -132.895505 \n",
       "L 280.81998 -132.197901 \n",
       "L 277.540637 -131.642323 \n",
       "L 274.261315 -131.214426 \n",
       "L 270.981953 -130.901787 \n",
       "L 267.70263 -130.694224 \n",
       "L 264.423288 -130.584036 \n",
       "L 261.143946 -130.566251 \n",
       "L 257.864623 -130.638737 \n",
       "L 254.585262 -130.802262 \n",
       "L 251.305939 -131.060476 \n",
       "L 248.026597 -131.419795 \n",
       "L 244.747254 -131.889234 \n",
       "L 241.467912 -132.480087 \n",
       "L 238.18857 -133.205633 \n",
       "L 234.909247 -134.080624 \n",
       "L 231.629886 -135.120824 \n",
       "L 228.350563 -136.342364 \n",
       "L 225.071221 -137.761139 \n",
       "L 221.791879 -139.392085 \n",
       "L 218.512556 -141.248429 \n",
       "L 215.233204 -143.341041 \n",
       "L 211.953871 -145.677568 \n",
       "L 208.674529 -148.261876 \n",
       "L 205.395187 -151.093348 \n",
       "L 202.115855 -154.166336 \n",
       "L 198.836512 -157.469762 \n",
       "L 195.55717 -160.986757 \n",
       "L 192.277838 -164.694545 \n",
       "L 188.998496 -168.564411 \n",
       "L 185.719153 -172.561918 \n",
       "L 182.439821 -176.647176 \n",
       "L 179.160479 -180.775548 \n",
       "L 175.881137 -184.8981 \n",
       "L 172.601804 -188.962784 \n",
       "L 169.322462 -192.915284 \n",
       "L 166.04312 -196.699932 \n",
       "L 162.763787 -200.261499 \n",
       "L 159.484445 -203.545524 \n",
       "L 156.205103 -204.486126 \n",
       "L 152.92577 -201.314285 \n",
       "L 149.646428 -198.585042 \n",
       "L 146.367086 -196.340346 \n",
       "L 143.087754 -194.616015 \n",
       "L 139.808412 -193.439273 \n",
       "L 136.529069 -192.828627 \n",
       "L 133.249737 -192.79343 \n",
       "L 129.970395 -193.333729 \n",
       "L 126.691057 -194.439612 \n",
       "L 123.41172 -196.092809 \n",
       "L 120.132378 -198.265433 \n",
       "L 116.853041 -200.922203 \n",
       "L 113.573703 -202.673183 \n",
       "L 110.294361 -199.279301 \n",
       "L 107.015024 -195.611041 \n",
       "L 103.735686 -191.726054 \n",
       "L 100.456344 -187.680185 \n",
       "L 97.177007 -183.529867 \n",
       "L 93.89767 -179.330388 \n",
       "L 90.61833 -175.13431 \n",
       "L 87.33899 -170.991411 \n",
       "L 84.059653 -166.94703 \n",
       "L 80.780313 -163.04156 \n",
       "L 77.500973 -159.309947 \n",
       "L 74.221636 -155.7811 \n",
       "L 70.942296 -152.478053 \n",
       "L 67.662958 -149.417649 \n",
       "L 64.383619 -146.610838 \n",
       "L 61.10428 -144.062902 \n",
       "L 57.824941 -141.773884 \n",
       "L 54.545602 -139.739149 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p903a380801)\">\n",
       "     <use xlink:href=\"#md974d39526\" x=\"0\" y=\"309.639375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_3\">\n",
       "    <defs>\n",
       "     <path id=\"mf487351b7b\" d=\"M 54.545602 -275.586429 \n",
       "L 54.545602 -275.586429 \n",
       "L 57.824941 -272.937476 \n",
       "L 61.10428 -270.020219 \n",
       "L 64.383619 -266.834692 \n",
       "L 67.662958 -263.386076 \n",
       "L 70.942296 -259.685255 \n",
       "L 74.221636 -255.749084 \n",
       "L 77.500973 -251.600611 \n",
       "L 80.780313 -247.269228 \n",
       "L 84.059653 -242.790231 \n",
       "L 87.33899 -238.20494 \n",
       "L 90.61833 -233.55992 \n",
       "L 93.89767 -228.906405 \n",
       "L 97.177007 -224.299655 \n",
       "L 100.456344 -219.797185 \n",
       "L 103.735686 -215.458636 \n",
       "L 107.015024 -211.34407 \n",
       "L 110.294361 -207.512173 \n",
       "L 113.573703 -204.02261 \n",
       "L 116.853041 -205.746958 \n",
       "L 120.132378 -208.446358 \n",
       "L 123.41172 -210.730165 \n",
       "L 126.691057 -212.561503 \n",
       "L 129.970395 -213.910016 \n",
       "L 133.249737 -214.754195 \n",
       "L 136.529069 -215.080134 \n",
       "L 139.808412 -214.883262 \n",
       "L 143.087754 -214.167767 \n",
       "L 146.367086 -212.94655 \n",
       "L 149.646428 -211.240908 \n",
       "L 152.92577 -209.080513 \n",
       "L 156.205103 -206.501072 \n",
       "L 159.484445 -208.051399 \n",
       "L 162.763787 -211.956346 \n",
       "L 166.04312 -216.144121 \n",
       "L 169.322462 -220.554636 \n",
       "L 172.601804 -225.127394 \n",
       "L 175.881137 -229.80188 \n",
       "L 179.160479 -234.519392 \n",
       "L 182.439821 -239.223983 \n",
       "L 185.719153 -243.863329 \n",
       "L 188.998496 -248.389918 \n",
       "L 192.277838 -252.761482 \n",
       "L 195.55717 -256.941681 \n",
       "L 198.836512 -260.900352 \n",
       "L 202.115855 -264.613709 \n",
       "L 205.395187 -268.064204 \n",
       "L 208.674529 -271.240438 \n",
       "L 211.953871 -274.136705 \n",
       "L 215.233204 -276.752563 \n",
       "L 218.512556 -279.092217 \n",
       "L 221.791879 -281.163791 \n",
       "L 225.071221 -282.978708 \n",
       "L 228.350563 -284.550807 \n",
       "L 231.629886 -285.895625 \n",
       "L 234.909247 -287.029661 \n",
       "L 238.18857 -287.969597 \n",
       "L 241.467912 -288.731705 \n",
       "L 244.747254 -289.331161 \n",
       "L 248.026597 -289.781635 \n",
       "L 251.305939 -290.09474 \n",
       "L 254.585262 -290.279755 \n",
       "L 257.864623 -290.343375 \n",
       "L 261.143946 -290.289495 \n",
       "L 264.423288 -290.119172 \n",
       "L 267.70263 -289.830626 \n",
       "L 270.981953 -289.41935 \n",
       "L 274.261315 -288.878226 \n",
       "L 277.540637 -288.19783 \n",
       "L 280.81998 -287.366708 \n",
       "L 284.099322 -286.37174 \n",
       "L 287.378664 -285.19859 \n",
       "L 290.658006 -283.83215 \n",
       "L 293.937329 -282.257099 \n",
       "L 297.21669 -280.458317 \n",
       "L 300.496013 -278.421644 \n",
       "L 303.775355 -276.134175 \n",
       "L 307.054697 -273.585045 \n",
       "L 310.33402 -270.765765 \n",
       "L 313.613382 -267.670752 \n",
       "L 316.892705 -264.297792 \n",
       "L 320.172047 -260.648284 \n",
       "L 323.451389 -256.727529 \n",
       "L 326.730731 -252.545014 \n",
       "L 330.010073 -248.114321 \n",
       "L 333.289396 -243.453133 \n",
       "L 336.568738 -238.583119 \n",
       "L 339.84808 -233.529518 \n",
       "L 343.127423 -228.321369 \n",
       "L 346.406765 -222.990222 \n",
       "L 349.686088 -217.56955 \n",
       "L 352.96543 -212.095191 \n",
       "L 356.244772 -206.607825 \n",
       "L 359.524114 -211.744339 \n",
       "L 362.803456 -217.221017 \n",
       "L 366.082798 -222.645935 \n",
       "L 369.362141 -227.984084 \n",
       "L 372.641463 -233.201444 \n",
       "L 375.920806 -238.265878 \n",
       "L 379.200148 -243.148938 \n",
       "L 379.200148 -243.148938 \n",
       "L 379.200148 -243.148938 \n",
       "L 375.920806 -238.265878 \n",
       "L 372.641463 -233.201444 \n",
       "L 369.362141 -227.984084 \n",
       "L 366.082798 -222.645935 \n",
       "L 362.803456 -217.221017 \n",
       "L 359.524114 -211.744339 \n",
       "L 356.244772 -206.607825 \n",
       "L 352.96543 -212.095191 \n",
       "L 349.686088 -217.56955 \n",
       "L 346.406765 -222.990222 \n",
       "L 343.127423 -228.321369 \n",
       "L 339.84808 -233.529518 \n",
       "L 336.568738 -238.583119 \n",
       "L 333.289396 -243.453133 \n",
       "L 330.010073 -248.114321 \n",
       "L 326.730731 -252.545014 \n",
       "L 323.451389 -256.727529 \n",
       "L 320.172047 -260.648284 \n",
       "L 316.892705 -264.297792 \n",
       "L 313.613382 -267.670752 \n",
       "L 310.33402 -270.765765 \n",
       "L 307.054697 -273.585045 \n",
       "L 303.775355 -276.134175 \n",
       "L 300.496013 -278.421644 \n",
       "L 297.21669 -280.458317 \n",
       "L 293.937329 -282.257099 \n",
       "L 290.658006 -283.83215 \n",
       "L 287.378664 -285.19859 \n",
       "L 284.099322 -286.37174 \n",
       "L 280.81998 -287.366708 \n",
       "L 277.540637 -288.19783 \n",
       "L 274.261315 -288.878226 \n",
       "L 270.981953 -289.41935 \n",
       "L 267.70263 -289.830626 \n",
       "L 264.423288 -290.119172 \n",
       "L 261.143946 -290.289495 \n",
       "L 257.864623 -290.343375 \n",
       "L 254.585262 -290.279755 \n",
       "L 251.305939 -290.09474 \n",
       "L 248.026597 -289.781635 \n",
       "L 244.747254 -289.331161 \n",
       "L 241.467912 -288.731705 \n",
       "L 238.18857 -287.969597 \n",
       "L 234.909247 -287.029661 \n",
       "L 231.629886 -285.895625 \n",
       "L 228.350563 -284.550807 \n",
       "L 225.071221 -282.978708 \n",
       "L 221.791879 -281.163791 \n",
       "L 218.512556 -279.092217 \n",
       "L 215.233204 -276.752563 \n",
       "L 211.953871 -274.136705 \n",
       "L 208.674529 -271.240438 \n",
       "L 205.395187 -268.064204 \n",
       "L 202.115855 -264.613709 \n",
       "L 198.836512 -260.900352 \n",
       "L 195.55717 -256.941681 \n",
       "L 192.277838 -252.761482 \n",
       "L 188.998496 -248.389918 \n",
       "L 185.719153 -243.863329 \n",
       "L 182.439821 -239.223983 \n",
       "L 179.160479 -234.519392 \n",
       "L 175.881137 -229.80188 \n",
       "L 172.601804 -225.127394 \n",
       "L 169.322462 -220.554636 \n",
       "L 166.04312 -216.144121 \n",
       "L 162.763787 -211.956346 \n",
       "L 159.484445 -208.051399 \n",
       "L 156.205103 -206.501072 \n",
       "L 152.92577 -209.080513 \n",
       "L 149.646428 -211.240908 \n",
       "L 146.367086 -212.94655 \n",
       "L 143.087754 -214.167767 \n",
       "L 139.808412 -214.883262 \n",
       "L 136.529069 -215.080134 \n",
       "L 133.249737 -214.754195 \n",
       "L 129.970395 -213.910016 \n",
       "L 126.691057 -212.561503 \n",
       "L 123.41172 -210.730165 \n",
       "L 120.132378 -208.446358 \n",
       "L 116.853041 -205.746958 \n",
       "L 113.573703 -204.02261 \n",
       "L 110.294361 -207.512173 \n",
       "L 107.015024 -211.34407 \n",
       "L 103.735686 -215.458636 \n",
       "L 100.456344 -219.797185 \n",
       "L 97.177007 -224.299655 \n",
       "L 93.89767 -228.906405 \n",
       "L 90.61833 -233.55992 \n",
       "L 87.33899 -238.20494 \n",
       "L 84.059653 -242.790231 \n",
       "L 80.780313 -247.269228 \n",
       "L 77.500973 -251.600611 \n",
       "L 74.221636 -255.749084 \n",
       "L 70.942296 -259.685255 \n",
       "L 67.662958 -263.386076 \n",
       "L 64.383619 -266.834692 \n",
       "L 61.10428 -270.020219 \n",
       "L 57.824941 -272.937476 \n",
       "L 54.545602 -275.586429 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p903a380801)\">\n",
       "     <use xlink:href=\"#mf487351b7b\" x=\"0\" y=\"309.639375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_14\">\n",
       "    <defs>\n",
       "     <path id=\"m4d235c7fbf\" d=\"M -5 5 \n",
       "L 5 -5 \n",
       "M -5 -5 \n",
       "L 5 5 \n",
       "\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p903a380801)\">\n",
       "     <use xlink:href=\"#m4d235c7fbf\" x=\"356.349693\" y=\"103.209424\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m4d235c7fbf\" x=\"157.258364\" y=\"104.048656\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m4d235c7fbf\" x=\"114.255683\" y=\"106.297103\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_15\">\n",
       "    <path d=\"M 54.545602 101.976586 \n",
       "L 57.824941 102.283694 \n",
       "L 61.10428 102.597814 \n",
       "L 64.383619 102.916612 \n",
       "L 67.662958 103.237512 \n",
       "L 70.942296 103.557723 \n",
       "L 74.221636 103.874282 \n",
       "L 77.500973 104.184095 \n",
       "L 80.780313 104.483982 \n",
       "L 84.059653 104.770743 \n",
       "L 87.33899 105.041199 \n",
       "L 90.61833 105.29226 \n",
       "L 93.89767 105.520979 \n",
       "L 97.177007 105.724614 \n",
       "L 100.456344 105.900689 \n",
       "L 103.735686 106.04703 \n",
       "L 107.015024 106.16182 \n",
       "L 110.294361 106.243638 \n",
       "L 113.573703 106.291479 \n",
       "L 116.853041 106.304795 \n",
       "L 120.132378 106.283479 \n",
       "L 123.41172 106.227888 \n",
       "L 126.691057 106.138818 \n",
       "L 129.970395 106.017502 \n",
       "L 133.249737 105.865562 \n",
       "L 136.529069 105.684995 \n",
       "L 139.808412 105.478108 \n",
       "L 143.087754 105.247484 \n",
       "L 146.367086 104.995927 \n",
       "L 149.646428 104.726401 \n",
       "L 152.92577 104.441976 \n",
       "L 156.205103 104.145776 \n",
       "L 159.484445 103.840914 \n",
       "L 162.763787 103.530453 \n",
       "L 166.04312 103.217348 \n",
       "L 169.322462 102.904415 \n",
       "L 172.601804 102.594286 \n",
       "L 175.881137 102.289384 \n",
       "L 179.160479 101.991905 \n",
       "L 182.439821 101.703795 \n",
       "L 185.719153 101.426751 \n",
       "L 188.998496 101.16221 \n",
       "L 192.277838 100.911363 \n",
       "L 195.55717 100.675158 \n",
       "L 198.836512 100.454316 \n",
       "L 202.115855 100.249353 \n",
       "L 205.395187 100.060599 \n",
       "L 208.674529 99.888217 \n",
       "L 211.953871 99.732236 \n",
       "L 215.233204 99.592573 \n",
       "L 218.512556 99.469051 \n",
       "L 221.791879 99.361438 \n",
       "L 225.071221 99.269452 \n",
       "L 228.350563 99.192791 \n",
       "L 231.629886 99.13115 \n",
       "L 234.909247 99.084232 \n",
       "L 238.18857 99.051759 \n",
       "L 241.467912 99.03348 \n",
       "L 244.747254 99.029176 \n",
       "L 248.026597 99.03866 \n",
       "L 251.305939 99.061769 \n",
       "L 254.585262 99.098365 \n",
       "L 257.864623 99.14832 \n",
       "L 261.143946 99.211503 \n",
       "L 264.423288 99.287771 \n",
       "L 267.70263 99.376948 \n",
       "L 270.981953 99.478806 \n",
       "L 274.261315 99.593051 \n",
       "L 277.540637 99.719301 \n",
       "L 280.81998 99.85707 \n",
       "L 284.099322 100.005755 \n",
       "L 287.378664 100.164611 \n",
       "L 290.658006 100.332754 \n",
       "L 293.937329 100.509137 \n",
       "L 297.21669 100.692565 \n",
       "L 300.496013 100.881669 \n",
       "L 303.775355 101.07494 \n",
       "L 307.054697 101.270713 \n",
       "L 310.33402 101.467198 \n",
       "L 313.613382 101.66249 \n",
       "L 316.892705 101.854598 \n",
       "L 320.172047 102.041474 \n",
       "L 323.451389 102.221039 \n",
       "L 326.730731 102.391221 \n",
       "L 330.010073 102.549994 \n",
       "L 333.289396 102.695409 \n",
       "L 336.568738 102.825641 \n",
       "L 339.84808 102.939019 \n",
       "L 343.127423 103.034054 \n",
       "L 346.406765 103.109487 \n",
       "L 349.686088 103.16431 \n",
       "L 352.96543 103.197774 \n",
       "L 356.244772 103.209414 \n",
       "L 359.524114 103.199079 \n",
       "L 362.803456 103.166895 \n",
       "L 366.082798 103.113304 \n",
       "L 369.362141 103.039021 \n",
       "L 372.641463 102.94503 \n",
       "L 375.920806 102.832574 \n",
       "L 379.200148 102.703101 \n",
       "\" clip-path=\"url(#p903a380801)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_16\">\n",
       "    <path d=\"M 54.545602 179.219315 \n",
       "L 57.824941 174.249548 \n",
       "L 61.10428 169.29822 \n",
       "L 64.383619 164.383697 \n",
       "L 67.662958 159.524273 \n",
       "L 70.942296 154.738039 \n",
       "L 74.221636 150.042911 \n",
       "L 77.500973 145.456491 \n",
       "L 80.780313 140.99603 \n",
       "L 84.059653 136.6784 \n",
       "L 87.33899 132.519983 \n",
       "L 90.61833 128.536651 \n",
       "L 93.89767 124.7437 \n",
       "L 97.177007 121.155797 \n",
       "L 100.456344 117.786915 \n",
       "L 103.735686 114.650331 \n",
       "L 107.015024 111.758526 \n",
       "L 110.294361 109.123173 \n",
       "L 113.573703 106.755076 \n",
       "L 116.853041 104.664159 \n",
       "L 120.132378 102.859418 \n",
       "L 123.41172 101.348876 \n",
       "L 126.691057 100.139572 \n",
       "L 129.970395 99.237532 \n",
       "L 133.249737 98.647733 \n",
       "L 136.529069 98.374097 \n",
       "L 139.808412 98.419476 \n",
       "L 143.087754 98.785611 \n",
       "L 146.367086 99.47315 \n",
       "L 149.646428 100.48163 \n",
       "L 152.92577 101.809459 \n",
       "L 156.205103 103.453908 \n",
       "L 159.484445 105.411151 \n",
       "L 162.763787 107.676193 \n",
       "L 166.04312 110.242939 \n",
       "L 169.322462 113.104155 \n",
       "L 172.601804 116.251484 \n",
       "L 175.881137 119.675455 \n",
       "L 179.160479 123.365467 \n",
       "L 182.439821 127.309858 \n",
       "L 185.719153 131.495801 \n",
       "L 188.998496 135.909432 \n",
       "L 192.277838 140.535748 \n",
       "L 195.55717 145.358728 \n",
       "L 198.836512 150.361221 \n",
       "L 202.115855 155.524996 \n",
       "L 205.395187 160.830762 \n",
       "L 208.674529 166.258171 \n",
       "L 211.953871 171.785746 \n",
       "L 215.233204 177.390973 \n",
       "L 218.512556 183.050241 \n",
       "L 221.791879 188.738792 \n",
       "L 225.071221 194.430838 \n",
       "L 228.350563 200.099453 \n",
       "L 231.629886 205.716445 \n",
       "L 234.909247 211.252731 \n",
       "L 238.18857 216.67776 \n",
       "L 241.467912 221.96006 \n",
       "L 244.747254 227.066827 \n",
       "L 248.026597 231.964114 \n",
       "L 251.305939 236.616834 \n",
       "L 254.585262 240.988641 \n",
       "L 257.864623 245.042148 \n",
       "L 261.143946 248.738812 \n",
       "L 264.423288 252.03913 \n",
       "L 267.70263 254.902667 \n",
       "L 270.981953 257.288306 \n",
       "L 274.261315 259.154332 \n",
       "L 277.540637 260.458792 \n",
       "L 280.81998 261.159804 \n",
       "L 284.099322 261.216 \n",
       "L 287.378664 260.587071 \n",
       "L 290.658006 259.234494 \n",
       "L 293.937329 257.12233 \n",
       "L 297.21669 254.218153 \n",
       "L 300.496013 250.494649 \n",
       "L 303.775355 245.930481 \n",
       "L 307.054697 240.512541 \n",
       "L 310.33402 234.237837 \n",
       "L 313.613382 227.115556 \n",
       "L 316.892705 219.170179 \n",
       "L 320.172047 210.444094 \n",
       "L 323.451389 201.001051 \n",
       "L 326.730731 190.929779 \n",
       "L 330.010073 180.347602 \n",
       "L 333.289396 169.404277 \n",
       "L 336.568738 158.285662 \n",
       "L 339.84808 147.216645 \n",
       "L 343.127423 136.463583 \n",
       "L 346.406765 126.33522 \n",
       "L 349.686088 117.181069 \n",
       "L 352.96543 109.387103 \n",
       "L 356.244772 103.367919 \n",
       "L 359.524114 99.55256 \n",
       "L 362.803456 98.364858 \n",
       "L 366.082798 100.195569 \n",
       "L 369.362141 105.365914 \n",
       "L 372.641463 114.082133 \n",
       "L 375.920806 126.381332 \n",
       "L 379.200148 142.071165 \n",
       "\" clip-path=\"url(#p903a380801)\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_17\">\n",
       "    <path d=\"M 54.545602 84.651761 \n",
       "L 57.824941 87.247603 \n",
       "L 61.10428 89.52468 \n",
       "L 64.383619 91.941562 \n",
       "L 67.662958 94.071517 \n",
       "L 70.942296 96.47313 \n",
       "L 74.221636 97.356954 \n",
       "L 77.500973 99.575896 \n",
       "L 80.780313 100.341985 \n",
       "L 84.059653 101.704832 \n",
       "L 87.33899 102.48765 \n",
       "L 90.61833 103.317326 \n",
       "L 93.89767 103.88296 \n",
       "L 97.177007 104.498548 \n",
       "L 100.456344 105.086086 \n",
       "L 103.735686 105.671739 \n",
       "L 107.015024 105.639859 \n",
       "L 110.294361 105.942006 \n",
       "L 113.573703 106.378623 \n",
       "L 116.853041 106.466924 \n",
       "L 120.132378 106.269364 \n",
       "L 123.41172 106.884012 \n",
       "L 126.691057 106.736876 \n",
       "L 129.970395 106.901919 \n",
       "L 133.249737 106.733588 \n",
       "L 136.529069 106.913211 \n",
       "L 139.808412 106.601259 \n",
       "L 143.087754 106.457666 \n",
       "L 146.367086 105.826581 \n",
       "L 149.646428 105.381799 \n",
       "L 152.92577 104.79577 \n",
       "L 156.205103 104.552296 \n",
       "L 159.484445 103.428291 \n",
       "L 162.763787 102.734314 \n",
       "L 166.04312 101.910272 \n",
       "L 169.322462 101.099511 \n",
       "L 172.601804 99.872005 \n",
       "L 175.881137 98.61343 \n",
       "L 179.160479 98.018462 \n",
       "L 182.439821 96.870149 \n",
       "L 185.719153 95.782258 \n",
       "L 188.998496 94.426208 \n",
       "L 192.277838 93.89561 \n",
       "L 195.55717 92.760809 \n",
       "L 198.836512 92.162726 \n",
       "L 202.115855 90.931677 \n",
       "L 205.395187 90.079376 \n",
       "L 208.674529 89.714873 \n",
       "L 211.953871 89.156956 \n",
       "L 215.233204 88.896319 \n",
       "L 218.512556 88.086089 \n",
       "L 221.791879 87.915612 \n",
       "L 225.071221 87.491339 \n",
       "L 228.350563 87.125184 \n",
       "L 231.629886 86.616647 \n",
       "L 234.909247 86.747703 \n",
       "L 238.18857 86.594576 \n",
       "L 241.467912 86.645571 \n",
       "L 244.747254 86.436995 \n",
       "L 248.026597 86.442841 \n",
       "L 251.305939 86.554731 \n",
       "L 254.585262 86.228355 \n",
       "L 257.864623 86.301203 \n",
       "L 261.143946 85.637945 \n",
       "L 264.423288 85.394114 \n",
       "L 267.70263 84.650586 \n",
       "L 270.981953 84.19595 \n",
       "L 274.261315 83.556358 \n",
       "L 277.540637 82.58113 \n",
       "L 280.81998 81.998185 \n",
       "L 284.099322 81.20619 \n",
       "L 287.378664 80.311039 \n",
       "L 290.658006 79.552494 \n",
       "L 293.937329 78.263905 \n",
       "L 297.21669 77.440881 \n",
       "L 300.496013 77.03478 \n",
       "L 303.775355 76.485769 \n",
       "L 307.054697 76.102727 \n",
       "L 310.33402 75.596452 \n",
       "L 313.613382 75.703863 \n",
       "L 316.892705 75.763939 \n",
       "L 320.172047 76.061677 \n",
       "L 323.451389 77.038082 \n",
       "L 326.730731 77.795521 \n",
       "L 330.010073 79.279254 \n",
       "L 333.289396 81.295708 \n",
       "L 336.568738 83.305711 \n",
       "L 339.84808 85.874143 \n",
       "L 343.127423 88.470677 \n",
       "L 346.406765 91.8179 \n",
       "L 349.686088 95.110797 \n",
       "L 352.96543 99.253816 \n",
       "L 356.244772 103.388676 \n",
       "L 359.524114 107.078561 \n",
       "L 362.803456 111.705065 \n",
       "L 366.082798 115.992592 \n",
       "L 369.362141 120.536821 \n",
       "L 372.641463 124.600417 \n",
       "L 375.920806 128.985948 \n",
       "L 379.200148 132.787292 \n",
       "\" clip-path=\"url(#p903a380801)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_18\">\n",
       "    <path d=\"M 54.545602 32.977574 \n",
       "L 57.824941 35.789464 \n",
       "L 61.10428 38.28248 \n",
       "L 64.383619 41.127465 \n",
       "L 67.662958 44.697563 \n",
       "L 70.942296 48.645431 \n",
       "L 74.221636 52.834388 \n",
       "L 77.500973 56.911356 \n",
       "L 80.780313 61.496769 \n",
       "L 84.059653 65.941816 \n",
       "L 87.33899 71.176956 \n",
       "L 90.61833 75.589966 \n",
       "L 93.89767 80.259208 \n",
       "L 97.177007 85.000306 \n",
       "L 100.456344 89.318985 \n",
       "L 103.735686 93.870672 \n",
       "L 107.015024 98.380027 \n",
       "L 110.294361 102.073941 \n",
       "L 113.573703 105.862623 \n",
       "L 116.853041 108.572882 \n",
       "L 120.132378 111.37136 \n",
       "L 123.41172 113.711223 \n",
       "L 126.691057 115.265295 \n",
       "L 129.970395 116.393094 \n",
       "L 133.249737 116.990713 \n",
       "L 136.529069 117.232267 \n",
       "L 139.808412 116.550987 \n",
       "L 143.087754 115.274153 \n",
       "L 146.367086 113.496634 \n",
       "L 149.646428 111.364977 \n",
       "L 152.92577 108.545084 \n",
       "L 156.205103 105.501292 \n",
       "L 159.484445 101.516403 \n",
       "L 162.763787 97.34261 \n",
       "L 166.04312 93.700952 \n",
       "L 169.322462 89.230178 \n",
       "L 172.601804 84.988438 \n",
       "L 175.881137 79.903725 \n",
       "L 179.160479 75.582784 \n",
       "L 182.439821 71.211551 \n",
       "L 185.719153 67.110291 \n",
       "L 188.998496 63.03781 \n",
       "L 192.277838 59.242334 \n",
       "L 195.55717 56.028432 \n",
       "L 198.836512 53.178092 \n",
       "L 202.115855 50.969703 \n",
       "L 205.395187 49.069462 \n",
       "L 208.674529 47.952187 \n",
       "L 211.953871 47.253914 \n",
       "L 215.233204 47.44592 \n",
       "L 218.512556 47.84012 \n",
       "L 221.791879 49.746867 \n",
       "L 225.071221 51.373633 \n",
       "L 228.350563 53.856395 \n",
       "L 231.629886 57.350347 \n",
       "L 234.909247 61.193047 \n",
       "L 238.18857 65.710743 \n",
       "L 241.467912 70.815397 \n",
       "L 244.747254 76.418679 \n",
       "L 248.026597 81.809613 \n",
       "L 251.305939 87.857533 \n",
       "L 254.585262 94.188277 \n",
       "L 257.864623 100.353498 \n",
       "L 261.143946 107.049431 \n",
       "L 264.423288 112.648818 \n",
       "L 267.70263 118.627785 \n",
       "L 270.981953 123.565614 \n",
       "L 274.261315 128.562778 \n",
       "L 277.540637 132.43361 \n",
       "L 280.81998 136.118636 \n",
       "L 284.099322 138.338767 \n",
       "L 287.378664 140.237244 \n",
       "L 290.658006 141.751204 \n",
       "L 293.937329 142.047577 \n",
       "L 297.21669 141.543325 \n",
       "L 300.496013 140.816939 \n",
       "L 303.775355 139.644444 \n",
       "L 307.054697 137.653713 \n",
       "L 310.33402 135.157977 \n",
       "L 313.613382 132.175262 \n",
       "L 316.892705 129.147348 \n",
       "L 320.172047 126.074629 \n",
       "L 323.451389 123.181652 \n",
       "L 326.730731 120.398071 \n",
       "L 330.010073 117.415412 \n",
       "L 333.289396 115.046707 \n",
       "L 336.568738 112.702055 \n",
       "L 339.84808 110.691144 \n",
       "L 343.127423 108.519657 \n",
       "L 346.406765 107.057027 \n",
       "L 349.686088 105.502827 \n",
       "L 352.96543 104.682687 \n",
       "L 356.244772 103.208032 \n",
       "L 359.524114 102.245436 \n",
       "L 362.803456 100.642418 \n",
       "L 366.082798 99.569423 \n",
       "L 369.362141 98.434962 \n",
       "L 372.641463 97.234511 \n",
       "L 375.920806 95.280166 \n",
       "L 379.200148 93.32001 \n",
       "\" clip-path=\"url(#p903a380801)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_19\">\n",
       "    <path d=\"M 54.545602 190.100031 \n",
       "L 57.824941 188.566396 \n",
       "L 61.10428 186.144205 \n",
       "L 64.383619 182.970506 \n",
       "L 67.662958 178.775547 \n",
       "L 70.942296 174.268144 \n",
       "L 74.221636 168.449036 \n",
       "L 77.500973 162.651788 \n",
       "L 80.780313 156.672855 \n",
       "L 84.059653 149.780579 \n",
       "L 87.33899 143.532153 \n",
       "L 90.61833 137.302053 \n",
       "L 93.89767 131.320579 \n",
       "L 97.177007 125.605977 \n",
       "L 100.456344 120.482188 \n",
       "L 103.735686 116.404779 \n",
       "L 107.015024 112.6918 \n",
       "L 110.294361 109.021513 \n",
       "L 113.573703 106.809481 \n",
       "L 116.853041 104.764568 \n",
       "L 120.132378 103.692796 \n",
       "L 123.41172 103.18624 \n",
       "L 126.691057 103.235117 \n",
       "L 129.970395 102.920167 \n",
       "L 133.249737 103.227762 \n",
       "L 136.529069 103.395182 \n",
       "L 139.808412 104.190462 \n",
       "L 143.087754 104.729516 \n",
       "L 146.367086 105.024799 \n",
       "L 149.646428 105.050054 \n",
       "L 152.92577 104.714822 \n",
       "L 156.205103 104.358471 \n",
       "L 159.484445 103.672676 \n",
       "L 162.763787 102.358868 \n",
       "L 166.04312 101.127697 \n",
       "L 169.322462 98.963232 \n",
       "L 172.601804 97.22635 \n",
       "L 175.881137 94.823861 \n",
       "L 179.160479 92.643328 \n",
       "L 182.439821 90.483697 \n",
       "L 185.719153 88.029554 \n",
       "L 188.998496 85.944524 \n",
       "L 192.277838 83.327189 \n",
       "L 195.55717 81.652822 \n",
       "L 198.836512 79.759489 \n",
       "L 202.115855 78.498401 \n",
       "L 205.395187 77.243239 \n",
       "L 208.674529 76.899145 \n",
       "L 211.953871 76.31658 \n",
       "L 215.233204 77.084786 \n",
       "L 218.512556 77.518574 \n",
       "L 221.791879 78.686871 \n",
       "L 225.071221 79.87867 \n",
       "L 228.350563 81.895603 \n",
       "L 231.629886 84.245553 \n",
       "L 234.909247 86.189907 \n",
       "L 238.18857 88.915948 \n",
       "L 241.467912 91.575408 \n",
       "L 244.747254 94.256672 \n",
       "L 248.026597 96.837701 \n",
       "L 251.305939 99.539299 \n",
       "L 254.585262 102.168176 \n",
       "L 257.864623 104.627965 \n",
       "L 261.143946 106.676184 \n",
       "L 264.423288 108.226962 \n",
       "L 267.70263 109.726225 \n",
       "L 270.981953 110.993938 \n",
       "L 274.261315 112.46552 \n",
       "L 277.540637 112.656532 \n",
       "L 280.81998 113.006861 \n",
       "L 284.099322 113.362679 \n",
       "L 287.378664 113.672493 \n",
       "L 290.658006 113.098625 \n",
       "L 293.937329 112.52439 \n",
       "L 297.21669 112.169197 \n",
       "L 300.496013 111.667661 \n",
       "L 303.775355 111.277917 \n",
       "L 307.054697 110.435734 \n",
       "L 310.33402 109.724188 \n",
       "L 313.613382 108.825923 \n",
       "L 316.892705 108.331292 \n",
       "L 320.172047 107.317439 \n",
       "L 323.451389 106.730114 \n",
       "L 326.730731 106.236829 \n",
       "L 330.010073 106.009297 \n",
       "L 333.289396 104.491359 \n",
       "L 336.568738 104.350602 \n",
       "L 339.84808 104.0897 \n",
       "L 343.127423 103.514566 \n",
       "L 346.406765 103.331136 \n",
       "L 349.686088 103.065344 \n",
       "L 352.96543 103.472655 \n",
       "L 356.244772 103.068804 \n",
       "L 359.524114 103.460971 \n",
       "L 362.803456 104.006128 \n",
       "L 366.082798 104.500474 \n",
       "L 369.362141 106.257027 \n",
       "L 372.641463 107.479844 \n",
       "L 375.920806 108.76756 \n",
       "L 379.200148 110.502797 \n",
       "\" clip-path=\"url(#p903a380801)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_20\">\n",
       "    <path d=\"M 54.545602 145.178797 \n",
       "L 57.824941 144.977555 \n",
       "L 61.10428 144.434873 \n",
       "L 64.383619 143.859309 \n",
       "L 67.662958 142.49238 \n",
       "L 70.942296 141.319715 \n",
       "L 74.221636 139.27185 \n",
       "L 77.500973 136.928657 \n",
       "L 80.780313 134.098644 \n",
       "L 84.059653 131.867894 \n",
       "L 87.33899 129.159475 \n",
       "L 90.61833 125.773837 \n",
       "L 93.89767 123.144566 \n",
       "L 97.177007 119.770652 \n",
       "L 100.456344 117.019318 \n",
       "L 103.735686 114.284484 \n",
       "L 107.015024 111.751667 \n",
       "L 110.294361 108.640078 \n",
       "L 113.573703 106.640898 \n",
       "L 116.853041 105.024777 \n",
       "L 120.132378 102.902182 \n",
       "L 123.41172 101.670476 \n",
       "L 126.691057 100.583492 \n",
       "L 129.970395 99.749155 \n",
       "L 133.249737 99.365685 \n",
       "L 136.529069 98.875675 \n",
       "L 139.808412 99.431654 \n",
       "L 143.087754 99.984183 \n",
       "L 146.367086 100.411613 \n",
       "L 149.646428 101.574495 \n",
       "L 152.92577 102.11319 \n",
       "L 156.205103 103.607746 \n",
       "L 159.484445 104.921144 \n",
       "L 162.763787 106.15488 \n",
       "L 166.04312 108.252335 \n",
       "L 169.322462 109.45587 \n",
       "L 172.601804 110.601877 \n",
       "L 175.881137 111.427926 \n",
       "L 179.160479 112.886698 \n",
       "L 182.439821 113.325298 \n",
       "L 185.719153 114.361461 \n",
       "L 188.998496 114.828225 \n",
       "L 192.277838 114.542256 \n",
       "L 195.55717 113.660625 \n",
       "L 198.836512 112.516253 \n",
       "L 202.115855 111.070877 \n",
       "L 205.395187 108.998819 \n",
       "L 208.674529 106.613047 \n",
       "L 211.953871 104.008338 \n",
       "L 215.233204 99.976196 \n",
       "L 218.512556 96.866157 \n",
       "L 221.791879 92.272104 \n",
       "L 225.071221 87.95831 \n",
       "L 228.350563 83.147027 \n",
       "L 231.629886 78.30331 \n",
       "L 234.909247 73.358145 \n",
       "L 238.18857 68.170214 \n",
       "L 241.467912 63.912587 \n",
       "L 244.747254 58.358213 \n",
       "L 248.026597 54.518113 \n",
       "L 251.305939 49.799116 \n",
       "L 254.585262 46.095033 \n",
       "L 257.864623 42.695165 \n",
       "L 261.143946 39.705499 \n",
       "L 264.423288 37.364248 \n",
       "L 267.70263 35.277894 \n",
       "L 270.981953 33.648477 \n",
       "L 274.261315 32.90568 \n",
       "L 277.540637 32.561928 \n",
       "L 280.81998 33.641073 \n",
       "L 284.099322 34.398859 \n",
       "L 287.378664 35.582837 \n",
       "L 290.658006 37.917117 \n",
       "L 293.937329 39.607513 \n",
       "L 297.21669 43.061057 \n",
       "L 300.496013 45.959048 \n",
       "L 303.775355 49.19577 \n",
       "L 307.054697 52.790675 \n",
       "L 310.33402 56.11009 \n",
       "L 313.613382 59.800655 \n",
       "L 316.892705 63.501172 \n",
       "L 320.172047 67.55775 \n",
       "L 323.451389 71.335443 \n",
       "L 326.730731 74.536345 \n",
       "L 330.010073 78.275865 \n",
       "L 333.289396 81.760279 \n",
       "L 336.568738 85.123287 \n",
       "L 339.84808 88.563159 \n",
       "L 343.127423 91.617269 \n",
       "L 346.406765 94.733503 \n",
       "L 349.686088 97.259929 \n",
       "L 352.96543 100.298468 \n",
       "L 356.244772 103.270351 \n",
       "L 359.524114 105.634477 \n",
       "L 362.803456 107.856512 \n",
       "L 366.082798 109.625641 \n",
       "L 369.362141 111.598079 \n",
       "L 372.641463 112.920792 \n",
       "L 375.920806 114.349623 \n",
       "L 379.200148 115.189289 \n",
       "\" clip-path=\"url(#p903a380801)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_21\">\n",
       "    <path d=\"M 54.545602 129.509425 \n",
       "L 57.824941 129.078897 \n",
       "L 61.10428 128.897026 \n",
       "L 64.383619 129.108187 \n",
       "L 67.662958 128.984775 \n",
       "L 70.942296 128.654858 \n",
       "L 74.221636 128.23634 \n",
       "L 77.500973 127.603008 \n",
       "L 80.780313 126.618149 \n",
       "L 84.059653 125.61567 \n",
       "L 87.33899 124.00133 \n",
       "L 90.61833 122.30527 \n",
       "L 93.89767 120.320669 \n",
       "L 97.177007 118.332921 \n",
       "L 100.456344 116.642632 \n",
       "L 103.735686 113.879543 \n",
       "L 107.015024 111.455213 \n",
       "L 110.294361 109.294027 \n",
       "L 113.573703 106.725218 \n",
       "L 116.853041 104.648389 \n",
       "L 120.132378 102.312008 \n",
       "L 123.41172 100.544959 \n",
       "L 126.691057 98.922117 \n",
       "L 129.970395 98.04469 \n",
       "L 133.249737 97.156824 \n",
       "L 136.529069 96.828103 \n",
       "L 139.808412 96.915849 \n",
       "L 143.087754 96.857117 \n",
       "L 146.367086 98.573603 \n",
       "L 149.646428 99.525904 \n",
       "L 152.92577 101.229237 \n",
       "L 156.205103 103.10023 \n",
       "L 159.484445 105.443366 \n",
       "L 162.763787 108.436557 \n",
       "L 166.04312 110.691802 \n",
       "L 169.322462 113.589303 \n",
       "L 172.601804 116.987278 \n",
       "L 175.881137 119.616445 \n",
       "L 179.160479 122.443238 \n",
       "L 182.439821 125.140174 \n",
       "L 185.719153 127.864153 \n",
       "L 188.998496 130.221546 \n",
       "L 192.277838 132.373986 \n",
       "L 195.55717 134.472172 \n",
       "L 198.836512 136.052387 \n",
       "L 202.115855 137.678424 \n",
       "L 205.395187 138.986574 \n",
       "L 208.674529 140.043499 \n",
       "L 211.953871 140.602316 \n",
       "L 215.233204 140.765782 \n",
       "L 218.512556 141.536571 \n",
       "L 221.791879 140.855447 \n",
       "L 225.071221 141.043424 \n",
       "L 228.350563 139.935364 \n",
       "L 231.629886 138.888255 \n",
       "L 234.909247 137.781227 \n",
       "L 238.18857 136.612711 \n",
       "L 241.467912 134.618581 \n",
       "L 244.747254 132.896521 \n",
       "L 248.026597 130.648027 \n",
       "L 251.305939 128.209269 \n",
       "L 254.585262 125.660661 \n",
       "L 257.864623 122.92894 \n",
       "L 261.143946 120.103837 \n",
       "L 264.423288 117.448001 \n",
       "L 267.70263 114.446567 \n",
       "L 270.981953 111.242426 \n",
       "L 274.261315 108.506652 \n",
       "L 277.540637 105.988478 \n",
       "L 280.81998 103.39708 \n",
       "L 284.099322 101.162336 \n",
       "L 287.378664 98.533978 \n",
       "L 290.658006 96.920355 \n",
       "L 293.937329 95.22329 \n",
       "L 297.21669 94.000377 \n",
       "L 300.496013 93.065209 \n",
       "L 303.775355 92.494683 \n",
       "L 307.054697 92.087034 \n",
       "L 310.33402 91.603478 \n",
       "L 313.613382 92.273031 \n",
       "L 316.892705 92.457137 \n",
       "L 320.172047 92.72387 \n",
       "L 323.451389 93.212541 \n",
       "L 326.730731 94.025758 \n",
       "L 330.010073 94.868293 \n",
       "L 333.289396 95.659781 \n",
       "L 336.568738 96.466848 \n",
       "L 339.84808 97.501682 \n",
       "L 343.127423 98.075654 \n",
       "L 346.406765 99.685514 \n",
       "L 349.686088 100.448533 \n",
       "L 352.96543 101.765961 \n",
       "L 356.244772 103.029129 \n",
       "L 359.524114 105.120265 \n",
       "L 362.803456 106.887311 \n",
       "L 366.082798 108.885686 \n",
       "L 369.362141 111.83371 \n",
       "L 372.641463 114.051692 \n",
       "L 375.920806 117.686747 \n",
       "L 379.200148 120.79749 \n",
       "\" clip-path=\"url(#p903a380801)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_22\">\n",
       "    <path d=\"M 54.545602 59.890767 \n",
       "L 57.824941 63.759004 \n",
       "L 61.10428 67.47994 \n",
       "L 64.383619 71.735251 \n",
       "L 67.662958 75.676712 \n",
       "L 70.942296 79.959818 \n",
       "L 74.221636 83.869782 \n",
       "L 77.500973 88.099531 \n",
       "L 80.780313 91.493467 \n",
       "L 84.059653 94.355552 \n",
       "L 87.33899 97.476902 \n",
       "L 90.61833 100.127531 \n",
       "L 93.89767 101.450019 \n",
       "L 97.177007 104.090131 \n",
       "L 100.456344 105.640439 \n",
       "L 103.735686 106.131025 \n",
       "L 107.015024 106.150383 \n",
       "L 110.294361 106.709222 \n",
       "L 113.573703 106.148598 \n",
       "L 116.853041 105.945394 \n",
       "L 120.132378 105.33102 \n",
       "L 123.41172 104.837434 \n",
       "L 126.691057 103.990601 \n",
       "L 129.970395 102.79967 \n",
       "L 133.249737 102.146307 \n",
       "L 136.529069 102.39468 \n",
       "L 139.808412 101.635151 \n",
       "L 143.087754 101.806905 \n",
       "L 146.367086 102.007544 \n",
       "L 149.646428 102.042291 \n",
       "L 152.92577 102.818585 \n",
       "L 156.205103 104.051028 \n",
       "L 159.484445 105.029137 \n",
       "L 162.763787 106.154486 \n",
       "L 166.04312 107.368112 \n",
       "L 169.322462 108.782803 \n",
       "L 172.601804 110.362278 \n",
       "L 175.881137 112.442597 \n",
       "L 179.160479 113.426629 \n",
       "L 182.439821 115.550693 \n",
       "L 185.719153 116.932919 \n",
       "L 188.998496 118.47039 \n",
       "L 192.277838 119.712667 \n",
       "L 195.55717 121.309601 \n",
       "L 198.836512 121.610808 \n",
       "L 202.115855 122.697977 \n",
       "L 205.395187 123.208827 \n",
       "L 208.674529 123.557066 \n",
       "L 211.953871 123.90848 \n",
       "L 215.233204 123.090676 \n",
       "L 218.512556 122.881829 \n",
       "L 221.791879 122.493822 \n",
       "L 225.071221 121.269986 \n",
       "L 228.350563 119.758579 \n",
       "L 231.629886 118.574799 \n",
       "L 234.909247 117.192515 \n",
       "L 238.18857 114.783611 \n",
       "L 241.467912 113.025734 \n",
       "L 244.747254 111.475527 \n",
       "L 248.026597 109.383792 \n",
       "L 251.305939 107.864714 \n",
       "L 254.585262 105.48527 \n",
       "L 257.864623 103.81355 \n",
       "L 261.143946 102.449704 \n",
       "L 264.423288 101.515323 \n",
       "L 267.70263 100.765928 \n",
       "L 270.981953 100.328005 \n",
       "L 274.261315 99.843995 \n",
       "L 277.540637 99.986213 \n",
       "L 280.81998 100.047167 \n",
       "L 284.099322 100.524578 \n",
       "L 287.378664 101.109978 \n",
       "L 290.658006 101.944786 \n",
       "L 293.937329 103.110905 \n",
       "L 297.21669 103.403151 \n",
       "L 300.496013 104.713353 \n",
       "L 303.775355 105.193245 \n",
       "L 307.054697 105.882718 \n",
       "L 310.33402 106.175634 \n",
       "L 313.613382 106.277505 \n",
       "L 316.892705 106.139598 \n",
       "L 320.172047 105.906605 \n",
       "L 323.451389 105.451387 \n",
       "L 326.730731 105.172503 \n",
       "L 330.010073 104.603622 \n",
       "L 333.289396 104.008389 \n",
       "L 336.568738 102.906811 \n",
       "L 339.84808 102.623569 \n",
       "L 343.127423 102.712958 \n",
       "L 346.406765 101.957905 \n",
       "L 349.686088 102.162698 \n",
       "L 352.96543 102.653137 \n",
       "L 356.244772 103.031288 \n",
       "L 359.524114 104.423726 \n",
       "L 362.803456 105.405219 \n",
       "L 366.082798 106.665774 \n",
       "L 369.362141 108.923675 \n",
       "L 372.641463 110.681539 \n",
       "L 375.920806 112.844702 \n",
       "L 379.200148 115.171953 \n",
       "\" clip-path=\"url(#p903a380801)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_23\">\n",
       "    <path d=\"M 54.545602 91.504633 \n",
       "L 57.824941 91.944855 \n",
       "L 61.10428 93.222448 \n",
       "L 64.383619 93.843315 \n",
       "L 67.662958 95.549168 \n",
       "L 70.942296 96.351371 \n",
       "L 74.221636 97.760961 \n",
       "L 77.500973 99.163259 \n",
       "L 80.780313 100.090698 \n",
       "L 84.059653 101.175992 \n",
       "L 87.33899 102.26141 \n",
       "L 90.61833 103.524611 \n",
       "L 93.89767 104.360178 \n",
       "L 97.177007 105.062567 \n",
       "L 100.456344 105.711941 \n",
       "L 103.735686 105.910271 \n",
       "L 107.015024 106.208286 \n",
       "L 110.294361 106.267656 \n",
       "L 113.573703 106.223765 \n",
       "L 116.853041 106.4196 \n",
       "L 120.132378 106.001156 \n",
       "L 123.41172 105.770154 \n",
       "L 126.691057 105.749686 \n",
       "L 129.970395 105.060117 \n",
       "L 133.249737 105.078864 \n",
       "L 136.529069 104.748806 \n",
       "L 139.808412 104.70001 \n",
       "L 143.087754 104.212424 \n",
       "L 146.367086 103.998031 \n",
       "L 149.646428 104.269444 \n",
       "L 152.92577 104.357998 \n",
       "L 156.205103 104.014921 \n",
       "L 159.484445 104.144233 \n",
       "L 162.763787 104.174878 \n",
       "L 166.04312 103.341333 \n",
       "L 169.322462 103.08838 \n",
       "L 172.601804 102.8911 \n",
       "L 175.881137 102.444856 \n",
       "L 179.160479 101.412253 \n",
       "L 182.439821 100.321554 \n",
       "L 185.719153 99.895727 \n",
       "L 188.998496 98.15276 \n",
       "L 192.277838 96.848951 \n",
       "L 195.55717 95.156445 \n",
       "L 198.836512 93.187211 \n",
       "L 202.115855 90.946627 \n",
       "L 205.395187 89.310592 \n",
       "L 208.674529 86.728369 \n",
       "L 211.953871 84.054422 \n",
       "L 215.233204 81.623152 \n",
       "L 218.512556 79.2016 \n",
       "L 221.791879 77.468853 \n",
       "L 225.071221 74.664418 \n",
       "L 228.350563 72.541858 \n",
       "L 231.629886 70.983294 \n",
       "L 234.909247 68.793671 \n",
       "L 238.18857 67.697061 \n",
       "L 241.467912 66.186193 \n",
       "L 244.747254 65.039352 \n",
       "L 248.026597 64.563508 \n",
       "L 251.305939 64.289569 \n",
       "L 254.585262 64.14525 \n",
       "L 257.864623 64.487653 \n",
       "L 261.143946 64.946252 \n",
       "L 264.423288 65.710195 \n",
       "L 267.70263 66.171664 \n",
       "L 270.981953 67.353233 \n",
       "L 274.261315 68.536828 \n",
       "L 277.540637 69.257757 \n",
       "L 280.81998 70.548095 \n",
       "L 284.099322 71.610319 \n",
       "L 287.378664 72.906554 \n",
       "L 290.658006 74.223201 \n",
       "L 293.937329 75.227695 \n",
       "L 297.21669 76.680482 \n",
       "L 300.496013 77.701477 \n",
       "L 303.775355 79.250081 \n",
       "L 307.054697 80.227287 \n",
       "L 310.33402 82.011676 \n",
       "L 313.613382 83.319571 \n",
       "L 316.892705 84.467726 \n",
       "L 320.172047 86.287977 \n",
       "L 323.451389 88.079143 \n",
       "L 326.730731 89.395468 \n",
       "L 330.010073 91.088412 \n",
       "L 333.289396 93.021766 \n",
       "L 336.568738 94.711255 \n",
       "L 339.84808 97.218644 \n",
       "L 343.127423 98.12257 \n",
       "L 346.406765 99.939611 \n",
       "L 349.686088 101.216995 \n",
       "L 352.96543 102.16487 \n",
       "L 356.244772 103.346518 \n",
       "L 359.524114 103.923725 \n",
       "L 362.803456 104.743069 \n",
       "L 366.082798 103.787288 \n",
       "L 369.362141 103.655934 \n",
       "L 372.641463 102.928317 \n",
       "L 375.920806 102.3046 \n",
       "L 379.200148 101.657909 \n",
       "\" clip-path=\"url(#p903a380801)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_24\">\n",
       "    <path d=\"M 54.545602 108.473027 \n",
       "L 57.824941 108.873341 \n",
       "L 61.10428 108.655843 \n",
       "L 64.383619 109.047777 \n",
       "L 67.662958 108.971381 \n",
       "L 70.942296 109.482572 \n",
       "L 74.221636 109.347946 \n",
       "L 77.500973 110.053639 \n",
       "L 80.780313 110.146761 \n",
       "L 84.059653 109.989442 \n",
       "L 87.33899 109.743059 \n",
       "L 90.61833 109.720029 \n",
       "L 93.89767 109.556925 \n",
       "L 97.177007 109.172639 \n",
       "L 100.456344 108.565583 \n",
       "L 103.735686 108.156081 \n",
       "L 107.015024 107.462903 \n",
       "L 110.294361 106.900463 \n",
       "L 113.573703 106.232815 \n",
       "L 116.853041 105.827156 \n",
       "L 120.132378 105.446269 \n",
       "L 123.41172 104.585377 \n",
       "L 126.691057 103.64597 \n",
       "L 129.970395 103.183464 \n",
       "L 133.249737 103.005574 \n",
       "L 136.529069 102.968805 \n",
       "L 139.808412 102.78771 \n",
       "L 143.087754 102.531938 \n",
       "L 146.367086 102.663988 \n",
       "L 149.646428 102.973953 \n",
       "L 152.92577 103.228564 \n",
       "L 156.205103 103.964232 \n",
       "L 159.484445 104.485964 \n",
       "L 162.763787 105.202238 \n",
       "L 166.04312 105.301472 \n",
       "L 169.322462 105.84615 \n",
       "L 172.601804 106.012537 \n",
       "L 175.881137 105.850497 \n",
       "L 179.160479 106.053868 \n",
       "L 182.439821 105.752273 \n",
       "L 185.719153 105.069208 \n",
       "L 188.998496 104.315025 \n",
       "L 192.277838 103.59225 \n",
       "L 195.55717 102.291023 \n",
       "L 198.836512 101.21505 \n",
       "L 202.115855 98.645407 \n",
       "L 205.395187 96.945336 \n",
       "L 208.674529 94.716297 \n",
       "L 211.953871 92.625985 \n",
       "L 215.233204 90.080118 \n",
       "L 218.512556 87.833061 \n",
       "L 221.791879 85.608781 \n",
       "L 225.071221 83.30827 \n",
       "L 228.350563 81.531253 \n",
       "L 231.629886 79.267539 \n",
       "L 234.909247 77.7744 \n",
       "L 238.18857 76.643795 \n",
       "L 241.467912 75.367712 \n",
       "L 244.747254 74.360364 \n",
       "L 248.026597 74.120201 \n",
       "L 251.305939 74.164094 \n",
       "L 254.585262 74.191209 \n",
       "L 257.864623 75.04788 \n",
       "L 261.143946 76.491663 \n",
       "L 264.423288 77.661913 \n",
       "L 267.70263 79.216565 \n",
       "L 270.981953 81.227428 \n",
       "L 274.261315 83.276774 \n",
       "L 277.540637 85.734005 \n",
       "L 280.81998 87.254465 \n",
       "L 284.099322 89.840542 \n",
       "L 287.378664 92.324419 \n",
       "L 290.658006 94.889934 \n",
       "L 293.937329 97.25076 \n",
       "L 297.21669 99.077961 \n",
       "L 300.496013 100.654856 \n",
       "L 303.775355 102.923422 \n",
       "L 307.054697 104.065429 \n",
       "L 310.33402 105.564108 \n",
       "L 313.613382 106.111155 \n",
       "L 316.892705 106.496373 \n",
       "L 320.172047 106.989267 \n",
       "L 323.451389 107.355574 \n",
       "L 326.730731 107.430909 \n",
       "L 330.010073 106.814341 \n",
       "L 333.289396 106.751483 \n",
       "L 336.568738 106.009863 \n",
       "L 339.84808 105.143012 \n",
       "L 343.127423 104.615018 \n",
       "L 346.406765 104.197033 \n",
       "L 349.686088 104.05618 \n",
       "L 352.96543 103.323323 \n",
       "L 356.244772 102.861533 \n",
       "L 359.524114 103.183881 \n",
       "L 362.803456 103.287546 \n",
       "L 366.082798 104.033851 \n",
       "L 369.362141 104.76248 \n",
       "L 372.641463 105.618083 \n",
       "L 375.920806 106.833209 \n",
       "L 379.200148 108.02871 \n",
       "\" clip-path=\"url(#p903a380801)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_25\">\n",
       "    <path d=\"M 54.545602 59.915306 \n",
       "L 57.824941 59.691482 \n",
       "L 61.10428 60.017361 \n",
       "L 64.383619 60.854376 \n",
       "L 67.662958 61.983073 \n",
       "L 70.942296 63.71691 \n",
       "L 74.221636 65.888014 \n",
       "L 77.500973 68.141922 \n",
       "L 80.780313 70.95394 \n",
       "L 84.059653 74.202891 \n",
       "L 87.33899 77.788437 \n",
       "L 90.61833 81.262192 \n",
       "L 93.89767 84.897471 \n",
       "L 97.177007 88.934296 \n",
       "L 100.456344 92.517755 \n",
       "L 103.735686 96.102837 \n",
       "L 107.015024 99.810897 \n",
       "L 110.294361 102.853515 \n",
       "L 113.573703 105.603969 \n",
       "L 116.853041 108.685961 \n",
       "L 120.132378 110.505396 \n",
       "L 123.41172 111.792214 \n",
       "L 126.691057 113.092323 \n",
       "L 129.970395 113.564725 \n",
       "L 133.249737 113.732239 \n",
       "L 136.529069 113.613535 \n",
       "L 139.808412 113.247296 \n",
       "L 143.087754 111.881025 \n",
       "L 146.367086 110.627775 \n",
       "L 149.646428 108.780516 \n",
       "L 152.92577 106.781707 \n",
       "L 156.205103 104.612674 \n",
       "L 159.484445 102.459144 \n",
       "L 162.763787 100.370228 \n",
       "L 166.04312 98.133129 \n",
       "L 169.322462 96.03965 \n",
       "L 172.601804 94.526433 \n",
       "L 175.881137 92.998863 \n",
       "L 179.160479 91.489779 \n",
       "L 182.439821 90.966241 \n",
       "L 185.719153 90.168522 \n",
       "L 188.998496 90.257212 \n",
       "L 192.277838 90.48922 \n",
       "L 195.55717 91.296615 \n",
       "L 198.836512 92.157992 \n",
       "L 202.115855 93.589878 \n",
       "L 205.395187 94.936977 \n",
       "L 208.674529 97.011767 \n",
       "L 211.953871 98.92619 \n",
       "L 215.233204 100.908653 \n",
       "L 218.512556 103.553584 \n",
       "L 221.791879 105.885273 \n",
       "L 225.071221 107.072502 \n",
       "L 228.350563 109.225321 \n",
       "L 231.629886 111.604037 \n",
       "L 234.909247 113.053524 \n",
       "L 238.18857 114.33394 \n",
       "L 241.467912 115.463304 \n",
       "L 244.747254 116.547187 \n",
       "L 248.026597 117.660162 \n",
       "L 251.305939 118.053219 \n",
       "L 254.585262 118.424206 \n",
       "L 257.864623 118.317777 \n",
       "L 261.143946 118.83142 \n",
       "L 264.423288 118.366268 \n",
       "L 267.70263 118.973564 \n",
       "L 270.981953 118.659403 \n",
       "L 274.261315 118.507832 \n",
       "L 277.540637 118.352968 \n",
       "L 280.81998 118.239294 \n",
       "L 284.099322 118.052621 \n",
       "L 287.378664 118.46421 \n",
       "L 290.658006 118.471118 \n",
       "L 293.937329 118.56082 \n",
       "L 297.21669 118.457516 \n",
       "L 300.496013 118.970034 \n",
       "L 303.775355 118.990478 \n",
       "L 307.054697 118.99351 \n",
       "L 310.33402 119.125062 \n",
       "L 313.613382 118.836321 \n",
       "L 316.892705 118.963023 \n",
       "L 320.172047 118.277941 \n",
       "L 323.451389 118.037985 \n",
       "L 326.730731 117.382116 \n",
       "L 330.010073 116.607865 \n",
       "L 333.289396 115.258919 \n",
       "L 336.568738 114.023124 \n",
       "L 339.84808 112.619998 \n",
       "L 343.127423 110.556064 \n",
       "L 346.406765 109.194938 \n",
       "L 349.686088 106.972436 \n",
       "L 352.96543 105.175245 \n",
       "L 356.244772 103.224282 \n",
       "L 359.524114 101.504695 \n",
       "L 362.803456 99.590263 \n",
       "L 366.082798 98.135029 \n",
       "L 369.362141 96.337385 \n",
       "L 372.641463 95.483984 \n",
       "L 375.920806 94.036623 \n",
       "L 379.200148 93.192106 \n",
       "\" clip-path=\"url(#p903a380801)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_26\">\n",
       "    <path d=\"M 54.545602 84.007727 \n",
       "L 57.824941 84.819901 \n",
       "L 61.10428 86.357846 \n",
       "L 64.383619 87.641988 \n",
       "L 67.662958 89.922111 \n",
       "L 70.942296 92.019848 \n",
       "L 74.221636 93.511431 \n",
       "L 77.500973 95.03779 \n",
       "L 80.780313 97.081479 \n",
       "L 84.059653 98.449225 \n",
       "L 87.33899 99.99818 \n",
       "L 90.61833 101.797145 \n",
       "L 93.89767 102.24986 \n",
       "L 97.177007 102.929585 \n",
       "L 100.456344 104.529038 \n",
       "L 103.735686 104.550728 \n",
       "L 107.015024 105.401075 \n",
       "L 110.294361 105.595106 \n",
       "L 113.573703 106.365103 \n",
       "L 116.853041 106.408418 \n",
       "L 120.132378 107.283209 \n",
       "L 123.41172 107.645176 \n",
       "L 126.691057 107.430623 \n",
       "L 129.970395 107.779349 \n",
       "L 133.249737 108.222357 \n",
       "L 136.529069 108.281517 \n",
       "L 139.808412 107.991829 \n",
       "L 143.087754 107.624015 \n",
       "L 146.367086 107.747338 \n",
       "L 149.646428 106.726393 \n",
       "L 152.92577 105.766892 \n",
       "L 156.205103 104.528673 \n",
       "L 159.484445 102.966839 \n",
       "L 162.763787 101.376918 \n",
       "L 166.04312 99.348161 \n",
       "L 169.322462 97.323797 \n",
       "L 172.601804 95.274844 \n",
       "L 175.881137 92.833571 \n",
       "L 179.160479 90.187835 \n",
       "L 182.439821 87.961042 \n",
       "L 185.719153 85.949233 \n",
       "L 188.998496 84.488857 \n",
       "L 192.277838 82.801288 \n",
       "L 195.55717 81.960556 \n",
       "L 198.836512 81.295203 \n",
       "L 202.115855 80.970679 \n",
       "L 205.395187 81.072593 \n",
       "L 208.674529 82.322512 \n",
       "L 211.953871 83.3951 \n",
       "L 215.233204 85.631462 \n",
       "L 218.512556 87.46257 \n",
       "L 221.791879 90.390002 \n",
       "L 225.071221 93.492703 \n",
       "L 228.350563 97.011498 \n",
       "L 231.629886 100.478637 \n",
       "L 234.909247 103.873036 \n",
       "L 238.18857 107.28552 \n",
       "L 241.467912 110.425237 \n",
       "L 244.747254 113.594937 \n",
       "L 248.026597 116.53686 \n",
       "L 251.305939 118.920349 \n",
       "L 254.585262 121.094738 \n",
       "L 257.864623 122.380973 \n",
       "L 261.143946 123.351675 \n",
       "L 264.423288 124.020601 \n",
       "L 267.70263 124.090831 \n",
       "L 270.981953 123.950042 \n",
       "L 274.261315 123.003551 \n",
       "L 277.540637 121.475286 \n",
       "L 280.81998 119.862477 \n",
       "L 284.099322 117.737345 \n",
       "L 287.378664 115.736531 \n",
       "L 290.658006 113.064429 \n",
       "L 293.937329 110.534644 \n",
       "L 297.21669 107.919795 \n",
       "L 300.496013 105.508534 \n",
       "L 303.775355 102.7457 \n",
       "L 307.054697 100.538289 \n",
       "L 310.33402 98.804833 \n",
       "L 313.613382 96.685909 \n",
       "L 316.892705 95.506648 \n",
       "L 320.172047 94.151078 \n",
       "L 323.451389 93.042746 \n",
       "L 326.730731 92.868009 \n",
       "L 330.010073 92.716341 \n",
       "L 333.289396 92.942804 \n",
       "L 336.568738 93.833947 \n",
       "L 339.84808 94.650491 \n",
       "L 343.127423 96.018577 \n",
       "L 346.406765 97.481354 \n",
       "L 349.686088 99.131329 \n",
       "L 352.96543 101.210132 \n",
       "L 356.244772 103.355707 \n",
       "L 359.524114 105.301189 \n",
       "L 362.803456 107.746503 \n",
       "L 366.082798 110.488843 \n",
       "L 369.362141 112.619897 \n",
       "L 372.641463 115.523859 \n",
       "L 375.920806 117.544462 \n",
       "L 379.200148 120.79053 \n",
       "\" clip-path=\"url(#p903a380801)\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_27\"/>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 38.312875 261.273566 \n",
       "L 38.312875 16.89357 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 54.545602 273.312 \n",
       "L 379.200148 273.312 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"legend_1\">\n",
       "    <g id=\"line2d_28\">\n",
       "     <g>\n",
       "      <use xlink:href=\"#m4d235c7fbf\" x=\"55.032875\" y=\"194.65925\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_16\">\n",
       "     <!-- Observations -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 197.73925) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4f\" d=\"M 309 2231 \n",
       "Q 309 3372 921 4017 \n",
       "Q 1534 4663 2503 4663 \n",
       "Q 3138 4663 3647 4359 \n",
       "Q 4156 4056 4423 3514 \n",
       "Q 4691 2972 4691 2284 \n",
       "Q 4691 1588 4409 1038 \n",
       "Q 4128 488 3612 205 \n",
       "Q 3097 -78 2500 -78 \n",
       "Q 1853 -78 1343 234 \n",
       "Q 834 547 571 1087 \n",
       "Q 309 1628 309 2231 \n",
       "z\n",
       "M 934 2222 \n",
       "Q 934 1394 1379 917 \n",
       "Q 1825 441 2497 441 \n",
       "Q 3181 441 3623 922 \n",
       "Q 4066 1403 4066 2288 \n",
       "Q 4066 2847 3877 3264 \n",
       "Q 3688 3681 3323 3911 \n",
       "Q 2959 4141 2506 4141 \n",
       "Q 1863 4141 1398 3698 \n",
       "Q 934 3256 934 2222 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-62\" d=\"M 941 0 \n",
       "L 419 0 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 2947 \n",
       "Q 1338 3394 1891 3394 \n",
       "Q 2197 3394 2470 3270 \n",
       "Q 2744 3147 2920 2923 \n",
       "Q 3097 2700 3197 2384 \n",
       "Q 3297 2069 3297 1709 \n",
       "Q 3297 856 2875 390 \n",
       "Q 2453 -75 1863 -75 \n",
       "Q 1275 -75 941 416 \n",
       "L 941 0 \n",
       "z\n",
       "M 934 1684 \n",
       "Q 934 1088 1097 822 \n",
       "Q 1363 388 1816 388 \n",
       "Q 2184 388 2453 708 \n",
       "Q 2722 1028 2722 1663 \n",
       "Q 2722 2313 2464 2622 \n",
       "Q 2206 2931 1841 2931 \n",
       "Q 1472 2931 1203 2611 \n",
       "Q 934 2291 934 1684 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-76\" d=\"M 1344 0 \n",
       "L 81 3319 \n",
       "L 675 3319 \n",
       "L 1388 1331 \n",
       "Q 1503 1009 1600 663 \n",
       "Q 1675 925 1809 1294 \n",
       "L 2547 3319 \n",
       "L 3125 3319 \n",
       "L 1869 0 \n",
       "L 1344 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4f\"/>\n",
       "      <use xlink:href=\"#ArialMT-62\" x=\"77.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"133.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"183.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"239.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"272.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"322.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"377.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"405.712891\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"427.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"483.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"539.160156\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_29\">\n",
       "     <path d=\"M 46.232875 207.24325 \n",
       "L 55.032875 207.24325 \n",
       "L 63.832875 207.24325 \n",
       "\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "    </g>\n",
       "    <g id=\"text_17\">\n",
       "     <!-- $m_n(x)$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 210.32325) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-6d\" d=\"M 5747 2113 \n",
       "L 5338 0 \n",
       "L 4763 0 \n",
       "L 5166 2094 \n",
       "Q 5191 2228 5203 2325 \n",
       "Q 5216 2422 5216 2491 \n",
       "Q 5216 2772 5059 2928 \n",
       "Q 4903 3084 4622 3084 \n",
       "Q 4203 3084 3875 2770 \n",
       "Q 3547 2456 3450 1953 \n",
       "L 3066 0 \n",
       "L 2491 0 \n",
       "L 2900 2094 \n",
       "Q 2925 2209 2937 2307 \n",
       "Q 2950 2406 2950 2484 \n",
       "Q 2950 2769 2794 2926 \n",
       "Q 2638 3084 2363 3084 \n",
       "Q 1938 3084 1609 2770 \n",
       "Q 1281 2456 1184 1953 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 909 3500 \n",
       "L 1484 3500 \n",
       "L 1375 2956 \n",
       "Q 1609 3263 1923 3423 \n",
       "Q 2238 3584 2597 3584 \n",
       "Q 2978 3584 3223 3384 \n",
       "Q 3469 3184 3519 2828 \n",
       "Q 3781 3197 4126 3390 \n",
       "Q 4472 3584 4856 3584 \n",
       "Q 5306 3584 5551 3325 \n",
       "Q 5797 3066 5797 2591 \n",
       "Q 5797 2488 5784 2364 \n",
       "Q 5772 2241 5747 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Oblique-6e\" d=\"M 3566 2113 \n",
       "L 3156 0 \n",
       "L 2578 0 \n",
       "L 2988 2091 \n",
       "Q 3016 2238 3031 2350 \n",
       "Q 3047 2463 3047 2528 \n",
       "Q 3047 2791 2881 2937 \n",
       "Q 2716 3084 2419 3084 \n",
       "Q 1956 3084 1622 2776 \n",
       "Q 1288 2469 1184 1941 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 903 3500 \n",
       "L 1478 3500 \n",
       "L 1363 2950 \n",
       "Q 1603 3253 1940 3418 \n",
       "Q 2278 3584 2650 3584 \n",
       "Q 3113 3584 3367 3334 \n",
       "Q 3622 3084 3622 2631 \n",
       "Q 3622 2519 3608 2391 \n",
       "Q 3594 2263 3566 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-28\" d=\"M 1984 4856 \n",
       "Q 1566 4138 1362 3434 \n",
       "Q 1159 2731 1159 2009 \n",
       "Q 1159 1288 1364 580 \n",
       "Q 1569 -128 1984 -844 \n",
       "L 1484 -844 \n",
       "Q 1016 -109 783 600 \n",
       "Q 550 1309 550 2009 \n",
       "Q 550 2706 781 3412 \n",
       "Q 1013 4119 1484 4856 \n",
       "L 1984 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-29\" d=\"M 513 4856 \n",
       "L 1013 4856 \n",
       "Q 1481 4119 1714 3412 \n",
       "Q 1947 2706 1947 2009 \n",
       "Q 1947 1309 1714 600 \n",
       "Q 1481 -109 1013 -844 \n",
       "L 513 -844 \n",
       "Q 928 -128 1133 580 \n",
       "Q 1338 1288 1338 2009 \n",
       "Q 1338 2731 1133 3434 \n",
       "Q 928 4138 513 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6d\" transform=\"translate(0 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6e\" transform=\"translate(97.412109 -16.28125) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(144.511719 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(183.525391 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(242.705078 0.125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_5\">\n",
       "     <path d=\"M 46.232875 224.48025 \n",
       "L 63.832875 224.48025 \n",
       "L 63.832875 218.32025 \n",
       "L 46.232875 218.32025 \n",
       "z\n",
       "\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_18\">\n",
       "     <!-- $f(\\mathbf{x}^*)$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 224.48025) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-66\" d=\"M 3059 4863 \n",
       "L 2969 4384 \n",
       "L 2419 4384 \n",
       "Q 2106 4384 1964 4261 \n",
       "Q 1822 4138 1753 3809 \n",
       "L 1691 3500 \n",
       "L 2638 3500 \n",
       "L 2553 3053 \n",
       "L 1606 3053 \n",
       "L 1013 0 \n",
       "L 434 0 \n",
       "L 1031 3053 \n",
       "L 481 3053 \n",
       "L 563 3500 \n",
       "L 1113 3500 \n",
       "L 1159 3744 \n",
       "Q 1278 4363 1576 4613 \n",
       "Q 1875 4863 2516 4863 \n",
       "L 3059 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Bold-78\" d=\"M 1422 1791 \n",
       "L 159 3500 \n",
       "L 1344 3500 \n",
       "L 2059 2463 \n",
       "L 2784 3500 \n",
       "L 3969 3500 \n",
       "L 2706 1797 \n",
       "L 4031 0 \n",
       "L 2847 0 \n",
       "L 2059 1106 \n",
       "L 1281 0 \n",
       "L 97 0 \n",
       "L 1422 1791 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-2a\" d=\"M 3009 3897 \n",
       "L 1888 3291 \n",
       "L 3009 2681 \n",
       "L 2828 2375 \n",
       "L 1778 3009 \n",
       "L 1778 1831 \n",
       "L 1422 1831 \n",
       "L 1422 3009 \n",
       "L 372 2375 \n",
       "L 191 2681 \n",
       "L 1313 3291 \n",
       "L 191 3897 \n",
       "L 372 4206 \n",
       "L 1422 3572 \n",
       "L 1422 4750 \n",
       "L 1778 4750 \n",
       "L 1778 3572 \n",
       "L 2828 4206 \n",
       "L 3009 3897 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-39\" d=\"M 350 1059 \n",
       "L 891 1109 \n",
       "Q 959 728 1153 556 \n",
       "Q 1347 384 1650 384 \n",
       "Q 1909 384 2104 503 \n",
       "Q 2300 622 2425 820 \n",
       "Q 2550 1019 2634 1356 \n",
       "Q 2719 1694 2719 2044 \n",
       "Q 2719 2081 2716 2156 \n",
       "Q 2547 1888 2255 1720 \n",
       "Q 1963 1553 1622 1553 \n",
       "Q 1053 1553 659 1965 \n",
       "Q 266 2378 266 3053 \n",
       "Q 266 3750 677 4175 \n",
       "Q 1088 4600 1706 4600 \n",
       "Q 2153 4600 2523 4359 \n",
       "Q 2894 4119 3086 3673 \n",
       "Q 3278 3228 3278 2384 \n",
       "Q 3278 1506 3087 986 \n",
       "Q 2897 466 2520 194 \n",
       "Q 2144 -78 1638 -78 \n",
       "Q 1100 -78 759 220 \n",
       "Q 419 519 350 1059 \n",
       "z\n",
       "M 2653 3081 \n",
       "Q 2653 3566 2395 3850 \n",
       "Q 2138 4134 1775 4134 \n",
       "Q 1400 4134 1122 3828 \n",
       "Q 844 3522 844 3034 \n",
       "Q 844 2597 1108 2323 \n",
       "Q 1372 2050 1759 2050 \n",
       "Q 2150 2050 2401 2323 \n",
       "Q 2653 2597 2653 3081 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-25\" d=\"M 372 3481 \n",
       "Q 372 3972 619 4315 \n",
       "Q 866 4659 1334 4659 \n",
       "Q 1766 4659 2048 4351 \n",
       "Q 2331 4044 2331 3447 \n",
       "Q 2331 2866 2045 2552 \n",
       "Q 1759 2238 1341 2238 \n",
       "Q 925 2238 648 2547 \n",
       "Q 372 2856 372 3481 \n",
       "z\n",
       "M 1350 4272 \n",
       "Q 1141 4272 1002 4090 \n",
       "Q 863 3909 863 3425 \n",
       "Q 863 2984 1003 2804 \n",
       "Q 1144 2625 1350 2625 \n",
       "Q 1563 2625 1702 2806 \n",
       "Q 1841 2988 1841 3469 \n",
       "Q 1841 3913 1700 4092 \n",
       "Q 1559 4272 1350 4272 \n",
       "z\n",
       "M 1353 -169 \n",
       "L 3859 4659 \n",
       "L 4316 4659 \n",
       "L 1819 -169 \n",
       "L 1353 -169 \n",
       "z\n",
       "M 3334 1075 \n",
       "Q 3334 1569 3581 1911 \n",
       "Q 3828 2253 4300 2253 \n",
       "Q 4731 2253 5014 1945 \n",
       "Q 5297 1638 5297 1041 \n",
       "Q 5297 459 5011 145 \n",
       "Q 4725 -169 4303 -169 \n",
       "Q 3888 -169 3611 142 \n",
       "Q 3334 453 3334 1075 \n",
       "z\n",
       "M 4316 1866 \n",
       "Q 4103 1866 3964 1684 \n",
       "Q 3825 1503 3825 1019 \n",
       "Q 3825 581 3965 400 \n",
       "Q 4106 219 4313 219 \n",
       "Q 4528 219 4667 400 \n",
       "Q 4806 581 4806 1063 \n",
       "Q 4806 1506 4665 1686 \n",
       "Q 4525 1866 4316 1866 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-66\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(35.205078 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Bold-78\" transform=\"translate(74.21875 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(153.31543 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(204.6875 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(243.701172 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(271.484375 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(327.099609 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(382.714844 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(471.630859 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(499.414062 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(555.029297 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(588.330078 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(643.945312 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(699.560547 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_6\">\n",
       "     <path d=\"M 46.232875 238.64825 \n",
       "L 63.832875 238.64825 \n",
       "L 63.832875 232.48825 \n",
       "L 46.232875 232.48825 \n",
       "z\n",
       "\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_19\">\n",
       "     <!-- $y^*$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 238.64825) scale(0.088 -0.088)\">\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(77.283529 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(128.655599 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(156.438802 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(212.054036 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(267.669271 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(356.585286 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(384.36849 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(439.983724 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(473.284505 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(528.89974 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(584.514974 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_30\">\n",
       "     <path d=\"M 46.232875 248.115125 \n",
       "L 55.032875 248.115125 \n",
       "L 63.832875 248.115125 \n",
       "\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "    </g>\n",
       "    <g id=\"text_20\">\n",
       "     <!-- True function -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 251.195125) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-54\" d=\"M 1659 0 \n",
       "L 1659 4041 \n",
       "L 150 4041 \n",
       "L 150 4581 \n",
       "L 3781 4581 \n",
       "L 3781 4041 \n",
       "L 2266 4041 \n",
       "L 2266 0 \n",
       "L 1659 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-66\" d=\"M 556 0 \n",
       "L 556 2881 \n",
       "L 59 2881 \n",
       "L 59 3319 \n",
       "L 556 3319 \n",
       "L 556 3672 \n",
       "Q 556 4006 616 4169 \n",
       "Q 697 4388 901 4523 \n",
       "Q 1106 4659 1475 4659 \n",
       "Q 1713 4659 2000 4603 \n",
       "L 1916 4113 \n",
       "Q 1741 4144 1584 4144 \n",
       "Q 1328 4144 1222 4034 \n",
       "Q 1116 3925 1116 3625 \n",
       "L 1116 3319 \n",
       "L 1763 3319 \n",
       "L 1763 2881 \n",
       "L 1116 2881 \n",
       "L 1116 0 \n",
       "L 556 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-54\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"57.333984\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"90.634766\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"146.25\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"201.865234\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"229.648438\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"257.431641\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"313.046875\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"368.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"418.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"446.445312\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"468.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"524.277344\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_31\">\n",
       "     <path d=\"M 46.232875 260.563 \n",
       "L 55.032875 260.563 \n",
       "L 63.832875 260.563 \n",
       "\" style=\"fill: none; stroke: #ff0000; stroke-width: 0.5; stroke-linecap: round\"/>\n",
       "    </g>\n",
       "    <g id=\"text_21\">\n",
       "     <!-- Posterior samples -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 263.643) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-50\" d=\"M 494 0 \n",
       "L 494 4581 \n",
       "L 2222 4581 \n",
       "Q 2678 4581 2919 4538 \n",
       "Q 3256 4481 3484 4323 \n",
       "Q 3713 4166 3852 3881 \n",
       "Q 3991 3597 3991 3256 \n",
       "Q 3991 2672 3619 2267 \n",
       "Q 3247 1863 2275 1863 \n",
       "L 1100 1863 \n",
       "L 1100 0 \n",
       "L 494 0 \n",
       "z\n",
       "M 1100 2403 \n",
       "L 2284 2403 \n",
       "Q 2872 2403 3119 2622 \n",
       "Q 3366 2841 3366 3238 \n",
       "Q 3366 3525 3220 3729 \n",
       "Q 3075 3934 2838 4000 \n",
       "Q 2684 4041 2272 4041 \n",
       "L 1100 4041 \n",
       "L 1100 2403 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6c\" d=\"M 409 0 \n",
       "L 409 4581 \n",
       "L 972 4581 \n",
       "L 972 0 \n",
       "L 409 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-50\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"66.699219\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"122.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"172.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"200.097656\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"255.712891\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"289.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"311.230469\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"366.845703\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"400.146484\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"427.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"477.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-6d\" x=\"533.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" x=\"616.845703\"/>\n",
       "      <use xlink:href=\"#ArialMT-6c\" x=\"672.460938\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"694.677734\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"750.292969\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"p903a380801\">\n",
       "   <rect x=\"38.312875\" y=\"7.2\" width=\"357.12\" height=\"266.112\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 640x480 with 1 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "train_x = torch.from_numpy(X).float()\n",
    "train_y = torch.from_numpy(Y).float()\n",
    "model = ExactGP(train_x, train_y)\n",
    "\n",
    "# It is not a good idea to train the model when we don't have enough data\n",
    "# So we fix the hyperparameters to something reasonable\n",
    "model.covar_module.base_kernel.lengthscale = 0.15\n",
    "model.covar_module.outputscale = 4.0\n",
    "model.likelihood.noise = 0.0\n",
    "model.eval()\n",
    "\n",
    "x = torch.linspace(0, 1, 100)\n",
    "plot_1d_regression(\n",
    "    x,\n",
    "    model,\n",
    "    f_true=f\n",
    ");"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "The expected improvement is more involved, but it serves as a template for deriving more general information acquisition functions.\n",
    "Here is how you think.\n",
    "Consider a hypothetical experiment at $\\mathbf{x}$ and assume that you observed $y$.\n",
    "How much improvement is that compared to your currently best-observed point $y_n^*$?\n",
    "It is:\n",
    "\n",
    "$$\n",
    "I_n(\\mathbf{x}, y) =\n",
    "\\begin{cases}\n",
    "0,&\\;\\text{if}\\;y \\le y_n^*,\\\\\n",
    "y - y_n^*,&\\;\\text{otherwise}.\n",
    "\\end{cases}\n",
    "$$\n",
    "\n",
    "But you don't know what $y$ is. What do you do now?\n",
    "Well, the only legitimate thing to do is to take the expectation over what you expected $y$ to be given what you know.\n",
    "So it is:\n",
    "\n",
    "$$\n",
    "\\begin{align}\n",
    "\\operatorname{EI}_n(\\mathbf{x}) &=& \n",
    "\\int_{-\\infty}^\\infty I_n(\\mathbf{x}, y)p(y|\\mathbf{x}, \\mathcal{D}_n)dy\\\\\n",
    "&=& \\int_{-\\infty}^{y_n^*}0\\cdot p(y|\\mathbf{x}, \\mathcal{D}_n)dy\n",
    "+ \\int_{y_n^*}^{\\infty}(y - y_n^*)\\cdot p(y|\\mathbf{x}, \\mathcal{D}_n)dy.\n",
    "\\end{align}\n",
    "$$\n",
    "\n",
    "You can work this out analytically.\n",
    "You will get:\n",
    "\n",
    "$$\n",
    "\\operatorname{EI}_n(\\mathbf{x}) = \\left(m_n(\\mathbf{x}) - y_n^*\\right)\\Phi\\left(\\frac{m_n(\\mathbf{x}) - y_n^*}{\\sigma_n(\\mathbf{x})}\\right)\n",
    "+ \\sigma_n(x)\\phi\\left(\\frac{m_n(\\mathbf{x}) - y_n^*}{\\sigma_n(\\mathbf{x})}\\right).\n",
    "$$"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"436.061375pt\" height=\"309.639375pt\" viewBox=\"0 0 436.061375 309.639375\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2023-10-23T15:18:57.947428</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.8.0, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 309.639375 \n",
       "L 436.061375 309.639375 \n",
       "L 436.061375 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 38.312875 273.312 \n",
       "L 395.432875 273.312 \n",
       "L 395.432875 7.2 \n",
       "L 38.312875 7.2 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"mec581bb539\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mec581bb539\" x=\"54.545602\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(48.429602 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mec581bb539\" x=\"119.476511\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(113.360511 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mec581bb539\" x=\"184.40742\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(178.29142 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mec581bb539\" x=\"249.33833\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(243.22233 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mec581bb539\" x=\"314.269239\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(308.153239 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mec581bb539\" x=\"379.200148\" y=\"273.312\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 1.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(373.084148 287.910875) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_7\">\n",
       "     <!-- $x$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(213.992875 300.531375) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-78\" d=\"M 3841 3500 \n",
       "L 2234 1784 \n",
       "L 3219 0 \n",
       "L 2559 0 \n",
       "L 1819 1388 \n",
       "L 531 0 \n",
       "L -166 0 \n",
       "L 1556 1844 \n",
       "L 641 3500 \n",
       "L 1300 3500 \n",
       "L 1972 2234 \n",
       "L 3144 3500 \n",
       "L 3841 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <defs>\n",
       "       <path id=\"m2def10dbaa\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m2def10dbaa\" x=\"38.312875\" y=\"262.337111\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 265.486549) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m2def10dbaa\" x=\"38.312875\" y=\"231.50228\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- −3 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 234.651717) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-33\" d=\"M 269 1209 \n",
       "L 831 1284 \n",
       "Q 928 806 1161 595 \n",
       "Q 1394 384 1728 384 \n",
       "Q 2125 384 2398 659 \n",
       "Q 2672 934 2672 1341 \n",
       "Q 2672 1728 2419 1979 \n",
       "Q 2166 2231 1775 2231 \n",
       "Q 1616 2231 1378 2169 \n",
       "L 1441 2663 \n",
       "Q 1497 2656 1531 2656 \n",
       "Q 1891 2656 2178 2843 \n",
       "Q 2466 3031 2466 3422 \n",
       "Q 2466 3731 2256 3934 \n",
       "Q 2047 4138 1716 4138 \n",
       "Q 1388 4138 1169 3931 \n",
       "Q 950 3725 888 3313 \n",
       "L 325 3413 \n",
       "Q 428 3978 793 4289 \n",
       "Q 1159 4600 1703 4600 \n",
       "Q 2078 4600 2393 4439 \n",
       "Q 2709 4278 2876 4000 \n",
       "Q 3044 3722 3044 3409 \n",
       "Q 3044 3113 2884 2869 \n",
       "Q 2725 2625 2413 2481 \n",
       "Q 2819 2388 3044 2092 \n",
       "Q 3269 1797 3269 1353 \n",
       "Q 3269 753 2831 336 \n",
       "Q 2394 -81 1725 -81 \n",
       "Q 1122 -81 723 278 \n",
       "Q 325 638 269 1209 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m2def10dbaa\" x=\"38.312875\" y=\"200.667448\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 203.816886) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m2def10dbaa\" x=\"38.312875\" y=\"169.832617\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- −1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 172.982054) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m2def10dbaa\" x=\"38.312875\" y=\"138.997785\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 142.147223) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m2def10dbaa\" x=\"38.312875\" y=\"108.162954\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- 1 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 111.312391) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_13\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m2def10dbaa\" x=\"38.312875\" y=\"77.328122\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_14\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 80.47756) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_14\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m2def10dbaa\" x=\"38.312875\" y=\"46.493291\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_15\">\n",
       "      <!-- 3 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 49.642728) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-33\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_9\">\n",
       "     <g id=\"line2d_15\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m2def10dbaa\" x=\"38.312875\" y=\"15.658459\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_16\">\n",
       "      <!-- 4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 18.807897) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-34\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_17\">\n",
       "     <!-- $y$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(13.9635 143.136) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-79\" d=\"M 1588 -325 \n",
       "Q 1188 -997 936 -1164 \n",
       "Q 684 -1331 294 -1331 \n",
       "L -159 -1331 \n",
       "L -63 -850 \n",
       "L 269 -850 \n",
       "Q 509 -850 678 -719 \n",
       "Q 847 -588 1056 -206 \n",
       "L 1234 128 \n",
       "L 459 3500 \n",
       "L 1069 3500 \n",
       "L 1650 819 \n",
       "L 3256 3500 \n",
       "L 3859 3500 \n",
       "L 1588 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_1\">\n",
       "    <defs>\n",
       "     <path id=\"m1aa946eb1b\" d=\"M 54.545602 -267.999748 \n",
       "L 54.545602 -62.312144 \n",
       "L 57.824941 -65.392955 \n",
       "L 61.10428 -68.858777 \n",
       "L 64.383619 -72.716631 \n",
       "L 67.662958 -76.966449 \n",
       "L 70.942296 -81.600234 \n",
       "L 74.221636 -86.601408 \n",
       "L 77.500973 -91.944467 \n",
       "L 80.780313 -97.594537 \n",
       "L 84.059653 -103.507845 \n",
       "L 87.33899 -109.631479 \n",
       "L 90.61833 -115.90428 \n",
       "L 93.89767 -122.2576 \n",
       "L 97.177007 -128.61607 \n",
       "L 100.456344 -134.900104 \n",
       "L 103.735686 -141.025991 \n",
       "L 107.015024 -146.908285 \n",
       "L 110.294361 -152.462431 \n",
       "L 113.573703 -157.601138 \n",
       "L 116.853041 -154.949963 \n",
       "L 120.132378 -150.927324 \n",
       "L 123.41172 -147.637734 \n",
       "L 126.691057 -145.134613 \n",
       "L 129.970395 -143.460186 \n",
       "L 133.249737 -142.642115 \n",
       "L 136.529069 -142.695406 \n",
       "L 139.808412 -143.619991 \n",
       "L 143.087754 -145.401707 \n",
       "L 146.367086 -148.012531 \n",
       "L 149.646428 -151.411246 \n",
       "L 152.92577 -155.543619 \n",
       "L 156.205103 -160.346132 \n",
       "L 159.484445 -158.921957 \n",
       "L 162.763787 -153.949585 \n",
       "L 166.04312 -148.556985 \n",
       "L 169.322462 -142.826614 \n",
       "L 172.601804 -136.842098 \n",
       "L 175.881137 -130.687724 \n",
       "L 179.160479 -124.445729 \n",
       "L 182.439821 -118.194924 \n",
       "L 185.719153 -112.009397 \n",
       "L 188.998496 -105.956736 \n",
       "L 192.277838 -100.097337 \n",
       "L 195.55717 -94.483341 \n",
       "L 198.836512 -89.158227 \n",
       "L 202.115855 -84.15648 \n",
       "L 205.395187 -79.50364 \n",
       "L 208.674529 -75.216482 \n",
       "L 211.953871 -71.303558 \n",
       "L 215.233204 -67.765801 \n",
       "L 218.512556 -64.597358 \n",
       "L 221.791879 -61.786652 \n",
       "L 225.071221 -59.317221 \n",
       "L 228.350563 -57.16904 \n",
       "L 231.629886 -55.319496 \n",
       "L 234.909247 -53.74452 \n",
       "L 238.18857 -52.419688 \n",
       "L 241.467912 -51.321132 \n",
       "L 244.747254 -50.426516 \n",
       "L 248.026597 -49.715734 \n",
       "L 251.305939 -49.171687 \n",
       "L 254.585262 -48.780721 \n",
       "L 257.864623 -48.533127 \n",
       "L 261.143946 -48.423375 \n",
       "L 264.423288 -48.450304 \n",
       "L 267.70263 -48.617141 \n",
       "L 270.981953 -48.931414 \n",
       "L 274.261315 -49.404784 \n",
       "L 277.540637 -50.052665 \n",
       "L 280.81998 -50.893872 \n",
       "L 284.099322 -51.95012 \n",
       "L 287.378664 -53.245339 \n",
       "L 290.658006 -54.805105 \n",
       "L 293.937329 -56.655781 \n",
       "L 297.21669 -58.823877 \n",
       "L 300.496013 -61.334962 \n",
       "L 303.775355 -64.213179 \n",
       "L 307.054697 -67.479993 \n",
       "L 310.33402 -71.153696 \n",
       "L 313.613382 -75.248491 \n",
       "L 316.892705 -79.773774 \n",
       "L 320.172047 -84.733632 \n",
       "L 323.451389 -90.126314 \n",
       "L 326.730731 -95.943751 \n",
       "L 330.010073 -102.171509 \n",
       "L 333.289396 -108.78871 \n",
       "L 336.568738 -115.768066 \n",
       "L 339.84808 -123.076443 \n",
       "L 343.127423 -130.674359 \n",
       "L 346.406765 -138.517869 \n",
       "L 349.686088 -146.559343 \n",
       "L 352.96543 -154.746783 \n",
       "L 356.244772 -163.020004 \n",
       "L 359.524114 -155.274058 \n",
       "L 362.803456 -147.07923 \n",
       "L 366.082798 -139.027599 \n",
       "L 369.362141 -131.170007 \n",
       "L 372.641463 -123.55498 \n",
       "L 375.920806 -116.227409 \n",
       "L 379.200148 -109.225998 \n",
       "L 379.200148 -218.885848 \n",
       "L 379.200148 -218.885848 \n",
       "L 375.920806 -211.492362 \n",
       "L 372.641463 -203.824257 \n",
       "L 369.362141 -195.924604 \n",
       "L 366.082798 -187.842064 \n",
       "L 362.803456 -179.628146 \n",
       "L 359.524114 -171.335858 \n",
       "L 356.244772 -163.558616 \n",
       "L 352.96543 -171.867087 \n",
       "L 349.686088 -180.155864 \n",
       "L 346.406765 -188.363352 \n",
       "L 343.127423 -196.43529 \n",
       "L 339.84808 -204.320997 \n",
       "L 336.568738 -211.9727 \n",
       "L 333.289396 -219.346433 \n",
       "L 330.010073 -226.40398 \n",
       "L 326.730731 -233.112533 \n",
       "L 323.451389 -239.445316 \n",
       "L 320.172047 -245.381767 \n",
       "L 316.892705 -250.907521 \n",
       "L 313.613382 -256.01455 \n",
       "L 310.33402 -260.700737 \n",
       "L 307.054697 -264.969435 \n",
       "L 303.775355 -268.829096 \n",
       "L 300.496013 -272.292573 \n",
       "L 297.21669 -275.376318 \n",
       "L 293.937329 -278.099871 \n",
       "L 290.658006 -280.484671 \n",
       "L 287.378664 -282.553608 \n",
       "L 284.099322 -284.329887 \n",
       "L 280.81998 -285.836376 \n",
       "L 277.540637 -287.094785 \n",
       "L 274.261315 -288.124979 \n",
       "L 270.981953 -288.9443 \n",
       "L 267.70263 -289.567017 \n",
       "L 264.423288 -290.003908 \n",
       "L 261.143946 -290.261794 \n",
       "L 257.864623 -290.343375 \n",
       "L 254.585262 -290.247047 \n",
       "L 251.305939 -289.966914 \n",
       "L 248.026597 -289.492839 \n",
       "L 244.747254 -288.810773 \n",
       "L 241.467912 -287.90313 \n",
       "L 238.18857 -286.749216 \n",
       "L 234.909247 -285.32605 \n",
       "L 231.629886 -283.608996 \n",
       "L 228.350563 -281.572795 \n",
       "L 225.071221 -279.192466 \n",
       "L 221.791879 -276.444483 \n",
       "L 218.512556 -273.307895 \n",
       "L 215.233204 -269.765403 \n",
       "L 211.953871 -265.804708 \n",
       "L 208.674529 -261.419444 \n",
       "L 205.395187 -256.610279 \n",
       "L 202.115855 -251.385853 \n",
       "L 198.836512 -245.763425 \n",
       "L 195.55717 -239.769565 \n",
       "L 192.277838 -233.440289 \n",
       "L 188.998496 -226.821264 \n",
       "L 185.719153 -219.967514 \n",
       "L 182.439821 -212.943037 \n",
       "L 179.160479 -205.819774 \n",
       "L 175.881137 -198.676946 \n",
       "L 172.601804 -191.599264 \n",
       "L 169.322462 -184.675609 \n",
       "L 166.04312 -177.997609 \n",
       "L 162.763787 -171.65686 \n",
       "L 159.484445 -165.744344 \n",
       "L 156.205103 -163.39698 \n",
       "L 152.92577 -167.302535 \n",
       "L 149.646428 -170.573609 \n",
       "L 146.367086 -173.156137 \n",
       "L 143.087754 -175.005192 \n",
       "L 139.808412 -176.08853 \n",
       "L 136.529069 -176.386615 \n",
       "L 133.249737 -175.893108 \n",
       "L 129.970395 -174.61493 \n",
       "L 126.691057 -172.573134 \n",
       "L 123.41172 -169.800289 \n",
       "L 120.132378 -166.342356 \n",
       "L 116.853041 -162.255169 \n",
       "L 113.573703 -159.644318 \n",
       "L 110.294361 -164.927898 \n",
       "L 107.015024 -170.729807 \n",
       "L 103.735686 -176.959709 \n",
       "L 100.456344 -183.528746 \n",
       "L 97.177007 -190.345977 \n",
       "L 93.89767 -197.321098 \n",
       "L 90.61833 -204.367029 \n",
       "L 87.33899 -211.400095 \n",
       "L 84.059653 -218.342726 \n",
       "L 80.780313 -225.124416 \n",
       "L 77.500973 -231.682603 \n",
       "L 74.221636 -237.963844 \n",
       "L 70.942296 -243.923636 \n",
       "L 67.662958 -249.527082 \n",
       "L 64.383619 -254.748664 \n",
       "L 61.10428 -259.5719 \n",
       "L 57.824941 -263.988945 \n",
       "L 54.545602 -267.999748 \n",
       "z\n",
       "\" style=\"stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pf9371554da)\">\n",
       "     <use xlink:href=\"#m1aa946eb1b\" x=\"0\" y=\"309.639375\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_2\">\n",
       "    <defs>\n",
       "     <path id=\"m27f68196ac\" d=\"M 54.545602 -62.312144 \n",
       "L 54.545602 -62.312144 \n",
       "L 57.824941 -65.392955 \n",
       "L 61.10428 -68.858777 \n",
       "L 64.383619 -72.716631 \n",
       "L 67.662958 -76.966449 \n",
       "L 70.942296 -81.600234 \n",
       "L 74.221636 -86.601408 \n",
       "L 77.500973 -91.944467 \n",
       "L 80.780313 -97.594537 \n",
       "L 84.059653 -103.507845 \n",
       "L 87.33899 -109.631479 \n",
       "L 90.61833 -115.90428 \n",
       "L 93.89767 -122.2576 \n",
       "L 97.177007 -128.61607 \n",
       "L 100.456344 -134.900104 \n",
       "L 103.735686 -141.025991 \n",
       "L 107.015024 -146.908285 \n",
       "L 110.294361 -152.462431 \n",
       "L 113.573703 -157.601138 \n",
       "L 116.853041 -154.949963 \n",
       "L 120.132378 -150.927324 \n",
       "L 123.41172 -147.637734 \n",
       "L 126.691057 -145.134613 \n",
       "L 129.970395 -143.460186 \n",
       "L 133.249737 -142.642115 \n",
       "L 136.529069 -142.695406 \n",
       "L 139.808412 -143.619991 \n",
       "L 143.087754 -145.401707 \n",
       "L 146.367086 -148.012531 \n",
       "L 149.646428 -151.411246 \n",
       "L 152.92577 -155.543619 \n",
       "L 156.205103 -160.346132 \n",
       "L 159.484445 -158.921957 \n",
       "L 162.763787 -153.949585 \n",
       "L 166.04312 -148.556985 \n",
       "L 169.322462 -142.826614 \n",
       "L 172.601804 -136.842098 \n",
       "L 175.881137 -130.687724 \n",
       "L 179.160479 -124.445729 \n",
       "L 182.439821 -118.194924 \n",
       "L 185.719153 -112.009397 \n",
       "L 188.998496 -105.956736 \n",
       "L 192.277838 -100.097337 \n",
       "L 195.55717 -94.483341 \n",
       "L 198.836512 -89.158227 \n",
       "L 202.115855 -84.15648 \n",
       "L 205.395187 -79.50364 \n",
       "L 208.674529 -75.216482 \n",
       "L 211.953871 -71.303558 \n",
       "L 215.233204 -67.765801 \n",
       "L 218.512556 -64.597358 \n",
       "L 221.791879 -61.786652 \n",
       "L 225.071221 -59.317221 \n",
       "L 228.350563 -57.16904 \n",
       "L 231.629886 -55.319496 \n",
       "L 234.909247 -53.74452 \n",
       "L 238.18857 -52.419688 \n",
       "L 241.467912 -51.321132 \n",
       "L 244.747254 -50.426516 \n",
       "L 248.026597 -49.715734 \n",
       "L 251.305939 -49.171687 \n",
       "L 254.585262 -48.780721 \n",
       "L 257.864623 -48.533127 \n",
       "L 261.143946 -48.423375 \n",
       "L 264.423288 -48.450304 \n",
       "L 267.70263 -48.617141 \n",
       "L 270.981953 -48.931414 \n",
       "L 274.261315 -49.404784 \n",
       "L 277.540637 -50.052665 \n",
       "L 280.81998 -50.893872 \n",
       "L 284.099322 -51.95012 \n",
       "L 287.378664 -53.245339 \n",
       "L 290.658006 -54.805105 \n",
       "L 293.937329 -56.655781 \n",
       "L 297.21669 -58.823877 \n",
       "L 300.496013 -61.334962 \n",
       "L 303.775355 -64.213179 \n",
       "L 307.054697 -67.479993 \n",
       "L 310.33402 -71.153696 \n",
       "L 313.613382 -75.248491 \n",
       "L 316.892705 -79.773774 \n",
       "L 320.172047 -84.733632 \n",
       "L 323.451389 -90.126314 \n",
       "L 326.730731 -95.943751 \n",
       "L 330.010073 -102.171509 \n",
       "L 333.289396 -108.78871 \n",
       "L 336.568738 -115.768066 \n",
       "L 339.84808 -123.076443 \n",
       "L 343.127423 -130.674359 \n",
       "L 346.406765 -138.517869 \n",
       "L 349.686088 -146.559343 \n",
       "L 352.96543 -154.746783 \n",
       "L 356.244772 -163.020004 \n",
       "L 359.524114 -155.274058 \n",
       "L 362.803456 -147.07923 \n",
       "L 366.082798 -139.027599 \n",
       "L 369.362141 -131.170007 \n",
       "L 372.641463 -123.55498 \n",
       "L 375.920806 -116.227409 \n",
       "L 379.200148 -109.225998 \n",
       "L 379.200148 -109.225998 \n",
       "L 379.200148 -109.225998 \n",
       "L 375.920806 -116.227409 \n",
       "L 372.641463 -123.55498 \n",
       "L 369.362141 -131.170007 \n",
       "L 366.082798 -139.027599 \n",
       "L 362.803456 -147.07923 \n",
       "L 359.524114 -155.274058 \n",
       "L 356.244772 -163.020004 \n",
       "L 352.96543 -154.746783 \n",
       "L 349.686088 -146.559343 \n",
       "L 346.406765 -138.517869 \n",
       "L 343.127423 -130.674359 \n",
       "L 339.84808 -123.076443 \n",
       "L 336.568738 -115.768066 \n",
       "L 333.289396 -108.78871 \n",
       "L 330.010073 -102.171509 \n",
       "L 326.730731 -95.943751 \n",
       "L 323.451389 -90.126314 \n",
       "L 320.172047 -84.733632 \n",
       "L 316.892705 -79.773774 \n",
       "L 313.613382 -75.248491 \n",
       "L 310.33402 -71.153696 \n",
       "L 307.054697 -67.479993 \n",
       "L 303.775355 -64.213179 \n",
       "L 300.496013 -61.334962 \n",
       "L 297.21669 -58.823877 \n",
       "L 293.937329 -56.655781 \n",
       "L 290.658006 -54.805105 \n",
       "L 287.378664 -53.245339 \n",
       "L 284.099322 -51.95012 \n",
       "L 280.81998 -50.893872 \n",
       "L 277.540637 -50.052665 \n",
       "L 274.261315 -49.404784 \n",
       "L 270.981953 -48.931414 \n",
       "L 267.70263 -48.617141 \n",
       "L 264.423288 -48.450304 \n",
       "L 261.143946 -48.423375 \n",
       "L 257.864623 -48.533127 \n",
       "L 254.585262 -48.780721 \n",
       "L 251.305939 -49.171687 \n",
       "L 248.026597 -49.715734 \n",
       "L 244.747254 -50.426516 \n",
       "L 241.467912 -51.321132 \n",
       "L 238.18857 -52.419688 \n",
       "L 234.909247 -53.74452 \n",
       "L 231.629886 -55.319496 \n",
       "L 228.350563 -57.16904 \n",
       "L 225.071221 -59.317221 \n",
       "L 221.791879 -61.786652 \n",
       "L 218.512556 -64.597358 \n",
       "L 215.233204 -67.765801 \n",
       "L 211.953871 -71.303558 \n",
       "L 208.674529 -75.216482 \n",
       "L 205.395187 -79.50364 \n",
       "L 202.115855 -84.15648 \n",
       "L 198.836512 -89.158227 \n",
       "L 195.55717 -94.483341 \n",
       "L 192.277838 -100.097337 \n",
       "L 188.998496 -105.956736 \n",
       "L 185.719153 -112.009397 \n",
       "L 182.439821 -118.194924 \n",
       "L 179.160479 -124.445729 \n",
       "L 175.881137 -130.687724 \n",
       "L 172.601804 -136.842098 \n",
       "L 169.322462 -142.826614 \n",
       "L 166.04312 -148.556985 \n",
       "L 162.763787 -153.949585 \n",
       "L 159.484445 -158.921957 \n",
       "L 156.205103 -160.346132 \n",
       "L 152.92577 -155.543619 \n",
       "L 149.646428 -151.411246 \n",
       "L 146.367086 -148.012531 \n",
       "L 143.087754 -145.401707 \n",
       "L 139.808412 -143.619991 \n",
       "L 136.529069 -142.695406 \n",
       "L 133.249737 -142.642115 \n",
       "L 129.970395 -143.460186 \n",
       "L 126.691057 -145.134613 \n",
       "L 123.41172 -147.637734 \n",
       "L 120.132378 -150.927324 \n",
       "L 116.853041 -154.949963 \n",
       "L 113.573703 -157.601138 \n",
       "L 110.294361 -152.462431 \n",
       "L 107.015024 -146.908285 \n",
       "L 103.735686 -141.025991 \n",
       "L 100.456344 -134.900104 \n",
       "L 97.177007 -128.61607 \n",
       "L 93.89767 -122.2576 \n",
       "L 90.61833 -115.90428 \n",
       "L 87.33899 -109.631479 \n",
       "L 84.059653 -103.507845 \n",
       "L 80.780313 -97.594537 \n",
       "L 77.500973 -91.944467 \n",
       "L 74.221636 -86.601408 \n",
       "L 70.942296 -81.600234 \n",
       "L 67.662958 -76.966449 \n",
       "L 64.383619 -72.716631 \n",
       "L 61.10428 -68.858777 \n",
       "L 57.824941 -65.392955 \n",
       "L 54.545602 -62.312144 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pf9371554da)\">\n",
       "     <use xlink:href=\"#m27f68196ac\" x=\"0\" y=\"309.639375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_3\">\n",
       "    <defs>\n",
       "     <path id=\"m65a757ae21\" d=\"M 54.545602 -267.999748 \n",
       "L 54.545602 -267.999748 \n",
       "L 57.824941 -263.988945 \n",
       "L 61.10428 -259.5719 \n",
       "L 64.383619 -254.748664 \n",
       "L 67.662958 -249.527082 \n",
       "L 70.942296 -243.923636 \n",
       "L 74.221636 -237.963844 \n",
       "L 77.500973 -231.682603 \n",
       "L 80.780313 -225.124416 \n",
       "L 84.059653 -218.342726 \n",
       "L 87.33899 -211.400095 \n",
       "L 90.61833 -204.367029 \n",
       "L 93.89767 -197.321098 \n",
       "L 97.177007 -190.345977 \n",
       "L 100.456344 -183.528746 \n",
       "L 103.735686 -176.959709 \n",
       "L 107.015024 -170.729807 \n",
       "L 110.294361 -164.927898 \n",
       "L 113.573703 -159.644318 \n",
       "L 116.853041 -162.255169 \n",
       "L 120.132378 -166.342356 \n",
       "L 123.41172 -169.800289 \n",
       "L 126.691057 -172.573134 \n",
       "L 129.970395 -174.61493 \n",
       "L 133.249737 -175.893108 \n",
       "L 136.529069 -176.386615 \n",
       "L 139.808412 -176.08853 \n",
       "L 143.087754 -175.005192 \n",
       "L 146.367086 -173.156137 \n",
       "L 149.646428 -170.573609 \n",
       "L 152.92577 -167.302535 \n",
       "L 156.205103 -163.39698 \n",
       "L 159.484445 -165.744344 \n",
       "L 162.763787 -171.65686 \n",
       "L 166.04312 -177.997609 \n",
       "L 169.322462 -184.675609 \n",
       "L 172.601804 -191.599264 \n",
       "L 175.881137 -198.676946 \n",
       "L 179.160479 -205.819774 \n",
       "L 182.439821 -212.943037 \n",
       "L 185.719153 -219.967514 \n",
       "L 188.998496 -226.821264 \n",
       "L 192.277838 -233.440289 \n",
       "L 195.55717 -239.769565 \n",
       "L 198.836512 -245.763425 \n",
       "L 202.115855 -251.385853 \n",
       "L 205.395187 -256.610279 \n",
       "L 208.674529 -261.419444 \n",
       "L 211.953871 -265.804708 \n",
       "L 215.233204 -269.765403 \n",
       "L 218.512556 -273.307895 \n",
       "L 221.791879 -276.444483 \n",
       "L 225.071221 -279.192466 \n",
       "L 228.350563 -281.572795 \n",
       "L 231.629886 -283.608996 \n",
       "L 234.909247 -285.32605 \n",
       "L 238.18857 -286.749216 \n",
       "L 241.467912 -287.90313 \n",
       "L 244.747254 -288.810773 \n",
       "L 248.026597 -289.492839 \n",
       "L 251.305939 -289.966914 \n",
       "L 254.585262 -290.247047 \n",
       "L 257.864623 -290.343375 \n",
       "L 261.143946 -290.261794 \n",
       "L 264.423288 -290.003908 \n",
       "L 267.70263 -289.567017 \n",
       "L 270.981953 -288.9443 \n",
       "L 274.261315 -288.124979 \n",
       "L 277.540637 -287.094785 \n",
       "L 280.81998 -285.836376 \n",
       "L 284.099322 -284.329887 \n",
       "L 287.378664 -282.553608 \n",
       "L 290.658006 -280.484671 \n",
       "L 293.937329 -278.099871 \n",
       "L 297.21669 -275.376318 \n",
       "L 300.496013 -272.292573 \n",
       "L 303.775355 -268.829096 \n",
       "L 307.054697 -264.969435 \n",
       "L 310.33402 -260.700737 \n",
       "L 313.613382 -256.01455 \n",
       "L 316.892705 -250.907521 \n",
       "L 320.172047 -245.381767 \n",
       "L 323.451389 -239.445316 \n",
       "L 326.730731 -233.112533 \n",
       "L 330.010073 -226.40398 \n",
       "L 333.289396 -219.346433 \n",
       "L 336.568738 -211.9727 \n",
       "L 339.84808 -204.320997 \n",
       "L 343.127423 -196.43529 \n",
       "L 346.406765 -188.363352 \n",
       "L 349.686088 -180.155864 \n",
       "L 352.96543 -171.867087 \n",
       "L 356.244772 -163.558616 \n",
       "L 359.524114 -171.335858 \n",
       "L 362.803456 -179.628146 \n",
       "L 366.082798 -187.842064 \n",
       "L 369.362141 -195.924604 \n",
       "L 372.641463 -203.824257 \n",
       "L 375.920806 -211.492362 \n",
       "L 379.200148 -218.885848 \n",
       "L 379.200148 -218.885848 \n",
       "L 379.200148 -218.885848 \n",
       "L 375.920806 -211.492362 \n",
       "L 372.641463 -203.824257 \n",
       "L 369.362141 -195.924604 \n",
       "L 366.082798 -187.842064 \n",
       "L 362.803456 -179.628146 \n",
       "L 359.524114 -171.335858 \n",
       "L 356.244772 -163.558616 \n",
       "L 352.96543 -171.867087 \n",
       "L 349.686088 -180.155864 \n",
       "L 346.406765 -188.363352 \n",
       "L 343.127423 -196.43529 \n",
       "L 339.84808 -204.320997 \n",
       "L 336.568738 -211.9727 \n",
       "L 333.289396 -219.346433 \n",
       "L 330.010073 -226.40398 \n",
       "L 326.730731 -233.112533 \n",
       "L 323.451389 -239.445316 \n",
       "L 320.172047 -245.381767 \n",
       "L 316.892705 -250.907521 \n",
       "L 313.613382 -256.01455 \n",
       "L 310.33402 -260.700737 \n",
       "L 307.054697 -264.969435 \n",
       "L 303.775355 -268.829096 \n",
       "L 300.496013 -272.292573 \n",
       "L 297.21669 -275.376318 \n",
       "L 293.937329 -278.099871 \n",
       "L 290.658006 -280.484671 \n",
       "L 287.378664 -282.553608 \n",
       "L 284.099322 -284.329887 \n",
       "L 280.81998 -285.836376 \n",
       "L 277.540637 -287.094785 \n",
       "L 274.261315 -288.124979 \n",
       "L 270.981953 -288.9443 \n",
       "L 267.70263 -289.567017 \n",
       "L 264.423288 -290.003908 \n",
       "L 261.143946 -290.261794 \n",
       "L 257.864623 -290.343375 \n",
       "L 254.585262 -290.247047 \n",
       "L 251.305939 -289.966914 \n",
       "L 248.026597 -289.492839 \n",
       "L 244.747254 -288.810773 \n",
       "L 241.467912 -287.90313 \n",
       "L 238.18857 -286.749216 \n",
       "L 234.909247 -285.32605 \n",
       "L 231.629886 -283.608996 \n",
       "L 228.350563 -281.572795 \n",
       "L 225.071221 -279.192466 \n",
       "L 221.791879 -276.444483 \n",
       "L 218.512556 -273.307895 \n",
       "L 215.233204 -269.765403 \n",
       "L 211.953871 -265.804708 \n",
       "L 208.674529 -261.419444 \n",
       "L 205.395187 -256.610279 \n",
       "L 202.115855 -251.385853 \n",
       "L 198.836512 -245.763425 \n",
       "L 195.55717 -239.769565 \n",
       "L 192.277838 -233.440289 \n",
       "L 188.998496 -226.821264 \n",
       "L 185.719153 -219.967514 \n",
       "L 182.439821 -212.943037 \n",
       "L 179.160479 -205.819774 \n",
       "L 175.881137 -198.676946 \n",
       "L 172.601804 -191.599264 \n",
       "L 169.322462 -184.675609 \n",
       "L 166.04312 -177.997609 \n",
       "L 162.763787 -171.65686 \n",
       "L 159.484445 -165.744344 \n",
       "L 156.205103 -163.39698 \n",
       "L 152.92577 -167.302535 \n",
       "L 149.646428 -170.573609 \n",
       "L 146.367086 -173.156137 \n",
       "L 143.087754 -175.005192 \n",
       "L 139.808412 -176.08853 \n",
       "L 136.529069 -176.386615 \n",
       "L 133.249737 -175.893108 \n",
       "L 129.970395 -174.61493 \n",
       "L 126.691057 -172.573134 \n",
       "L 123.41172 -169.800289 \n",
       "L 120.132378 -166.342356 \n",
       "L 116.853041 -162.255169 \n",
       "L 113.573703 -159.644318 \n",
       "L 110.294361 -164.927898 \n",
       "L 107.015024 -170.729807 \n",
       "L 103.735686 -176.959709 \n",
       "L 100.456344 -183.528746 \n",
       "L 97.177007 -190.345977 \n",
       "L 93.89767 -197.321098 \n",
       "L 90.61833 -204.367029 \n",
       "L 87.33899 -211.400095 \n",
       "L 84.059653 -218.342726 \n",
       "L 80.780313 -225.124416 \n",
       "L 77.500973 -231.682603 \n",
       "L 74.221636 -237.963844 \n",
       "L 70.942296 -243.923636 \n",
       "L 67.662958 -249.527082 \n",
       "L 64.383619 -254.748664 \n",
       "L 61.10428 -259.5719 \n",
       "L 57.824941 -263.988945 \n",
       "L 54.545602 -267.999748 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pf9371554da)\">\n",
       "     <use xlink:href=\"#m65a757ae21\" x=\"0\" y=\"309.639375\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_16\">\n",
       "    <defs>\n",
       "     <path id=\"ma2b79fadc2\" d=\"M -5 5 \n",
       "L 5 -5 \n",
       "M -5 -5 \n",
       "L 5 5 \n",
       "\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pf9371554da)\">\n",
       "     <use xlink:href=\"#ma2b79fadc2\" x=\"356.349693\" y=\"146.35008\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#ma2b79fadc2\" x=\"157.258364\" y=\"147.620769\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#ma2b79fadc2\" x=\"114.255683\" y=\"151.025163\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_17\">\n",
       "    <path d=\"M 54.545602 144.483429 \n",
       "L 57.824941 144.948424 \n",
       "L 61.10428 145.424035 \n",
       "L 64.383619 145.90673 \n",
       "L 67.662958 146.392608 \n",
       "L 70.942296 146.877443 \n",
       "L 74.221636 147.356747 \n",
       "L 77.500973 147.825838 \n",
       "L 80.780313 148.279899 \n",
       "L 84.059653 148.714087 \n",
       "L 87.33899 149.123587 \n",
       "L 90.61833 149.503721 \n",
       "L 93.89767 149.850027 \n",
       "L 97.177007 150.158353 \n",
       "L 100.456344 150.424949 \n",
       "L 103.735686 150.646525 \n",
       "L 107.015024 150.820329 \n",
       "L 110.294361 150.944211 \n",
       "L 113.573703 151.016647 \n",
       "L 116.853041 151.036809 \n",
       "L 120.132378 151.004535 \n",
       "L 123.41172 150.920363 \n",
       "L 126.691057 150.785502 \n",
       "L 129.970395 150.601817 \n",
       "L 133.249737 150.371763 \n",
       "L 136.529069 150.098365 \n",
       "L 139.808412 149.785115 \n",
       "L 143.087754 149.435925 \n",
       "L 146.367086 149.055041 \n",
       "L 149.646428 148.646948 \n",
       "L 152.92577 148.216298 \n",
       "L 156.205103 147.767819 \n",
       "L 159.484445 147.306224 \n",
       "L 162.763787 146.836152 \n",
       "L 166.04312 146.362078 \n",
       "L 169.322462 145.888263 \n",
       "L 172.601804 145.418693 \n",
       "L 175.881137 144.95704 \n",
       "L 179.160479 144.506623 \n",
       "L 182.439821 144.070393 \n",
       "L 185.719153 143.650919 \n",
       "L 188.998496 143.250375 \n",
       "L 192.277838 142.870564 \n",
       "L 195.55717 142.512924 \n",
       "L 198.836512 142.178546 \n",
       "L 202.115855 141.86821 \n",
       "L 205.395187 141.582415 \n",
       "L 208.674529 141.32141 \n",
       "L 211.953871 141.085238 \n",
       "L 215.233204 140.873772 \n",
       "L 218.512556 140.686748 \n",
       "L 221.791879 140.52381 \n",
       "L 225.071221 140.384532 \n",
       "L 228.350563 140.268459 \n",
       "L 231.629886 140.175129 \n",
       "L 234.909247 140.104089 \n",
       "L 238.18857 140.054921 \n",
       "L 241.467912 140.027245 \n",
       "L 244.747254 140.020729 \n",
       "L 248.026597 140.035088 \n",
       "L 251.305939 140.070078 \n",
       "L 254.585262 140.125488 \n",
       "L 257.864623 140.201125 \n",
       "L 261.143946 140.296792 \n",
       "L 264.423288 140.41227 \n",
       "L 267.70263 140.547294 \n",
       "L 270.981953 140.701517 \n",
       "L 274.261315 140.874497 \n",
       "L 277.540637 141.065652 \n",
       "L 280.81998 141.27425 \n",
       "L 284.099322 141.499375 \n",
       "L 287.378664 141.739901 \n",
       "L 290.658006 141.994487 \n",
       "L 293.937329 142.26155 \n",
       "L 297.21669 142.539281 \n",
       "L 300.496013 142.825605 \n",
       "L 303.775355 143.118238 \n",
       "L 307.054697 143.41466 \n",
       "L 310.33402 143.712159 \n",
       "L 313.613382 144.007853 \n",
       "L 316.892705 144.298726 \n",
       "L 320.172047 144.581676 \n",
       "L 323.451389 144.853558 \n",
       "L 326.730731 145.111232 \n",
       "L 330.010073 145.351631 \n",
       "L 333.289396 145.571805 \n",
       "L 336.568738 145.76899 \n",
       "L 339.84808 145.940657 \n",
       "L 343.127423 146.08455 \n",
       "L 346.406765 146.198764 \n",
       "L 349.686088 146.281772 \n",
       "L 352.96543 146.33244 \n",
       "L 356.244772 146.350065 \n",
       "L 359.524114 146.334416 \n",
       "L 362.803456 146.285687 \n",
       "L 366.082798 146.204544 \n",
       "L 369.362141 146.092071 \n",
       "L 372.641463 145.949758 \n",
       "L 375.920806 145.779488 \n",
       "L 379.200148 145.583452 \n",
       "\" clip-path=\"url(#pf9371554da)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 38.312875 262.337111 \n",
       "L 38.312875 15.658459 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 54.545602 273.312 \n",
       "L 379.200148 273.312 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"legend_1\">\n",
       "    <g id=\"line2d_18\">\n",
       "     <g>\n",
       "      <use xlink:href=\"#ma2b79fadc2\" x=\"307.608875\" y=\"18.338875\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_18\">\n",
       "     <!-- Observations -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(323.448875 21.418875) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4f\" d=\"M 309 2231 \n",
       "Q 309 3372 921 4017 \n",
       "Q 1534 4663 2503 4663 \n",
       "Q 3138 4663 3647 4359 \n",
       "Q 4156 4056 4423 3514 \n",
       "Q 4691 2972 4691 2284 \n",
       "Q 4691 1588 4409 1038 \n",
       "Q 4128 488 3612 205 \n",
       "Q 3097 -78 2500 -78 \n",
       "Q 1853 -78 1343 234 \n",
       "Q 834 547 571 1087 \n",
       "Q 309 1628 309 2231 \n",
       "z\n",
       "M 934 2222 \n",
       "Q 934 1394 1379 917 \n",
       "Q 1825 441 2497 441 \n",
       "Q 3181 441 3623 922 \n",
       "Q 4066 1403 4066 2288 \n",
       "Q 4066 2847 3877 3264 \n",
       "Q 3688 3681 3323 3911 \n",
       "Q 2959 4141 2506 4141 \n",
       "Q 1863 4141 1398 3698 \n",
       "Q 934 3256 934 2222 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-62\" d=\"M 941 0 \n",
       "L 419 0 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 2947 \n",
       "Q 1338 3394 1891 3394 \n",
       "Q 2197 3394 2470 3270 \n",
       "Q 2744 3147 2920 2923 \n",
       "Q 3097 2700 3197 2384 \n",
       "Q 3297 2069 3297 1709 \n",
       "Q 3297 856 2875 390 \n",
       "Q 2453 -75 1863 -75 \n",
       "Q 1275 -75 941 416 \n",
       "L 941 0 \n",
       "z\n",
       "M 934 1684 \n",
       "Q 934 1088 1097 822 \n",
       "Q 1363 388 1816 388 \n",
       "Q 2184 388 2453 708 \n",
       "Q 2722 1028 2722 1663 \n",
       "Q 2722 2313 2464 2622 \n",
       "Q 2206 2931 1841 2931 \n",
       "Q 1472 2931 1203 2611 \n",
       "Q 934 2291 934 1684 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-76\" d=\"M 1344 0 \n",
       "L 81 3319 \n",
       "L 675 3319 \n",
       "L 1388 1331 \n",
       "Q 1503 1009 1600 663 \n",
       "Q 1675 925 1809 1294 \n",
       "L 2547 3319 \n",
       "L 3125 3319 \n",
       "L 1869 0 \n",
       "L 1344 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4f\"/>\n",
       "      <use xlink:href=\"#ArialMT-62\" x=\"77.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"133.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"183.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"239.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"272.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"322.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"377.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"405.712891\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"427.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"483.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"539.160156\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_19\">\n",
       "     <path d=\"M 298.808875 30.922875 \n",
       "L 307.608875 30.922875 \n",
       "L 316.408875 30.922875 \n",
       "\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "    </g>\n",
       "    <g id=\"text_19\">\n",
       "     <!-- $m_n(x)$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(323.448875 34.002875) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-6d\" d=\"M 5747 2113 \n",
       "L 5338 0 \n",
       "L 4763 0 \n",
       "L 5166 2094 \n",
       "Q 5191 2228 5203 2325 \n",
       "Q 5216 2422 5216 2491 \n",
       "Q 5216 2772 5059 2928 \n",
       "Q 4903 3084 4622 3084 \n",
       "Q 4203 3084 3875 2770 \n",
       "Q 3547 2456 3450 1953 \n",
       "L 3066 0 \n",
       "L 2491 0 \n",
       "L 2900 2094 \n",
       "Q 2925 2209 2937 2307 \n",
       "Q 2950 2406 2950 2484 \n",
       "Q 2950 2769 2794 2926 \n",
       "Q 2638 3084 2363 3084 \n",
       "Q 1938 3084 1609 2770 \n",
       "Q 1281 2456 1184 1953 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 909 3500 \n",
       "L 1484 3500 \n",
       "L 1375 2956 \n",
       "Q 1609 3263 1923 3423 \n",
       "Q 2238 3584 2597 3584 \n",
       "Q 2978 3584 3223 3384 \n",
       "Q 3469 3184 3519 2828 \n",
       "Q 3781 3197 4126 3390 \n",
       "Q 4472 3584 4856 3584 \n",
       "Q 5306 3584 5551 3325 \n",
       "Q 5797 3066 5797 2591 \n",
       "Q 5797 2488 5784 2364 \n",
       "Q 5772 2241 5747 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Oblique-6e\" d=\"M 3566 2113 \n",
       "L 3156 0 \n",
       "L 2578 0 \n",
       "L 2988 2091 \n",
       "Q 3016 2238 3031 2350 \n",
       "Q 3047 2463 3047 2528 \n",
       "Q 3047 2791 2881 2937 \n",
       "Q 2716 3084 2419 3084 \n",
       "Q 1956 3084 1622 2776 \n",
       "Q 1288 2469 1184 1941 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 903 3500 \n",
       "L 1478 3500 \n",
       "L 1363 2950 \n",
       "Q 1603 3253 1940 3418 \n",
       "Q 2278 3584 2650 3584 \n",
       "Q 3113 3584 3367 3334 \n",
       "Q 3622 3084 3622 2631 \n",
       "Q 3622 2519 3608 2391 \n",
       "Q 3594 2263 3566 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-28\" d=\"M 1984 4856 \n",
       "Q 1566 4138 1362 3434 \n",
       "Q 1159 2731 1159 2009 \n",
       "Q 1159 1288 1364 580 \n",
       "Q 1569 -128 1984 -844 \n",
       "L 1484 -844 \n",
       "Q 1016 -109 783 600 \n",
       "Q 550 1309 550 2009 \n",
       "Q 550 2706 781 3412 \n",
       "Q 1013 4119 1484 4856 \n",
       "L 1984 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-29\" d=\"M 513 4856 \n",
       "L 1013 4856 \n",
       "Q 1481 4119 1714 3412 \n",
       "Q 1947 2706 1947 2009 \n",
       "Q 1947 1309 1714 600 \n",
       "Q 1481 -109 1013 -844 \n",
       "L 513 -844 \n",
       "Q 928 -128 1133 580 \n",
       "Q 1338 1288 1338 2009 \n",
       "Q 1338 2731 1133 3434 \n",
       "Q 928 4138 513 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6d\" transform=\"translate(0 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6e\" transform=\"translate(97.412109 -16.28125) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(144.511719 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(183.525391 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(242.705078 0.125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_5\">\n",
       "     <path d=\"M 298.808875 48.159875 \n",
       "L 316.408875 48.159875 \n",
       "L 316.408875 41.999875 \n",
       "L 298.808875 41.999875 \n",
       "z\n",
       "\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_20\">\n",
       "     <!-- $f(\\mathbf{x}^*)$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(323.448875 48.159875) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-66\" d=\"M 3059 4863 \n",
       "L 2969 4384 \n",
       "L 2419 4384 \n",
       "Q 2106 4384 1964 4261 \n",
       "Q 1822 4138 1753 3809 \n",
       "L 1691 3500 \n",
       "L 2638 3500 \n",
       "L 2553 3053 \n",
       "L 1606 3053 \n",
       "L 1013 0 \n",
       "L 434 0 \n",
       "L 1031 3053 \n",
       "L 481 3053 \n",
       "L 563 3500 \n",
       "L 1113 3500 \n",
       "L 1159 3744 \n",
       "Q 1278 4363 1576 4613 \n",
       "Q 1875 4863 2516 4863 \n",
       "L 3059 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Bold-78\" d=\"M 1422 1791 \n",
       "L 159 3500 \n",
       "L 1344 3500 \n",
       "L 2059 2463 \n",
       "L 2784 3500 \n",
       "L 3969 3500 \n",
       "L 2706 1797 \n",
       "L 4031 0 \n",
       "L 2847 0 \n",
       "L 2059 1106 \n",
       "L 1281 0 \n",
       "L 97 0 \n",
       "L 1422 1791 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-2a\" d=\"M 3009 3897 \n",
       "L 1888 3291 \n",
       "L 3009 2681 \n",
       "L 2828 2375 \n",
       "L 1778 3009 \n",
       "L 1778 1831 \n",
       "L 1422 1831 \n",
       "L 1422 3009 \n",
       "L 372 2375 \n",
       "L 191 2681 \n",
       "L 1313 3291 \n",
       "L 191 3897 \n",
       "L 372 4206 \n",
       "L 1422 3572 \n",
       "L 1422 4750 \n",
       "L 1778 4750 \n",
       "L 1778 3572 \n",
       "L 2828 4206 \n",
       "L 3009 3897 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-39\" d=\"M 350 1059 \n",
       "L 891 1109 \n",
       "Q 959 728 1153 556 \n",
       "Q 1347 384 1650 384 \n",
       "Q 1909 384 2104 503 \n",
       "Q 2300 622 2425 820 \n",
       "Q 2550 1019 2634 1356 \n",
       "Q 2719 1694 2719 2044 \n",
       "Q 2719 2081 2716 2156 \n",
       "Q 2547 1888 2255 1720 \n",
       "Q 1963 1553 1622 1553 \n",
       "Q 1053 1553 659 1965 \n",
       "Q 266 2378 266 3053 \n",
       "Q 266 3750 677 4175 \n",
       "Q 1088 4600 1706 4600 \n",
       "Q 2153 4600 2523 4359 \n",
       "Q 2894 4119 3086 3673 \n",
       "Q 3278 3228 3278 2384 \n",
       "Q 3278 1506 3087 986 \n",
       "Q 2897 466 2520 194 \n",
       "Q 2144 -78 1638 -78 \n",
       "Q 1100 -78 759 220 \n",
       "Q 419 519 350 1059 \n",
       "z\n",
       "M 2653 3081 \n",
       "Q 2653 3566 2395 3850 \n",
       "Q 2138 4134 1775 4134 \n",
       "Q 1400 4134 1122 3828 \n",
       "Q 844 3522 844 3034 \n",
       "Q 844 2597 1108 2323 \n",
       "Q 1372 2050 1759 2050 \n",
       "Q 2150 2050 2401 2323 \n",
       "Q 2653 2597 2653 3081 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-25\" d=\"M 372 3481 \n",
       "Q 372 3972 619 4315 \n",
       "Q 866 4659 1334 4659 \n",
       "Q 1766 4659 2048 4351 \n",
       "Q 2331 4044 2331 3447 \n",
       "Q 2331 2866 2045 2552 \n",
       "Q 1759 2238 1341 2238 \n",
       "Q 925 2238 648 2547 \n",
       "Q 372 2856 372 3481 \n",
       "z\n",
       "M 1350 4272 \n",
       "Q 1141 4272 1002 4090 \n",
       "Q 863 3909 863 3425 \n",
       "Q 863 2984 1003 2804 \n",
       "Q 1144 2625 1350 2625 \n",
       "Q 1563 2625 1702 2806 \n",
       "Q 1841 2988 1841 3469 \n",
       "Q 1841 3913 1700 4092 \n",
       "Q 1559 4272 1350 4272 \n",
       "z\n",
       "M 1353 -169 \n",
       "L 3859 4659 \n",
       "L 4316 4659 \n",
       "L 1819 -169 \n",
       "L 1353 -169 \n",
       "z\n",
       "M 3334 1075 \n",
       "Q 3334 1569 3581 1911 \n",
       "Q 3828 2253 4300 2253 \n",
       "Q 4731 2253 5014 1945 \n",
       "Q 5297 1638 5297 1041 \n",
       "Q 5297 459 5011 145 \n",
       "Q 4725 -169 4303 -169 \n",
       "Q 3888 -169 3611 142 \n",
       "Q 3334 453 3334 1075 \n",
       "z\n",
       "M 4316 1866 \n",
       "Q 4103 1866 3964 1684 \n",
       "Q 3825 1503 3825 1019 \n",
       "Q 3825 581 3965 400 \n",
       "Q 4106 219 4313 219 \n",
       "Q 4528 219 4667 400 \n",
       "Q 4806 581 4806 1063 \n",
       "Q 4806 1506 4665 1686 \n",
       "Q 4525 1866 4316 1866 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-66\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(35.205078 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Bold-78\" transform=\"translate(74.21875 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(153.31543 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(204.6875 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(243.701172 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(271.484375 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(327.099609 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(382.714844 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(471.630859 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(499.414062 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(555.029297 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(588.330078 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(643.945312 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(699.560547 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_6\">\n",
       "     <path d=\"M 298.808875 62.327875 \n",
       "L 316.408875 62.327875 \n",
       "L 316.408875 56.167875 \n",
       "L 298.808875 56.167875 \n",
       "z\n",
       "\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_21\">\n",
       "     <!-- $y^*$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(323.448875 62.327875) scale(0.088 -0.088)\">\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(77.283529 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(128.655599 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(156.438802 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(212.054036 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(267.669271 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(356.585286 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(384.36849 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(439.983724 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(473.284505 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(528.89974 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(584.514974 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"ytick_10\">\n",
       "     <g id=\"line2d_20\">\n",
       "      <defs>\n",
       "       <path id=\"md0919d378b\" d=\"M 0 0 \n",
       "L 4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#md0919d378b\" x=\"395.432875\" y=\"261.216\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_22\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 264.365437) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_11\">\n",
       "     <g id=\"line2d_21\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#md0919d378b\" x=\"395.432875\" y=\"206.613181\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_23\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 209.762619) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_12\">\n",
       "     <g id=\"line2d_22\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#md0919d378b\" x=\"395.432875\" y=\"152.010362\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_24\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 155.1598) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_13\">\n",
       "     <g id=\"line2d_23\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#md0919d378b\" x=\"395.432875\" y=\"97.407544\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_25\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 100.556981) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_14\">\n",
       "     <g id=\"line2d_24\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#md0919d378b\" x=\"395.432875\" y=\"42.804725\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_26\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 45.954162) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_27\">\n",
       "     <!-- Information Acquisition Function -->\n",
       "     <g style=\"fill: #ff7f0e\" transform=\"translate(426.953375 208.28925) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-49\" d=\"M 597 0 \n",
       "L 597 4581 \n",
       "L 1203 4581 \n",
       "L 1203 0 \n",
       "L 597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-66\" d=\"M 556 0 \n",
       "L 556 2881 \n",
       "L 59 2881 \n",
       "L 59 3319 \n",
       "L 556 3319 \n",
       "L 556 3672 \n",
       "Q 556 4006 616 4169 \n",
       "Q 697 4388 901 4523 \n",
       "Q 1106 4659 1475 4659 \n",
       "Q 1713 4659 2000 4603 \n",
       "L 1916 4113 \n",
       "Q 1741 4144 1584 4144 \n",
       "Q 1328 4144 1222 4034 \n",
       "Q 1116 3925 1116 3625 \n",
       "L 1116 3319 \n",
       "L 1763 3319 \n",
       "L 1763 2881 \n",
       "L 1116 2881 \n",
       "L 1116 0 \n",
       "L 556 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-41\" d=\"M -9 0 \n",
       "L 1750 4581 \n",
       "L 2403 4581 \n",
       "L 4278 0 \n",
       "L 3588 0 \n",
       "L 3053 1388 \n",
       "L 1138 1388 \n",
       "L 634 0 \n",
       "L -9 0 \n",
       "z\n",
       "M 1313 1881 \n",
       "L 2866 1881 \n",
       "L 2388 3150 \n",
       "Q 2169 3728 2063 4100 \n",
       "Q 1975 3659 1816 3225 \n",
       "L 1313 1881 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-71\" d=\"M 2538 -1272 \n",
       "L 2538 353 \n",
       "Q 2406 169 2170 47 \n",
       "Q 1934 -75 1669 -75 \n",
       "Q 1078 -75 651 397 \n",
       "Q 225 869 225 1691 \n",
       "Q 225 2191 398 2587 \n",
       "Q 572 2984 901 3189 \n",
       "Q 1231 3394 1625 3394 \n",
       "Q 2241 3394 2594 2875 \n",
       "L 2594 3319 \n",
       "L 3100 3319 \n",
       "L 3100 -1272 \n",
       "L 2538 -1272 \n",
       "z\n",
       "M 803 1669 \n",
       "Q 803 1028 1072 708 \n",
       "Q 1341 388 1716 388 \n",
       "Q 2075 388 2334 692 \n",
       "Q 2594 997 2594 1619 \n",
       "Q 2594 2281 2320 2615 \n",
       "Q 2047 2950 1678 2950 \n",
       "Q 1313 2950 1058 2639 \n",
       "Q 803 2328 803 1669 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-46\" d=\"M 525 0 \n",
       "L 525 4581 \n",
       "L 3616 4581 \n",
       "L 3616 4041 \n",
       "L 1131 4041 \n",
       "L 1131 2622 \n",
       "L 3281 2622 \n",
       "L 3281 2081 \n",
       "L 1131 2081 \n",
       "L 1131 0 \n",
       "L 525 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-49\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"27.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"83.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"111.181641\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"166.796875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6d\" x=\"200.097656\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"283.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"339.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"366.796875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"389.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"444.628906\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"500.244141\"/>\n",
       "      <use xlink:href=\"#ArialMT-41\" x=\"522.527344\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"589.226562\"/>\n",
       "      <use xlink:href=\"#ArialMT-71\" x=\"639.226562\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"694.841797\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"750.457031\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"772.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"822.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"844.890625\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"872.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"894.890625\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"950.505859\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"1006.121094\"/>\n",
       "      <use xlink:href=\"#ArialMT-46\" x=\"1033.904297\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"1094.988281\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"1150.603516\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"1206.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"1256.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"1284.001953\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"1306.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"1361.833984\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_25\">\n",
       "    <path d=\"M 54.545602 71.196699 \n",
       "L 57.824941 79.567402 \n",
       "L 61.10428 88.672175 \n",
       "L 64.383619 98.499189 \n",
       "L 67.662958 109.021626 \n",
       "L 70.942296 120.196134 \n",
       "L 74.221636 131.962114 \n",
       "L 77.500973 144.24104 \n",
       "L 80.780313 156.935739 \n",
       "L 84.059653 169.931072 \n",
       "L 87.33899 183.092478 \n",
       "L 90.61833 196.265877 \n",
       "L 93.89767 209.274789 \n",
       "L 97.177007 221.912358 \n",
       "L 100.456344 233.923378 \n",
       "L 103.735686 244.943176 \n",
       "L 107.015024 254.30709 \n",
       "L 110.294361 260.358577 \n",
       "L 113.573703 261.216 \n",
       "L 116.853041 261.189656 \n",
       "L 120.132378 259.332013 \n",
       "L 123.41172 255.573027 \n",
       "L 126.691057 251.725952 \n",
       "L 129.970395 248.526594 \n",
       "L 133.249737 246.286466 \n",
       "L 136.529069 245.159894 \n",
       "L 139.808412 245.22145 \n",
       "L 143.087754 246.495244 \n",
       "L 146.367086 248.962846 \n",
       "L 149.646428 252.554157 \n",
       "L 152.92577 257.069066 \n",
       "L 156.205103 261.132975 \n",
       "L 159.484445 258.501639 \n",
       "L 162.763787 247.636986 \n",
       "L 166.04312 235.271041 \n",
       "L 169.322462 222.18006 \n",
       "L 172.601804 208.626599 \n",
       "L 175.881137 194.808402 \n",
       "L 179.160479 180.901388 \n",
       "L 182.439821 167.067626 \n",
       "L 185.719153 153.456119 \n",
       "L 188.998496 140.200916 \n",
       "L 192.277838 127.420451 \n",
       "L 195.55717 115.216022 \n",
       "L 198.836512 103.671338 \n",
       "L 202.115855 92.852099 \n",
       "L 205.395187 82.80654 \n",
       "L 208.674529 73.565742 \n",
       "L 211.953871 65.145016 \n",
       "L 215.233204 57.545194 \n",
       "L 218.512556 50.754281 \n",
       "L 221.791879 44.749578 \n",
       "L 225.071221 39.499434 \n",
       "L 228.350563 34.965671 \n",
       "L 231.629886 31.105559 \n",
       "L 234.909247 27.873824 \n",
       "L 238.18857 25.224855 \n",
       "L 241.467912 23.114194 \n",
       "L 244.747254 21.500393 \n",
       "L 248.026597 20.346188 \n",
       "L 251.305939 19.61988 \n",
       "L 254.585262 19.296 \n",
       "L 257.864623 19.356047 \n",
       "L 261.143946 19.788858 \n",
       "L 264.423288 20.590786 \n",
       "L 267.70263 21.765495 \n",
       "L 270.981953 23.323724 \n",
       "L 274.261315 25.282835 \n",
       "L 277.540637 27.665889 \n",
       "L 280.81998 30.500939 \n",
       "L 284.099322 33.819977 \n",
       "L 287.378664 37.657585 \n",
       "L 290.658006 42.049887 \n",
       "L 293.937329 47.032944 \n",
       "L 297.21669 52.641597 \n",
       "L 300.496013 58.907513 \n",
       "L 303.775355 65.858469 \n",
       "L 307.054697 73.516272 \n",
       "L 310.33402 81.895827 \n",
       "L 313.613382 91.004018 \n",
       "L 316.892705 100.838371 \n",
       "L 320.172047 111.386681 \n",
       "L 323.451389 122.626232 \n",
       "L 326.730731 134.523339 \n",
       "L 330.010073 147.03356 \n",
       "L 333.289396 160.101983 \n",
       "L 336.568738 173.663581 \n",
       "L 339.84808 187.644523 \n",
       "L 343.127423 201.961618 \n",
       "L 346.406765 216.525981 \n",
       "L 349.686088 231.244641 \n",
       "L 352.96543 246.019403 \n",
       "L 356.244772 260.740302 \n",
       "L 359.524114 246.962905 \n",
       "L 362.803456 232.18716 \n",
       "L 366.082798 217.462206 \n",
       "L 369.362141 202.883881 \n",
       "L 372.641463 188.546514 \n",
       "L 375.920806 174.540503 \n",
       "L 379.200148 160.947271 \n",
       "\" clip-path=\"url(#pf9371554da)\" style=\"fill: none; stroke: #ff7f0e; stroke-width: 1.2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_26\">\n",
       "    <path d=\"M 254.585262 261.216 \n",
       "L 254.585262 258.772364 \n",
       "L 254.585262 256.328728 \n",
       "L 254.585262 253.885092 \n",
       "L 254.585262 251.441455 \n",
       "L 254.585262 248.997819 \n",
       "L 254.585262 246.554183 \n",
       "L 254.585262 244.110546 \n",
       "L 254.585262 241.66691 \n",
       "L 254.585262 239.223275 \n",
       "L 254.585262 236.779637 \n",
       "L 254.585262 234.336002 \n",
       "L 254.585262 231.892366 \n",
       "L 254.585262 229.448729 \n",
       "L 254.585262 227.005091 \n",
       "L 254.585262 224.561458 \n",
       "L 254.585262 222.11782 \n",
       "L 254.585262 219.674183 \n",
       "L 254.585262 217.230549 \n",
       "L 254.585262 214.786912 \n",
       "L 254.585262 212.343274 \n",
       "L 254.585262 209.899641 \n",
       "L 254.585262 207.456003 \n",
       "L 254.585262 205.012366 \n",
       "L 254.585262 202.568732 \n",
       "L 254.585262 200.125095 \n",
       "L 254.585262 197.681457 \n",
       "L 254.585262 195.23782 \n",
       "L 254.585262 192.794182 \n",
       "L 254.585262 190.350553 \n",
       "L 254.585262 187.906915 \n",
       "L 254.585262 185.463278 \n",
       "L 254.585262 183.01964 \n",
       "L 254.585262 180.576003 \n",
       "L 254.585262 178.132365 \n",
       "L 254.585262 175.688728 \n",
       "L 254.585262 173.245098 \n",
       "L 254.585262 170.801461 \n",
       "L 254.585262 168.357823 \n",
       "L 254.585262 165.914186 \n",
       "L 254.585262 163.470548 \n",
       "L 254.585262 161.026911 \n",
       "L 254.585262 158.583281 \n",
       "L 254.585262 156.139644 \n",
       "L 254.585262 153.696006 \n",
       "L 254.585262 151.252369 \n",
       "L 254.585262 148.808731 \n",
       "L 254.585262 146.365094 \n",
       "L 254.585262 143.921464 \n",
       "L 254.585262 141.477827 \n",
       "L 254.585262 139.034173 \n",
       "L 254.585262 136.590536 \n",
       "L 254.585262 134.146906 \n",
       "L 254.585262 131.703269 \n",
       "L 254.585262 129.259631 \n",
       "L 254.585262 126.815994 \n",
       "L 254.585262 124.372364 \n",
       "L 254.585262 121.928727 \n",
       "L 254.585262 119.485089 \n",
       "L 254.585262 117.041452 \n",
       "L 254.585262 114.597814 \n",
       "L 254.585262 112.154177 \n",
       "L 254.585262 109.710539 \n",
       "L 254.585262 107.266902 \n",
       "L 254.585262 104.823264 \n",
       "L 254.585262 102.379627 \n",
       "L 254.585262 99.935989 \n",
       "L 254.585262 97.492352 \n",
       "L 254.585262 95.048714 \n",
       "L 254.585262 92.605077 \n",
       "L 254.585262 90.161439 \n",
       "L 254.585262 87.717818 \n",
       "L 254.585262 85.27418 \n",
       "L 254.585262 82.830543 \n",
       "L 254.585262 80.386905 \n",
       "L 254.585262 77.943268 \n",
       "L 254.585262 75.49963 \n",
       "L 254.585262 73.055993 \n",
       "L 254.585262 70.612355 \n",
       "L 254.585262 68.168734 \n",
       "L 254.585262 65.725096 \n",
       "L 254.585262 63.281459 \n",
       "L 254.585262 60.837821 \n",
       "L 254.585262 58.394184 \n",
       "L 254.585262 55.950546 \n",
       "L 254.585262 53.506909 \n",
       "L 254.585262 51.063271 \n",
       "L 254.585262 48.619634 \n",
       "L 254.585262 46.175996 \n",
       "L 254.585262 43.732359 \n",
       "L 254.585262 41.288721 \n",
       "L 254.585262 38.845084 \n",
       "L 254.585262 36.401446 \n",
       "L 254.585262 33.957809 \n",
       "L 254.585262 31.514188 \n",
       "L 254.585262 29.07055 \n",
       "L 254.585262 26.626913 \n",
       "L 254.585262 24.183275 \n",
       "L 254.585262 21.739638 \n",
       "L 254.585262 19.296 \n",
       "\" clip-path=\"url(#pf9371554da)\" style=\"fill: none; stroke: #ff7f0e; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_7\">\n",
       "    <path d=\"M 38.312875 273.312 \n",
       "L 38.312875 7.2 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 395.432875 273.312 \n",
       "L 395.432875 7.2 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 38.312875 273.312 \n",
       "L 395.432875 273.312 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 38.312875 7.2 \n",
       "L 395.432875 7.2 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"pf9371554da\">\n",
       "   <rect x=\"38.312875\" y=\"7.2\" width=\"357.12\" height=\"266.112\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 640x480 with 2 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "def ei(m, sigma, ymax):\n",
    "    \"\"\"Return the expected improvement.\n",
    "    \n",
    "    Arguments\n",
    "    m     -- The predictive mean at the test points.\n",
    "    sigma -- The predictive standard deviation at\n",
    "             the test points.\n",
    "    ymax  -- The maximum observed value (so far).\n",
    "    \"\"\"\n",
    "    diff = m - ymax\n",
    "    u = diff / sigma\n",
    "    ei = ( diff * torch.distributions.Normal(0, 1).cdf(u) + \n",
    "          sigma * torch.distributions.Normal(0, 1).log_prob(u).exp()\n",
    "    )\n",
    "    ei[sigma <= 0.] = 0.\n",
    "    return ei\n",
    "\n",
    "plot_iaf(\n",
    "    x,\n",
    "    model,\n",
    "    ei\n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Bayesian global optimization with the expected improvement\n",
    "\n",
    "Let's now run the Bayesian global optimization algorithm using the expected improvement as the information acquisition function:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "metadata": {
    "tags": [
     "hide-output"
    ]
   },
   "outputs": [
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "/Users/ibilion/.pyenv/versions/3.11.6/lib/python3.11/site-packages/gpytorch/distributions/multivariate_normal.py:319: NumericalWarning: Negative variance values detected. This is likely due to numerical instabilities. Rounding negative variances up to 1e-06.\n",
      "  warnings.warn(\n"
     ]
    },
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"436.061375pt\" height=\"322.510875pt\" viewBox=\"0 0 436.061375 322.510875\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2023-10-23T15:18:58.311822</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.8.0, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 322.510875 \n",
       "L 436.061375 322.510875 \n",
       "L 436.061375 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 38.312875 286.1835 \n",
       "L 395.432875 286.1835 \n",
       "L 395.432875 20.0715 \n",
       "L 38.312875 20.0715 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"mce179a4565\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mce179a4565\" x=\"54.545602\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(48.429602 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mce179a4565\" x=\"119.476511\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(113.360511 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mce179a4565\" x=\"184.40742\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(178.29142 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mce179a4565\" x=\"249.33833\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(243.22233 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mce179a4565\" x=\"314.269239\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(308.153239 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mce179a4565\" x=\"379.200148\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 1.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(373.084148 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_7\">\n",
       "     <!-- $x$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(213.992875 313.402875) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-78\" d=\"M 3841 3500 \n",
       "L 2234 1784 \n",
       "L 3219 0 \n",
       "L 2559 0 \n",
       "L 1819 1388 \n",
       "L 531 0 \n",
       "L -166 0 \n",
       "L 1556 1844 \n",
       "L 641 3500 \n",
       "L 1300 3500 \n",
       "L 1972 2234 \n",
       "L 3144 3500 \n",
       "L 3841 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <defs>\n",
       "       <path id=\"mbaf2e46b22\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbaf2e46b22\" x=\"38.312875\" y=\"274.150537\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- −8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 277.299975) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbaf2e46b22\" x=\"38.312875\" y=\"229.548969\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- −6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 232.698406) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbaf2e46b22\" x=\"38.312875\" y=\"184.9474\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 188.096837) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbaf2e46b22\" x=\"38.312875\" y=\"140.345831\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 143.495269) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbaf2e46b22\" x=\"38.312875\" y=\"95.744262\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 98.8937) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbaf2e46b22\" x=\"38.312875\" y=\"51.142694\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 54.292131) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_14\">\n",
       "     <!-- $y$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(13.9635 156.0075) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-79\" d=\"M 1588 -325 \n",
       "Q 1188 -997 936 -1164 \n",
       "Q 684 -1331 294 -1331 \n",
       "L -159 -1331 \n",
       "L -63 -850 \n",
       "L 269 -850 \n",
       "Q 509 -850 678 -719 \n",
       "Q 847 -588 1056 -206 \n",
       "L 1234 128 \n",
       "L 459 3500 \n",
       "L 1069 3500 \n",
       "L 1650 819 \n",
       "L 3256 3500 \n",
       "L 3859 3500 \n",
       "L 1588 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_1\">\n",
       "    <defs>\n",
       "     <path id=\"m892c57389d\" d=\"M 54.545602 -290.343375 \n",
       "L 54.545602 -141.776173 \n",
       "L 57.824941 -143.714143 \n",
       "L 61.10428 -145.97653 \n",
       "L 64.383619 -148.577595 \n",
       "L 67.662958 -151.52638 \n",
       "L 70.942296 -154.825764 \n",
       "L 74.221636 -158.471811 \n",
       "L 77.500973 -162.453068 \n",
       "L 80.780313 -166.750055 \n",
       "L 84.059653 -171.335209 \n",
       "L 87.33899 -176.172384 \n",
       "L 90.61833 -181.217276 \n",
       "L 93.89767 -186.417592 \n",
       "L 97.177007 -191.71344 \n",
       "L 100.456344 -197.038812 \n",
       "L 103.735686 -202.321626 \n",
       "L 107.015024 -207.485437 \n",
       "L 110.294361 -212.45093 \n",
       "L 113.573703 -217.134153 \n",
       "L 116.853041 -216.253911 \n",
       "L 120.132378 -214.375932 \n",
       "L 123.41172 -212.97066 \n",
       "L 126.691057 -212.041399 \n",
       "L 129.970395 -211.580523 \n",
       "L 133.249737 -211.567766 \n",
       "L 136.529069 -211.97173 \n",
       "L 139.808412 -212.749019 \n",
       "L 143.087754 -213.845412 \n",
       "L 146.367086 -215.196578 \n",
       "L 149.646428 -216.729543 \n",
       "L 152.92577 -218.36329 \n",
       "L 156.205103 -220.012329 \n",
       "L 159.484445 -216.94553 \n",
       "L 162.763787 -211.036219 \n",
       "L 166.04312 -204.425818 \n",
       "L 169.322462 -197.177212 \n",
       "L 172.601804 -189.362007 \n",
       "L 175.881137 -181.06014 \n",
       "L 179.160479 -172.358312 \n",
       "L 182.439821 -163.348964 \n",
       "L 185.719153 -154.129322 \n",
       "L 188.998496 -144.799874 \n",
       "L 192.277838 -135.463398 \n",
       "L 195.55717 -126.223673 \n",
       "L 198.836512 -117.184173 \n",
       "L 202.115855 -108.447036 \n",
       "L 205.395187 -100.111836 \n",
       "L 208.674529 -92.274258 \n",
       "L 211.953871 -85.025232 \n",
       "L 215.233204 -78.449604 \n",
       "L 218.512556 -72.625065 \n",
       "L 221.791879 -67.621289 \n",
       "L 225.071221 -63.498761 \n",
       "L 228.350563 -60.307949 \n",
       "L 231.629886 -58.088623 \n",
       "L 234.909247 -56.868943 \n",
       "L 238.18857 -56.665135 \n",
       "L 241.467912 -57.48091 \n",
       "L 244.747254 -59.307421 \n",
       "L 248.026597 -62.123071 \n",
       "L 251.305939 -65.893949 \n",
       "L 254.585262 -70.528816 \n",
       "L 257.864623 -65.106662 \n",
       "L 261.143946 -60.464011 \n",
       "L 264.423288 -56.69307 \n",
       "L 267.70263 -53.829121 \n",
       "L 270.981953 -51.895846 \n",
       "L 274.261315 -50.90508 \n",
       "L 277.540637 -50.857419 \n",
       "L 280.81998 -51.742665 \n",
       "L 284.099322 -53.540742 \n",
       "L 287.378664 -56.222448 \n",
       "L 290.658006 -59.750629 \n",
       "L 293.937329 -64.081081 \n",
       "L 297.21669 -69.163973 \n",
       "L 300.496013 -74.944349 \n",
       "L 303.775355 -81.364063 \n",
       "L 307.054697 -88.36194 \n",
       "L 310.33402 -95.875228 \n",
       "L 313.613382 -103.840349 \n",
       "L 316.892705 -112.193349 \n",
       "L 320.172047 -120.870916 \n",
       "L 323.451389 -129.810638 \n",
       "L 326.730731 -138.951287 \n",
       "L 330.010073 -148.233521 \n",
       "L 333.289396 -157.599804 \n",
       "L 336.568738 -166.994846 \n",
       "L 339.84808 -176.365777 \n",
       "L 343.127423 -185.661632 \n",
       "L 346.406765 -194.834597 \n",
       "L 349.686088 -203.840011 \n",
       "L 352.96543 -212.635578 \n",
       "L 356.244772 -221.176677 \n",
       "L 359.524114 -218.119945 \n",
       "L 362.803456 -214.362187 \n",
       "L 366.082798 -210.348248 \n",
       "L 369.362141 -206.14224 \n",
       "L 372.641463 -201.807083 \n",
       "L 375.920806 -197.40308 \n",
       "L 379.200148 -192.985768 \n",
       "L 379.200148 -271.459377 \n",
       "L 379.200148 -271.459377 \n",
       "L 375.920806 -265.457397 \n",
       "L 372.641463 -259.0345 \n",
       "L 369.362141 -252.202528 \n",
       "L 366.082798 -244.978425 \n",
       "L 362.803456 -237.382928 \n",
       "L 359.524114 -229.439996 \n",
       "L 356.244772 -221.557022 \n",
       "L 352.96543 -224.597324 \n",
       "L 349.686088 -227.188658 \n",
       "L 346.406765 -229.263645 \n",
       "L 343.127423 -230.763796 \n",
       "L 339.84808 -231.636466 \n",
       "L 336.568738 -231.834657 \n",
       "L 333.289396 -231.318352 \n",
       "L 330.010073 -230.056272 \n",
       "L 326.730731 -228.026242 \n",
       "L 323.451389 -225.216177 \n",
       "L 320.172047 -221.624395 \n",
       "L 316.892705 -217.260425 \n",
       "L 313.613382 -212.144999 \n",
       "L 310.33402 -206.310045 \n",
       "L 307.054697 -199.799023 \n",
       "L 303.775355 -192.665926 \n",
       "L 300.496013 -184.97517 \n",
       "L 297.21669 -176.801089 \n",
       "L 293.937329 -168.226235 \n",
       "L 290.658006 -159.341494 \n",
       "L 287.378664 -150.243609 \n",
       "L 284.099322 -141.034856 \n",
       "L 280.81998 -131.820945 \n",
       "L 277.540637 -122.709932 \n",
       "L 274.261315 -113.810087 \n",
       "L 270.981953 -105.228714 \n",
       "L 267.70263 -97.07043 \n",
       "L 264.423288 -89.435246 \n",
       "L 261.143946 -82.417579 \n",
       "L 257.864623 -76.104054 \n",
       "L 254.585262 -70.618012 \n",
       "L 251.305939 -76.805633 \n",
       "L 248.026597 -83.734017 \n",
       "L 244.747254 -91.278367 \n",
       "L 241.467912 -99.350219 \n",
       "L 238.18857 -107.853157 \n",
       "L 234.909247 -116.684627 \n",
       "L 231.629886 -125.737642 \n",
       "L 228.350563 -134.902399 \n",
       "L 225.071221 -144.068425 \n",
       "L 221.791879 -153.126375 \n",
       "L 218.512556 -161.969936 \n",
       "L 215.233204 -170.498139 \n",
       "L 211.953871 -178.616685 \n",
       "L 208.674529 -186.240204 \n",
       "L 205.395187 -193.293424 \n",
       "L 202.115855 -199.712889 \n",
       "L 198.836512 -205.448034 \n",
       "L 195.55717 -210.461989 \n",
       "L 192.277838 -214.732266 \n",
       "L 188.998496 -218.251175 \n",
       "L 185.719153 -221.025661 \n",
       "L 182.439821 -223.077089 \n",
       "L 179.160479 -224.440622 \n",
       "L 175.881137 -225.164245 \n",
       "L 172.601804 -225.307462 \n",
       "L 169.322462 -224.940004 \n",
       "L 166.04312 -224.140096 \n",
       "L 162.763787 -222.992236 \n",
       "L 159.484445 -221.585779 \n",
       "L 156.205103 -222.100949 \n",
       "L 152.92577 -226.460837 \n",
       "L 149.646428 -229.993677 \n",
       "L 146.367086 -232.6812 \n",
       "L 143.087754 -234.516045 \n",
       "L 139.808412 -235.503483 \n",
       "L 136.529069 -235.660494 \n",
       "L 133.249737 -235.015552 \n",
       "L 129.970395 -233.607778 \n",
       "L 126.691057 -231.486773 \n",
       "L 123.41172 -228.710196 \n",
       "L 120.132378 -225.344235 \n",
       "L 116.853041 -221.460809 \n",
       "L 113.573703 -218.592817 \n",
       "L 110.294361 -221.361661 \n",
       "L 107.015024 -224.534584 \n",
       "L 103.735686 -228.068337 \n",
       "L 100.456344 -231.916597 \n",
       "L 97.177007 -236.028107 \n",
       "L 93.89767 -240.348454 \n",
       "L 90.61833 -244.822207 \n",
       "L 87.33899 -249.393186 \n",
       "L 84.059653 -254.006788 \n",
       "L 80.780313 -258.610928 \n",
       "L 77.500973 -263.156943 \n",
       "L 74.221636 -267.60093 \n",
       "L 70.942296 -271.903829 \n",
       "L 67.662958 -276.032334 \n",
       "L 64.383619 -279.959018 \n",
       "L 61.10428 -283.662451 \n",
       "L 57.824941 -287.127185 \n",
       "L 54.545602 -290.343375 \n",
       "z\n",
       "\" style=\"stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p3dc39753f7)\">\n",
       "     <use xlink:href=\"#m892c57389d\" x=\"0\" y=\"322.510875\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_2\">\n",
       "    <defs>\n",
       "     <path id=\"m14ec0a650f\" d=\"M 54.545602 -141.776173 \n",
       "L 54.545602 -141.776173 \n",
       "L 57.824941 -143.714143 \n",
       "L 61.10428 -145.97653 \n",
       "L 64.383619 -148.577595 \n",
       "L 67.662958 -151.52638 \n",
       "L 70.942296 -154.825764 \n",
       "L 74.221636 -158.471811 \n",
       "L 77.500973 -162.453068 \n",
       "L 80.780313 -166.750055 \n",
       "L 84.059653 -171.335209 \n",
       "L 87.33899 -176.172384 \n",
       "L 90.61833 -181.217276 \n",
       "L 93.89767 -186.417592 \n",
       "L 97.177007 -191.71344 \n",
       "L 100.456344 -197.038812 \n",
       "L 103.735686 -202.321626 \n",
       "L 107.015024 -207.485437 \n",
       "L 110.294361 -212.45093 \n",
       "L 113.573703 -217.134153 \n",
       "L 116.853041 -216.253911 \n",
       "L 120.132378 -214.375932 \n",
       "L 123.41172 -212.97066 \n",
       "L 126.691057 -212.041399 \n",
       "L 129.970395 -211.580523 \n",
       "L 133.249737 -211.567766 \n",
       "L 136.529069 -211.97173 \n",
       "L 139.808412 -212.749019 \n",
       "L 143.087754 -213.845412 \n",
       "L 146.367086 -215.196578 \n",
       "L 149.646428 -216.729543 \n",
       "L 152.92577 -218.36329 \n",
       "L 156.205103 -220.012329 \n",
       "L 159.484445 -216.94553 \n",
       "L 162.763787 -211.036219 \n",
       "L 166.04312 -204.425818 \n",
       "L 169.322462 -197.177212 \n",
       "L 172.601804 -189.362007 \n",
       "L 175.881137 -181.06014 \n",
       "L 179.160479 -172.358312 \n",
       "L 182.439821 -163.348964 \n",
       "L 185.719153 -154.129322 \n",
       "L 188.998496 -144.799874 \n",
       "L 192.277838 -135.463398 \n",
       "L 195.55717 -126.223673 \n",
       "L 198.836512 -117.184173 \n",
       "L 202.115855 -108.447036 \n",
       "L 205.395187 -100.111836 \n",
       "L 208.674529 -92.274258 \n",
       "L 211.953871 -85.025232 \n",
       "L 215.233204 -78.449604 \n",
       "L 218.512556 -72.625065 \n",
       "L 221.791879 -67.621289 \n",
       "L 225.071221 -63.498761 \n",
       "L 228.350563 -60.307949 \n",
       "L 231.629886 -58.088623 \n",
       "L 234.909247 -56.868943 \n",
       "L 238.18857 -56.665135 \n",
       "L 241.467912 -57.48091 \n",
       "L 244.747254 -59.307421 \n",
       "L 248.026597 -62.123071 \n",
       "L 251.305939 -65.893949 \n",
       "L 254.585262 -70.528816 \n",
       "L 257.864623 -65.106662 \n",
       "L 261.143946 -60.464011 \n",
       "L 264.423288 -56.69307 \n",
       "L 267.70263 -53.829121 \n",
       "L 270.981953 -51.895846 \n",
       "L 274.261315 -50.90508 \n",
       "L 277.540637 -50.857419 \n",
       "L 280.81998 -51.742665 \n",
       "L 284.099322 -53.540742 \n",
       "L 287.378664 -56.222448 \n",
       "L 290.658006 -59.750629 \n",
       "L 293.937329 -64.081081 \n",
       "L 297.21669 -69.163973 \n",
       "L 300.496013 -74.944349 \n",
       "L 303.775355 -81.364063 \n",
       "L 307.054697 -88.36194 \n",
       "L 310.33402 -95.875228 \n",
       "L 313.613382 -103.840349 \n",
       "L 316.892705 -112.193349 \n",
       "L 320.172047 -120.870916 \n",
       "L 323.451389 -129.810638 \n",
       "L 326.730731 -138.951287 \n",
       "L 330.010073 -148.233521 \n",
       "L 333.289396 -157.599804 \n",
       "L 336.568738 -166.994846 \n",
       "L 339.84808 -176.365777 \n",
       "L 343.127423 -185.661632 \n",
       "L 346.406765 -194.834597 \n",
       "L 349.686088 -203.840011 \n",
       "L 352.96543 -212.635578 \n",
       "L 356.244772 -221.176677 \n",
       "L 359.524114 -218.119945 \n",
       "L 362.803456 -214.362187 \n",
       "L 366.082798 -210.348248 \n",
       "L 369.362141 -206.14224 \n",
       "L 372.641463 -201.807083 \n",
       "L 375.920806 -197.40308 \n",
       "L 379.200148 -192.985768 \n",
       "L 379.200148 -192.985768 \n",
       "L 379.200148 -192.985768 \n",
       "L 375.920806 -197.40308 \n",
       "L 372.641463 -201.807083 \n",
       "L 369.362141 -206.14224 \n",
       "L 366.082798 -210.348248 \n",
       "L 362.803456 -214.362187 \n",
       "L 359.524114 -218.119945 \n",
       "L 356.244772 -221.176677 \n",
       "L 352.96543 -212.635578 \n",
       "L 349.686088 -203.840011 \n",
       "L 346.406765 -194.834597 \n",
       "L 343.127423 -185.661632 \n",
       "L 339.84808 -176.365777 \n",
       "L 336.568738 -166.994846 \n",
       "L 333.289396 -157.599804 \n",
       "L 330.010073 -148.233521 \n",
       "L 326.730731 -138.951287 \n",
       "L 323.451389 -129.810638 \n",
       "L 320.172047 -120.870916 \n",
       "L 316.892705 -112.193349 \n",
       "L 313.613382 -103.840349 \n",
       "L 310.33402 -95.875228 \n",
       "L 307.054697 -88.36194 \n",
       "L 303.775355 -81.364063 \n",
       "L 300.496013 -74.944349 \n",
       "L 297.21669 -69.163973 \n",
       "L 293.937329 -64.081081 \n",
       "L 290.658006 -59.750629 \n",
       "L 287.378664 -56.222448 \n",
       "L 284.099322 -53.540742 \n",
       "L 280.81998 -51.742665 \n",
       "L 277.540637 -50.857419 \n",
       "L 274.261315 -50.90508 \n",
       "L 270.981953 -51.895846 \n",
       "L 267.70263 -53.829121 \n",
       "L 264.423288 -56.69307 \n",
       "L 261.143946 -60.464011 \n",
       "L 257.864623 -65.106662 \n",
       "L 254.585262 -70.528816 \n",
       "L 251.305939 -65.893949 \n",
       "L 248.026597 -62.123071 \n",
       "L 244.747254 -59.307421 \n",
       "L 241.467912 -57.48091 \n",
       "L 238.18857 -56.665135 \n",
       "L 234.909247 -56.868943 \n",
       "L 231.629886 -58.088623 \n",
       "L 228.350563 -60.307949 \n",
       "L 225.071221 -63.498761 \n",
       "L 221.791879 -67.621289 \n",
       "L 218.512556 -72.625065 \n",
       "L 215.233204 -78.449604 \n",
       "L 211.953871 -85.025232 \n",
       "L 208.674529 -92.274258 \n",
       "L 205.395187 -100.111836 \n",
       "L 202.115855 -108.447036 \n",
       "L 198.836512 -117.184173 \n",
       "L 195.55717 -126.223673 \n",
       "L 192.277838 -135.463398 \n",
       "L 188.998496 -144.799874 \n",
       "L 185.719153 -154.129322 \n",
       "L 182.439821 -163.348964 \n",
       "L 179.160479 -172.358312 \n",
       "L 175.881137 -181.06014 \n",
       "L 172.601804 -189.362007 \n",
       "L 169.322462 -197.177212 \n",
       "L 166.04312 -204.425818 \n",
       "L 162.763787 -211.036219 \n",
       "L 159.484445 -216.94553 \n",
       "L 156.205103 -220.012329 \n",
       "L 152.92577 -218.36329 \n",
       "L 149.646428 -216.729543 \n",
       "L 146.367086 -215.196578 \n",
       "L 143.087754 -213.845412 \n",
       "L 139.808412 -212.749019 \n",
       "L 136.529069 -211.97173 \n",
       "L 133.249737 -211.567766 \n",
       "L 129.970395 -211.580523 \n",
       "L 126.691057 -212.041399 \n",
       "L 123.41172 -212.97066 \n",
       "L 120.132378 -214.375932 \n",
       "L 116.853041 -216.253911 \n",
       "L 113.573703 -217.134153 \n",
       "L 110.294361 -212.45093 \n",
       "L 107.015024 -207.485437 \n",
       "L 103.735686 -202.321626 \n",
       "L 100.456344 -197.038812 \n",
       "L 97.177007 -191.71344 \n",
       "L 93.89767 -186.417592 \n",
       "L 90.61833 -181.217276 \n",
       "L 87.33899 -176.172384 \n",
       "L 84.059653 -171.335209 \n",
       "L 80.780313 -166.750055 \n",
       "L 77.500973 -162.453068 \n",
       "L 74.221636 -158.471811 \n",
       "L 70.942296 -154.825764 \n",
       "L 67.662958 -151.52638 \n",
       "L 64.383619 -148.577595 \n",
       "L 61.10428 -145.97653 \n",
       "L 57.824941 -143.714143 \n",
       "L 54.545602 -141.776173 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p3dc39753f7)\">\n",
       "     <use xlink:href=\"#m14ec0a650f\" x=\"0\" y=\"322.510875\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_3\">\n",
       "    <defs>\n",
       "     <path id=\"m9db711d92b\" d=\"M 54.545602 -290.343375 \n",
       "L 54.545602 -290.343375 \n",
       "L 57.824941 -287.127185 \n",
       "L 61.10428 -283.662451 \n",
       "L 64.383619 -279.959018 \n",
       "L 67.662958 -276.032334 \n",
       "L 70.942296 -271.903829 \n",
       "L 74.221636 -267.60093 \n",
       "L 77.500973 -263.156943 \n",
       "L 80.780313 -258.610928 \n",
       "L 84.059653 -254.006788 \n",
       "L 87.33899 -249.393186 \n",
       "L 90.61833 -244.822207 \n",
       "L 93.89767 -240.348454 \n",
       "L 97.177007 -236.028107 \n",
       "L 100.456344 -231.916597 \n",
       "L 103.735686 -228.068337 \n",
       "L 107.015024 -224.534584 \n",
       "L 110.294361 -221.361661 \n",
       "L 113.573703 -218.592817 \n",
       "L 116.853041 -221.460809 \n",
       "L 120.132378 -225.344235 \n",
       "L 123.41172 -228.710196 \n",
       "L 126.691057 -231.486773 \n",
       "L 129.970395 -233.607778 \n",
       "L 133.249737 -235.015552 \n",
       "L 136.529069 -235.660494 \n",
       "L 139.808412 -235.503483 \n",
       "L 143.087754 -234.516045 \n",
       "L 146.367086 -232.6812 \n",
       "L 149.646428 -229.993677 \n",
       "L 152.92577 -226.460837 \n",
       "L 156.205103 -222.100949 \n",
       "L 159.484445 -221.585779 \n",
       "L 162.763787 -222.992236 \n",
       "L 166.04312 -224.140096 \n",
       "L 169.322462 -224.940004 \n",
       "L 172.601804 -225.307462 \n",
       "L 175.881137 -225.164245 \n",
       "L 179.160479 -224.440622 \n",
       "L 182.439821 -223.077089 \n",
       "L 185.719153 -221.025661 \n",
       "L 188.998496 -218.251175 \n",
       "L 192.277838 -214.732266 \n",
       "L 195.55717 -210.461989 \n",
       "L 198.836512 -205.448034 \n",
       "L 202.115855 -199.712889 \n",
       "L 205.395187 -193.293424 \n",
       "L 208.674529 -186.240204 \n",
       "L 211.953871 -178.616685 \n",
       "L 215.233204 -170.498139 \n",
       "L 218.512556 -161.969936 \n",
       "L 221.791879 -153.126375 \n",
       "L 225.071221 -144.068425 \n",
       "L 228.350563 -134.902399 \n",
       "L 231.629886 -125.737642 \n",
       "L 234.909247 -116.684627 \n",
       "L 238.18857 -107.853157 \n",
       "L 241.467912 -99.350219 \n",
       "L 244.747254 -91.278367 \n",
       "L 248.026597 -83.734017 \n",
       "L 251.305939 -76.805633 \n",
       "L 254.585262 -70.618012 \n",
       "L 257.864623 -76.104054 \n",
       "L 261.143946 -82.417579 \n",
       "L 264.423288 -89.435246 \n",
       "L 267.70263 -97.07043 \n",
       "L 270.981953 -105.228714 \n",
       "L 274.261315 -113.810087 \n",
       "L 277.540637 -122.709932 \n",
       "L 280.81998 -131.820945 \n",
       "L 284.099322 -141.034856 \n",
       "L 287.378664 -150.243609 \n",
       "L 290.658006 -159.341494 \n",
       "L 293.937329 -168.226235 \n",
       "L 297.21669 -176.801089 \n",
       "L 300.496013 -184.97517 \n",
       "L 303.775355 -192.665926 \n",
       "L 307.054697 -199.799023 \n",
       "L 310.33402 -206.310045 \n",
       "L 313.613382 -212.144999 \n",
       "L 316.892705 -217.260425 \n",
       "L 320.172047 -221.624395 \n",
       "L 323.451389 -225.216177 \n",
       "L 326.730731 -228.026242 \n",
       "L 330.010073 -230.056272 \n",
       "L 333.289396 -231.318352 \n",
       "L 336.568738 -231.834657 \n",
       "L 339.84808 -231.636466 \n",
       "L 343.127423 -230.763796 \n",
       "L 346.406765 -229.263645 \n",
       "L 349.686088 -227.188658 \n",
       "L 352.96543 -224.597324 \n",
       "L 356.244772 -221.557022 \n",
       "L 359.524114 -229.439996 \n",
       "L 362.803456 -237.382928 \n",
       "L 366.082798 -244.978425 \n",
       "L 369.362141 -252.202528 \n",
       "L 372.641463 -259.0345 \n",
       "L 375.920806 -265.457397 \n",
       "L 379.200148 -271.459377 \n",
       "L 379.200148 -271.459377 \n",
       "L 379.200148 -271.459377 \n",
       "L 375.920806 -265.457397 \n",
       "L 372.641463 -259.0345 \n",
       "L 369.362141 -252.202528 \n",
       "L 366.082798 -244.978425 \n",
       "L 362.803456 -237.382928 \n",
       "L 359.524114 -229.439996 \n",
       "L 356.244772 -221.557022 \n",
       "L 352.96543 -224.597324 \n",
       "L 349.686088 -227.188658 \n",
       "L 346.406765 -229.263645 \n",
       "L 343.127423 -230.763796 \n",
       "L 339.84808 -231.636466 \n",
       "L 336.568738 -231.834657 \n",
       "L 333.289396 -231.318352 \n",
       "L 330.010073 -230.056272 \n",
       "L 326.730731 -228.026242 \n",
       "L 323.451389 -225.216177 \n",
       "L 320.172047 -221.624395 \n",
       "L 316.892705 -217.260425 \n",
       "L 313.613382 -212.144999 \n",
       "L 310.33402 -206.310045 \n",
       "L 307.054697 -199.799023 \n",
       "L 303.775355 -192.665926 \n",
       "L 300.496013 -184.97517 \n",
       "L 297.21669 -176.801089 \n",
       "L 293.937329 -168.226235 \n",
       "L 290.658006 -159.341494 \n",
       "L 287.378664 -150.243609 \n",
       "L 284.099322 -141.034856 \n",
       "L 280.81998 -131.820945 \n",
       "L 277.540637 -122.709932 \n",
       "L 274.261315 -113.810087 \n",
       "L 270.981953 -105.228714 \n",
       "L 267.70263 -97.07043 \n",
       "L 264.423288 -89.435246 \n",
       "L 261.143946 -82.417579 \n",
       "L 257.864623 -76.104054 \n",
       "L 254.585262 -70.618012 \n",
       "L 251.305939 -76.805633 \n",
       "L 248.026597 -83.734017 \n",
       "L 244.747254 -91.278367 \n",
       "L 241.467912 -99.350219 \n",
       "L 238.18857 -107.853157 \n",
       "L 234.909247 -116.684627 \n",
       "L 231.629886 -125.737642 \n",
       "L 228.350563 -134.902399 \n",
       "L 225.071221 -144.068425 \n",
       "L 221.791879 -153.126375 \n",
       "L 218.512556 -161.969936 \n",
       "L 215.233204 -170.498139 \n",
       "L 211.953871 -178.616685 \n",
       "L 208.674529 -186.240204 \n",
       "L 205.395187 -193.293424 \n",
       "L 202.115855 -199.712889 \n",
       "L 198.836512 -205.448034 \n",
       "L 195.55717 -210.461989 \n",
       "L 192.277838 -214.732266 \n",
       "L 188.998496 -218.251175 \n",
       "L 185.719153 -221.025661 \n",
       "L 182.439821 -223.077089 \n",
       "L 179.160479 -224.440622 \n",
       "L 175.881137 -225.164245 \n",
       "L 172.601804 -225.307462 \n",
       "L 169.322462 -224.940004 \n",
       "L 166.04312 -224.140096 \n",
       "L 162.763787 -222.992236 \n",
       "L 159.484445 -221.585779 \n",
       "L 156.205103 -222.100949 \n",
       "L 152.92577 -226.460837 \n",
       "L 149.646428 -229.993677 \n",
       "L 146.367086 -232.6812 \n",
       "L 143.087754 -234.516045 \n",
       "L 139.808412 -235.503483 \n",
       "L 136.529069 -235.660494 \n",
       "L 133.249737 -235.015552 \n",
       "L 129.970395 -233.607778 \n",
       "L 126.691057 -231.486773 \n",
       "L 123.41172 -228.710196 \n",
       "L 120.132378 -225.344235 \n",
       "L 116.853041 -221.460809 \n",
       "L 113.573703 -218.592817 \n",
       "L 110.294361 -221.361661 \n",
       "L 107.015024 -224.534584 \n",
       "L 103.735686 -228.068337 \n",
       "L 100.456344 -231.916597 \n",
       "L 97.177007 -236.028107 \n",
       "L 93.89767 -240.348454 \n",
       "L 90.61833 -244.822207 \n",
       "L 87.33899 -249.393186 \n",
       "L 84.059653 -254.006788 \n",
       "L 80.780313 -258.610928 \n",
       "L 77.500973 -263.156943 \n",
       "L 74.221636 -267.60093 \n",
       "L 70.942296 -271.903829 \n",
       "L 67.662958 -276.032334 \n",
       "L 64.383619 -279.959018 \n",
       "L 61.10428 -283.662451 \n",
       "L 57.824941 -287.127185 \n",
       "L 54.545602 -290.343375 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p3dc39753f7)\">\n",
       "     <use xlink:href=\"#m9db711d92b\" x=\"0\" y=\"322.510875\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_13\">\n",
       "    <defs>\n",
       "     <path id=\"mf9867ea00b\" d=\"M -5 5 \n",
       "L 5 -5 \n",
       "M -5 -5 \n",
       "L 5 5 \n",
       "\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p3dc39753f7)\">\n",
       "     <use xlink:href=\"#mf9867ea00b\" x=\"356.349693\" y=\"101.061689\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mf9867ea00b\" x=\"157.258364\" y=\"101.980693\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mf9867ea00b\" x=\"114.255683\" y=\"104.442865\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mf9867ea00b\" x=\"254.585262\" y=\"251.93744\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_14\">\n",
       "    <path d=\"M 54.545602 106.451101 \n",
       "L 57.824941 107.090211 \n",
       "L 61.10428 107.691383 \n",
       "L 64.383619 108.242569 \n",
       "L 67.662958 108.731521 \n",
       "L 70.942296 109.146077 \n",
       "L 74.221636 109.474505 \n",
       "L 77.500973 109.705868 \n",
       "L 80.780313 109.830385 \n",
       "L 84.059653 109.839875 \n",
       "L 87.33899 109.72809 \n",
       "L 90.61833 109.491133 \n",
       "L 93.89767 109.127852 \n",
       "L 97.177007 108.640101 \n",
       "L 100.456344 108.033171 \n",
       "L 103.735686 107.315893 \n",
       "L 107.015024 106.500865 \n",
       "L 110.294361 105.604579 \n",
       "L 113.573703 104.64739 \n",
       "L 116.853041 103.653515 \n",
       "L 120.132378 102.650792 \n",
       "L 123.41172 101.670447 \n",
       "L 126.691057 100.746789 \n",
       "L 129.970395 99.916724 \n",
       "L 133.249737 99.219216 \n",
       "L 136.529069 98.694763 \n",
       "L 139.808412 98.384624 \n",
       "L 143.087754 98.330147 \n",
       "L 146.367086 98.571986 \n",
       "L 149.646428 99.149265 \n",
       "L 152.92577 100.098812 \n",
       "L 156.205103 101.454236 \n",
       "L 159.484445 103.245221 \n",
       "L 162.763787 105.496647 \n",
       "L 166.04312 108.227918 \n",
       "L 169.322462 111.452266 \n",
       "L 172.601804 115.17614 \n",
       "L 175.881137 119.398682 \n",
       "L 179.160479 124.111409 \n",
       "L 182.439821 129.297848 \n",
       "L 185.719153 134.933383 \n",
       "L 188.998496 140.98535 \n",
       "L 192.277838 147.41304 \n",
       "L 195.55717 154.168045 \n",
       "L 198.836512 161.194772 \n",
       "L 202.115855 168.43091 \n",
       "L 205.395187 175.808245 \n",
       "L 208.674529 183.253641 \n",
       "L 211.953871 190.68992 \n",
       "L 215.233204 198.037001 \n",
       "L 218.512556 205.213377 \n",
       "L 221.791879 212.13704 \n",
       "L 225.071221 218.727279 \n",
       "L 228.350563 224.905701 \n",
       "L 231.629886 230.597742 \n",
       "L 234.909247 235.73409 \n",
       "L 238.18857 240.251729 \n",
       "L 241.467912 244.09531 \n",
       "L 244.747254 247.217981 \n",
       "L 248.026597 249.582331 \n",
       "L 251.305939 251.161084 \n",
       "L 254.585262 251.937461 \n",
       "L 257.864623 251.905517 \n",
       "L 261.143946 251.07008 \n",
       "L 264.423288 249.446717 \n",
       "L 267.70263 247.0611 \n",
       "L 270.981953 243.948595 \n",
       "L 274.261315 240.153292 \n",
       "L 277.540637 235.727199 \n",
       "L 280.81998 230.72907 \n",
       "L 284.099322 225.223079 \n",
       "L 287.378664 219.277846 \n",
       "L 290.658006 212.96481 \n",
       "L 293.937329 206.357217 \n",
       "L 297.21669 199.528344 \n",
       "L 300.496013 192.551118 \n",
       "L 303.775355 185.495883 \n",
       "L 307.054697 178.430396 \n",
       "L 310.33402 171.418238 \n",
       "L 313.613382 164.518204 \n",
       "L 316.892705 157.783988 \n",
       "L 320.172047 151.26322 \n",
       "L 323.451389 144.997467 \n",
       "L 326.730731 139.022112 \n",
       "L 330.010073 133.365979 \n",
       "L 333.289396 128.051796 \n",
       "L 336.568738 123.096125 \n",
       "L 339.84808 118.509754 \n",
       "L 343.127423 114.29816 \n",
       "L 346.406765 110.461753 \n",
       "L 349.686088 106.99654 \n",
       "L 352.96543 103.894424 \n",
       "L 356.244772 101.144025 \n",
       "L 359.524114 98.730905 \n",
       "L 362.803456 96.638317 \n",
       "L 366.082798 94.847538 \n",
       "L 369.362141 93.338492 \n",
       "L 372.641463 92.090083 \n",
       "L 375.920806 91.080636 \n",
       "L 379.200148 90.288301 \n",
       "\" clip-path=\"url(#p3dc39753f7)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_15\">\n",
       "    <path d=\"M 54.545602 184.296662 \n",
       "L 57.824941 178.854495 \n",
       "L 61.10428 173.432522 \n",
       "L 64.383619 168.050851 \n",
       "L 67.662958 162.729517 \n",
       "L 70.942296 157.48833 \n",
       "L 74.221636 152.346909 \n",
       "L 77.500973 147.32453 \n",
       "L 80.780313 142.440081 \n",
       "L 84.059653 137.712041 \n",
       "L 87.33899 133.158348 \n",
       "L 90.61833 128.796383 \n",
       "L 93.89767 124.642894 \n",
       "L 97.177007 120.713945 \n",
       "L 100.456344 117.024836 \n",
       "L 103.735686 113.590105 \n",
       "L 107.015024 110.423421 \n",
       "L 110.294361 107.537566 \n",
       "L 113.573703 104.944371 \n",
       "L 116.853041 102.654702 \n",
       "L 120.132378 100.678413 \n",
       "L 123.41172 99.024287 \n",
       "L 126.691057 97.700033 \n",
       "L 129.970395 96.71225 \n",
       "L 133.249737 96.066388 \n",
       "L 136.529069 95.766742 \n",
       "L 139.808412 95.816434 \n",
       "L 143.087754 96.217373 \n",
       "L 146.367086 96.970265 \n",
       "L 149.646428 98.074605 \n",
       "L 152.92577 99.52865 \n",
       "L 156.205103 101.329412 \n",
       "L 159.484445 103.4727 \n",
       "L 162.763787 105.953044 \n",
       "L 166.04312 108.76377 \n",
       "L 169.322462 111.896958 \n",
       "L 172.601804 115.343455 \n",
       "L 175.881137 119.09289 \n",
       "L 179.160479 123.133654 \n",
       "L 182.439821 127.452978 \n",
       "L 185.719153 132.036812 \n",
       "L 188.998496 136.869979 \n",
       "L 192.277838 141.936048 \n",
       "L 195.55717 147.217473 \n",
       "L 198.836512 152.695476 \n",
       "L 202.115855 158.350091 \n",
       "L 205.395187 164.160194 \n",
       "L 208.674529 170.103502 \n",
       "L 211.953871 176.156498 \n",
       "L 215.233204 182.294527 \n",
       "L 218.512556 188.491734 \n",
       "L 221.791879 194.721007 \n",
       "L 225.071221 200.954109 \n",
       "L 228.350563 207.16155 \n",
       "L 231.629886 213.312463 \n",
       "L 234.909247 219.374997 \n",
       "L 238.18857 225.3157 \n",
       "L 241.467912 231.100106 \n",
       "L 244.747254 236.692295 \n",
       "L 248.026597 242.055091 \n",
       "L 251.305939 247.150073 \n",
       "L 254.585262 251.93744 \n",
       "L 257.864623 256.37625 \n",
       "L 261.143946 260.424299 \n",
       "L 264.423288 264.038327 \n",
       "L 267.70263 267.174056 \n",
       "L 270.981953 269.786462 \n",
       "L 274.261315 271.829861 \n",
       "L 277.540637 273.258315 \n",
       "L 280.81998 274.025962 \n",
       "L 284.099322 274.0875 \n",
       "L 287.378664 273.398789 \n",
       "L 290.658006 271.917643 \n",
       "L 293.937329 269.604708 \n",
       "L 297.21669 266.424477 \n",
       "L 300.496013 262.347036 \n",
       "L 303.775355 257.349023 \n",
       "L 307.054697 251.416084 \n",
       "L 310.33402 244.544941 \n",
       "L 313.613382 236.745656 \n",
       "L 316.892705 228.045035 \n",
       "L 320.172047 218.489496 \n",
       "L 323.451389 208.148849 \n",
       "L 326.730731 197.120257 \n",
       "L 330.010073 185.532197 \n",
       "L 333.289396 173.54866 \n",
       "L 336.568738 161.37317 \n",
       "L 339.84808 149.251993 \n",
       "L 343.127423 137.476804 \n",
       "L 346.406765 126.385696 \n",
       "L 349.686088 116.361401 \n",
       "L 352.96543 107.826583 \n",
       "L 356.244772 101.235249 \n",
       "L 359.524114 97.057223 \n",
       "L 362.803456 95.756624 \n",
       "L 366.082798 97.761353 \n",
       "L 369.362141 103.423162 \n",
       "L 372.641463 112.967897 \n",
       "L 375.920806 126.436191 \n",
       "L 379.200148 143.617413 \n",
       "\" clip-path=\"url(#p3dc39753f7)\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 38.312875 274.150537 \n",
       "L 38.312875 51.142694 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 54.545602 286.1835 \n",
       "L 379.200148 286.1835 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_15\">\n",
       "    <!-- N=0,  -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(205.266625 14.0715) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-4e\" d=\"M 488 0 \n",
       "L 488 4581 \n",
       "L 1109 4581 \n",
       "L 3516 984 \n",
       "L 3516 4581 \n",
       "L 4097 4581 \n",
       "L 4097 0 \n",
       "L 3475 0 \n",
       "L 1069 3600 \n",
       "L 1069 0 \n",
       "L 488 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-3d\" d=\"M 3381 2694 \n",
       "L 356 2694 \n",
       "L 356 3219 \n",
       "L 3381 3219 \n",
       "L 3381 2694 \n",
       "z\n",
       "M 3381 1303 \n",
       "L 356 1303 \n",
       "L 356 1828 \n",
       "L 3381 1828 \n",
       "L 3381 1303 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-2c\" d=\"M 569 0 \n",
       "L 569 641 \n",
       "L 1209 641 \n",
       "L 1209 0 \n",
       "Q 1209 -353 1084 -570 \n",
       "Q 959 -788 688 -906 \n",
       "L 531 -666 \n",
       "Q 709 -588 793 -436 \n",
       "Q 878 -284 888 0 \n",
       "L 569 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-4e\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"72.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-30\" x=\"130.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-2c\" x=\"186.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-20\" x=\"214.013672\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"legend_1\">\n",
       "    <g id=\"line2d_16\">\n",
       "     <g>\n",
       "      <use xlink:href=\"#mf9867ea00b\" x=\"55.032875\" y=\"31.210375\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_16\">\n",
       "     <!-- Observations -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 34.290375) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4f\" d=\"M 309 2231 \n",
       "Q 309 3372 921 4017 \n",
       "Q 1534 4663 2503 4663 \n",
       "Q 3138 4663 3647 4359 \n",
       "Q 4156 4056 4423 3514 \n",
       "Q 4691 2972 4691 2284 \n",
       "Q 4691 1588 4409 1038 \n",
       "Q 4128 488 3612 205 \n",
       "Q 3097 -78 2500 -78 \n",
       "Q 1853 -78 1343 234 \n",
       "Q 834 547 571 1087 \n",
       "Q 309 1628 309 2231 \n",
       "z\n",
       "M 934 2222 \n",
       "Q 934 1394 1379 917 \n",
       "Q 1825 441 2497 441 \n",
       "Q 3181 441 3623 922 \n",
       "Q 4066 1403 4066 2288 \n",
       "Q 4066 2847 3877 3264 \n",
       "Q 3688 3681 3323 3911 \n",
       "Q 2959 4141 2506 4141 \n",
       "Q 1863 4141 1398 3698 \n",
       "Q 934 3256 934 2222 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-62\" d=\"M 941 0 \n",
       "L 419 0 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 2947 \n",
       "Q 1338 3394 1891 3394 \n",
       "Q 2197 3394 2470 3270 \n",
       "Q 2744 3147 2920 2923 \n",
       "Q 3097 2700 3197 2384 \n",
       "Q 3297 2069 3297 1709 \n",
       "Q 3297 856 2875 390 \n",
       "Q 2453 -75 1863 -75 \n",
       "Q 1275 -75 941 416 \n",
       "L 941 0 \n",
       "z\n",
       "M 934 1684 \n",
       "Q 934 1088 1097 822 \n",
       "Q 1363 388 1816 388 \n",
       "Q 2184 388 2453 708 \n",
       "Q 2722 1028 2722 1663 \n",
       "Q 2722 2313 2464 2622 \n",
       "Q 2206 2931 1841 2931 \n",
       "Q 1472 2931 1203 2611 \n",
       "Q 934 2291 934 1684 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-76\" d=\"M 1344 0 \n",
       "L 81 3319 \n",
       "L 675 3319 \n",
       "L 1388 1331 \n",
       "Q 1503 1009 1600 663 \n",
       "Q 1675 925 1809 1294 \n",
       "L 2547 3319 \n",
       "L 3125 3319 \n",
       "L 1869 0 \n",
       "L 1344 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4f\"/>\n",
       "      <use xlink:href=\"#ArialMT-62\" x=\"77.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"133.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"183.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"239.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"272.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"322.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"377.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"405.712891\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"427.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"483.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"539.160156\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_17\">\n",
       "     <path d=\"M 46.232875 43.794375 \n",
       "L 55.032875 43.794375 \n",
       "L 63.832875 43.794375 \n",
       "\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "    </g>\n",
       "    <g id=\"text_17\">\n",
       "     <!-- $m_n(x)$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 46.874375) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-6d\" d=\"M 5747 2113 \n",
       "L 5338 0 \n",
       "L 4763 0 \n",
       "L 5166 2094 \n",
       "Q 5191 2228 5203 2325 \n",
       "Q 5216 2422 5216 2491 \n",
       "Q 5216 2772 5059 2928 \n",
       "Q 4903 3084 4622 3084 \n",
       "Q 4203 3084 3875 2770 \n",
       "Q 3547 2456 3450 1953 \n",
       "L 3066 0 \n",
       "L 2491 0 \n",
       "L 2900 2094 \n",
       "Q 2925 2209 2937 2307 \n",
       "Q 2950 2406 2950 2484 \n",
       "Q 2950 2769 2794 2926 \n",
       "Q 2638 3084 2363 3084 \n",
       "Q 1938 3084 1609 2770 \n",
       "Q 1281 2456 1184 1953 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 909 3500 \n",
       "L 1484 3500 \n",
       "L 1375 2956 \n",
       "Q 1609 3263 1923 3423 \n",
       "Q 2238 3584 2597 3584 \n",
       "Q 2978 3584 3223 3384 \n",
       "Q 3469 3184 3519 2828 \n",
       "Q 3781 3197 4126 3390 \n",
       "Q 4472 3584 4856 3584 \n",
       "Q 5306 3584 5551 3325 \n",
       "Q 5797 3066 5797 2591 \n",
       "Q 5797 2488 5784 2364 \n",
       "Q 5772 2241 5747 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Oblique-6e\" d=\"M 3566 2113 \n",
       "L 3156 0 \n",
       "L 2578 0 \n",
       "L 2988 2091 \n",
       "Q 3016 2238 3031 2350 \n",
       "Q 3047 2463 3047 2528 \n",
       "Q 3047 2791 2881 2937 \n",
       "Q 2716 3084 2419 3084 \n",
       "Q 1956 3084 1622 2776 \n",
       "Q 1288 2469 1184 1941 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 903 3500 \n",
       "L 1478 3500 \n",
       "L 1363 2950 \n",
       "Q 1603 3253 1940 3418 \n",
       "Q 2278 3584 2650 3584 \n",
       "Q 3113 3584 3367 3334 \n",
       "Q 3622 3084 3622 2631 \n",
       "Q 3622 2519 3608 2391 \n",
       "Q 3594 2263 3566 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-28\" d=\"M 1984 4856 \n",
       "Q 1566 4138 1362 3434 \n",
       "Q 1159 2731 1159 2009 \n",
       "Q 1159 1288 1364 580 \n",
       "Q 1569 -128 1984 -844 \n",
       "L 1484 -844 \n",
       "Q 1016 -109 783 600 \n",
       "Q 550 1309 550 2009 \n",
       "Q 550 2706 781 3412 \n",
       "Q 1013 4119 1484 4856 \n",
       "L 1984 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-29\" d=\"M 513 4856 \n",
       "L 1013 4856 \n",
       "Q 1481 4119 1714 3412 \n",
       "Q 1947 2706 1947 2009 \n",
       "Q 1947 1309 1714 600 \n",
       "Q 1481 -109 1013 -844 \n",
       "L 513 -844 \n",
       "Q 928 -128 1133 580 \n",
       "Q 1338 1288 1338 2009 \n",
       "Q 1338 2731 1133 3434 \n",
       "Q 928 4138 513 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6d\" transform=\"translate(0 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6e\" transform=\"translate(97.412109 -16.28125) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(144.511719 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(183.525391 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(242.705078 0.125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_5\">\n",
       "     <path d=\"M 46.232875 61.031375 \n",
       "L 63.832875 61.031375 \n",
       "L 63.832875 54.871375 \n",
       "L 46.232875 54.871375 \n",
       "z\n",
       "\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_18\">\n",
       "     <!-- $f(\\mathbf{x}^*)$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 61.031375) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-66\" d=\"M 3059 4863 \n",
       "L 2969 4384 \n",
       "L 2419 4384 \n",
       "Q 2106 4384 1964 4261 \n",
       "Q 1822 4138 1753 3809 \n",
       "L 1691 3500 \n",
       "L 2638 3500 \n",
       "L 2553 3053 \n",
       "L 1606 3053 \n",
       "L 1013 0 \n",
       "L 434 0 \n",
       "L 1031 3053 \n",
       "L 481 3053 \n",
       "L 563 3500 \n",
       "L 1113 3500 \n",
       "L 1159 3744 \n",
       "Q 1278 4363 1576 4613 \n",
       "Q 1875 4863 2516 4863 \n",
       "L 3059 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Bold-78\" d=\"M 1422 1791 \n",
       "L 159 3500 \n",
       "L 1344 3500 \n",
       "L 2059 2463 \n",
       "L 2784 3500 \n",
       "L 3969 3500 \n",
       "L 2706 1797 \n",
       "L 4031 0 \n",
       "L 2847 0 \n",
       "L 2059 1106 \n",
       "L 1281 0 \n",
       "L 97 0 \n",
       "L 1422 1791 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-2a\" d=\"M 3009 3897 \n",
       "L 1888 3291 \n",
       "L 3009 2681 \n",
       "L 2828 2375 \n",
       "L 1778 3009 \n",
       "L 1778 1831 \n",
       "L 1422 1831 \n",
       "L 1422 3009 \n",
       "L 372 2375 \n",
       "L 191 2681 \n",
       "L 1313 3291 \n",
       "L 191 3897 \n",
       "L 372 4206 \n",
       "L 1422 3572 \n",
       "L 1422 4750 \n",
       "L 1778 4750 \n",
       "L 1778 3572 \n",
       "L 2828 4206 \n",
       "L 3009 3897 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-39\" d=\"M 350 1059 \n",
       "L 891 1109 \n",
       "Q 959 728 1153 556 \n",
       "Q 1347 384 1650 384 \n",
       "Q 1909 384 2104 503 \n",
       "Q 2300 622 2425 820 \n",
       "Q 2550 1019 2634 1356 \n",
       "Q 2719 1694 2719 2044 \n",
       "Q 2719 2081 2716 2156 \n",
       "Q 2547 1888 2255 1720 \n",
       "Q 1963 1553 1622 1553 \n",
       "Q 1053 1553 659 1965 \n",
       "Q 266 2378 266 3053 \n",
       "Q 266 3750 677 4175 \n",
       "Q 1088 4600 1706 4600 \n",
       "Q 2153 4600 2523 4359 \n",
       "Q 2894 4119 3086 3673 \n",
       "Q 3278 3228 3278 2384 \n",
       "Q 3278 1506 3087 986 \n",
       "Q 2897 466 2520 194 \n",
       "Q 2144 -78 1638 -78 \n",
       "Q 1100 -78 759 220 \n",
       "Q 419 519 350 1059 \n",
       "z\n",
       "M 2653 3081 \n",
       "Q 2653 3566 2395 3850 \n",
       "Q 2138 4134 1775 4134 \n",
       "Q 1400 4134 1122 3828 \n",
       "Q 844 3522 844 3034 \n",
       "Q 844 2597 1108 2323 \n",
       "Q 1372 2050 1759 2050 \n",
       "Q 2150 2050 2401 2323 \n",
       "Q 2653 2597 2653 3081 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-25\" d=\"M 372 3481 \n",
       "Q 372 3972 619 4315 \n",
       "Q 866 4659 1334 4659 \n",
       "Q 1766 4659 2048 4351 \n",
       "Q 2331 4044 2331 3447 \n",
       "Q 2331 2866 2045 2552 \n",
       "Q 1759 2238 1341 2238 \n",
       "Q 925 2238 648 2547 \n",
       "Q 372 2856 372 3481 \n",
       "z\n",
       "M 1350 4272 \n",
       "Q 1141 4272 1002 4090 \n",
       "Q 863 3909 863 3425 \n",
       "Q 863 2984 1003 2804 \n",
       "Q 1144 2625 1350 2625 \n",
       "Q 1563 2625 1702 2806 \n",
       "Q 1841 2988 1841 3469 \n",
       "Q 1841 3913 1700 4092 \n",
       "Q 1559 4272 1350 4272 \n",
       "z\n",
       "M 1353 -169 \n",
       "L 3859 4659 \n",
       "L 4316 4659 \n",
       "L 1819 -169 \n",
       "L 1353 -169 \n",
       "z\n",
       "M 3334 1075 \n",
       "Q 3334 1569 3581 1911 \n",
       "Q 3828 2253 4300 2253 \n",
       "Q 4731 2253 5014 1945 \n",
       "Q 5297 1638 5297 1041 \n",
       "Q 5297 459 5011 145 \n",
       "Q 4725 -169 4303 -169 \n",
       "Q 3888 -169 3611 142 \n",
       "Q 3334 453 3334 1075 \n",
       "z\n",
       "M 4316 1866 \n",
       "Q 4103 1866 3964 1684 \n",
       "Q 3825 1503 3825 1019 \n",
       "Q 3825 581 3965 400 \n",
       "Q 4106 219 4313 219 \n",
       "Q 4528 219 4667 400 \n",
       "Q 4806 581 4806 1063 \n",
       "Q 4806 1506 4665 1686 \n",
       "Q 4525 1866 4316 1866 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-66\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(35.205078 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Bold-78\" transform=\"translate(74.21875 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(153.31543 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(204.6875 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(243.701172 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(271.484375 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(327.099609 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(382.714844 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(471.630859 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(499.414062 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(555.029297 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(588.330078 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(643.945312 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(699.560547 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_6\">\n",
       "     <path d=\"M 46.232875 75.199375 \n",
       "L 63.832875 75.199375 \n",
       "L 63.832875 69.039375 \n",
       "L 46.232875 69.039375 \n",
       "z\n",
       "\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_19\">\n",
       "     <!-- $y^*$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 75.199375) scale(0.088 -0.088)\">\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(77.283529 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(128.655599 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(156.438802 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(212.054036 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(267.669271 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(356.585286 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(384.36849 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(439.983724 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(473.284505 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(528.89974 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(584.514974 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_18\">\n",
       "     <path d=\"M 46.232875 84.66625 \n",
       "L 55.032875 84.66625 \n",
       "L 63.832875 84.66625 \n",
       "\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "    </g>\n",
       "    <g id=\"text_20\">\n",
       "     <!-- True function -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 87.74625) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-54\" d=\"M 1659 0 \n",
       "L 1659 4041 \n",
       "L 150 4041 \n",
       "L 150 4581 \n",
       "L 3781 4581 \n",
       "L 3781 4041 \n",
       "L 2266 4041 \n",
       "L 2266 0 \n",
       "L 1659 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-66\" d=\"M 556 0 \n",
       "L 556 2881 \n",
       "L 59 2881 \n",
       "L 59 3319 \n",
       "L 556 3319 \n",
       "L 556 3672 \n",
       "Q 556 4006 616 4169 \n",
       "Q 697 4388 901 4523 \n",
       "Q 1106 4659 1475 4659 \n",
       "Q 1713 4659 2000 4603 \n",
       "L 1916 4113 \n",
       "Q 1741 4144 1584 4144 \n",
       "Q 1328 4144 1222 4034 \n",
       "Q 1116 3925 1116 3625 \n",
       "L 1116 3319 \n",
       "L 1763 3319 \n",
       "L 1763 2881 \n",
       "L 1116 2881 \n",
       "L 1116 0 \n",
       "L 556 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-54\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"57.333984\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"90.634766\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"146.25\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"201.865234\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"229.648438\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"257.431641\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"313.046875\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"368.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"418.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"446.445312\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"468.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"524.277344\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_19\">\n",
       "      <defs>\n",
       "       <path id=\"mbe54a24dd7\" d=\"M 0 0 \n",
       "L 4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbe54a24dd7\" x=\"395.432875\" y=\"274.0875\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_21\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 277.236937) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_20\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbe54a24dd7\" x=\"395.432875\" y=\"236.529919\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_22\">\n",
       "      <!-- 0.1 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 239.679357) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_9\">\n",
       "     <g id=\"line2d_21\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbe54a24dd7\" x=\"395.432875\" y=\"198.972338\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_23\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 202.121776) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_10\">\n",
       "     <g id=\"line2d_22\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbe54a24dd7\" x=\"395.432875\" y=\"161.414758\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_24\">\n",
       "      <!-- 0.3 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 164.564195) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-33\" d=\"M 269 1209 \n",
       "L 831 1284 \n",
       "Q 928 806 1161 595 \n",
       "Q 1394 384 1728 384 \n",
       "Q 2125 384 2398 659 \n",
       "Q 2672 934 2672 1341 \n",
       "Q 2672 1728 2419 1979 \n",
       "Q 2166 2231 1775 2231 \n",
       "Q 1616 2231 1378 2169 \n",
       "L 1441 2663 \n",
       "Q 1497 2656 1531 2656 \n",
       "Q 1891 2656 2178 2843 \n",
       "Q 2466 3031 2466 3422 \n",
       "Q 2466 3731 2256 3934 \n",
       "Q 2047 4138 1716 4138 \n",
       "Q 1388 4138 1169 3931 \n",
       "Q 950 3725 888 3313 \n",
       "L 325 3413 \n",
       "Q 428 3978 793 4289 \n",
       "Q 1159 4600 1703 4600 \n",
       "Q 2078 4600 2393 4439 \n",
       "Q 2709 4278 2876 4000 \n",
       "Q 3044 3722 3044 3409 \n",
       "Q 3044 3113 2884 2869 \n",
       "Q 2725 2625 2413 2481 \n",
       "Q 2819 2388 3044 2092 \n",
       "Q 3269 1797 3269 1353 \n",
       "Q 3269 753 2831 336 \n",
       "Q 2394 -81 1725 -81 \n",
       "Q 1122 -81 723 278 \n",
       "Q 325 638 269 1209 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_11\">\n",
       "     <g id=\"line2d_23\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbe54a24dd7\" x=\"395.432875\" y=\"123.857177\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_25\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 127.006614) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_12\">\n",
       "     <g id=\"line2d_24\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbe54a24dd7\" x=\"395.432875\" y=\"86.299596\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_26\">\n",
       "      <!-- 0.5 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 89.449034) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_13\">\n",
       "     <g id=\"line2d_25\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mbe54a24dd7\" x=\"395.432875\" y=\"48.742015\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_27\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 51.891453) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_28\">\n",
       "     <!-- Information Acquisition Function -->\n",
       "     <g style=\"fill: #ff7f0e\" transform=\"translate(426.953375 221.16075) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-49\" d=\"M 597 0 \n",
       "L 597 4581 \n",
       "L 1203 4581 \n",
       "L 1203 0 \n",
       "L 597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-41\" d=\"M -9 0 \n",
       "L 1750 4581 \n",
       "L 2403 4581 \n",
       "L 4278 0 \n",
       "L 3588 0 \n",
       "L 3053 1388 \n",
       "L 1138 1388 \n",
       "L 634 0 \n",
       "L -9 0 \n",
       "z\n",
       "M 1313 1881 \n",
       "L 2866 1881 \n",
       "L 2388 3150 \n",
       "Q 2169 3728 2063 4100 \n",
       "Q 1975 3659 1816 3225 \n",
       "L 1313 1881 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-71\" d=\"M 2538 -1272 \n",
       "L 2538 353 \n",
       "Q 2406 169 2170 47 \n",
       "Q 1934 -75 1669 -75 \n",
       "Q 1078 -75 651 397 \n",
       "Q 225 869 225 1691 \n",
       "Q 225 2191 398 2587 \n",
       "Q 572 2984 901 3189 \n",
       "Q 1231 3394 1625 3394 \n",
       "Q 2241 3394 2594 2875 \n",
       "L 2594 3319 \n",
       "L 3100 3319 \n",
       "L 3100 -1272 \n",
       "L 2538 -1272 \n",
       "z\n",
       "M 803 1669 \n",
       "Q 803 1028 1072 708 \n",
       "Q 1341 388 1716 388 \n",
       "Q 2075 388 2334 692 \n",
       "Q 2594 997 2594 1619 \n",
       "Q 2594 2281 2320 2615 \n",
       "Q 2047 2950 1678 2950 \n",
       "Q 1313 2950 1058 2639 \n",
       "Q 803 2328 803 1669 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-46\" d=\"M 525 0 \n",
       "L 525 4581 \n",
       "L 3616 4581 \n",
       "L 3616 4041 \n",
       "L 1131 4041 \n",
       "L 1131 2622 \n",
       "L 3281 2622 \n",
       "L 3281 2081 \n",
       "L 1131 2081 \n",
       "L 1131 0 \n",
       "L 525 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-49\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"27.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"83.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"111.181641\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"166.796875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6d\" x=\"200.097656\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"283.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"339.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"366.796875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"389.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"444.628906\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"500.244141\"/>\n",
       "      <use xlink:href=\"#ArialMT-41\" x=\"522.527344\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"589.226562\"/>\n",
       "      <use xlink:href=\"#ArialMT-71\" x=\"639.226562\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"694.841797\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"750.457031\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"772.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"822.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"844.890625\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"872.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"894.890625\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"950.505859\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"1006.121094\"/>\n",
       "      <use xlink:href=\"#ArialMT-46\" x=\"1033.904297\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"1094.988281\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"1150.603516\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"1206.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"1256.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"1284.001953\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"1306.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"1361.833984\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_26\">\n",
       "    <path d=\"M 54.545602 67.301619 \n",
       "L 57.824941 80.565966 \n",
       "L 61.10428 94.368876 \n",
       "L 64.383619 108.62309 \n",
       "L 67.662958 123.225138 \n",
       "L 70.942296 138.055457 \n",
       "L 74.221636 152.980334 \n",
       "L 77.500973 167.85303 \n",
       "L 80.780313 182.515861 \n",
       "L 84.059653 196.803878 \n",
       "L 87.33899 210.545003 \n",
       "L 90.61833 223.56341 \n",
       "L 93.89767 235.678904 \n",
       "L 97.177007 246.701759 \n",
       "L 100.456344 256.420828 \n",
       "L 103.735686 264.557687 \n",
       "L 107.015024 270.649885 \n",
       "L 110.294361 273.800959 \n",
       "L 113.573703 274.0875 \n",
       "L 116.853041 273.896856 \n",
       "L 120.132378 266.035586 \n",
       "L 123.41172 252.460463 \n",
       "L 126.691057 238.705245 \n",
       "L 129.970395 226.650432 \n",
       "L 133.249737 217.258169 \n",
       "L 136.529069 211.230436 \n",
       "L 139.808412 209.168663 \n",
       "L 143.087754 211.625348 \n",
       "L 146.367086 219.114751 \n",
       "L 149.646428 232.098248 \n",
       "L 152.92577 250.867927 \n",
       "L 156.205103 272.937592 \n",
       "L 159.484445 273.861368 \n",
       "L 162.763787 272.556742 \n",
       "L 166.04312 271.388321 \n",
       "L 169.322462 270.638714 \n",
       "L 172.601804 270.319261 \n",
       "L 175.881137 270.373745 \n",
       "L 179.160479 270.714905 \n",
       "L 182.439821 271.241747 \n",
       "L 185.719153 271.85347 \n",
       "L 188.998496 272.461281 \n",
       "L 192.277838 272.997862 \n",
       "L 195.55717 273.423086 \n",
       "L 198.836512 273.724788 \n",
       "L 202.115855 273.914175 \n",
       "L 205.395187 274.017201 \n",
       "L 208.674529 274.064334 \n",
       "L 211.953871 274.081634 \n",
       "L 215.233204 274.086463 \n",
       "L 218.512556 274.087368 \n",
       "L 221.791879 274.08747 \n",
       "L 225.071221 274.087495 \n",
       "L 228.350563 274.0875 \n",
       "L 231.629886 274.0875 \n",
       "L 234.909247 274.0875 \n",
       "L 238.18857 274.0875 \n",
       "L 241.467912 274.0875 \n",
       "L 244.747254 274.0875 \n",
       "L 248.026597 274.0875 \n",
       "L 251.305939 274.0875 \n",
       "L 254.585262 274.0875 \n",
       "L 257.864623 274.0875 \n",
       "L 261.143946 274.0875 \n",
       "L 264.423288 274.0875 \n",
       "L 267.70263 274.0875 \n",
       "L 270.981953 274.0875 \n",
       "L 274.261315 274.0875 \n",
       "L 277.540637 274.0875 \n",
       "L 280.81998 274.0875 \n",
       "L 284.099322 274.087485 \n",
       "L 287.378664 274.087467 \n",
       "L 290.658006 274.087202 \n",
       "L 293.937329 274.084932 \n",
       "L 297.21669 274.073663 \n",
       "L 300.496013 274.034168 \n",
       "L 303.775355 273.929099 \n",
       "L 307.054697 273.70205 \n",
       "L 310.33402 273.286118 \n",
       "L 313.613382 272.619279 \n",
       "L 316.892705 271.663018 \n",
       "L 320.172047 270.417939 \n",
       "L 323.451389 268.932852 \n",
       "L 326.730731 267.306252 \n",
       "L 330.010073 265.680221 \n",
       "L 333.289396 264.229238 \n",
       "L 336.568738 263.145763 \n",
       "L 339.84808 262.625204 \n",
       "L 343.127423 262.851126 \n",
       "L 346.406765 263.984373 \n",
       "L 349.686088 266.154821 \n",
       "L 352.96543 269.452863 \n",
       "L 356.244772 273.916375 \n",
       "L 359.524114 229.33909 \n",
       "L 362.803456 187.28177 \n",
       "L 366.082798 149.220013 \n",
       "L 369.362141 114.908827 \n",
       "L 372.641463 84.112612 \n",
       "L 375.920806 56.60529 \n",
       "L 379.200148 32.1675 \n",
       "\" clip-path=\"url(#p3dc39753f7)\" style=\"fill: none; stroke: #ff7f0e; stroke-width: 1.2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_27\">\n",
       "    <path d=\"M 379.200148 274.0875 \n",
       "L 379.200148 271.643864 \n",
       "L 379.200148 269.200227 \n",
       "L 379.200148 266.756591 \n",
       "L 379.200148 264.312955 \n",
       "L 379.200148 261.869319 \n",
       "L 379.200148 259.425681 \n",
       "L 379.200148 256.982045 \n",
       "L 379.200148 254.538409 \n",
       "L 379.200148 252.094773 \n",
       "L 379.200148 249.651137 \n",
       "L 379.200148 247.2075 \n",
       "L 379.200148 244.763862 \n",
       "L 379.200148 242.320228 \n",
       "L 379.200148 239.87659 \n",
       "L 379.200148 237.432956 \n",
       "L 379.200148 234.989318 \n",
       "L 379.200148 232.545681 \n",
       "L 379.200148 230.102046 \n",
       "L 379.200148 227.658409 \n",
       "L 379.200148 225.214774 \n",
       "L 379.200148 222.771134 \n",
       "L 379.200148 220.327499 \n",
       "L 379.200148 217.883865 \n",
       "L 379.200148 215.440225 \n",
       "L 379.200148 212.99659 \n",
       "L 379.200148 210.552955 \n",
       "L 379.200148 208.109321 \n",
       "L 379.200148 205.665681 \n",
       "L 379.200148 203.222046 \n",
       "L 379.200148 200.778411 \n",
       "L 379.200148 198.334771 \n",
       "L 379.200148 195.891136 \n",
       "L 379.200148 193.447502 \n",
       "L 379.200148 191.003862 \n",
       "L 379.200148 188.560227 \n",
       "L 379.200148 186.116592 \n",
       "L 379.200148 183.672952 \n",
       "L 379.200148 181.229318 \n",
       "L 379.200148 178.785677 \n",
       "L 379.200148 176.342048 \n",
       "L 379.200148 173.898408 \n",
       "L 379.200148 171.454768 \n",
       "L 379.200148 169.011139 \n",
       "L 379.200148 166.567499 \n",
       "L 379.200148 164.123859 \n",
       "L 379.200148 161.68023 \n",
       "L 379.200148 159.236589 \n",
       "L 379.200148 156.792949 \n",
       "L 379.200148 154.34932 \n",
       "L 379.200148 151.90568 \n",
       "L 379.200148 149.462051 \n",
       "L 379.200148 147.018411 \n",
       "L 379.200148 144.57477 \n",
       "L 379.200148 142.131141 \n",
       "L 379.200148 139.687501 \n",
       "L 379.200148 137.243861 \n",
       "L 379.200148 134.800232 \n",
       "L 379.200148 132.356592 \n",
       "L 379.200148 129.912952 \n",
       "L 379.200148 127.469323 \n",
       "L 379.200148 125.025682 \n",
       "L 379.200148 122.582053 \n",
       "L 379.200148 120.138413 \n",
       "L 379.200148 117.694773 \n",
       "L 379.200148 115.251133 \n",
       "L 379.200148 112.807493 \n",
       "L 379.200148 110.363864 \n",
       "L 379.200148 107.920235 \n",
       "L 379.200148 105.476594 \n",
       "L 379.200148 103.032954 \n",
       "L 379.200148 100.589314 \n",
       "L 379.200148 98.145674 \n",
       "L 379.200148 95.702045 \n",
       "L 379.200148 93.258416 \n",
       "L 379.200148 90.814775 \n",
       "L 379.200148 88.371135 \n",
       "L 379.200148 85.927495 \n",
       "L 379.200148 83.483877 \n",
       "L 379.200148 81.040215 \n",
       "L 379.200148 78.596597 \n",
       "L 379.200148 76.152957 \n",
       "L 379.200148 73.709316 \n",
       "L 379.200148 71.265676 \n",
       "L 379.200148 68.822036 \n",
       "L 379.200148 66.378418 \n",
       "L 379.200148 63.934778 \n",
       "L 379.200148 61.491138 \n",
       "L 379.200148 59.047498 \n",
       "L 379.200148 56.603857 \n",
       "L 379.200148 54.160217 \n",
       "L 379.200148 51.716599 \n",
       "L 379.200148 49.272959 \n",
       "L 379.200148 46.829319 \n",
       "L 379.200148 44.385679 \n",
       "L 379.200148 41.942038 \n",
       "L 379.200148 39.498398 \n",
       "L 379.200148 37.05478 \n",
       "L 379.200148 34.61114 \n",
       "L 379.200148 32.1675 \n",
       "\" clip-path=\"url(#p3dc39753f7)\" style=\"fill: none; stroke: #ff7f0e; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_7\">\n",
       "    <path d=\"M 38.312875 286.1835 \n",
       "L 38.312875 20.0715 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 395.432875 286.1835 \n",
       "L 395.432875 20.0715 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 38.312875 286.1835 \n",
       "L 395.432875 286.1835 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 38.312875 20.0715 \n",
       "L 395.432875 20.0715 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"p3dc39753f7\">\n",
       "   <rect x=\"38.312875\" y=\"20.0715\" width=\"357.12\" height=\"266.112\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 640x480 with 2 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"436.061375pt\" height=\"322.510875pt\" viewBox=\"0 0 436.061375 322.510875\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2023-10-23T15:18:58.381642</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.8.0, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 322.510875 \n",
       "L 436.061375 322.510875 \n",
       "L 436.061375 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 38.312875 286.1835 \n",
       "L 395.432875 286.1835 \n",
       "L 395.432875 20.0715 \n",
       "L 38.312875 20.0715 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"mb503269160\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb503269160\" x=\"54.545602\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(48.429602 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb503269160\" x=\"119.476511\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(113.360511 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb503269160\" x=\"184.40742\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(178.29142 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb503269160\" x=\"249.33833\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(243.22233 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb503269160\" x=\"314.269239\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(308.153239 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb503269160\" x=\"379.200148\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 1.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(373.084148 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_7\">\n",
       "     <!-- $x$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(213.992875 313.402875) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-78\" d=\"M 3841 3500 \n",
       "L 2234 1784 \n",
       "L 3219 0 \n",
       "L 2559 0 \n",
       "L 1819 1388 \n",
       "L 531 0 \n",
       "L -166 0 \n",
       "L 1556 1844 \n",
       "L 641 3500 \n",
       "L 1300 3500 \n",
       "L 1972 2234 \n",
       "L 3144 3500 \n",
       "L 3841 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <defs>\n",
       "       <path id=\"md8261342bf\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#md8261342bf\" x=\"38.312875\" y=\"274.15073\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- −8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 277.300168) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#md8261342bf\" x=\"38.312875\" y=\"229.412902\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- −6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 232.562339) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#md8261342bf\" x=\"38.312875\" y=\"184.675073\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 187.824511) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#md8261342bf\" x=\"38.312875\" y=\"139.937245\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 143.086682) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#md8261342bf\" x=\"38.312875\" y=\"95.199417\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 98.348854) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#md8261342bf\" x=\"38.312875\" y=\"50.461588\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(25.11925 53.611026) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_14\">\n",
       "     <!-- $y$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(13.9635 156.0075) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-79\" d=\"M 1588 -325 \n",
       "Q 1188 -997 936 -1164 \n",
       "Q 684 -1331 294 -1331 \n",
       "L -159 -1331 \n",
       "L -63 -850 \n",
       "L 269 -850 \n",
       "Q 509 -850 678 -719 \n",
       "Q 847 -588 1056 -206 \n",
       "L 1234 128 \n",
       "L 459 3500 \n",
       "L 1069 3500 \n",
       "L 1650 819 \n",
       "L 3256 3500 \n",
       "L 3859 3500 \n",
       "L 1588 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_1\">\n",
       "    <defs>\n",
       "     <path id=\"md19424d57e\" d=\"M 54.545602 -290.343375 \n",
       "L 54.545602 -141.326251 \n",
       "L 57.824941 -143.237354 \n",
       "L 61.10428 -145.478877 \n",
       "L 64.383619 -148.066145 \n",
       "L 67.662958 -151.009252 \n",
       "L 70.942296 -154.312107 \n",
       "L 74.221636 -157.971629 \n",
       "L 77.500973 -161.97715 \n",
       "L 80.780313 -166.309835 \n",
       "L 84.059653 -170.94252 \n",
       "L 87.33899 -175.839208 \n",
       "L 90.61833 -180.955516 \n",
       "L 93.89767 -186.238738 \n",
       "L 97.177007 -191.628224 \n",
       "L 100.456344 -197.056865 \n",
       "L 103.735686 -202.451188 \n",
       "L 107.015024 -207.732799 \n",
       "L 110.294361 -212.82033 \n",
       "L 113.573703 -217.627 \n",
       "L 116.853041 -216.85412 \n",
       "L 120.132378 -215.078037 \n",
       "L 123.41172 -213.769274 \n",
       "L 126.691057 -212.927636 \n",
       "L 129.970395 -212.541689 \n",
       "L 133.249737 -212.586851 \n",
       "L 136.529069 -213.027513 \n",
       "L 139.808412 -213.81592 \n",
       "L 143.087754 -214.89348 \n",
       "L 146.367086 -216.191725 \n",
       "L 149.646428 -217.633573 \n",
       "L 152.92577 -219.134411 \n",
       "L 156.205103 -220.605398 \n",
       "L 159.484445 -217.304256 \n",
       "L 162.763787 -211.107949 \n",
       "L 166.04312 -204.16126 \n",
       "L 169.322462 -196.527626 \n",
       "L 172.601804 -188.280154 \n",
       "L 175.881137 -179.501556 \n",
       "L 179.160479 -170.282285 \n",
       "L 182.439821 -160.719836 \n",
       "L 185.719153 -150.917873 \n",
       "L 188.998496 -140.984577 \n",
       "L 192.277838 -131.031793 \n",
       "L 195.55717 -121.173704 \n",
       "L 198.836512 -111.525529 \n",
       "L 202.115855 -102.202326 \n",
       "L 205.395187 -93.317849 \n",
       "L 208.674529 -84.982966 \n",
       "L 211.953871 -77.304659 \n",
       "L 215.233204 -70.384494 \n",
       "L 218.512556 -64.317401 \n",
       "L 221.791879 -59.190373 \n",
       "L 225.071221 -55.081053 \n",
       "L 228.350563 -52.056604 \n",
       "L 231.629886 -50.172461 \n",
       "L 234.909247 -49.471193 \n",
       "L 238.18857 -49.981438 \n",
       "L 241.467912 -51.717148 \n",
       "L 244.747254 -54.676724 \n",
       "L 248.026597 -58.842555 \n",
       "L 251.305939 -64.180925 \n",
       "L 254.585262 -70.596327 \n",
       "L 257.864623 -67.617904 \n",
       "L 261.143946 -65.727735 \n",
       "L 264.423288 -65.011544 \n",
       "L 267.70263 -65.492073 \n",
       "L 270.981953 -67.172969 \n",
       "L 274.261315 -70.039161 \n",
       "L 277.540637 -74.055994 \n",
       "L 280.81998 -79.170158 \n",
       "L 284.099322 -85.310241 \n",
       "L 287.378664 -92.387244 \n",
       "L 290.658006 -100.296423 \n",
       "L 293.937329 -108.918572 \n",
       "L 297.21669 -118.122142 \n",
       "L 300.496013 -127.76444 \n",
       "L 303.775355 -137.695443 \n",
       "L 307.054697 -147.758752 \n",
       "L 310.33402 -157.795245 \n",
       "L 313.613382 -167.645409 \n",
       "L 316.892705 -177.152383 \n",
       "L 320.172047 -186.164482 \n",
       "L 323.451389 -194.538345 \n",
       "L 326.730731 -202.140937 \n",
       "L 330.010073 -208.852991 \n",
       "L 333.289396 -214.570566 \n",
       "L 336.568738 -219.207711 \n",
       "L 339.84808 -222.697762 \n",
       "L 343.127423 -224.993322 \n",
       "L 346.406765 -226.070164 \n",
       "L 349.686088 -225.92783 \n",
       "L 352.96543 -224.584945 \n",
       "L 356.244772 -222.065898 \n",
       "L 359.524114 -215.330544 \n",
       "L 362.803456 -208.463093 \n",
       "L 366.082798 -201.756701 \n",
       "L 369.362141 -195.355061 \n",
       "L 372.641463 -189.39675 \n",
       "L 375.920806 -184.007939 \n",
       "L 379.200148 -179.247181 \n",
       "L 379.200148 -179.33666 \n",
       "L 379.200148 -179.33666 \n",
       "L 375.920806 -187.299169 \n",
       "L 372.641463 -194.896742 \n",
       "L 369.362141 -201.940559 \n",
       "L 366.082798 -208.297983 \n",
       "L 362.803456 -213.846648 \n",
       "L 359.524114 -218.469437 \n",
       "L 356.244772 -222.206754 \n",
       "L 352.96543 -228.902818 \n",
       "L 349.686088 -235.295881 \n",
       "L 346.406765 -241.212747 \n",
       "L 343.127423 -246.502533 \n",
       "L 339.84808 -251.026418 \n",
       "L 336.568738 -254.656754 \n",
       "L 333.289396 -257.280906 \n",
       "L 330.010073 -258.805716 \n",
       "L 326.730731 -259.157865 \n",
       "L 323.451389 -258.285674 \n",
       "L 320.172047 -256.160221 \n",
       "L 316.892705 -252.775997 \n",
       "L 313.613382 -248.15036 \n",
       "L 310.33402 -242.323285 \n",
       "L 307.054697 -235.356537 \n",
       "L 303.775355 -227.331703 \n",
       "L 300.496013 -218.348851 \n",
       "L 297.21669 -208.524463 \n",
       "L 293.937329 -197.98822 \n",
       "L 290.658006 -186.88196 \n",
       "L 287.378664 -175.355138 \n",
       "L 284.099322 -163.563596 \n",
       "L 280.81998 -151.66578 \n",
       "L 277.540637 -139.820763 \n",
       "L 274.261315 -128.184907 \n",
       "L 270.981953 -116.909829 \n",
       "L 267.70263 -106.140068 \n",
       "L 264.423288 -96.010692 \n",
       "L 261.143946 -86.645857 \n",
       "L 257.864623 -78.156814 \n",
       "L 254.585262 -70.685797 \n",
       "L 251.305939 -74.739204 \n",
       "L 248.026597 -79.838841 \n",
       "L 244.747254 -85.850885 \n",
       "L 241.467912 -92.674637 \n",
       "L 238.18857 -100.198176 \n",
       "L 234.909247 -108.301119 \n",
       "L 231.629886 -116.856774 \n",
       "L 228.350563 -125.734339 \n",
       "L 225.071221 -134.801562 \n",
       "L 221.791879 -143.926985 \n",
       "L 218.512556 -152.982208 \n",
       "L 215.233204 -161.844595 \n",
       "L 211.953871 -170.398746 \n",
       "L 208.674529 -178.539246 \n",
       "L 205.395187 -186.171906 \n",
       "L 202.115855 -193.21555 \n",
       "L 198.836512 -199.603326 \n",
       "L 195.55717 -205.283635 \n",
       "L 192.277838 -210.220751 \n",
       "L 188.998496 -214.395333 \n",
       "L 185.719153 -217.804258 \n",
       "L 182.439821 -220.460382 \n",
       "L 179.160479 -222.391809 \n",
       "L 175.881137 -223.641034 \n",
       "L 172.601804 -224.263375 \n",
       "L 169.322462 -224.325599 \n",
       "L 166.04312 -223.904359 \n",
       "L 162.763787 -223.083563 \n",
       "L 159.484445 -221.952994 \n",
       "L 156.205103 -222.69794 \n",
       "L 152.92577 -227.248449 \n",
       "L 149.646428 -230.926271 \n",
       "L 146.367086 -233.715645 \n",
       "L 143.087754 -235.612399 \n",
       "L 139.808412 -236.625204 \n",
       "L 136.529069 -236.77497 \n",
       "L 133.249737 -236.094137 \n",
       "L 129.970395 -234.625996 \n",
       "L 126.691057 -232.4244 \n",
       "L 123.41172 -229.550981 \n",
       "L 120.132378 -226.076052 \n",
       "L 116.853041 -222.075549 \n",
       "L 113.573703 -219.089368 \n",
       "L 110.294361 -221.755851 \n",
       "L 107.015024 -224.830303 \n",
       "L 103.735686 -228.271533 \n",
       "L 100.456344 -232.035218 \n",
       "L 97.177007 -236.071465 \n",
       "L 93.89767 -240.326986 \n",
       "L 90.61833 -244.747064 \n",
       "L 87.33899 -249.275875 \n",
       "L 84.059653 -253.858856 \n",
       "L 80.780313 -258.443719 \n",
       "L 77.500973 -262.981341 \n",
       "L 74.221636 -267.427145 \n",
       "L 70.942296 -271.741291 \n",
       "L 67.662958 -275.889528 \n",
       "L 64.383619 -279.843408 \n",
       "L 61.10428 -283.580421 \n",
       "L 57.824941 -287.084049 \n",
       "L 54.545602 -290.343375 \n",
       "z\n",
       "\" style=\"stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pbad712fcc5)\">\n",
       "     <use xlink:href=\"#md19424d57e\" x=\"0\" y=\"322.510875\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_2\">\n",
       "    <defs>\n",
       "     <path id=\"m98f44af90e\" d=\"M 54.545602 -141.326251 \n",
       "L 54.545602 -141.326251 \n",
       "L 57.824941 -143.237354 \n",
       "L 61.10428 -145.478877 \n",
       "L 64.383619 -148.066145 \n",
       "L 67.662958 -151.009252 \n",
       "L 70.942296 -154.312107 \n",
       "L 74.221636 -157.971629 \n",
       "L 77.500973 -161.97715 \n",
       "L 80.780313 -166.309835 \n",
       "L 84.059653 -170.94252 \n",
       "L 87.33899 -175.839208 \n",
       "L 90.61833 -180.955516 \n",
       "L 93.89767 -186.238738 \n",
       "L 97.177007 -191.628224 \n",
       "L 100.456344 -197.056865 \n",
       "L 103.735686 -202.451188 \n",
       "L 107.015024 -207.732799 \n",
       "L 110.294361 -212.82033 \n",
       "L 113.573703 -217.627 \n",
       "L 116.853041 -216.85412 \n",
       "L 120.132378 -215.078037 \n",
       "L 123.41172 -213.769274 \n",
       "L 126.691057 -212.927636 \n",
       "L 129.970395 -212.541689 \n",
       "L 133.249737 -212.586851 \n",
       "L 136.529069 -213.027513 \n",
       "L 139.808412 -213.81592 \n",
       "L 143.087754 -214.89348 \n",
       "L 146.367086 -216.191725 \n",
       "L 149.646428 -217.633573 \n",
       "L 152.92577 -219.134411 \n",
       "L 156.205103 -220.605398 \n",
       "L 159.484445 -217.304256 \n",
       "L 162.763787 -211.107949 \n",
       "L 166.04312 -204.16126 \n",
       "L 169.322462 -196.527626 \n",
       "L 172.601804 -188.280154 \n",
       "L 175.881137 -179.501556 \n",
       "L 179.160479 -170.282285 \n",
       "L 182.439821 -160.719836 \n",
       "L 185.719153 -150.917873 \n",
       "L 188.998496 -140.984577 \n",
       "L 192.277838 -131.031793 \n",
       "L 195.55717 -121.173704 \n",
       "L 198.836512 -111.525529 \n",
       "L 202.115855 -102.202326 \n",
       "L 205.395187 -93.317849 \n",
       "L 208.674529 -84.982966 \n",
       "L 211.953871 -77.304659 \n",
       "L 215.233204 -70.384494 \n",
       "L 218.512556 -64.317401 \n",
       "L 221.791879 -59.190373 \n",
       "L 225.071221 -55.081053 \n",
       "L 228.350563 -52.056604 \n",
       "L 231.629886 -50.172461 \n",
       "L 234.909247 -49.471193 \n",
       "L 238.18857 -49.981438 \n",
       "L 241.467912 -51.717148 \n",
       "L 244.747254 -54.676724 \n",
       "L 248.026597 -58.842555 \n",
       "L 251.305939 -64.180925 \n",
       "L 254.585262 -70.596327 \n",
       "L 257.864623 -67.617904 \n",
       "L 261.143946 -65.727735 \n",
       "L 264.423288 -65.011544 \n",
       "L 267.70263 -65.492073 \n",
       "L 270.981953 -67.172969 \n",
       "L 274.261315 -70.039161 \n",
       "L 277.540637 -74.055994 \n",
       "L 280.81998 -79.170158 \n",
       "L 284.099322 -85.310241 \n",
       "L 287.378664 -92.387244 \n",
       "L 290.658006 -100.296423 \n",
       "L 293.937329 -108.918572 \n",
       "L 297.21669 -118.122142 \n",
       "L 300.496013 -127.76444 \n",
       "L 303.775355 -137.695443 \n",
       "L 307.054697 -147.758752 \n",
       "L 310.33402 -157.795245 \n",
       "L 313.613382 -167.645409 \n",
       "L 316.892705 -177.152383 \n",
       "L 320.172047 -186.164482 \n",
       "L 323.451389 -194.538345 \n",
       "L 326.730731 -202.140937 \n",
       "L 330.010073 -208.852991 \n",
       "L 333.289396 -214.570566 \n",
       "L 336.568738 -219.207711 \n",
       "L 339.84808 -222.697762 \n",
       "L 343.127423 -224.993322 \n",
       "L 346.406765 -226.070164 \n",
       "L 349.686088 -225.92783 \n",
       "L 352.96543 -224.584945 \n",
       "L 356.244772 -222.065898 \n",
       "L 359.524114 -215.330544 \n",
       "L 362.803456 -208.463093 \n",
       "L 366.082798 -201.756701 \n",
       "L 369.362141 -195.355061 \n",
       "L 372.641463 -189.39675 \n",
       "L 375.920806 -184.007939 \n",
       "L 379.200148 -179.247181 \n",
       "L 379.200148 -179.247181 \n",
       "L 379.200148 -179.247181 \n",
       "L 375.920806 -184.007939 \n",
       "L 372.641463 -189.39675 \n",
       "L 369.362141 -195.355061 \n",
       "L 366.082798 -201.756701 \n",
       "L 362.803456 -208.463093 \n",
       "L 359.524114 -215.330544 \n",
       "L 356.244772 -222.065898 \n",
       "L 352.96543 -224.584945 \n",
       "L 349.686088 -225.92783 \n",
       "L 346.406765 -226.070164 \n",
       "L 343.127423 -224.993322 \n",
       "L 339.84808 -222.697762 \n",
       "L 336.568738 -219.207711 \n",
       "L 333.289396 -214.570566 \n",
       "L 330.010073 -208.852991 \n",
       "L 326.730731 -202.140937 \n",
       "L 323.451389 -194.538345 \n",
       "L 320.172047 -186.164482 \n",
       "L 316.892705 -177.152383 \n",
       "L 313.613382 -167.645409 \n",
       "L 310.33402 -157.795245 \n",
       "L 307.054697 -147.758752 \n",
       "L 303.775355 -137.695443 \n",
       "L 300.496013 -127.76444 \n",
       "L 297.21669 -118.122142 \n",
       "L 293.937329 -108.918572 \n",
       "L 290.658006 -100.296423 \n",
       "L 287.378664 -92.387244 \n",
       "L 284.099322 -85.310241 \n",
       "L 280.81998 -79.170158 \n",
       "L 277.540637 -74.055994 \n",
       "L 274.261315 -70.039161 \n",
       "L 270.981953 -67.172969 \n",
       "L 267.70263 -65.492073 \n",
       "L 264.423288 -65.011544 \n",
       "L 261.143946 -65.727735 \n",
       "L 257.864623 -67.617904 \n",
       "L 254.585262 -70.596327 \n",
       "L 251.305939 -64.180925 \n",
       "L 248.026597 -58.842555 \n",
       "L 244.747254 -54.676724 \n",
       "L 241.467912 -51.717148 \n",
       "L 238.18857 -49.981438 \n",
       "L 234.909247 -49.471193 \n",
       "L 231.629886 -50.172461 \n",
       "L 228.350563 -52.056604 \n",
       "L 225.071221 -55.081053 \n",
       "L 221.791879 -59.190373 \n",
       "L 218.512556 -64.317401 \n",
       "L 215.233204 -70.384494 \n",
       "L 211.953871 -77.304659 \n",
       "L 208.674529 -84.982966 \n",
       "L 205.395187 -93.317849 \n",
       "L 202.115855 -102.202326 \n",
       "L 198.836512 -111.525529 \n",
       "L 195.55717 -121.173704 \n",
       "L 192.277838 -131.031793 \n",
       "L 188.998496 -140.984577 \n",
       "L 185.719153 -150.917873 \n",
       "L 182.439821 -160.719836 \n",
       "L 179.160479 -170.282285 \n",
       "L 175.881137 -179.501556 \n",
       "L 172.601804 -188.280154 \n",
       "L 169.322462 -196.527626 \n",
       "L 166.04312 -204.16126 \n",
       "L 162.763787 -211.107949 \n",
       "L 159.484445 -217.304256 \n",
       "L 156.205103 -220.605398 \n",
       "L 152.92577 -219.134411 \n",
       "L 149.646428 -217.633573 \n",
       "L 146.367086 -216.191725 \n",
       "L 143.087754 -214.89348 \n",
       "L 139.808412 -213.81592 \n",
       "L 136.529069 -213.027513 \n",
       "L 133.249737 -212.586851 \n",
       "L 129.970395 -212.541689 \n",
       "L 126.691057 -212.927636 \n",
       "L 123.41172 -213.769274 \n",
       "L 120.132378 -215.078037 \n",
       "L 116.853041 -216.85412 \n",
       "L 113.573703 -217.627 \n",
       "L 110.294361 -212.82033 \n",
       "L 107.015024 -207.732799 \n",
       "L 103.735686 -202.451188 \n",
       "L 100.456344 -197.056865 \n",
       "L 97.177007 -191.628224 \n",
       "L 93.89767 -186.238738 \n",
       "L 90.61833 -180.955516 \n",
       "L 87.33899 -175.839208 \n",
       "L 84.059653 -170.94252 \n",
       "L 80.780313 -166.309835 \n",
       "L 77.500973 -161.97715 \n",
       "L 74.221636 -157.971629 \n",
       "L 70.942296 -154.312107 \n",
       "L 67.662958 -151.009252 \n",
       "L 64.383619 -148.066145 \n",
       "L 61.10428 -145.478877 \n",
       "L 57.824941 -143.237354 \n",
       "L 54.545602 -141.326251 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pbad712fcc5)\">\n",
       "     <use xlink:href=\"#m98f44af90e\" x=\"0\" y=\"322.510875\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_3\">\n",
       "    <defs>\n",
       "     <path id=\"m3483b126ca\" d=\"M 54.545602 -290.343375 \n",
       "L 54.545602 -290.343375 \n",
       "L 57.824941 -287.084049 \n",
       "L 61.10428 -283.580421 \n",
       "L 64.383619 -279.843408 \n",
       "L 67.662958 -275.889528 \n",
       "L 70.942296 -271.741291 \n",
       "L 74.221636 -267.427145 \n",
       "L 77.500973 -262.981341 \n",
       "L 80.780313 -258.443719 \n",
       "L 84.059653 -253.858856 \n",
       "L 87.33899 -249.275875 \n",
       "L 90.61833 -244.747064 \n",
       "L 93.89767 -240.326986 \n",
       "L 97.177007 -236.071465 \n",
       "L 100.456344 -232.035218 \n",
       "L 103.735686 -228.271533 \n",
       "L 107.015024 -224.830303 \n",
       "L 110.294361 -221.755851 \n",
       "L 113.573703 -219.089368 \n",
       "L 116.853041 -222.075549 \n",
       "L 120.132378 -226.076052 \n",
       "L 123.41172 -229.550981 \n",
       "L 126.691057 -232.4244 \n",
       "L 129.970395 -234.625996 \n",
       "L 133.249737 -236.094137 \n",
       "L 136.529069 -236.77497 \n",
       "L 139.808412 -236.625204 \n",
       "L 143.087754 -235.612399 \n",
       "L 146.367086 -233.715645 \n",
       "L 149.646428 -230.926271 \n",
       "L 152.92577 -227.248449 \n",
       "L 156.205103 -222.69794 \n",
       "L 159.484445 -221.952994 \n",
       "L 162.763787 -223.083563 \n",
       "L 166.04312 -223.904359 \n",
       "L 169.322462 -224.325599 \n",
       "L 172.601804 -224.263375 \n",
       "L 175.881137 -223.641034 \n",
       "L 179.160479 -222.391809 \n",
       "L 182.439821 -220.460382 \n",
       "L 185.719153 -217.804258 \n",
       "L 188.998496 -214.395333 \n",
       "L 192.277838 -210.220751 \n",
       "L 195.55717 -205.283635 \n",
       "L 198.836512 -199.603326 \n",
       "L 202.115855 -193.21555 \n",
       "L 205.395187 -186.171906 \n",
       "L 208.674529 -178.539246 \n",
       "L 211.953871 -170.398746 \n",
       "L 215.233204 -161.844595 \n",
       "L 218.512556 -152.982208 \n",
       "L 221.791879 -143.926985 \n",
       "L 225.071221 -134.801562 \n",
       "L 228.350563 -125.734339 \n",
       "L 231.629886 -116.856774 \n",
       "L 234.909247 -108.301119 \n",
       "L 238.18857 -100.198176 \n",
       "L 241.467912 -92.674637 \n",
       "L 244.747254 -85.850885 \n",
       "L 248.026597 -79.838841 \n",
       "L 251.305939 -74.739204 \n",
       "L 254.585262 -70.685797 \n",
       "L 257.864623 -78.156814 \n",
       "L 261.143946 -86.645857 \n",
       "L 264.423288 -96.010692 \n",
       "L 267.70263 -106.140068 \n",
       "L 270.981953 -116.909829 \n",
       "L 274.261315 -128.184907 \n",
       "L 277.540637 -139.820763 \n",
       "L 280.81998 -151.66578 \n",
       "L 284.099322 -163.563596 \n",
       "L 287.378664 -175.355138 \n",
       "L 290.658006 -186.88196 \n",
       "L 293.937329 -197.98822 \n",
       "L 297.21669 -208.524463 \n",
       "L 300.496013 -218.348851 \n",
       "L 303.775355 -227.331703 \n",
       "L 307.054697 -235.356537 \n",
       "L 310.33402 -242.323285 \n",
       "L 313.613382 -248.15036 \n",
       "L 316.892705 -252.775997 \n",
       "L 320.172047 -256.160221 \n",
       "L 323.451389 -258.285674 \n",
       "L 326.730731 -259.157865 \n",
       "L 330.010073 -258.805716 \n",
       "L 333.289396 -257.280906 \n",
       "L 336.568738 -254.656754 \n",
       "L 339.84808 -251.026418 \n",
       "L 343.127423 -246.502533 \n",
       "L 346.406765 -241.212747 \n",
       "L 349.686088 -235.295881 \n",
       "L 352.96543 -228.902818 \n",
       "L 356.244772 -222.206754 \n",
       "L 359.524114 -218.469437 \n",
       "L 362.803456 -213.846648 \n",
       "L 366.082798 -208.297983 \n",
       "L 369.362141 -201.940559 \n",
       "L 372.641463 -194.896742 \n",
       "L 375.920806 -187.299169 \n",
       "L 379.200148 -179.33666 \n",
       "L 379.200148 -179.33666 \n",
       "L 379.200148 -179.33666 \n",
       "L 375.920806 -187.299169 \n",
       "L 372.641463 -194.896742 \n",
       "L 369.362141 -201.940559 \n",
       "L 366.082798 -208.297983 \n",
       "L 362.803456 -213.846648 \n",
       "L 359.524114 -218.469437 \n",
       "L 356.244772 -222.206754 \n",
       "L 352.96543 -228.902818 \n",
       "L 349.686088 -235.295881 \n",
       "L 346.406765 -241.212747 \n",
       "L 343.127423 -246.502533 \n",
       "L 339.84808 -251.026418 \n",
       "L 336.568738 -254.656754 \n",
       "L 333.289396 -257.280906 \n",
       "L 330.010073 -258.805716 \n",
       "L 326.730731 -259.157865 \n",
       "L 323.451389 -258.285674 \n",
       "L 320.172047 -256.160221 \n",
       "L 316.892705 -252.775997 \n",
       "L 313.613382 -248.15036 \n",
       "L 310.33402 -242.323285 \n",
       "L 307.054697 -235.356537 \n",
       "L 303.775355 -227.331703 \n",
       "L 300.496013 -218.348851 \n",
       "L 297.21669 -208.524463 \n",
       "L 293.937329 -197.98822 \n",
       "L 290.658006 -186.88196 \n",
       "L 287.378664 -175.355138 \n",
       "L 284.099322 -163.563596 \n",
       "L 280.81998 -151.66578 \n",
       "L 277.540637 -139.820763 \n",
       "L 274.261315 -128.184907 \n",
       "L 270.981953 -116.909829 \n",
       "L 267.70263 -106.140068 \n",
       "L 264.423288 -96.010692 \n",
       "L 261.143946 -86.645857 \n",
       "L 257.864623 -78.156814 \n",
       "L 254.585262 -70.685797 \n",
       "L 251.305939 -74.739204 \n",
       "L 248.026597 -79.838841 \n",
       "L 244.747254 -85.850885 \n",
       "L 241.467912 -92.674637 \n",
       "L 238.18857 -100.198176 \n",
       "L 234.909247 -108.301119 \n",
       "L 231.629886 -116.856774 \n",
       "L 228.350563 -125.734339 \n",
       "L 225.071221 -134.801562 \n",
       "L 221.791879 -143.926985 \n",
       "L 218.512556 -152.982208 \n",
       "L 215.233204 -161.844595 \n",
       "L 211.953871 -170.398746 \n",
       "L 208.674529 -178.539246 \n",
       "L 205.395187 -186.171906 \n",
       "L 202.115855 -193.21555 \n",
       "L 198.836512 -199.603326 \n",
       "L 195.55717 -205.283635 \n",
       "L 192.277838 -210.220751 \n",
       "L 188.998496 -214.395333 \n",
       "L 185.719153 -217.804258 \n",
       "L 182.439821 -220.460382 \n",
       "L 179.160479 -222.391809 \n",
       "L 175.881137 -223.641034 \n",
       "L 172.601804 -224.263375 \n",
       "L 169.322462 -224.325599 \n",
       "L 166.04312 -223.904359 \n",
       "L 162.763787 -223.083563 \n",
       "L 159.484445 -221.952994 \n",
       "L 156.205103 -222.69794 \n",
       "L 152.92577 -227.248449 \n",
       "L 149.646428 -230.926271 \n",
       "L 146.367086 -233.715645 \n",
       "L 143.087754 -235.612399 \n",
       "L 139.808412 -236.625204 \n",
       "L 136.529069 -236.77497 \n",
       "L 133.249737 -236.094137 \n",
       "L 129.970395 -234.625996 \n",
       "L 126.691057 -232.4244 \n",
       "L 123.41172 -229.550981 \n",
       "L 120.132378 -226.076052 \n",
       "L 116.853041 -222.075549 \n",
       "L 113.573703 -219.089368 \n",
       "L 110.294361 -221.755851 \n",
       "L 107.015024 -224.830303 \n",
       "L 103.735686 -228.271533 \n",
       "L 100.456344 -232.035218 \n",
       "L 97.177007 -236.071465 \n",
       "L 93.89767 -240.326986 \n",
       "L 90.61833 -244.747064 \n",
       "L 87.33899 -249.275875 \n",
       "L 84.059653 -253.858856 \n",
       "L 80.780313 -258.443719 \n",
       "L 77.500973 -262.981341 \n",
       "L 74.221636 -267.427145 \n",
       "L 70.942296 -271.741291 \n",
       "L 67.662958 -275.889528 \n",
       "L 64.383619 -279.843408 \n",
       "L 61.10428 -283.580421 \n",
       "L 57.824941 -287.084049 \n",
       "L 54.545602 -290.343375 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pbad712fcc5)\">\n",
       "     <use xlink:href=\"#m3483b126ca\" x=\"0\" y=\"322.510875\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_13\">\n",
       "    <defs>\n",
       "     <path id=\"m377f865f04\" d=\"M -5 5 \n",
       "L 5 -5 \n",
       "M -5 -5 \n",
       "L 5 5 \n",
       "\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pbad712fcc5)\">\n",
       "     <use xlink:href=\"#m377f865f04\" x=\"356.349693\" y=\"100.533088\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m377f865f04\" x=\"157.258364\" y=\"101.4549\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m377f865f04\" x=\"114.255683\" y=\"103.924594\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m377f865f04\" x=\"254.585262\" y=\"251.86977\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m377f865f04\" x=\"379.200148\" y=\"143.218821\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_14\">\n",
       "    <path d=\"M 54.545602 106.676065 \n",
       "L 57.824941 107.350174 \n",
       "L 61.10428 107.981229 \n",
       "L 64.383619 108.556101 \n",
       "L 67.662958 109.061482 \n",
       "L 70.942296 109.484176 \n",
       "L 74.221636 109.811488 \n",
       "L 77.500973 110.031628 \n",
       "L 80.780313 110.134099 \n",
       "L 84.059653 110.110188 \n",
       "L 87.33899 109.953333 \n",
       "L 90.61833 109.659586 \n",
       "L 93.89767 109.228013 \n",
       "L 97.177007 108.66103 \n",
       "L 100.456344 107.964833 \n",
       "L 103.735686 107.149515 \n",
       "L 107.015024 106.229324 \n",
       "L 110.294361 105.222785 \n",
       "L 113.573703 104.152691 \n",
       "L 116.853041 103.046041 \n",
       "L 120.132378 101.93383 \n",
       "L 123.41172 100.850747 \n",
       "L 126.691057 99.834857 \n",
       "L 129.970395 98.927032 \n",
       "L 133.249737 98.170381 \n",
       "L 136.529069 97.609634 \n",
       "L 139.808412 97.290313 \n",
       "L 143.087754 97.257936 \n",
       "L 146.367086 97.55719 \n",
       "L 149.646428 98.230953 \n",
       "L 152.92577 99.319445 \n",
       "L 156.205103 100.859206 \n",
       "L 159.484445 102.88225 \n",
       "L 162.763787 105.415119 \n",
       "L 166.04312 108.478066 \n",
       "L 169.322462 112.084263 \n",
       "L 172.601804 116.239112 \n",
       "L 175.881137 120.939579 \n",
       "L 179.160479 126.173827 \n",
       "L 182.439821 131.920768 \n",
       "L 185.719153 138.149808 \n",
       "L 188.998496 144.82092 \n",
       "L 192.277838 151.884601 \n",
       "L 195.55717 159.282207 \n",
       "L 198.836512 166.94645 \n",
       "L 202.115855 174.801935 \n",
       "L 205.395187 182.765998 \n",
       "L 208.674529 190.749772 \n",
       "L 211.953871 198.659175 \n",
       "L 215.233204 206.396328 \n",
       "L 218.512556 213.861073 \n",
       "L 221.791879 220.952198 \n",
       "L 225.071221 227.569568 \n",
       "L 228.350563 233.615403 \n",
       "L 231.629886 238.996257 \n",
       "L 234.909247 243.624719 \n",
       "L 238.18857 247.421068 \n",
       "L 241.467912 250.314982 \n",
       "L 244.747254 252.24707 \n",
       "L 248.026597 253.170177 \n",
       "L 251.305939 253.05081 \n",
       "L 254.585262 251.869813 \n",
       "L 257.864623 249.623516 \n",
       "L 261.143946 246.324079 \n",
       "L 264.423288 241.999757 \n",
       "L 267.70263 236.694805 \n",
       "L 270.981953 230.469476 \n",
       "L 274.261315 223.398841 \n",
       "L 277.540637 215.572497 \n",
       "L 280.81998 207.092903 \n",
       "L 284.099322 198.073956 \n",
       "L 287.378664 188.639684 \n",
       "L 290.658006 178.921682 \n",
       "L 293.937329 169.057476 \n",
       "L 297.21669 159.18757 \n",
       "L 300.496013 149.454229 \n",
       "L 303.775355 139.997302 \n",
       "L 307.054697 130.95323 \n",
       "L 310.33402 122.451611 \n",
       "L 313.613382 114.61299 \n",
       "L 316.892705 107.546685 \n",
       "L 320.172047 101.348524 \n",
       "L 323.451389 96.098866 \n",
       "L 326.730731 91.861474 \n",
       "L 330.010073 88.681521 \n",
       "L 333.289396 86.58514 \n",
       "L 336.568738 85.578643 \n",
       "L 339.84808 85.648785 \n",
       "L 343.127423 86.762947 \n",
       "L 346.406765 88.869419 \n",
       "L 349.686088 91.89902 \n",
       "L 352.96543 95.766993 \n",
       "L 356.244772 100.374549 \n",
       "L 359.524114 105.610885 \n",
       "L 362.803456 111.356005 \n",
       "L 366.082798 117.483534 \n",
       "L 369.362141 123.863065 \n",
       "L 372.641463 130.364129 \n",
       "L 375.920806 136.857321 \n",
       "L 379.200148 143.218955 \n",
       "\" clip-path=\"url(#pbad712fcc5)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_15\">\n",
       "    <path d=\"M 54.545602 184.022347 \n",
       "L 57.824941 178.563555 \n",
       "L 61.10428 173.125017 \n",
       "L 64.383619 167.726905 \n",
       "L 67.662958 162.389314 \n",
       "L 70.942296 157.132115 \n",
       "L 74.221636 151.974987 \n",
       "L 77.500973 146.937264 \n",
       "L 80.780313 142.037893 \n",
       "L 84.059653 137.295409 \n",
       "L 87.33899 132.727804 \n",
       "L 90.61833 128.352513 \n",
       "L 93.89767 124.186335 \n",
       "L 97.177007 120.245382 \n",
       "L 100.456344 116.545003 \n",
       "L 103.735686 113.099779 \n",
       "L 107.015024 109.923421 \n",
       "L 110.294361 107.028749 \n",
       "L 113.573703 104.427632 \n",
       "L 116.853041 102.130968 \n",
       "L 120.132378 100.148642 \n",
       "L 123.41172 98.489462 \n",
       "L 126.691057 97.161163 \n",
       "L 129.970395 96.170362 \n",
       "L 133.249737 95.522526 \n",
       "L 136.529069 95.221965 \n",
       "L 139.808412 95.271809 \n",
       "L 143.087754 95.673972 \n",
       "L 146.367086 96.429164 \n",
       "L 149.646428 97.536879 \n",
       "L 152.92577 98.995366 \n",
       "L 156.205103 100.801629 \n",
       "L 159.484445 102.951465 \n",
       "L 162.763787 105.439386 \n",
       "L 166.04312 108.2587 \n",
       "L 169.322462 111.401459 \n",
       "L 172.601804 114.858486 \n",
       "L 175.881137 118.619375 \n",
       "L 179.160479 122.672484 \n",
       "L 182.439821 127.005003 \n",
       "L 185.719153 131.602842 \n",
       "L 188.998496 136.450774 \n",
       "L 192.277838 141.53232 \n",
       "L 195.55717 146.82988 \n",
       "L 198.836512 152.324619 \n",
       "L 202.115855 157.996509 \n",
       "L 205.395187 163.824362 \n",
       "L 208.674529 169.785827 \n",
       "L 211.953871 175.857315 \n",
       "L 215.233204 182.014096 \n",
       "L 218.512556 188.230236 \n",
       "L 221.791879 194.478539 \n",
       "L 225.071221 200.730683 \n",
       "L 228.350563 206.957089 \n",
       "L 231.629886 213.126793 \n",
       "L 234.909247 219.207848 \n",
       "L 238.18857 225.1667 \n",
       "L 241.467912 230.968778 \n",
       "L 244.747254 236.578051 \n",
       "L 248.026597 241.95723 \n",
       "L 251.305939 247.067778 \n",
       "L 254.585262 251.86977 \n",
       "L 257.864623 256.322142 \n",
       "L 261.143946 260.382557 \n",
       "L 264.423288 264.007627 \n",
       "L 267.70263 267.152935 \n",
       "L 270.981953 269.773322 \n",
       "L 274.261315 271.822964 \n",
       "L 277.540637 273.255782 \n",
       "L 280.81998 274.025774 \n",
       "L 284.099322 274.0875 \n",
       "L 287.378664 273.396685 \n",
       "L 290.658006 271.911014 \n",
       "L 293.937329 269.591013 \n",
       "L 297.21669 266.401066 \n",
       "L 300.496013 262.311168 \n",
       "L 303.775355 257.297887 \n",
       "L 307.054697 251.346822 \n",
       "L 310.33402 244.454687 \n",
       "L 313.613382 236.631575 \n",
       "L 316.892705 227.904373 \n",
       "L 320.172047 218.319642 \n",
       "L 323.451389 207.947404 \n",
       "L 326.730731 196.885119 \n",
       "L 330.010073 185.261657 \n",
       "L 333.289396 173.241509 \n",
       "L 336.568738 161.028824 \n",
       "L 339.84808 148.870616 \n",
       "L 343.127423 137.059453 \n",
       "L 346.406765 125.934461 \n",
       "L 349.686088 115.879542 \n",
       "L 352.96543 107.31865 \n",
       "L 356.244772 100.707179 \n",
       "L 359.524114 96.516388 \n",
       "L 362.803456 95.211816 \n",
       "L 366.082798 97.22267 \n",
       "L 369.362141 102.901776 \n",
       "L 372.641463 112.47567 \n",
       "L 375.920806 125.98511 \n",
       "L 379.200148 143.218821 \n",
       "\" clip-path=\"url(#pbad712fcc5)\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 38.312875 274.15073 \n",
       "L 38.312875 50.461588 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 54.545602 286.1835 \n",
       "L 379.200148 286.1835 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_15\">\n",
       "    <!-- N=1,  -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(205.266625 14.0715) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-4e\" d=\"M 488 0 \n",
       "L 488 4581 \n",
       "L 1109 4581 \n",
       "L 3516 984 \n",
       "L 3516 4581 \n",
       "L 4097 4581 \n",
       "L 4097 0 \n",
       "L 3475 0 \n",
       "L 1069 3600 \n",
       "L 1069 0 \n",
       "L 488 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-3d\" d=\"M 3381 2694 \n",
       "L 356 2694 \n",
       "L 356 3219 \n",
       "L 3381 3219 \n",
       "L 3381 2694 \n",
       "z\n",
       "M 3381 1303 \n",
       "L 356 1303 \n",
       "L 356 1828 \n",
       "L 3381 1828 \n",
       "L 3381 1303 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-2c\" d=\"M 569 0 \n",
       "L 569 641 \n",
       "L 1209 641 \n",
       "L 1209 0 \n",
       "Q 1209 -353 1084 -570 \n",
       "Q 959 -788 688 -906 \n",
       "L 531 -666 \n",
       "Q 709 -588 793 -436 \n",
       "Q 878 -284 888 0 \n",
       "L 569 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-4e\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"72.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-31\" x=\"130.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-2c\" x=\"186.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-20\" x=\"214.013672\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"legend_1\">\n",
       "    <g id=\"line2d_16\">\n",
       "     <g>\n",
       "      <use xlink:href=\"#m377f865f04\" x=\"55.032875\" y=\"31.210375\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_16\">\n",
       "     <!-- Observations -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 34.290375) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4f\" d=\"M 309 2231 \n",
       "Q 309 3372 921 4017 \n",
       "Q 1534 4663 2503 4663 \n",
       "Q 3138 4663 3647 4359 \n",
       "Q 4156 4056 4423 3514 \n",
       "Q 4691 2972 4691 2284 \n",
       "Q 4691 1588 4409 1038 \n",
       "Q 4128 488 3612 205 \n",
       "Q 3097 -78 2500 -78 \n",
       "Q 1853 -78 1343 234 \n",
       "Q 834 547 571 1087 \n",
       "Q 309 1628 309 2231 \n",
       "z\n",
       "M 934 2222 \n",
       "Q 934 1394 1379 917 \n",
       "Q 1825 441 2497 441 \n",
       "Q 3181 441 3623 922 \n",
       "Q 4066 1403 4066 2288 \n",
       "Q 4066 2847 3877 3264 \n",
       "Q 3688 3681 3323 3911 \n",
       "Q 2959 4141 2506 4141 \n",
       "Q 1863 4141 1398 3698 \n",
       "Q 934 3256 934 2222 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-62\" d=\"M 941 0 \n",
       "L 419 0 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 2947 \n",
       "Q 1338 3394 1891 3394 \n",
       "Q 2197 3394 2470 3270 \n",
       "Q 2744 3147 2920 2923 \n",
       "Q 3097 2700 3197 2384 \n",
       "Q 3297 2069 3297 1709 \n",
       "Q 3297 856 2875 390 \n",
       "Q 2453 -75 1863 -75 \n",
       "Q 1275 -75 941 416 \n",
       "L 941 0 \n",
       "z\n",
       "M 934 1684 \n",
       "Q 934 1088 1097 822 \n",
       "Q 1363 388 1816 388 \n",
       "Q 2184 388 2453 708 \n",
       "Q 2722 1028 2722 1663 \n",
       "Q 2722 2313 2464 2622 \n",
       "Q 2206 2931 1841 2931 \n",
       "Q 1472 2931 1203 2611 \n",
       "Q 934 2291 934 1684 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-76\" d=\"M 1344 0 \n",
       "L 81 3319 \n",
       "L 675 3319 \n",
       "L 1388 1331 \n",
       "Q 1503 1009 1600 663 \n",
       "Q 1675 925 1809 1294 \n",
       "L 2547 3319 \n",
       "L 3125 3319 \n",
       "L 1869 0 \n",
       "L 1344 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4f\"/>\n",
       "      <use xlink:href=\"#ArialMT-62\" x=\"77.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"133.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"183.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"239.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"272.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"322.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"377.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"405.712891\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"427.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"483.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"539.160156\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_17\">\n",
       "     <path d=\"M 46.232875 43.794375 \n",
       "L 55.032875 43.794375 \n",
       "L 63.832875 43.794375 \n",
       "\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "    </g>\n",
       "    <g id=\"text_17\">\n",
       "     <!-- $m_n(x)$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 46.874375) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-6d\" d=\"M 5747 2113 \n",
       "L 5338 0 \n",
       "L 4763 0 \n",
       "L 5166 2094 \n",
       "Q 5191 2228 5203 2325 \n",
       "Q 5216 2422 5216 2491 \n",
       "Q 5216 2772 5059 2928 \n",
       "Q 4903 3084 4622 3084 \n",
       "Q 4203 3084 3875 2770 \n",
       "Q 3547 2456 3450 1953 \n",
       "L 3066 0 \n",
       "L 2491 0 \n",
       "L 2900 2094 \n",
       "Q 2925 2209 2937 2307 \n",
       "Q 2950 2406 2950 2484 \n",
       "Q 2950 2769 2794 2926 \n",
       "Q 2638 3084 2363 3084 \n",
       "Q 1938 3084 1609 2770 \n",
       "Q 1281 2456 1184 1953 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 909 3500 \n",
       "L 1484 3500 \n",
       "L 1375 2956 \n",
       "Q 1609 3263 1923 3423 \n",
       "Q 2238 3584 2597 3584 \n",
       "Q 2978 3584 3223 3384 \n",
       "Q 3469 3184 3519 2828 \n",
       "Q 3781 3197 4126 3390 \n",
       "Q 4472 3584 4856 3584 \n",
       "Q 5306 3584 5551 3325 \n",
       "Q 5797 3066 5797 2591 \n",
       "Q 5797 2488 5784 2364 \n",
       "Q 5772 2241 5747 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Oblique-6e\" d=\"M 3566 2113 \n",
       "L 3156 0 \n",
       "L 2578 0 \n",
       "L 2988 2091 \n",
       "Q 3016 2238 3031 2350 \n",
       "Q 3047 2463 3047 2528 \n",
       "Q 3047 2791 2881 2937 \n",
       "Q 2716 3084 2419 3084 \n",
       "Q 1956 3084 1622 2776 \n",
       "Q 1288 2469 1184 1941 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 903 3500 \n",
       "L 1478 3500 \n",
       "L 1363 2950 \n",
       "Q 1603 3253 1940 3418 \n",
       "Q 2278 3584 2650 3584 \n",
       "Q 3113 3584 3367 3334 \n",
       "Q 3622 3084 3622 2631 \n",
       "Q 3622 2519 3608 2391 \n",
       "Q 3594 2263 3566 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-28\" d=\"M 1984 4856 \n",
       "Q 1566 4138 1362 3434 \n",
       "Q 1159 2731 1159 2009 \n",
       "Q 1159 1288 1364 580 \n",
       "Q 1569 -128 1984 -844 \n",
       "L 1484 -844 \n",
       "Q 1016 -109 783 600 \n",
       "Q 550 1309 550 2009 \n",
       "Q 550 2706 781 3412 \n",
       "Q 1013 4119 1484 4856 \n",
       "L 1984 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-29\" d=\"M 513 4856 \n",
       "L 1013 4856 \n",
       "Q 1481 4119 1714 3412 \n",
       "Q 1947 2706 1947 2009 \n",
       "Q 1947 1309 1714 600 \n",
       "Q 1481 -109 1013 -844 \n",
       "L 513 -844 \n",
       "Q 928 -128 1133 580 \n",
       "Q 1338 1288 1338 2009 \n",
       "Q 1338 2731 1133 3434 \n",
       "Q 928 4138 513 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6d\" transform=\"translate(0 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6e\" transform=\"translate(97.412109 -16.28125) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(144.511719 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(183.525391 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(242.705078 0.125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_5\">\n",
       "     <path d=\"M 46.232875 61.031375 \n",
       "L 63.832875 61.031375 \n",
       "L 63.832875 54.871375 \n",
       "L 46.232875 54.871375 \n",
       "z\n",
       "\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_18\">\n",
       "     <!-- $f(\\mathbf{x}^*)$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 61.031375) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-66\" d=\"M 3059 4863 \n",
       "L 2969 4384 \n",
       "L 2419 4384 \n",
       "Q 2106 4384 1964 4261 \n",
       "Q 1822 4138 1753 3809 \n",
       "L 1691 3500 \n",
       "L 2638 3500 \n",
       "L 2553 3053 \n",
       "L 1606 3053 \n",
       "L 1013 0 \n",
       "L 434 0 \n",
       "L 1031 3053 \n",
       "L 481 3053 \n",
       "L 563 3500 \n",
       "L 1113 3500 \n",
       "L 1159 3744 \n",
       "Q 1278 4363 1576 4613 \n",
       "Q 1875 4863 2516 4863 \n",
       "L 3059 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Bold-78\" d=\"M 1422 1791 \n",
       "L 159 3500 \n",
       "L 1344 3500 \n",
       "L 2059 2463 \n",
       "L 2784 3500 \n",
       "L 3969 3500 \n",
       "L 2706 1797 \n",
       "L 4031 0 \n",
       "L 2847 0 \n",
       "L 2059 1106 \n",
       "L 1281 0 \n",
       "L 97 0 \n",
       "L 1422 1791 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-2a\" d=\"M 3009 3897 \n",
       "L 1888 3291 \n",
       "L 3009 2681 \n",
       "L 2828 2375 \n",
       "L 1778 3009 \n",
       "L 1778 1831 \n",
       "L 1422 1831 \n",
       "L 1422 3009 \n",
       "L 372 2375 \n",
       "L 191 2681 \n",
       "L 1313 3291 \n",
       "L 191 3897 \n",
       "L 372 4206 \n",
       "L 1422 3572 \n",
       "L 1422 4750 \n",
       "L 1778 4750 \n",
       "L 1778 3572 \n",
       "L 2828 4206 \n",
       "L 3009 3897 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-39\" d=\"M 350 1059 \n",
       "L 891 1109 \n",
       "Q 959 728 1153 556 \n",
       "Q 1347 384 1650 384 \n",
       "Q 1909 384 2104 503 \n",
       "Q 2300 622 2425 820 \n",
       "Q 2550 1019 2634 1356 \n",
       "Q 2719 1694 2719 2044 \n",
       "Q 2719 2081 2716 2156 \n",
       "Q 2547 1888 2255 1720 \n",
       "Q 1963 1553 1622 1553 \n",
       "Q 1053 1553 659 1965 \n",
       "Q 266 2378 266 3053 \n",
       "Q 266 3750 677 4175 \n",
       "Q 1088 4600 1706 4600 \n",
       "Q 2153 4600 2523 4359 \n",
       "Q 2894 4119 3086 3673 \n",
       "Q 3278 3228 3278 2384 \n",
       "Q 3278 1506 3087 986 \n",
       "Q 2897 466 2520 194 \n",
       "Q 2144 -78 1638 -78 \n",
       "Q 1100 -78 759 220 \n",
       "Q 419 519 350 1059 \n",
       "z\n",
       "M 2653 3081 \n",
       "Q 2653 3566 2395 3850 \n",
       "Q 2138 4134 1775 4134 \n",
       "Q 1400 4134 1122 3828 \n",
       "Q 844 3522 844 3034 \n",
       "Q 844 2597 1108 2323 \n",
       "Q 1372 2050 1759 2050 \n",
       "Q 2150 2050 2401 2323 \n",
       "Q 2653 2597 2653 3081 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-25\" d=\"M 372 3481 \n",
       "Q 372 3972 619 4315 \n",
       "Q 866 4659 1334 4659 \n",
       "Q 1766 4659 2048 4351 \n",
       "Q 2331 4044 2331 3447 \n",
       "Q 2331 2866 2045 2552 \n",
       "Q 1759 2238 1341 2238 \n",
       "Q 925 2238 648 2547 \n",
       "Q 372 2856 372 3481 \n",
       "z\n",
       "M 1350 4272 \n",
       "Q 1141 4272 1002 4090 \n",
       "Q 863 3909 863 3425 \n",
       "Q 863 2984 1003 2804 \n",
       "Q 1144 2625 1350 2625 \n",
       "Q 1563 2625 1702 2806 \n",
       "Q 1841 2988 1841 3469 \n",
       "Q 1841 3913 1700 4092 \n",
       "Q 1559 4272 1350 4272 \n",
       "z\n",
       "M 1353 -169 \n",
       "L 3859 4659 \n",
       "L 4316 4659 \n",
       "L 1819 -169 \n",
       "L 1353 -169 \n",
       "z\n",
       "M 3334 1075 \n",
       "Q 3334 1569 3581 1911 \n",
       "Q 3828 2253 4300 2253 \n",
       "Q 4731 2253 5014 1945 \n",
       "Q 5297 1638 5297 1041 \n",
       "Q 5297 459 5011 145 \n",
       "Q 4725 -169 4303 -169 \n",
       "Q 3888 -169 3611 142 \n",
       "Q 3334 453 3334 1075 \n",
       "z\n",
       "M 4316 1866 \n",
       "Q 4103 1866 3964 1684 \n",
       "Q 3825 1503 3825 1019 \n",
       "Q 3825 581 3965 400 \n",
       "Q 4106 219 4313 219 \n",
       "Q 4528 219 4667 400 \n",
       "Q 4806 581 4806 1063 \n",
       "Q 4806 1506 4665 1686 \n",
       "Q 4525 1866 4316 1866 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-66\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(35.205078 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Bold-78\" transform=\"translate(74.21875 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(153.31543 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(204.6875 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(243.701172 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(271.484375 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(327.099609 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(382.714844 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(471.630859 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(499.414062 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(555.029297 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(588.330078 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(643.945312 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(699.560547 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_6\">\n",
       "     <path d=\"M 46.232875 75.199375 \n",
       "L 63.832875 75.199375 \n",
       "L 63.832875 69.039375 \n",
       "L 46.232875 69.039375 \n",
       "z\n",
       "\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_19\">\n",
       "     <!-- $y^*$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 75.199375) scale(0.088 -0.088)\">\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(77.283529 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(128.655599 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(156.438802 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(212.054036 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(267.669271 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(356.585286 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(384.36849 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(439.983724 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(473.284505 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(528.89974 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(584.514974 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_18\">\n",
       "     <path d=\"M 46.232875 84.66625 \n",
       "L 55.032875 84.66625 \n",
       "L 63.832875 84.66625 \n",
       "\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "    </g>\n",
       "    <g id=\"text_20\">\n",
       "     <!-- True function -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(70.872875 87.74625) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-54\" d=\"M 1659 0 \n",
       "L 1659 4041 \n",
       "L 150 4041 \n",
       "L 150 4581 \n",
       "L 3781 4581 \n",
       "L 3781 4041 \n",
       "L 2266 4041 \n",
       "L 2266 0 \n",
       "L 1659 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-66\" d=\"M 556 0 \n",
       "L 556 2881 \n",
       "L 59 2881 \n",
       "L 59 3319 \n",
       "L 556 3319 \n",
       "L 556 3672 \n",
       "Q 556 4006 616 4169 \n",
       "Q 697 4388 901 4523 \n",
       "Q 1106 4659 1475 4659 \n",
       "Q 1713 4659 2000 4603 \n",
       "L 1916 4113 \n",
       "Q 1741 4144 1584 4144 \n",
       "Q 1328 4144 1222 4034 \n",
       "Q 1116 3925 1116 3625 \n",
       "L 1116 3319 \n",
       "L 1763 3319 \n",
       "L 1763 2881 \n",
       "L 1116 2881 \n",
       "L 1116 0 \n",
       "L 556 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-54\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"57.333984\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"90.634766\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"146.25\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"201.865234\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"229.648438\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"257.431641\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"313.046875\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"368.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"418.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"446.445312\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"468.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"524.277344\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_19\">\n",
       "      <defs>\n",
       "       <path id=\"ma199b051a4\" d=\"M 0 0 \n",
       "L 4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma199b051a4\" x=\"395.432875\" y=\"274.0875\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_21\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 277.236937) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_20\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma199b051a4\" x=\"395.432875\" y=\"238.3009\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_22\">\n",
       "      <!-- 0.1 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 241.450337) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_9\">\n",
       "     <g id=\"line2d_21\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma199b051a4\" x=\"395.432875\" y=\"202.514299\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_23\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 205.663737) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_10\">\n",
       "     <g id=\"line2d_22\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma199b051a4\" x=\"395.432875\" y=\"166.727699\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_24\">\n",
       "      <!-- 0.3 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 169.877136) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-33\" d=\"M 269 1209 \n",
       "L 831 1284 \n",
       "Q 928 806 1161 595 \n",
       "Q 1394 384 1728 384 \n",
       "Q 2125 384 2398 659 \n",
       "Q 2672 934 2672 1341 \n",
       "Q 2672 1728 2419 1979 \n",
       "Q 2166 2231 1775 2231 \n",
       "Q 1616 2231 1378 2169 \n",
       "L 1441 2663 \n",
       "Q 1497 2656 1531 2656 \n",
       "Q 1891 2656 2178 2843 \n",
       "Q 2466 3031 2466 3422 \n",
       "Q 2466 3731 2256 3934 \n",
       "Q 2047 4138 1716 4138 \n",
       "Q 1388 4138 1169 3931 \n",
       "Q 950 3725 888 3313 \n",
       "L 325 3413 \n",
       "Q 428 3978 793 4289 \n",
       "Q 1159 4600 1703 4600 \n",
       "Q 2078 4600 2393 4439 \n",
       "Q 2709 4278 2876 4000 \n",
       "Q 3044 3722 3044 3409 \n",
       "Q 3044 3113 2884 2869 \n",
       "Q 2725 2625 2413 2481 \n",
       "Q 2819 2388 3044 2092 \n",
       "Q 3269 1797 3269 1353 \n",
       "Q 3269 753 2831 336 \n",
       "Q 2394 -81 1725 -81 \n",
       "Q 1122 -81 723 278 \n",
       "Q 325 638 269 1209 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_11\">\n",
       "     <g id=\"line2d_23\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma199b051a4\" x=\"395.432875\" y=\"130.941098\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_25\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 134.090536) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_12\">\n",
       "     <g id=\"line2d_24\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma199b051a4\" x=\"395.432875\" y=\"95.154498\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_26\">\n",
       "      <!-- 0.5 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 98.303935) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_13\">\n",
       "     <g id=\"line2d_25\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma199b051a4\" x=\"395.432875\" y=\"59.367897\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_27\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 62.517335) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_14\">\n",
       "     <g id=\"line2d_26\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma199b051a4\" x=\"395.432875\" y=\"23.581297\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_28\">\n",
       "      <!-- 0.7 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(403.732875 26.730734) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-37\" d=\"M 303 3981 \n",
       "L 303 4522 \n",
       "L 3269 4522 \n",
       "L 3269 4084 \n",
       "Q 2831 3619 2401 2847 \n",
       "Q 1972 2075 1738 1259 \n",
       "Q 1569 684 1522 0 \n",
       "L 944 0 \n",
       "Q 953 541 1156 1306 \n",
       "Q 1359 2072 1739 2783 \n",
       "Q 2119 3494 2547 3981 \n",
       "L 303 3981 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-37\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_29\">\n",
       "     <!-- Information Acquisition Function -->\n",
       "     <g style=\"fill: #ff7f0e\" transform=\"translate(426.953375 221.16075) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-49\" d=\"M 597 0 \n",
       "L 597 4581 \n",
       "L 1203 4581 \n",
       "L 1203 0 \n",
       "L 597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-41\" d=\"M -9 0 \n",
       "L 1750 4581 \n",
       "L 2403 4581 \n",
       "L 4278 0 \n",
       "L 3588 0 \n",
       "L 3053 1388 \n",
       "L 1138 1388 \n",
       "L 634 0 \n",
       "L -9 0 \n",
       "z\n",
       "M 1313 1881 \n",
       "L 2866 1881 \n",
       "L 2388 3150 \n",
       "Q 2169 3728 2063 4100 \n",
       "Q 1975 3659 1816 3225 \n",
       "L 1313 1881 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-71\" d=\"M 2538 -1272 \n",
       "L 2538 353 \n",
       "Q 2406 169 2170 47 \n",
       "Q 1934 -75 1669 -75 \n",
       "Q 1078 -75 651 397 \n",
       "Q 225 869 225 1691 \n",
       "Q 225 2191 398 2587 \n",
       "Q 572 2984 901 3189 \n",
       "Q 1231 3394 1625 3394 \n",
       "Q 2241 3394 2594 2875 \n",
       "L 2594 3319 \n",
       "L 3100 3319 \n",
       "L 3100 -1272 \n",
       "L 2538 -1272 \n",
       "z\n",
       "M 803 1669 \n",
       "Q 803 1028 1072 708 \n",
       "Q 1341 388 1716 388 \n",
       "Q 2075 388 2334 692 \n",
       "Q 2594 997 2594 1619 \n",
       "Q 2594 2281 2320 2615 \n",
       "Q 2047 2950 1678 2950 \n",
       "Q 1313 2950 1058 2639 \n",
       "Q 803 2328 803 1669 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-46\" d=\"M 525 0 \n",
       "L 525 4581 \n",
       "L 3616 4581 \n",
       "L 3616 4041 \n",
       "L 1131 4041 \n",
       "L 1131 2622 \n",
       "L 3281 2622 \n",
       "L 3281 2081 \n",
       "L 1131 2081 \n",
       "L 1131 0 \n",
       "L 525 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-49\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"27.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"83.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"111.181641\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"166.796875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6d\" x=\"200.097656\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"283.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"339.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"366.796875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"389.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"444.628906\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"500.244141\"/>\n",
       "      <use xlink:href=\"#ArialMT-41\" x=\"522.527344\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"589.226562\"/>\n",
       "      <use xlink:href=\"#ArialMT-71\" x=\"639.226562\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"694.841797\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"750.457031\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"772.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"822.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"844.890625\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"872.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"894.890625\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"950.505859\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"1006.121094\"/>\n",
       "      <use xlink:href=\"#ArialMT-46\" x=\"1033.904297\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"1094.988281\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"1150.603516\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"1206.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"1256.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"1284.001953\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"1306.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"1361.833984\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_27\">\n",
       "    <path d=\"M 54.545602 82.228485 \n",
       "L 57.824941 94.984366 \n",
       "L 61.10428 108.203096 \n",
       "L 64.383619 121.7959 \n",
       "L 67.662958 135.659291 \n",
       "L 70.942296 149.675568 \n",
       "L 74.221636 163.714573 \n",
       "L 77.500973 177.635524 \n",
       "L 80.780313 191.288954 \n",
       "L 84.059653 204.520296 \n",
       "L 87.33899 217.170441 \n",
       "L 90.61833 229.079097 \n",
       "L 93.89767 240.084471 \n",
       "L 97.177007 250.018913 \n",
       "L 100.456344 258.6989 \n",
       "L 103.735686 265.885221 \n",
       "L 107.015024 271.184118 \n",
       "L 110.294361 273.855913 \n",
       "L 113.573703 274.0875 \n",
       "L 116.853041 273.871274 \n",
       "L 120.132378 265.514513 \n",
       "L 123.41172 251.365554 \n",
       "L 126.691057 237.074423 \n",
       "L 129.970395 224.522033 \n",
       "L 133.249737 214.688267 \n",
       "L 136.529069 208.307303 \n",
       "L 139.808412 206.022057 \n",
       "L 143.087754 208.432785 \n",
       "L 146.367086 216.107634 \n",
       "L 149.646428 229.567192 \n",
       "L 152.92577 249.182081 \n",
       "L 156.205103 272.728754 \n",
       "L 159.484445 273.938428 \n",
       "L 162.763787 273.052277 \n",
       "L 166.04312 272.293658 \n",
       "L 169.322462 271.859118 \n",
       "L 172.601804 271.736205 \n",
       "L 175.881137 271.863389 \n",
       "L 179.160479 272.161374 \n",
       "L 182.439821 272.548755 \n",
       "L 185.719153 272.953311 \n",
       "L 188.998496 273.319829 \n",
       "L 192.277838 273.614762 \n",
       "L 195.55717 273.826234 \n",
       "L 198.836512 273.960418 \n",
       "L 202.115855 274.0345 \n",
       "L 205.395187 274.06922 \n",
       "L 208.674529 274.08255 \n",
       "L 211.953871 274.08651 \n",
       "L 215.233204 274.087348 \n",
       "L 218.512556 274.087472 \n",
       "L 221.791879 274.087487 \n",
       "L 225.071221 274.0875 \n",
       "L 228.350563 274.0875 \n",
       "L 231.629886 274.0875 \n",
       "L 234.909247 274.0875 \n",
       "L 238.18857 274.0875 \n",
       "L 241.467912 274.0875 \n",
       "L 244.747254 274.0875 \n",
       "L 248.026597 274.0875 \n",
       "L 251.305939 274.0875 \n",
       "L 254.585262 274.0875 \n",
       "L 257.864623 274.0875 \n",
       "L 261.143946 274.0875 \n",
       "L 264.423288 274.0875 \n",
       "L 267.70263 274.0875 \n",
       "L 270.981953 274.0875 \n",
       "L 274.261315 274.0875 \n",
       "L 277.540637 274.0875 \n",
       "L 280.81998 274.087496 \n",
       "L 284.099322 274.087466 \n",
       "L 287.378664 274.086762 \n",
       "L 290.658006 274.075145 \n",
       "L 293.937329 273.984262 \n",
       "L 297.21669 273.550191 \n",
       "L 300.496013 272.106177 \n",
       "L 303.775355 268.446309 \n",
       "L 307.054697 260.928623 \n",
       "L 310.33402 247.86081 \n",
       "L 313.613382 228.049437 \n",
       "L 316.892705 201.315893 \n",
       "L 320.172047 168.80348 \n",
       "L 323.451389 132.989749 \n",
       "L 326.730731 97.410814 \n",
       "L 330.010073 66.156462 \n",
       "L 333.289396 43.269224 \n",
       "L 336.568738 32.1675 \n",
       "L 339.84808 35.233479 \n",
       "L 343.127423 53.64522 \n",
       "L 346.406765 87.470577 \n",
       "L 349.686088 135.955518 \n",
       "L 352.96543 197.837767 \n",
       "L 356.244772 271.551135 \n",
       "L 359.524114 274.0875 \n",
       "L 362.803456 274.0875 \n",
       "L 366.082798 274.0875 \n",
       "L 369.362141 274.0875 \n",
       "L 372.641463 274.0875 \n",
       "L 375.920806 274.0875 \n",
       "L 379.200148 274.0875 \n",
       "\" clip-path=\"url(#pbad712fcc5)\" style=\"fill: none; stroke: #ff7f0e; stroke-width: 1.2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_28\">\n",
       "    <path d=\"M 336.568738 274.0875 \n",
       "L 336.568738 271.643864 \n",
       "L 336.568738 269.200227 \n",
       "L 336.568738 266.756591 \n",
       "L 336.568738 264.312955 \n",
       "L 336.568738 261.869318 \n",
       "L 336.568738 259.425683 \n",
       "L 336.568738 256.982046 \n",
       "L 336.568738 254.538409 \n",
       "L 336.568738 252.094773 \n",
       "L 336.568738 249.651136 \n",
       "L 336.568738 247.207501 \n",
       "L 336.568738 244.763865 \n",
       "L 336.568738 242.320227 \n",
       "L 336.568738 239.876592 \n",
       "L 336.568738 237.432954 \n",
       "L 336.568738 234.989319 \n",
       "L 336.568738 232.545683 \n",
       "L 336.568738 230.102045 \n",
       "L 336.568738 227.658407 \n",
       "L 336.568738 225.214772 \n",
       "L 336.568738 222.771137 \n",
       "L 336.568738 220.327501 \n",
       "L 336.568738 217.883866 \n",
       "L 336.568738 215.440231 \n",
       "L 336.568738 212.99659 \n",
       "L 336.568738 210.552954 \n",
       "L 336.568738 208.109319 \n",
       "L 336.568738 205.665684 \n",
       "L 336.568738 203.222048 \n",
       "L 336.568738 200.778408 \n",
       "L 336.568738 198.334772 \n",
       "L 336.568738 195.891137 \n",
       "L 336.568738 193.447502 \n",
       "L 336.568738 191.003866 \n",
       "L 336.568738 188.560226 \n",
       "L 336.568738 186.11659 \n",
       "L 336.568738 183.672955 \n",
       "L 336.568738 181.229314 \n",
       "L 336.568738 178.785684 \n",
       "L 336.568738 176.342044 \n",
       "L 336.568738 173.898414 \n",
       "L 336.568738 171.454773 \n",
       "L 336.568738 169.011132 \n",
       "L 336.568738 166.567502 \n",
       "L 336.568738 164.123862 \n",
       "L 336.568738 161.680232 \n",
       "L 336.568738 159.236591 \n",
       "L 336.568738 156.792961 \n",
       "L 336.568738 154.34932 \n",
       "L 336.568738 151.90568 \n",
       "L 336.568738 149.462039 \n",
       "L 336.568738 147.018409 \n",
       "L 336.568738 144.574768 \n",
       "L 336.568738 142.131138 \n",
       "L 336.568738 139.687498 \n",
       "L 336.568738 137.243868 \n",
       "L 336.568738 134.800227 \n",
       "L 336.568738 132.356586 \n",
       "L 336.568738 129.912956 \n",
       "L 336.568738 127.469316 \n",
       "L 336.568738 125.025686 \n",
       "L 336.568738 122.582045 \n",
       "L 336.568738 120.138415 \n",
       "L 336.568738 117.694774 \n",
       "L 336.568738 115.251134 \n",
       "L 336.568738 112.807493 \n",
       "L 336.568738 110.363863 \n",
       "L 336.568738 107.920233 \n",
       "L 336.568738 105.476592 \n",
       "L 336.568738 103.032952 \n",
       "L 336.568738 100.589311 \n",
       "L 336.568738 98.145681 \n",
       "L 336.568738 95.702051 \n",
       "L 336.568738 93.25841 \n",
       "L 336.568738 90.814769 \n",
       "L 336.568738 88.371129 \n",
       "L 336.568738 85.927488 \n",
       "L 336.568738 83.483869 \n",
       "L 336.568738 81.040228 \n",
       "L 336.568738 78.596587 \n",
       "L 336.568738 76.152947 \n",
       "L 336.568738 73.709306 \n",
       "L 336.568738 71.265687 \n",
       "L 336.568738 68.822046 \n",
       "L 336.568738 66.378405 \n",
       "L 336.568738 63.934765 \n",
       "L 336.568738 61.491124 \n",
       "L 336.568738 59.047505 \n",
       "L 336.568738 56.603864 \n",
       "L 336.568738 54.160223 \n",
       "L 336.568738 51.716583 \n",
       "L 336.568738 49.272963 \n",
       "L 336.568738 46.829323 \n",
       "L 336.568738 44.385682 \n",
       "L 336.568738 41.942041 \n",
       "L 336.568738 39.498401 \n",
       "L 336.568738 37.054781 \n",
       "L 336.568738 34.611141 \n",
       "L 336.568738 32.1675 \n",
       "\" clip-path=\"url(#pbad712fcc5)\" style=\"fill: none; stroke: #ff7f0e; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_7\">\n",
       "    <path d=\"M 38.312875 286.1835 \n",
       "L 38.312875 20.0715 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 395.432875 286.1835 \n",
       "L 395.432875 20.0715 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 38.312875 286.1835 \n",
       "L 395.432875 286.1835 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 38.312875 20.0715 \n",
       "L 395.432875 20.0715 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"pbad712fcc5\">\n",
       "   <rect x=\"38.312875\" y=\"20.0715\" width=\"357.12\" height=\"266.112\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 640x480 with 2 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"440.955pt\" height=\"322.510875pt\" viewBox=\"0 0 440.955 322.510875\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2023-10-23T15:18:58.457703</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.8.0, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 322.510875 \n",
       "L 440.955 322.510875 \n",
       "L 440.955 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 43.2065 286.1835 \n",
       "L 400.3265 286.1835 \n",
       "L 400.3265 20.0715 \n",
       "L 43.2065 20.0715 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"m6bb9896eeb\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m6bb9896eeb\" x=\"59.439227\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(53.323227 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m6bb9896eeb\" x=\"124.370136\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(118.254136 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m6bb9896eeb\" x=\"189.301045\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(183.185045 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m6bb9896eeb\" x=\"254.231955\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(248.115955 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m6bb9896eeb\" x=\"319.162864\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(313.046864 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m6bb9896eeb\" x=\"384.093773\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 1.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(377.977773 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_7\">\n",
       "     <!-- $x$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(218.8865 313.402875) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-78\" d=\"M 3841 3500 \n",
       "L 2234 1784 \n",
       "L 3219 0 \n",
       "L 2559 0 \n",
       "L 1819 1388 \n",
       "L 531 0 \n",
       "L -166 0 \n",
       "L 1556 1844 \n",
       "L 641 3500 \n",
       "L 1300 3500 \n",
       "L 1972 2234 \n",
       "L 3144 3500 \n",
       "L 3841 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <defs>\n",
       "       <path id=\"me7abccce0b\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#me7abccce0b\" x=\"43.2065\" y=\"276.387543\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- −12 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 279.536981) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"114.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me7abccce0b\" x=\"43.2065\" y=\"244.137085\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- −10 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 247.286522) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"114.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me7abccce0b\" x=\"43.2065\" y=\"211.886627\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- −8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 215.036064) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me7abccce0b\" x=\"43.2065\" y=\"179.636168\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- −6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 182.785606) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me7abccce0b\" x=\"43.2065\" y=\"147.38571\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 150.535148) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me7abccce0b\" x=\"43.2065\" y=\"115.135252\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 118.284689) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_13\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me7abccce0b\" x=\"43.2065\" y=\"82.884794\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_14\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(30.012875 86.034231) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_14\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#me7abccce0b\" x=\"43.2065\" y=\"50.634336\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_15\">\n",
       "      <!-- 2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(30.012875 53.783773) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-32\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_16\">\n",
       "     <!-- $y$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(13.9635 156.0075) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-79\" d=\"M 1588 -325 \n",
       "Q 1188 -997 936 -1164 \n",
       "Q 684 -1331 294 -1331 \n",
       "L -159 -1331 \n",
       "L -63 -850 \n",
       "L 269 -850 \n",
       "Q 509 -850 678 -719 \n",
       "Q 847 -588 1056 -206 \n",
       "L 1234 128 \n",
       "L 459 3500 \n",
       "L 1069 3500 \n",
       "L 1650 819 \n",
       "L 3256 3500 \n",
       "L 3859 3500 \n",
       "L 1588 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_1\">\n",
       "    <defs>\n",
       "     <path id=\"m401de4afe6\" d=\"M 59.439227 -290.343375 \n",
       "L 59.439227 -182.94919 \n",
       "L 62.718566 -184.565172 \n",
       "L 65.997905 -186.383315 \n",
       "L 69.277244 -188.407192 \n",
       "L 72.556583 -190.636626 \n",
       "L 75.835921 -193.067253 \n",
       "L 79.115261 -195.69017 \n",
       "L 82.394598 -198.491769 \n",
       "L 85.673938 -201.453491 \n",
       "L 88.953278 -204.552136 \n",
       "L 92.232615 -207.759636 \n",
       "L 95.511955 -211.043672 \n",
       "L 98.791295 -214.367969 \n",
       "L 102.070632 -217.692792 \n",
       "L 105.349969 -220.976264 \n",
       "L 108.629311 -224.174357 \n",
       "L 111.908649 -227.242315 \n",
       "L 115.187986 -230.135883 \n",
       "L 118.467328 -232.809719 \n",
       "L 121.746666 -231.474884 \n",
       "L 125.026003 -229.445431 \n",
       "L 128.305345 -227.802394 \n",
       "L 131.584682 -226.571374 \n",
       "L 134.86402 -225.770929 \n",
       "L 138.143362 -225.411376 \n",
       "L 141.422694 -225.495176 \n",
       "L 144.702037 -226.015654 \n",
       "L 147.981379 -226.957587 \n",
       "L 151.260711 -228.296805 \n",
       "L 154.540053 -230.00046 \n",
       "L 157.819395 -232.027142 \n",
       "L 161.098728 -234.328324 \n",
       "L 164.37807 -233.537217 \n",
       "L 167.657412 -231.005879 \n",
       "L 170.936745 -228.266071 \n",
       "L 174.216087 -225.358202 \n",
       "L 177.495429 -222.321781 \n",
       "L 180.774762 -219.194949 \n",
       "L 184.054104 -216.012699 \n",
       "L 187.333446 -212.805916 \n",
       "L 190.612778 -209.600411 \n",
       "L 193.892121 -206.41583 \n",
       "L 197.171463 -203.265087 \n",
       "L 200.450795 -200.15382 \n",
       "L 203.730137 -197.080099 \n",
       "L 207.00948 -194.034443 \n",
       "L 210.288812 -191.000163 \n",
       "L 213.568154 -187.953723 \n",
       "L 216.847496 -184.865854 \n",
       "L 220.126829 -181.702474 \n",
       "L 223.406181 -178.426172 \n",
       "L 226.685504 -174.997941 \n",
       "L 229.964846 -171.378893 \n",
       "L 233.244188 -167.532539 \n",
       "L 236.523511 -163.426832 \n",
       "L 239.802872 -159.036336 \n",
       "L 243.082195 -154.344896 \n",
       "L 246.361537 -149.347306 \n",
       "L 249.640879 -144.051578 \n",
       "L 252.920222 -138.480596 \n",
       "L 256.199564 -132.67342 \n",
       "L 259.478887 -126.65381 \n",
       "L 262.758248 -114.848798 \n",
       "L 266.037571 -103.391888 \n",
       "L 269.316913 -92.513169 \n",
       "L 272.596255 -82.411941 \n",
       "L 275.875578 -73.285861 \n",
       "L 279.15494 -65.326234 \n",
       "L 282.434262 -58.710895 \n",
       "L 285.713605 -53.601221 \n",
       "L 288.992947 -50.135447 \n",
       "L 292.272289 -48.423375 \n",
       "L 295.551631 -48.542479 \n",
       "L 298.830954 -50.533589 \n",
       "L 302.110315 -54.39689 \n",
       "L 305.389638 -60.09072 \n",
       "L 308.66898 -67.52901 \n",
       "L 311.948322 -76.583212 \n",
       "L 315.227645 -87.08169 \n",
       "L 318.507007 -98.814439 \n",
       "L 321.78633 -111.537145 \n",
       "L 325.065672 -124.974808 \n",
       "L 328.345014 -138.830928 \n",
       "L 331.624356 -152.794587 \n",
       "L 334.903698 -166.546765 \n",
       "L 338.183021 -179.774888 \n",
       "L 341.462363 -192.138744 \n",
       "L 344.741705 -202.69735 \n",
       "L 348.021048 -212.219727 \n",
       "L 351.30039 -220.491441 \n",
       "L 354.579713 -227.290031 \n",
       "L 357.859055 -232.420502 \n",
       "L 361.138397 -235.68518 \n",
       "L 364.417739 -236.496534 \n",
       "L 367.697081 -235.314455 \n",
       "L 370.976423 -232.289996 \n",
       "L 374.255766 -227.548805 \n",
       "L 377.535088 -221.268504 \n",
       "L 380.814431 -213.676649 \n",
       "L 384.093773 -204.976725 \n",
       "L 384.093773 -205.041229 \n",
       "L 384.093773 -205.041229 \n",
       "L 380.814431 -214.676076 \n",
       "L 377.535088 -222.818475 \n",
       "L 374.255766 -229.24747 \n",
       "L 370.976423 -233.820558 \n",
       "L 367.697081 -236.446425 \n",
       "L 364.417739 -237.066919 \n",
       "L 361.138397 -235.749681 \n",
       "L 357.859055 -232.978962 \n",
       "L 354.579713 -228.288781 \n",
       "L 351.30039 -221.71103 \n",
       "L 348.021048 -213.375008 \n",
       "L 344.741705 -203.453167 \n",
       "L 341.462363 -192.203247 \n",
       "L 338.183021 -180.925002 \n",
       "L 334.903698 -169.246073 \n",
       "L 331.624356 -157.413081 \n",
       "L 328.345014 -145.710619 \n",
       "L 325.065672 -134.399364 \n",
       "L 321.78633 -123.726689 \n",
       "L 318.507007 -113.908136 \n",
       "L 315.227645 -105.123875 \n",
       "L 311.948322 -97.522069 \n",
       "L 308.66898 -91.208635 \n",
       "L 305.389638 -86.253312 \n",
       "L 302.110315 -82.684904 \n",
       "L 298.830954 -80.497553 \n",
       "L 295.551631 -79.649229 \n",
       "L 292.272289 -80.068885 \n",
       "L 288.992947 -81.659562 \n",
       "L 285.713605 -84.303738 \n",
       "L 282.434262 -87.869593 \n",
       "L 279.15494 -92.214554 \n",
       "L 275.875578 -97.191514 \n",
       "L 272.596255 -102.65518 \n",
       "L 269.316913 -108.46284 \n",
       "L 266.037571 -114.482197 \n",
       "L 262.758248 -120.591947 \n",
       "L 259.478887 -126.718306 \n",
       "L 256.199564 -138.713107 \n",
       "L 252.920222 -150.749184 \n",
       "L 249.640879 -162.625742 \n",
       "L 246.361537 -174.189631 \n",
       "L 243.082195 -185.303999 \n",
       "L 239.802872 -195.849776 \n",
       "L 236.523511 -205.726129 \n",
       "L 233.244188 -214.85029 \n",
       "L 229.964846 -223.157864 \n",
       "L 226.685504 -230.601809 \n",
       "L 223.406181 -237.151592 \n",
       "L 220.126829 -242.792637 \n",
       "L 216.847496 -247.524553 \n",
       "L 213.568154 -251.360472 \n",
       "L 210.288812 -254.325469 \n",
       "L 207.00948 -256.455439 \n",
       "L 203.730137 -257.795892 \n",
       "L 200.450795 -258.400641 \n",
       "L 197.171463 -258.330676 \n",
       "L 193.892121 -257.653034 \n",
       "L 190.612778 -256.439684 \n",
       "L 187.333446 -254.766399 \n",
       "L 184.054104 -252.711671 \n",
       "L 180.774762 -250.355769 \n",
       "L 177.495429 -247.779446 \n",
       "L 174.216087 -245.063 \n",
       "L 170.936745 -242.285399 \n",
       "L 167.657412 -239.522654 \n",
       "L 164.37807 -236.84765 \n",
       "L 161.098728 -235.820849 \n",
       "L 157.819395 -237.819563 \n",
       "L 154.540053 -239.499096 \n",
       "L 151.260711 -240.830163 \n",
       "L 147.981379 -241.788014 \n",
       "L 144.702037 -242.35414 \n",
       "L 141.422694 -242.516611 \n",
       "L 138.143362 -242.270539 \n",
       "L 134.86402 -241.617848 \n",
       "L 131.584682 -240.568027 \n",
       "L 128.305345 -239.136938 \n",
       "L 125.026003 -237.34735 \n",
       "L 121.746666 -235.227805 \n",
       "L 118.467328 -233.861109 \n",
       "L 115.187986 -236.561983 \n",
       "L 111.908649 -239.541167 \n",
       "L 108.629311 -242.752036 \n",
       "L 105.349969 -246.14822 \n",
       "L 102.070632 -249.682075 \n",
       "L 98.791295 -253.306014 \n",
       "L 95.511955 -256.974038 \n",
       "L 92.232615 -260.641806 \n",
       "L 88.953278 -264.268059 \n",
       "L 85.673938 -267.815241 \n",
       "L 82.394598 -271.249889 \n",
       "L 79.115261 -274.543345 \n",
       "L 75.835921 -277.671636 \n",
       "L 72.556583 -280.615872 \n",
       "L 69.277244 -283.362076 \n",
       "L 65.997905 -285.901108 \n",
       "L 62.718566 -288.228355 \n",
       "L 59.439227 -290.343375 \n",
       "z\n",
       "\" style=\"stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pa816e64d3d)\">\n",
       "     <use xlink:href=\"#m401de4afe6\" x=\"0\" y=\"322.510875\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_2\">\n",
       "    <defs>\n",
       "     <path id=\"m6cfca83075\" d=\"M 59.439227 -182.94919 \n",
       "L 59.439227 -182.94919 \n",
       "L 62.718566 -184.565172 \n",
       "L 65.997905 -186.383315 \n",
       "L 69.277244 -188.407192 \n",
       "L 72.556583 -190.636626 \n",
       "L 75.835921 -193.067253 \n",
       "L 79.115261 -195.69017 \n",
       "L 82.394598 -198.491769 \n",
       "L 85.673938 -201.453491 \n",
       "L 88.953278 -204.552136 \n",
       "L 92.232615 -207.759636 \n",
       "L 95.511955 -211.043672 \n",
       "L 98.791295 -214.367969 \n",
       "L 102.070632 -217.692792 \n",
       "L 105.349969 -220.976264 \n",
       "L 108.629311 -224.174357 \n",
       "L 111.908649 -227.242315 \n",
       "L 115.187986 -230.135883 \n",
       "L 118.467328 -232.809719 \n",
       "L 121.746666 -231.474884 \n",
       "L 125.026003 -229.445431 \n",
       "L 128.305345 -227.802394 \n",
       "L 131.584682 -226.571374 \n",
       "L 134.86402 -225.770929 \n",
       "L 138.143362 -225.411376 \n",
       "L 141.422694 -225.495176 \n",
       "L 144.702037 -226.015654 \n",
       "L 147.981379 -226.957587 \n",
       "L 151.260711 -228.296805 \n",
       "L 154.540053 -230.00046 \n",
       "L 157.819395 -232.027142 \n",
       "L 161.098728 -234.328324 \n",
       "L 164.37807 -233.537217 \n",
       "L 167.657412 -231.005879 \n",
       "L 170.936745 -228.266071 \n",
       "L 174.216087 -225.358202 \n",
       "L 177.495429 -222.321781 \n",
       "L 180.774762 -219.194949 \n",
       "L 184.054104 -216.012699 \n",
       "L 187.333446 -212.805916 \n",
       "L 190.612778 -209.600411 \n",
       "L 193.892121 -206.41583 \n",
       "L 197.171463 -203.265087 \n",
       "L 200.450795 -200.15382 \n",
       "L 203.730137 -197.080099 \n",
       "L 207.00948 -194.034443 \n",
       "L 210.288812 -191.000163 \n",
       "L 213.568154 -187.953723 \n",
       "L 216.847496 -184.865854 \n",
       "L 220.126829 -181.702474 \n",
       "L 223.406181 -178.426172 \n",
       "L 226.685504 -174.997941 \n",
       "L 229.964846 -171.378893 \n",
       "L 233.244188 -167.532539 \n",
       "L 236.523511 -163.426832 \n",
       "L 239.802872 -159.036336 \n",
       "L 243.082195 -154.344896 \n",
       "L 246.361537 -149.347306 \n",
       "L 249.640879 -144.051578 \n",
       "L 252.920222 -138.480596 \n",
       "L 256.199564 -132.67342 \n",
       "L 259.478887 -126.65381 \n",
       "L 262.758248 -114.848798 \n",
       "L 266.037571 -103.391888 \n",
       "L 269.316913 -92.513169 \n",
       "L 272.596255 -82.411941 \n",
       "L 275.875578 -73.285861 \n",
       "L 279.15494 -65.326234 \n",
       "L 282.434262 -58.710895 \n",
       "L 285.713605 -53.601221 \n",
       "L 288.992947 -50.135447 \n",
       "L 292.272289 -48.423375 \n",
       "L 295.551631 -48.542479 \n",
       "L 298.830954 -50.533589 \n",
       "L 302.110315 -54.39689 \n",
       "L 305.389638 -60.09072 \n",
       "L 308.66898 -67.52901 \n",
       "L 311.948322 -76.583212 \n",
       "L 315.227645 -87.08169 \n",
       "L 318.507007 -98.814439 \n",
       "L 321.78633 -111.537145 \n",
       "L 325.065672 -124.974808 \n",
       "L 328.345014 -138.830928 \n",
       "L 331.624356 -152.794587 \n",
       "L 334.903698 -166.546765 \n",
       "L 338.183021 -179.774888 \n",
       "L 341.462363 -192.138744 \n",
       "L 344.741705 -202.69735 \n",
       "L 348.021048 -212.219727 \n",
       "L 351.30039 -220.491441 \n",
       "L 354.579713 -227.290031 \n",
       "L 357.859055 -232.420502 \n",
       "L 361.138397 -235.68518 \n",
       "L 364.417739 -236.496534 \n",
       "L 367.697081 -235.314455 \n",
       "L 370.976423 -232.289996 \n",
       "L 374.255766 -227.548805 \n",
       "L 377.535088 -221.268504 \n",
       "L 380.814431 -213.676649 \n",
       "L 384.093773 -204.976725 \n",
       "L 384.093773 -204.976725 \n",
       "L 384.093773 -204.976725 \n",
       "L 380.814431 -213.676649 \n",
       "L 377.535088 -221.268504 \n",
       "L 374.255766 -227.548805 \n",
       "L 370.976423 -232.289996 \n",
       "L 367.697081 -235.314455 \n",
       "L 364.417739 -236.496534 \n",
       "L 361.138397 -235.68518 \n",
       "L 357.859055 -232.420502 \n",
       "L 354.579713 -227.290031 \n",
       "L 351.30039 -220.491441 \n",
       "L 348.021048 -212.219727 \n",
       "L 344.741705 -202.69735 \n",
       "L 341.462363 -192.138744 \n",
       "L 338.183021 -179.774888 \n",
       "L 334.903698 -166.546765 \n",
       "L 331.624356 -152.794587 \n",
       "L 328.345014 -138.830928 \n",
       "L 325.065672 -124.974808 \n",
       "L 321.78633 -111.537145 \n",
       "L 318.507007 -98.814439 \n",
       "L 315.227645 -87.08169 \n",
       "L 311.948322 -76.583212 \n",
       "L 308.66898 -67.52901 \n",
       "L 305.389638 -60.09072 \n",
       "L 302.110315 -54.39689 \n",
       "L 298.830954 -50.533589 \n",
       "L 295.551631 -48.542479 \n",
       "L 292.272289 -48.423375 \n",
       "L 288.992947 -50.135447 \n",
       "L 285.713605 -53.601221 \n",
       "L 282.434262 -58.710895 \n",
       "L 279.15494 -65.326234 \n",
       "L 275.875578 -73.285861 \n",
       "L 272.596255 -82.411941 \n",
       "L 269.316913 -92.513169 \n",
       "L 266.037571 -103.391888 \n",
       "L 262.758248 -114.848798 \n",
       "L 259.478887 -126.65381 \n",
       "L 256.199564 -132.67342 \n",
       "L 252.920222 -138.480596 \n",
       "L 249.640879 -144.051578 \n",
       "L 246.361537 -149.347306 \n",
       "L 243.082195 -154.344896 \n",
       "L 239.802872 -159.036336 \n",
       "L 236.523511 -163.426832 \n",
       "L 233.244188 -167.532539 \n",
       "L 229.964846 -171.378893 \n",
       "L 226.685504 -174.997941 \n",
       "L 223.406181 -178.426172 \n",
       "L 220.126829 -181.702474 \n",
       "L 216.847496 -184.865854 \n",
       "L 213.568154 -187.953723 \n",
       "L 210.288812 -191.000163 \n",
       "L 207.00948 -194.034443 \n",
       "L 203.730137 -197.080099 \n",
       "L 200.450795 -200.15382 \n",
       "L 197.171463 -203.265087 \n",
       "L 193.892121 -206.41583 \n",
       "L 190.612778 -209.600411 \n",
       "L 187.333446 -212.805916 \n",
       "L 184.054104 -216.012699 \n",
       "L 180.774762 -219.194949 \n",
       "L 177.495429 -222.321781 \n",
       "L 174.216087 -225.358202 \n",
       "L 170.936745 -228.266071 \n",
       "L 167.657412 -231.005879 \n",
       "L 164.37807 -233.537217 \n",
       "L 161.098728 -234.328324 \n",
       "L 157.819395 -232.027142 \n",
       "L 154.540053 -230.00046 \n",
       "L 151.260711 -228.296805 \n",
       "L 147.981379 -226.957587 \n",
       "L 144.702037 -226.015654 \n",
       "L 141.422694 -225.495176 \n",
       "L 138.143362 -225.411376 \n",
       "L 134.86402 -225.770929 \n",
       "L 131.584682 -226.571374 \n",
       "L 128.305345 -227.802394 \n",
       "L 125.026003 -229.445431 \n",
       "L 121.746666 -231.474884 \n",
       "L 118.467328 -232.809719 \n",
       "L 115.187986 -230.135883 \n",
       "L 111.908649 -227.242315 \n",
       "L 108.629311 -224.174357 \n",
       "L 105.349969 -220.976264 \n",
       "L 102.070632 -217.692792 \n",
       "L 98.791295 -214.367969 \n",
       "L 95.511955 -211.043672 \n",
       "L 92.232615 -207.759636 \n",
       "L 88.953278 -204.552136 \n",
       "L 85.673938 -201.453491 \n",
       "L 82.394598 -198.491769 \n",
       "L 79.115261 -195.69017 \n",
       "L 75.835921 -193.067253 \n",
       "L 72.556583 -190.636626 \n",
       "L 69.277244 -188.407192 \n",
       "L 65.997905 -186.383315 \n",
       "L 62.718566 -184.565172 \n",
       "L 59.439227 -182.94919 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pa816e64d3d)\">\n",
       "     <use xlink:href=\"#m6cfca83075\" x=\"0\" y=\"322.510875\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_3\">\n",
       "    <defs>\n",
       "     <path id=\"m62042524b2\" d=\"M 59.439227 -290.343375 \n",
       "L 59.439227 -290.343375 \n",
       "L 62.718566 -288.228355 \n",
       "L 65.997905 -285.901108 \n",
       "L 69.277244 -283.362076 \n",
       "L 72.556583 -280.615872 \n",
       "L 75.835921 -277.671636 \n",
       "L 79.115261 -274.543345 \n",
       "L 82.394598 -271.249889 \n",
       "L 85.673938 -267.815241 \n",
       "L 88.953278 -264.268059 \n",
       "L 92.232615 -260.641806 \n",
       "L 95.511955 -256.974038 \n",
       "L 98.791295 -253.306014 \n",
       "L 102.070632 -249.682075 \n",
       "L 105.349969 -246.14822 \n",
       "L 108.629311 -242.752036 \n",
       "L 111.908649 -239.541167 \n",
       "L 115.187986 -236.561983 \n",
       "L 118.467328 -233.861109 \n",
       "L 121.746666 -235.227805 \n",
       "L 125.026003 -237.34735 \n",
       "L 128.305345 -239.136938 \n",
       "L 131.584682 -240.568027 \n",
       "L 134.86402 -241.617848 \n",
       "L 138.143362 -242.270539 \n",
       "L 141.422694 -242.516611 \n",
       "L 144.702037 -242.35414 \n",
       "L 147.981379 -241.788014 \n",
       "L 151.260711 -240.830163 \n",
       "L 154.540053 -239.499096 \n",
       "L 157.819395 -237.819563 \n",
       "L 161.098728 -235.820849 \n",
       "L 164.37807 -236.84765 \n",
       "L 167.657412 -239.522654 \n",
       "L 170.936745 -242.285399 \n",
       "L 174.216087 -245.063 \n",
       "L 177.495429 -247.779446 \n",
       "L 180.774762 -250.355769 \n",
       "L 184.054104 -252.711671 \n",
       "L 187.333446 -254.766399 \n",
       "L 190.612778 -256.439684 \n",
       "L 193.892121 -257.653034 \n",
       "L 197.171463 -258.330676 \n",
       "L 200.450795 -258.400641 \n",
       "L 203.730137 -257.795892 \n",
       "L 207.00948 -256.455439 \n",
       "L 210.288812 -254.325469 \n",
       "L 213.568154 -251.360472 \n",
       "L 216.847496 -247.524553 \n",
       "L 220.126829 -242.792637 \n",
       "L 223.406181 -237.151592 \n",
       "L 226.685504 -230.601809 \n",
       "L 229.964846 -223.157864 \n",
       "L 233.244188 -214.85029 \n",
       "L 236.523511 -205.726129 \n",
       "L 239.802872 -195.849776 \n",
       "L 243.082195 -185.303999 \n",
       "L 246.361537 -174.189631 \n",
       "L 249.640879 -162.625742 \n",
       "L 252.920222 -150.749184 \n",
       "L 256.199564 -138.713107 \n",
       "L 259.478887 -126.718306 \n",
       "L 262.758248 -120.591947 \n",
       "L 266.037571 -114.482197 \n",
       "L 269.316913 -108.46284 \n",
       "L 272.596255 -102.65518 \n",
       "L 275.875578 -97.191514 \n",
       "L 279.15494 -92.214554 \n",
       "L 282.434262 -87.869593 \n",
       "L 285.713605 -84.303738 \n",
       "L 288.992947 -81.659562 \n",
       "L 292.272289 -80.068885 \n",
       "L 295.551631 -79.649229 \n",
       "L 298.830954 -80.497553 \n",
       "L 302.110315 -82.684904 \n",
       "L 305.389638 -86.253312 \n",
       "L 308.66898 -91.208635 \n",
       "L 311.948322 -97.522069 \n",
       "L 315.227645 -105.123875 \n",
       "L 318.507007 -113.908136 \n",
       "L 321.78633 -123.726689 \n",
       "L 325.065672 -134.399364 \n",
       "L 328.345014 -145.710619 \n",
       "L 331.624356 -157.413081 \n",
       "L 334.903698 -169.246073 \n",
       "L 338.183021 -180.925002 \n",
       "L 341.462363 -192.203247 \n",
       "L 344.741705 -203.453167 \n",
       "L 348.021048 -213.375008 \n",
       "L 351.30039 -221.71103 \n",
       "L 354.579713 -228.288781 \n",
       "L 357.859055 -232.978962 \n",
       "L 361.138397 -235.749681 \n",
       "L 364.417739 -237.066919 \n",
       "L 367.697081 -236.446425 \n",
       "L 370.976423 -233.820558 \n",
       "L 374.255766 -229.24747 \n",
       "L 377.535088 -222.818475 \n",
       "L 380.814431 -214.676076 \n",
       "L 384.093773 -205.041229 \n",
       "L 384.093773 -205.041229 \n",
       "L 384.093773 -205.041229 \n",
       "L 380.814431 -214.676076 \n",
       "L 377.535088 -222.818475 \n",
       "L 374.255766 -229.24747 \n",
       "L 370.976423 -233.820558 \n",
       "L 367.697081 -236.446425 \n",
       "L 364.417739 -237.066919 \n",
       "L 361.138397 -235.749681 \n",
       "L 357.859055 -232.978962 \n",
       "L 354.579713 -228.288781 \n",
       "L 351.30039 -221.71103 \n",
       "L 348.021048 -213.375008 \n",
       "L 344.741705 -203.453167 \n",
       "L 341.462363 -192.203247 \n",
       "L 338.183021 -180.925002 \n",
       "L 334.903698 -169.246073 \n",
       "L 331.624356 -157.413081 \n",
       "L 328.345014 -145.710619 \n",
       "L 325.065672 -134.399364 \n",
       "L 321.78633 -123.726689 \n",
       "L 318.507007 -113.908136 \n",
       "L 315.227645 -105.123875 \n",
       "L 311.948322 -97.522069 \n",
       "L 308.66898 -91.208635 \n",
       "L 305.389638 -86.253312 \n",
       "L 302.110315 -82.684904 \n",
       "L 298.830954 -80.497553 \n",
       "L 295.551631 -79.649229 \n",
       "L 292.272289 -80.068885 \n",
       "L 288.992947 -81.659562 \n",
       "L 285.713605 -84.303738 \n",
       "L 282.434262 -87.869593 \n",
       "L 279.15494 -92.214554 \n",
       "L 275.875578 -97.191514 \n",
       "L 272.596255 -102.65518 \n",
       "L 269.316913 -108.46284 \n",
       "L 266.037571 -114.482197 \n",
       "L 262.758248 -120.591947 \n",
       "L 259.478887 -126.718306 \n",
       "L 256.199564 -138.713107 \n",
       "L 252.920222 -150.749184 \n",
       "L 249.640879 -162.625742 \n",
       "L 246.361537 -174.189631 \n",
       "L 243.082195 -185.303999 \n",
       "L 239.802872 -195.849776 \n",
       "L 236.523511 -205.726129 \n",
       "L 233.244188 -214.85029 \n",
       "L 229.964846 -223.157864 \n",
       "L 226.685504 -230.601809 \n",
       "L 223.406181 -237.151592 \n",
       "L 220.126829 -242.792637 \n",
       "L 216.847496 -247.524553 \n",
       "L 213.568154 -251.360472 \n",
       "L 210.288812 -254.325469 \n",
       "L 207.00948 -256.455439 \n",
       "L 203.730137 -257.795892 \n",
       "L 200.450795 -258.400641 \n",
       "L 197.171463 -258.330676 \n",
       "L 193.892121 -257.653034 \n",
       "L 190.612778 -256.439684 \n",
       "L 187.333446 -254.766399 \n",
       "L 184.054104 -252.711671 \n",
       "L 180.774762 -250.355769 \n",
       "L 177.495429 -247.779446 \n",
       "L 174.216087 -245.063 \n",
       "L 170.936745 -242.285399 \n",
       "L 167.657412 -239.522654 \n",
       "L 164.37807 -236.84765 \n",
       "L 161.098728 -235.820849 \n",
       "L 157.819395 -237.819563 \n",
       "L 154.540053 -239.499096 \n",
       "L 151.260711 -240.830163 \n",
       "L 147.981379 -241.788014 \n",
       "L 144.702037 -242.35414 \n",
       "L 141.422694 -242.516611 \n",
       "L 138.143362 -242.270539 \n",
       "L 134.86402 -241.617848 \n",
       "L 131.584682 -240.568027 \n",
       "L 128.305345 -239.136938 \n",
       "L 125.026003 -237.34735 \n",
       "L 121.746666 -235.227805 \n",
       "L 118.467328 -233.861109 \n",
       "L 115.187986 -236.561983 \n",
       "L 111.908649 -239.541167 \n",
       "L 108.629311 -242.752036 \n",
       "L 105.349969 -246.14822 \n",
       "L 102.070632 -249.682075 \n",
       "L 98.791295 -253.306014 \n",
       "L 95.511955 -256.974038 \n",
       "L 92.232615 -260.641806 \n",
       "L 88.953278 -264.268059 \n",
       "L 85.673938 -267.815241 \n",
       "L 82.394598 -271.249889 \n",
       "L 79.115261 -274.543345 \n",
       "L 75.835921 -277.671636 \n",
       "L 72.556583 -280.615872 \n",
       "L 69.277244 -283.362076 \n",
       "L 65.997905 -285.901108 \n",
       "L 62.718566 -288.228355 \n",
       "L 59.439227 -290.343375 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pa816e64d3d)\">\n",
       "     <use xlink:href=\"#m62042524b2\" x=\"0\" y=\"322.510875\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_15\">\n",
       "    <defs>\n",
       "     <path id=\"mfe3e68898d\" d=\"M -5 5 \n",
       "L 5 -5 \n",
       "M -5 -5 \n",
       "L 5 5 \n",
       "\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#pa816e64d3d)\">\n",
       "     <use xlink:href=\"#mfe3e68898d\" x=\"361.243318\" y=\"86.729713\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mfe3e68898d\" x=\"162.151989\" y=\"87.394226\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mfe3e68898d\" x=\"119.149308\" y=\"89.174571\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mfe3e68898d\" x=\"259.478887\" y=\"195.824802\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mfe3e68898d\" x=\"384.093773\" y=\"117.500864\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#mfe3e68898d\" x=\"341.462363\" y=\"130.33968\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_16\">\n",
       "    <path d=\"M 59.439227 85.864591 \n",
       "L 62.718566 86.114111 \n",
       "L 65.997905 86.368664 \n",
       "L 69.277244 86.626239 \n",
       "L 72.556583 86.884625 \n",
       "L 75.835921 87.141429 \n",
       "L 79.115261 87.394117 \n",
       "L 82.394598 87.640047 \n",
       "L 85.673938 87.876509 \n",
       "L 88.953278 88.100778 \n",
       "L 92.232615 88.310155 \n",
       "L 95.511955 88.50202 \n",
       "L 98.791295 88.673883 \n",
       "L 102.070632 88.823441 \n",
       "L 105.349969 88.948633 \n",
       "L 108.629311 89.047679 \n",
       "L 111.908649 89.119134 \n",
       "L 115.187986 89.161942 \n",
       "L 118.467328 89.175461 \n",
       "L 121.746666 89.159531 \n",
       "L 125.026003 89.114485 \n",
       "L 128.305345 89.041209 \n",
       "L 131.584682 88.941175 \n",
       "L 134.86402 88.816487 \n",
       "L 138.143362 88.669917 \n",
       "L 141.422694 88.504981 \n",
       "L 144.702037 88.325978 \n",
       "L 147.981379 88.138074 \n",
       "L 151.260711 87.947391 \n",
       "L 154.540053 87.761097 \n",
       "L 157.819395 87.587523 \n",
       "L 161.098728 87.436288 \n",
       "L 164.37807 87.318442 \n",
       "L 167.657412 87.246608 \n",
       "L 170.936745 87.23514 \n",
       "L 174.216087 87.300273 \n",
       "L 177.495429 87.460262 \n",
       "L 180.774762 87.735516 \n",
       "L 184.054104 88.148691 \n",
       "L 187.333446 88.724718 \n",
       "L 190.612778 89.490828 \n",
       "L 193.892121 90.476442 \n",
       "L 197.171463 91.712994 \n",
       "L 200.450795 93.233646 \n",
       "L 203.730137 95.072878 \n",
       "L 207.00948 97.265933 \n",
       "L 210.288812 99.848059 \n",
       "L 213.568154 102.853777 \n",
       "L 216.847496 106.315672 \n",
       "L 220.126829 110.263319 \n",
       "L 223.406181 114.721993 \n",
       "L 226.685504 119.710998 \n",
       "L 229.964846 125.242497 \n",
       "L 233.244188 131.31946 \n",
       "L 236.523511 137.934397 \n",
       "L 239.802872 145.067821 \n",
       "L 243.082195 152.686428 \n",
       "L 246.361537 160.742407 \n",
       "L 249.640879 169.172215 \n",
       "L 252.920222 177.895985 \n",
       "L 256.199564 186.817611 \n",
       "L 259.478887 195.824817 \n",
       "L 262.758248 204.790502 \n",
       "L 266.037571 213.573832 \n",
       "L 269.316913 222.022871 \n",
       "L 272.596255 229.977315 \n",
       "L 275.875578 237.272187 \n",
       "L 279.15494 243.740481 \n",
       "L 282.434262 249.220631 \n",
       "L 285.713605 253.558396 \n",
       "L 288.992947 256.613371 \n",
       "L 292.272289 258.264745 \n",
       "L 295.551631 258.415021 \n",
       "L 298.830954 256.995304 \n",
       "L 302.110315 253.969978 \n",
       "L 305.389638 249.338859 \n",
       "L 308.66898 243.142053 \n",
       "L 311.948322 235.458234 \n",
       "L 315.227645 226.408092 \n",
       "L 318.507007 216.149591 \n",
       "L 321.78633 204.878958 \n",
       "L 325.065672 192.823789 \n",
       "L 328.345014 180.240102 \n",
       "L 331.624356 167.407041 \n",
       "L 334.903698 154.614456 \n",
       "L 338.183021 142.16093 \n",
       "L 341.462363 130.33988 \n",
       "L 344.741705 119.435617 \n",
       "L 348.021048 109.713508 \n",
       "L 351.30039 101.40964 \n",
       "L 354.579713 94.721469 \n",
       "L 357.859055 89.811143 \n",
       "L 361.138397 86.793444 \n",
       "L 364.417739 85.729149 \n",
       "L 367.697081 86.630435 \n",
       "L 370.976423 89.455598 \n",
       "L 374.255766 94.112737 \n",
       "L 377.535088 100.467386 \n",
       "L 380.814431 108.334512 \n",
       "L 384.093773 117.501898 \n",
       "\" clip-path=\"url(#pa816e64d3d)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_17\">\n",
       "    <path d=\"M 59.439227 146.915175 \n",
       "L 62.718566 142.980059 \n",
       "L 65.997905 139.059544 \n",
       "L 69.277244 135.168171 \n",
       "L 72.556583 131.320425 \n",
       "L 75.835921 127.530633 \n",
       "L 79.115261 123.81298 \n",
       "L 82.394598 120.181402 \n",
       "L 85.673938 116.64956 \n",
       "L 88.953278 113.230814 \n",
       "L 92.232615 109.938134 \n",
       "L 95.511955 106.784088 \n",
       "L 98.791295 103.780788 \n",
       "L 102.070632 100.939847 \n",
       "L 105.349969 98.27233 \n",
       "L 108.629311 95.788748 \n",
       "L 111.908649 93.498985 \n",
       "L 115.187986 91.412284 \n",
       "L 118.467328 89.537199 \n",
       "L 121.746666 87.881588 \n",
       "L 125.026003 86.452575 \n",
       "L 128.305345 85.256511 \n",
       "L 131.584682 84.298971 \n",
       "L 134.86402 83.584726 \n",
       "L 138.143362 83.117716 \n",
       "L 141.422694 82.901049 \n",
       "L 144.702037 82.93698 \n",
       "L 147.981379 83.22689 \n",
       "L 151.260711 83.77129 \n",
       "L 154.540053 84.569816 \n",
       "L 157.819395 85.621205 \n",
       "L 161.098728 86.923298 \n",
       "L 164.37807 88.473065 \n",
       "L 167.657412 90.266549 \n",
       "L 170.936745 92.298927 \n",
       "L 174.216087 94.564469 \n",
       "L 177.495429 97.056559 \n",
       "L 180.774762 99.767696 \n",
       "L 184.054104 102.689488 \n",
       "L 187.333446 105.8127 \n",
       "L 190.612778 109.127175 \n",
       "L 193.892121 112.621936 \n",
       "L 197.171463 116.285104 \n",
       "L 200.450795 120.103992 \n",
       "L 203.730137 124.065021 \n",
       "L 207.00948 128.153754 \n",
       "L 210.288812 132.354918 \n",
       "L 213.568154 136.652399 \n",
       "L 216.847496 141.029193 \n",
       "L 220.126829 145.467474 \n",
       "L 223.406181 149.948544 \n",
       "L 226.685504 154.4528 \n",
       "L 229.964846 158.959825 \n",
       "L 233.244188 163.448296 \n",
       "L 236.523511 167.895892 \n",
       "L 239.802872 172.279583 \n",
       "L 243.082195 176.57518 \n",
       "L 246.361537 180.757763 \n",
       "L 249.640879 184.801358 \n",
       "L 252.920222 188.679083 \n",
       "L 256.199564 192.363158 \n",
       "L 259.478887 195.824802 \n",
       "L 262.758248 199.034413 \n",
       "L 266.037571 201.961472 \n",
       "L 269.316913 204.5747 \n",
       "L 272.596255 206.842079 \n",
       "L 275.875578 208.731055 \n",
       "L 279.15494 210.208594 \n",
       "L 282.434262 211.24148 \n",
       "L 285.713605 211.796549 \n",
       "L 288.992947 211.841046 \n",
       "L 292.272289 211.343053 \n",
       "L 295.551631 210.272068 \n",
       "L 298.830954 208.599633 \n",
       "L 302.110315 206.300074 \n",
       "L 305.389638 203.351762 \n",
       "L 308.66898 199.737805 \n",
       "L 311.948322 195.44782 \n",
       "L 315.227645 190.479441 \n",
       "L 318.507007 184.839942 \n",
       "L 321.78633 178.548705 \n",
       "L 325.065672 171.639296 \n",
       "L 328.345014 164.162191 \n",
       "L 331.624356 156.187648 \n",
       "L 334.903698 147.808565 \n",
       "L 338.183021 139.14352 \n",
       "L 341.462363 130.33968 \n",
       "L 344.741705 121.575111 \n",
       "L 348.021048 113.060719 \n",
       "L 351.30039 105.040971 \n",
       "L 354.579713 97.792614 \n",
       "L 357.859055 91.621266 \n",
       "L 361.138397 86.855211 \n",
       "L 364.417739 83.834168 \n",
       "L 367.697081 82.893732 \n",
       "L 370.976423 84.34331 \n",
       "L 374.255766 88.437245 \n",
       "L 377.535088 95.338843 \n",
       "L 380.814431 105.077483 \n",
       "L 384.093773 117.500864 \n",
       "\" clip-path=\"url(#pa816e64d3d)\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 43.2065 276.387543 \n",
       "L 43.2065 50.634336 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 59.439227 286.1835 \n",
       "L 384.093773 286.1835 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_17\">\n",
       "    <!-- N=2,  -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(210.16025 14.0715) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-4e\" d=\"M 488 0 \n",
       "L 488 4581 \n",
       "L 1109 4581 \n",
       "L 3516 984 \n",
       "L 3516 4581 \n",
       "L 4097 4581 \n",
       "L 4097 0 \n",
       "L 3475 0 \n",
       "L 1069 3600 \n",
       "L 1069 0 \n",
       "L 488 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-3d\" d=\"M 3381 2694 \n",
       "L 356 2694 \n",
       "L 356 3219 \n",
       "L 3381 3219 \n",
       "L 3381 2694 \n",
       "z\n",
       "M 3381 1303 \n",
       "L 356 1303 \n",
       "L 356 1828 \n",
       "L 3381 1828 \n",
       "L 3381 1303 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-2c\" d=\"M 569 0 \n",
       "L 569 641 \n",
       "L 1209 641 \n",
       "L 1209 0 \n",
       "Q 1209 -353 1084 -570 \n",
       "Q 959 -788 688 -906 \n",
       "L 531 -666 \n",
       "Q 709 -588 793 -436 \n",
       "Q 878 -284 888 0 \n",
       "L 569 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-4e\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"72.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-32\" x=\"130.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-2c\" x=\"186.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-20\" x=\"214.013672\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"legend_1\">\n",
       "    <g id=\"line2d_18\">\n",
       "     <g>\n",
       "      <use xlink:href=\"#mfe3e68898d\" x=\"59.9265\" y=\"219.978625\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_18\">\n",
       "     <!-- Observations -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 223.058625) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4f\" d=\"M 309 2231 \n",
       "Q 309 3372 921 4017 \n",
       "Q 1534 4663 2503 4663 \n",
       "Q 3138 4663 3647 4359 \n",
       "Q 4156 4056 4423 3514 \n",
       "Q 4691 2972 4691 2284 \n",
       "Q 4691 1588 4409 1038 \n",
       "Q 4128 488 3612 205 \n",
       "Q 3097 -78 2500 -78 \n",
       "Q 1853 -78 1343 234 \n",
       "Q 834 547 571 1087 \n",
       "Q 309 1628 309 2231 \n",
       "z\n",
       "M 934 2222 \n",
       "Q 934 1394 1379 917 \n",
       "Q 1825 441 2497 441 \n",
       "Q 3181 441 3623 922 \n",
       "Q 4066 1403 4066 2288 \n",
       "Q 4066 2847 3877 3264 \n",
       "Q 3688 3681 3323 3911 \n",
       "Q 2959 4141 2506 4141 \n",
       "Q 1863 4141 1398 3698 \n",
       "Q 934 3256 934 2222 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-62\" d=\"M 941 0 \n",
       "L 419 0 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 2947 \n",
       "Q 1338 3394 1891 3394 \n",
       "Q 2197 3394 2470 3270 \n",
       "Q 2744 3147 2920 2923 \n",
       "Q 3097 2700 3197 2384 \n",
       "Q 3297 2069 3297 1709 \n",
       "Q 3297 856 2875 390 \n",
       "Q 2453 -75 1863 -75 \n",
       "Q 1275 -75 941 416 \n",
       "L 941 0 \n",
       "z\n",
       "M 934 1684 \n",
       "Q 934 1088 1097 822 \n",
       "Q 1363 388 1816 388 \n",
       "Q 2184 388 2453 708 \n",
       "Q 2722 1028 2722 1663 \n",
       "Q 2722 2313 2464 2622 \n",
       "Q 2206 2931 1841 2931 \n",
       "Q 1472 2931 1203 2611 \n",
       "Q 934 2291 934 1684 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-76\" d=\"M 1344 0 \n",
       "L 81 3319 \n",
       "L 675 3319 \n",
       "L 1388 1331 \n",
       "Q 1503 1009 1600 663 \n",
       "Q 1675 925 1809 1294 \n",
       "L 2547 3319 \n",
       "L 3125 3319 \n",
       "L 1869 0 \n",
       "L 1344 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4f\"/>\n",
       "      <use xlink:href=\"#ArialMT-62\" x=\"77.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"133.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"183.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"239.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"272.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"322.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"377.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"405.712891\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"427.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"483.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"539.160156\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_19\">\n",
       "     <path d=\"M 51.1265 232.562625 \n",
       "L 59.9265 232.562625 \n",
       "L 68.7265 232.562625 \n",
       "\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "    </g>\n",
       "    <g id=\"text_19\">\n",
       "     <!-- $m_n(x)$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 235.642625) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-6d\" d=\"M 5747 2113 \n",
       "L 5338 0 \n",
       "L 4763 0 \n",
       "L 5166 2094 \n",
       "Q 5191 2228 5203 2325 \n",
       "Q 5216 2422 5216 2491 \n",
       "Q 5216 2772 5059 2928 \n",
       "Q 4903 3084 4622 3084 \n",
       "Q 4203 3084 3875 2770 \n",
       "Q 3547 2456 3450 1953 \n",
       "L 3066 0 \n",
       "L 2491 0 \n",
       "L 2900 2094 \n",
       "Q 2925 2209 2937 2307 \n",
       "Q 2950 2406 2950 2484 \n",
       "Q 2950 2769 2794 2926 \n",
       "Q 2638 3084 2363 3084 \n",
       "Q 1938 3084 1609 2770 \n",
       "Q 1281 2456 1184 1953 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 909 3500 \n",
       "L 1484 3500 \n",
       "L 1375 2956 \n",
       "Q 1609 3263 1923 3423 \n",
       "Q 2238 3584 2597 3584 \n",
       "Q 2978 3584 3223 3384 \n",
       "Q 3469 3184 3519 2828 \n",
       "Q 3781 3197 4126 3390 \n",
       "Q 4472 3584 4856 3584 \n",
       "Q 5306 3584 5551 3325 \n",
       "Q 5797 3066 5797 2591 \n",
       "Q 5797 2488 5784 2364 \n",
       "Q 5772 2241 5747 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Oblique-6e\" d=\"M 3566 2113 \n",
       "L 3156 0 \n",
       "L 2578 0 \n",
       "L 2988 2091 \n",
       "Q 3016 2238 3031 2350 \n",
       "Q 3047 2463 3047 2528 \n",
       "Q 3047 2791 2881 2937 \n",
       "Q 2716 3084 2419 3084 \n",
       "Q 1956 3084 1622 2776 \n",
       "Q 1288 2469 1184 1941 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 903 3500 \n",
       "L 1478 3500 \n",
       "L 1363 2950 \n",
       "Q 1603 3253 1940 3418 \n",
       "Q 2278 3584 2650 3584 \n",
       "Q 3113 3584 3367 3334 \n",
       "Q 3622 3084 3622 2631 \n",
       "Q 3622 2519 3608 2391 \n",
       "Q 3594 2263 3566 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-28\" d=\"M 1984 4856 \n",
       "Q 1566 4138 1362 3434 \n",
       "Q 1159 2731 1159 2009 \n",
       "Q 1159 1288 1364 580 \n",
       "Q 1569 -128 1984 -844 \n",
       "L 1484 -844 \n",
       "Q 1016 -109 783 600 \n",
       "Q 550 1309 550 2009 \n",
       "Q 550 2706 781 3412 \n",
       "Q 1013 4119 1484 4856 \n",
       "L 1984 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-29\" d=\"M 513 4856 \n",
       "L 1013 4856 \n",
       "Q 1481 4119 1714 3412 \n",
       "Q 1947 2706 1947 2009 \n",
       "Q 1947 1309 1714 600 \n",
       "Q 1481 -109 1013 -844 \n",
       "L 513 -844 \n",
       "Q 928 -128 1133 580 \n",
       "Q 1338 1288 1338 2009 \n",
       "Q 1338 2731 1133 3434 \n",
       "Q 928 4138 513 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6d\" transform=\"translate(0 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6e\" transform=\"translate(97.412109 -16.28125) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(144.511719 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(183.525391 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(242.705078 0.125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_5\">\n",
       "     <path d=\"M 51.1265 249.799625 \n",
       "L 68.7265 249.799625 \n",
       "L 68.7265 243.639625 \n",
       "L 51.1265 243.639625 \n",
       "z\n",
       "\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_20\">\n",
       "     <!-- $f(\\mathbf{x}^*)$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 249.799625) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-66\" d=\"M 3059 4863 \n",
       "L 2969 4384 \n",
       "L 2419 4384 \n",
       "Q 2106 4384 1964 4261 \n",
       "Q 1822 4138 1753 3809 \n",
       "L 1691 3500 \n",
       "L 2638 3500 \n",
       "L 2553 3053 \n",
       "L 1606 3053 \n",
       "L 1013 0 \n",
       "L 434 0 \n",
       "L 1031 3053 \n",
       "L 481 3053 \n",
       "L 563 3500 \n",
       "L 1113 3500 \n",
       "L 1159 3744 \n",
       "Q 1278 4363 1576 4613 \n",
       "Q 1875 4863 2516 4863 \n",
       "L 3059 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Bold-78\" d=\"M 1422 1791 \n",
       "L 159 3500 \n",
       "L 1344 3500 \n",
       "L 2059 2463 \n",
       "L 2784 3500 \n",
       "L 3969 3500 \n",
       "L 2706 1797 \n",
       "L 4031 0 \n",
       "L 2847 0 \n",
       "L 2059 1106 \n",
       "L 1281 0 \n",
       "L 97 0 \n",
       "L 1422 1791 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-2a\" d=\"M 3009 3897 \n",
       "L 1888 3291 \n",
       "L 3009 2681 \n",
       "L 2828 2375 \n",
       "L 1778 3009 \n",
       "L 1778 1831 \n",
       "L 1422 1831 \n",
       "L 1422 3009 \n",
       "L 372 2375 \n",
       "L 191 2681 \n",
       "L 1313 3291 \n",
       "L 191 3897 \n",
       "L 372 4206 \n",
       "L 1422 3572 \n",
       "L 1422 4750 \n",
       "L 1778 4750 \n",
       "L 1778 3572 \n",
       "L 2828 4206 \n",
       "L 3009 3897 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-39\" d=\"M 350 1059 \n",
       "L 891 1109 \n",
       "Q 959 728 1153 556 \n",
       "Q 1347 384 1650 384 \n",
       "Q 1909 384 2104 503 \n",
       "Q 2300 622 2425 820 \n",
       "Q 2550 1019 2634 1356 \n",
       "Q 2719 1694 2719 2044 \n",
       "Q 2719 2081 2716 2156 \n",
       "Q 2547 1888 2255 1720 \n",
       "Q 1963 1553 1622 1553 \n",
       "Q 1053 1553 659 1965 \n",
       "Q 266 2378 266 3053 \n",
       "Q 266 3750 677 4175 \n",
       "Q 1088 4600 1706 4600 \n",
       "Q 2153 4600 2523 4359 \n",
       "Q 2894 4119 3086 3673 \n",
       "Q 3278 3228 3278 2384 \n",
       "Q 3278 1506 3087 986 \n",
       "Q 2897 466 2520 194 \n",
       "Q 2144 -78 1638 -78 \n",
       "Q 1100 -78 759 220 \n",
       "Q 419 519 350 1059 \n",
       "z\n",
       "M 2653 3081 \n",
       "Q 2653 3566 2395 3850 \n",
       "Q 2138 4134 1775 4134 \n",
       "Q 1400 4134 1122 3828 \n",
       "Q 844 3522 844 3034 \n",
       "Q 844 2597 1108 2323 \n",
       "Q 1372 2050 1759 2050 \n",
       "Q 2150 2050 2401 2323 \n",
       "Q 2653 2597 2653 3081 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-25\" d=\"M 372 3481 \n",
       "Q 372 3972 619 4315 \n",
       "Q 866 4659 1334 4659 \n",
       "Q 1766 4659 2048 4351 \n",
       "Q 2331 4044 2331 3447 \n",
       "Q 2331 2866 2045 2552 \n",
       "Q 1759 2238 1341 2238 \n",
       "Q 925 2238 648 2547 \n",
       "Q 372 2856 372 3481 \n",
       "z\n",
       "M 1350 4272 \n",
       "Q 1141 4272 1002 4090 \n",
       "Q 863 3909 863 3425 \n",
       "Q 863 2984 1003 2804 \n",
       "Q 1144 2625 1350 2625 \n",
       "Q 1563 2625 1702 2806 \n",
       "Q 1841 2988 1841 3469 \n",
       "Q 1841 3913 1700 4092 \n",
       "Q 1559 4272 1350 4272 \n",
       "z\n",
       "M 1353 -169 \n",
       "L 3859 4659 \n",
       "L 4316 4659 \n",
       "L 1819 -169 \n",
       "L 1353 -169 \n",
       "z\n",
       "M 3334 1075 \n",
       "Q 3334 1569 3581 1911 \n",
       "Q 3828 2253 4300 2253 \n",
       "Q 4731 2253 5014 1945 \n",
       "Q 5297 1638 5297 1041 \n",
       "Q 5297 459 5011 145 \n",
       "Q 4725 -169 4303 -169 \n",
       "Q 3888 -169 3611 142 \n",
       "Q 3334 453 3334 1075 \n",
       "z\n",
       "M 4316 1866 \n",
       "Q 4103 1866 3964 1684 \n",
       "Q 3825 1503 3825 1019 \n",
       "Q 3825 581 3965 400 \n",
       "Q 4106 219 4313 219 \n",
       "Q 4528 219 4667 400 \n",
       "Q 4806 581 4806 1063 \n",
       "Q 4806 1506 4665 1686 \n",
       "Q 4525 1866 4316 1866 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-66\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(35.205078 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Bold-78\" transform=\"translate(74.21875 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(153.31543 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(204.6875 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(243.701172 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(271.484375 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(327.099609 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(382.714844 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(471.630859 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(499.414062 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(555.029297 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(588.330078 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(643.945312 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(699.560547 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_6\">\n",
       "     <path d=\"M 51.1265 263.967625 \n",
       "L 68.7265 263.967625 \n",
       "L 68.7265 257.807625 \n",
       "L 51.1265 257.807625 \n",
       "z\n",
       "\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_21\">\n",
       "     <!-- $y^*$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 263.967625) scale(0.088 -0.088)\">\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(77.283529 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(128.655599 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(156.438802 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(212.054036 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(267.669271 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(356.585286 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(384.36849 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(439.983724 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(473.284505 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(528.89974 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(584.514974 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_20\">\n",
       "     <path d=\"M 51.1265 273.4345 \n",
       "L 59.9265 273.4345 \n",
       "L 68.7265 273.4345 \n",
       "\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "    </g>\n",
       "    <g id=\"text_22\">\n",
       "     <!-- True function -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 276.5145) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-54\" d=\"M 1659 0 \n",
       "L 1659 4041 \n",
       "L 150 4041 \n",
       "L 150 4581 \n",
       "L 3781 4581 \n",
       "L 3781 4041 \n",
       "L 2266 4041 \n",
       "L 2266 0 \n",
       "L 1659 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-66\" d=\"M 556 0 \n",
       "L 556 2881 \n",
       "L 59 2881 \n",
       "L 59 3319 \n",
       "L 556 3319 \n",
       "L 556 3672 \n",
       "Q 556 4006 616 4169 \n",
       "Q 697 4388 901 4523 \n",
       "Q 1106 4659 1475 4659 \n",
       "Q 1713 4659 2000 4603 \n",
       "L 1916 4113 \n",
       "Q 1741 4144 1584 4144 \n",
       "Q 1328 4144 1222 4034 \n",
       "Q 1116 3925 1116 3625 \n",
       "L 1116 3319 \n",
       "L 1763 3319 \n",
       "L 1763 2881 \n",
       "L 1116 2881 \n",
       "L 1116 0 \n",
       "L 556 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-54\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"57.333984\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"90.634766\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"146.25\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"201.865234\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"229.648438\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"257.431641\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"313.046875\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"368.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"418.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"446.445312\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"468.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"524.277344\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"ytick_9\">\n",
       "     <g id=\"line2d_21\">\n",
       "      <defs>\n",
       "       <path id=\"mba2a2a7497\" d=\"M 0 0 \n",
       "L 4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mba2a2a7497\" x=\"400.3265\" y=\"274.0875\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_23\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 277.236937) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_10\">\n",
       "     <g id=\"line2d_22\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mba2a2a7497\" x=\"400.3265\" y=\"239.098119\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_24\">\n",
       "      <!-- 0.1 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 242.247556) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_11\">\n",
       "     <g id=\"line2d_23\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mba2a2a7497\" x=\"400.3265\" y=\"204.108737\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_25\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 207.258175) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_12\">\n",
       "     <g id=\"line2d_24\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mba2a2a7497\" x=\"400.3265\" y=\"169.119356\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_26\">\n",
       "      <!-- 0.3 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 172.268793) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-33\" d=\"M 269 1209 \n",
       "L 831 1284 \n",
       "Q 928 806 1161 595 \n",
       "Q 1394 384 1728 384 \n",
       "Q 2125 384 2398 659 \n",
       "Q 2672 934 2672 1341 \n",
       "Q 2672 1728 2419 1979 \n",
       "Q 2166 2231 1775 2231 \n",
       "Q 1616 2231 1378 2169 \n",
       "L 1441 2663 \n",
       "Q 1497 2656 1531 2656 \n",
       "Q 1891 2656 2178 2843 \n",
       "Q 2466 3031 2466 3422 \n",
       "Q 2466 3731 2256 3934 \n",
       "Q 2047 4138 1716 4138 \n",
       "Q 1388 4138 1169 3931 \n",
       "Q 950 3725 888 3313 \n",
       "L 325 3413 \n",
       "Q 428 3978 793 4289 \n",
       "Q 1159 4600 1703 4600 \n",
       "Q 2078 4600 2393 4439 \n",
       "Q 2709 4278 2876 4000 \n",
       "Q 3044 3722 3044 3409 \n",
       "Q 3044 3113 2884 2869 \n",
       "Q 2725 2625 2413 2481 \n",
       "Q 2819 2388 3044 2092 \n",
       "Q 3269 1797 3269 1353 \n",
       "Q 3269 753 2831 336 \n",
       "Q 2394 -81 1725 -81 \n",
       "Q 1122 -81 723 278 \n",
       "Q 325 638 269 1209 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-33\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_13\">\n",
       "     <g id=\"line2d_25\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mba2a2a7497\" x=\"400.3265\" y=\"134.129975\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_27\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 137.279412) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_14\">\n",
       "     <g id=\"line2d_26\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mba2a2a7497\" x=\"400.3265\" y=\"99.140593\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_28\">\n",
       "      <!-- 0.5 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 102.290031) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_15\">\n",
       "     <g id=\"line2d_27\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mba2a2a7497\" x=\"400.3265\" y=\"64.151212\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_29\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 67.300649) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_16\">\n",
       "     <g id=\"line2d_28\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mba2a2a7497\" x=\"400.3265\" y=\"29.161831\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_30\">\n",
       "      <!-- 0.7 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 32.311268) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-37\" d=\"M 303 3981 \n",
       "L 303 4522 \n",
       "L 3269 4522 \n",
       "L 3269 4084 \n",
       "Q 2831 3619 2401 2847 \n",
       "Q 1972 2075 1738 1259 \n",
       "Q 1569 684 1522 0 \n",
       "L 944 0 \n",
       "Q 953 541 1156 1306 \n",
       "Q 1359 2072 1739 2783 \n",
       "Q 2119 3494 2547 3981 \n",
       "L 303 3981 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-37\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_31\">\n",
       "     <!-- Information Acquisition Function -->\n",
       "     <g style=\"fill: #ff7f0e\" transform=\"translate(431.847 221.16075) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-49\" d=\"M 597 0 \n",
       "L 597 4581 \n",
       "L 1203 4581 \n",
       "L 1203 0 \n",
       "L 597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-41\" d=\"M -9 0 \n",
       "L 1750 4581 \n",
       "L 2403 4581 \n",
       "L 4278 0 \n",
       "L 3588 0 \n",
       "L 3053 1388 \n",
       "L 1138 1388 \n",
       "L 634 0 \n",
       "L -9 0 \n",
       "z\n",
       "M 1313 1881 \n",
       "L 2866 1881 \n",
       "L 2388 3150 \n",
       "Q 2169 3728 2063 4100 \n",
       "Q 1975 3659 1816 3225 \n",
       "L 1313 1881 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-71\" d=\"M 2538 -1272 \n",
       "L 2538 353 \n",
       "Q 2406 169 2170 47 \n",
       "Q 1934 -75 1669 -75 \n",
       "Q 1078 -75 651 397 \n",
       "Q 225 869 225 1691 \n",
       "Q 225 2191 398 2587 \n",
       "Q 572 2984 901 3189 \n",
       "Q 1231 3394 1625 3394 \n",
       "Q 2241 3394 2594 2875 \n",
       "L 2594 3319 \n",
       "L 3100 3319 \n",
       "L 3100 -1272 \n",
       "L 2538 -1272 \n",
       "z\n",
       "M 803 1669 \n",
       "Q 803 1028 1072 708 \n",
       "Q 1341 388 1716 388 \n",
       "Q 2075 388 2334 692 \n",
       "Q 2594 997 2594 1619 \n",
       "Q 2594 2281 2320 2615 \n",
       "Q 2047 2950 1678 2950 \n",
       "Q 1313 2950 1058 2639 \n",
       "Q 803 2328 803 1669 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-46\" d=\"M 525 0 \n",
       "L 525 4581 \n",
       "L 3616 4581 \n",
       "L 3616 4041 \n",
       "L 1131 4041 \n",
       "L 1131 2622 \n",
       "L 3281 2622 \n",
       "L 3281 2081 \n",
       "L 1131 2081 \n",
       "L 1131 0 \n",
       "L 525 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-49\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"27.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"83.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"111.181641\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"166.796875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6d\" x=\"200.097656\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"283.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"339.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"366.796875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"389.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"444.628906\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"500.244141\"/>\n",
       "      <use xlink:href=\"#ArialMT-41\" x=\"522.527344\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"589.226562\"/>\n",
       "      <use xlink:href=\"#ArialMT-71\" x=\"639.226562\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"694.841797\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"750.457031\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"772.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"822.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"844.890625\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"872.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"894.890625\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"950.505859\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"1006.121094\"/>\n",
       "      <use xlink:href=\"#ArialMT-46\" x=\"1033.904297\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"1094.988281\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"1150.603516\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"1206.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"1256.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"1284.001953\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"1306.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"1361.833984\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_29\">\n",
       "    <path d=\"M 59.439227 32.1675 \n",
       "L 62.718566 43.006269 \n",
       "L 65.997905 54.779709 \n",
       "L 69.277244 67.469594 \n",
       "L 72.556583 81.038092 \n",
       "L 75.835921 95.425973 \n",
       "L 79.115261 110.551485 \n",
       "L 82.394598 126.30982 \n",
       "L 85.673938 142.571936 \n",
       "L 88.953278 159.185776 \n",
       "L 92.232615 175.974227 \n",
       "L 95.511955 192.735457 \n",
       "L 98.791295 209.238847 \n",
       "L 102.070632 225.215365 \n",
       "L 105.349969 240.334402 \n",
       "L 108.629311 254.12571 \n",
       "L 111.908649 265.739176 \n",
       "L 115.187986 273.097984 \n",
       "L 118.467328 274.0875 \n",
       "L 121.746666 274.056716 \n",
       "L 125.026003 271.717902 \n",
       "L 128.305345 266.899238 \n",
       "L 131.584682 261.934149 \n",
       "L 134.86402 257.782441 \n",
       "L 138.143362 254.853251 \n",
       "L 141.422694 253.35165 \n",
       "L 144.702037 253.381246 \n",
       "L 147.981379 254.984377 \n",
       "L 151.260711 258.151993 \n",
       "L 154.540053 262.812154 \n",
       "L 157.819395 268.721421 \n",
       "L 161.098728 273.996509 \n",
       "L 164.37807 271.570694 \n",
       "L 167.657412 260.723675 \n",
       "L 170.936745 248.916638 \n",
       "L 174.216087 237.348497 \n",
       "L 177.495429 226.557529 \n",
       "L 180.774762 217.00282 \n",
       "L 184.054104 209.113554 \n",
       "L 187.333446 203.287262 \n",
       "L 190.612778 199.873036 \n",
       "L 193.892121 199.143669 \n",
       "L 197.171463 201.260648 \n",
       "L 200.450795 206.229141 \n",
       "L 203.730137 213.84513 \n",
       "L 207.00948 223.639946 \n",
       "L 210.288812 234.837551 \n",
       "L 213.568154 246.35592 \n",
       "L 216.847496 256.904738 \n",
       "L 220.126829 265.246004 \n",
       "L 223.406181 270.62635 \n",
       "L 226.685504 273.196542 \n",
       "L 229.964846 273.970416 \n",
       "L 233.244188 274.082538 \n",
       "L 236.523511 274.087487 \n",
       "L 239.802872 274.0875 \n",
       "L 243.082195 274.0875 \n",
       "L 246.361537 274.0875 \n",
       "L 249.640879 274.0875 \n",
       "L 252.920222 274.0875 \n",
       "L 256.199564 274.0875 \n",
       "L 259.478887 274.0875 \n",
       "L 262.758248 274.0875 \n",
       "L 266.037571 274.0875 \n",
       "L 269.316913 274.0875 \n",
       "L 272.596255 274.0875 \n",
       "L 275.875578 274.0875 \n",
       "L 279.15494 274.0875 \n",
       "L 282.434262 274.0875 \n",
       "L 285.713605 274.0875 \n",
       "L 288.992947 274.0875 \n",
       "L 292.272289 274.0875 \n",
       "L 295.551631 274.0875 \n",
       "L 298.830954 274.0875 \n",
       "L 302.110315 274.0875 \n",
       "L 305.389638 274.0875 \n",
       "L 308.66898 274.0875 \n",
       "L 311.948322 274.0875 \n",
       "L 315.227645 274.0875 \n",
       "L 318.507007 274.0875 \n",
       "L 321.78633 274.0875 \n",
       "L 325.065672 274.0875 \n",
       "L 328.345014 274.0875 \n",
       "L 331.624356 274.0875 \n",
       "L 334.903698 274.0875 \n",
       "L 338.183021 274.0875 \n",
       "L 341.462363 274.0875 \n",
       "L 344.741705 274.0875 \n",
       "L 348.021048 274.0875 \n",
       "L 351.30039 274.0875 \n",
       "L 354.579713 274.0875 \n",
       "L 357.859055 274.0875 \n",
       "L 361.138397 274.087497 \n",
       "L 364.417739 252.376719 \n",
       "L 367.697081 270.411475 \n",
       "L 370.976423 274.0875 \n",
       "L 374.255766 274.0875 \n",
       "L 377.535088 274.0875 \n",
       "L 380.814431 274.0875 \n",
       "L 384.093773 274.0875 \n",
       "\" clip-path=\"url(#pa816e64d3d)\" style=\"fill: none; stroke: #ff7f0e; stroke-width: 1.2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_30\">\n",
       "    <path d=\"M 59.439227 274.0875 \n",
       "L 59.439227 271.643864 \n",
       "L 59.439227 269.200227 \n",
       "L 59.439227 266.756591 \n",
       "L 59.439227 264.312954 \n",
       "L 59.439227 261.869318 \n",
       "L 59.439227 259.425682 \n",
       "L 59.439227 256.982044 \n",
       "L 59.439227 254.538409 \n",
       "L 59.439227 252.094771 \n",
       "L 59.439227 249.651135 \n",
       "L 59.439227 247.207499 \n",
       "L 59.439227 244.763863 \n",
       "L 59.439227 242.320228 \n",
       "L 59.439227 239.876589 \n",
       "L 59.439227 237.432953 \n",
       "L 59.439227 234.989317 \n",
       "L 59.439227 232.545681 \n",
       "L 59.439227 230.102043 \n",
       "L 59.439227 227.658407 \n",
       "L 59.439227 225.214771 \n",
       "L 59.439227 222.771135 \n",
       "L 59.439227 220.327499 \n",
       "L 59.439227 217.883863 \n",
       "L 59.439227 215.440227 \n",
       "L 59.439227 212.996591 \n",
       "L 59.439227 210.552955 \n",
       "L 59.439227 208.109314 \n",
       "L 59.439227 205.665678 \n",
       "L 59.439227 203.222042 \n",
       "L 59.439227 200.778406 \n",
       "L 59.439227 198.33477 \n",
       "L 59.439227 195.891134 \n",
       "L 59.439227 193.447498 \n",
       "L 59.439227 191.003862 \n",
       "L 59.439227 188.560226 \n",
       "L 59.439227 186.116585 \n",
       "L 59.439227 183.672949 \n",
       "L 59.439227 181.229313 \n",
       "L 59.439227 178.785677 \n",
       "L 59.439227 176.342041 \n",
       "L 59.439227 173.898406 \n",
       "L 59.439227 171.45477 \n",
       "L 59.439227 169.011134 \n",
       "L 59.439227 166.567498 \n",
       "L 59.439227 164.123862 \n",
       "L 59.439227 161.680226 \n",
       "L 59.439227 159.23659 \n",
       "L 59.439227 156.792954 \n",
       "L 59.439227 154.349318 \n",
       "L 59.439227 151.905682 \n",
       "L 59.439227 149.462046 \n",
       "L 59.439227 147.01841 \n",
       "L 59.439227 144.574774 \n",
       "L 59.439227 142.131138 \n",
       "L 59.439227 139.687502 \n",
       "L 59.439227 137.243866 \n",
       "L 59.439227 134.80023 \n",
       "L 59.439227 132.356594 \n",
       "L 59.439227 129.912959 \n",
       "L 59.439227 127.469323 \n",
       "L 59.439227 125.025687 \n",
       "L 59.439227 122.582051 \n",
       "L 59.439227 120.138415 \n",
       "L 59.439227 117.694779 \n",
       "L 59.439227 115.251143 \n",
       "L 59.439227 112.807507 \n",
       "L 59.439227 110.363871 \n",
       "L 59.439227 107.920235 \n",
       "L 59.439227 105.476599 \n",
       "L 59.439227 103.032963 \n",
       "L 59.439227 100.589327 \n",
       "L 59.439227 98.145691 \n",
       "L 59.439227 95.702055 \n",
       "L 59.439227 93.258399 \n",
       "L 59.439227 90.814783 \n",
       "L 59.439227 88.371127 \n",
       "L 59.439227 85.927512 \n",
       "L 59.439227 83.483855 \n",
       "L 59.439227 81.04024 \n",
       "L 59.439227 78.596583 \n",
       "L 59.439227 76.152968 \n",
       "L 59.439227 73.709311 \n",
       "L 59.439227 71.265675 \n",
       "L 59.439227 68.822039 \n",
       "L 59.439227 66.378403 \n",
       "L 59.439227 63.934767 \n",
       "L 59.439227 61.491131 \n",
       "L 59.439227 59.047495 \n",
       "L 59.439227 56.603859 \n",
       "L 59.439227 54.160223 \n",
       "L 59.439227 51.716588 \n",
       "L 59.439227 49.272952 \n",
       "L 59.439227 46.829316 \n",
       "L 59.439227 44.38568 \n",
       "L 59.439227 41.942044 \n",
       "L 59.439227 39.498408 \n",
       "L 59.439227 37.054772 \n",
       "L 59.439227 34.611136 \n",
       "L 59.439227 32.1675 \n",
       "\" clip-path=\"url(#pa816e64d3d)\" style=\"fill: none; stroke: #ff7f0e; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_7\">\n",
       "    <path d=\"M 43.2065 286.1835 \n",
       "L 43.2065 20.0715 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 400.3265 286.1835 \n",
       "L 400.3265 20.0715 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 43.2065 286.1835 \n",
       "L 400.3265 286.1835 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 43.2065 20.0715 \n",
       "L 400.3265 20.0715 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"pa816e64d3d\">\n",
       "   <rect x=\"43.2065\" y=\"20.0715\" width=\"357.12\" height=\"266.112\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 640x480 with 2 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"445.848625pt\" height=\"322.510875pt\" viewBox=\"0 0 445.848625 322.510875\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2023-10-23T15:18:58.532188</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.8.0, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 322.510875 \n",
       "L 445.848625 322.510875 \n",
       "L 445.848625 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 43.2065 286.1835 \n",
       "L 400.3265 286.1835 \n",
       "L 400.3265 20.0715 \n",
       "L 43.2065 20.0715 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"m6e955477e3\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m6e955477e3\" x=\"59.439227\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(53.323227 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m6e955477e3\" x=\"124.370136\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(118.254136 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m6e955477e3\" x=\"189.301045\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(183.185045 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m6e955477e3\" x=\"254.231955\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(248.115955 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m6e955477e3\" x=\"319.162864\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(313.046864 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m6e955477e3\" x=\"384.093773\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 1.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(377.977773 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_7\">\n",
       "     <!-- $x$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(218.8865 313.402875) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-78\" d=\"M 3841 3500 \n",
       "L 2234 1784 \n",
       "L 3219 0 \n",
       "L 2559 0 \n",
       "L 1819 1388 \n",
       "L 531 0 \n",
       "L -166 0 \n",
       "L 1556 1844 \n",
       "L 641 3500 \n",
       "L 1300 3500 \n",
       "L 1972 2234 \n",
       "L 3144 3500 \n",
       "L 3841 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <defs>\n",
       "       <path id=\"m7787a8bf21\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m7787a8bf21\" x=\"43.2065\" y=\"278.413098\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- −12 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 281.562535) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"114.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m7787a8bf21\" x=\"43.2065\" y=\"239.157257\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- −10 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 242.306694) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"114.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m7787a8bf21\" x=\"43.2065\" y=\"199.901415\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- −8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 203.050853) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m7787a8bf21\" x=\"43.2065\" y=\"160.645574\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- −6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 163.795012) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m7787a8bf21\" x=\"43.2065\" y=\"121.389733\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 124.53917) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m7787a8bf21\" x=\"43.2065\" y=\"82.133892\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 85.283329) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_13\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m7787a8bf21\" x=\"43.2065\" y=\"42.878051\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_14\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(30.012875 46.027488) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_15\">\n",
       "     <!-- $y$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(13.9635 156.0075) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-79\" d=\"M 1588 -325 \n",
       "Q 1188 -997 936 -1164 \n",
       "Q 684 -1331 294 -1331 \n",
       "L -159 -1331 \n",
       "L -63 -850 \n",
       "L 269 -850 \n",
       "Q 509 -850 678 -719 \n",
       "Q 847 -588 1056 -206 \n",
       "L 1234 128 \n",
       "L 459 3500 \n",
       "L 1069 3500 \n",
       "L 1650 819 \n",
       "L 3256 3500 \n",
       "L 3859 3500 \n",
       "L 1588 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_1\">\n",
       "    <defs>\n",
       "     <path id=\"m1f56934d3b\" d=\"M 59.439227 -201.733106 \n",
       "L 59.439227 -201.654591 \n",
       "L 62.718566 -200.686785 \n",
       "L 65.997905 -200.491859 \n",
       "L 69.277244 -201.11431 \n",
       "L 72.556583 -202.544817 \n",
       "L 75.835921 -204.758638 \n",
       "L 79.115261 -207.716497 \n",
       "L 82.394598 -211.363998 \n",
       "L 85.673938 -215.633313 \n",
       "L 88.953278 -220.444276 \n",
       "L 92.232615 -225.705198 \n",
       "L 95.511955 -231.315391 \n",
       "L 98.791295 -237.166909 \n",
       "L 102.070632 -243.146753 \n",
       "L 105.349969 -249.14043 \n",
       "L 108.629311 -255.032909 \n",
       "L 111.908649 -260.711911 \n",
       "L 115.187986 -266.071293 \n",
       "L 118.467328 -271.008207 \n",
       "L 121.746666 -272.157755 \n",
       "L 125.026003 -272.174437 \n",
       "L 128.305345 -272.014724 \n",
       "L 131.584682 -271.745913 \n",
       "L 134.86402 -271.435201 \n",
       "L 138.143362 -271.146456 \n",
       "L 141.422694 -270.939715 \n",
       "L 144.702037 -270.868159 \n",
       "L 147.981379 -270.976638 \n",
       "L 151.260711 -271.30064 \n",
       "L 154.540053 -271.864509 \n",
       "L 157.819395 -272.680395 \n",
       "L 161.098728 -273.748591 \n",
       "L 164.37807 -271.426654 \n",
       "L 167.657412 -267.155635 \n",
       "L 170.936745 -262.637653 \n",
       "L 174.216087 -257.953238 \n",
       "L 177.495429 -253.178809 \n",
       "L 180.774762 -248.385425 \n",
       "L 184.054104 -243.636433 \n",
       "L 187.333446 -238.985846 \n",
       "L 190.612778 -234.477063 \n",
       "L 193.892121 -230.141629 \n",
       "L 197.171463 -225.998603 \n",
       "L 200.450795 -222.054159 \n",
       "L 203.730137 -218.301581 \n",
       "L 207.00948 -214.721706 \n",
       "L 210.288812 -211.283756 \n",
       "L 213.568154 -207.946362 \n",
       "L 216.847496 -204.659359 \n",
       "L 220.126829 -201.365542 \n",
       "L 223.406181 -198.002813 \n",
       "L 226.685504 -194.506928 \n",
       "L 229.964846 -190.813917 \n",
       "L 233.244188 -186.863357 \n",
       "L 236.523511 -182.601075 \n",
       "L 239.802872 -177.982165 \n",
       "L 243.082195 -172.974413 \n",
       "L 246.361537 -167.560532 \n",
       "L 249.640879 -161.741084 \n",
       "L 252.920222 -155.536228 \n",
       "L 256.199564 -148.987969 \n",
       "L 259.478887 -142.121006 \n",
       "L 262.758248 -128.18769 \n",
       "L 266.037571 -114.605873 \n",
       "L 269.316913 -101.656165 \n",
       "L 272.596255 -89.585261 \n",
       "L 275.875578 -78.637718 \n",
       "L 279.15494 -69.051433 \n",
       "L 282.434262 -61.048838 \n",
       "L 285.713605 -54.832489 \n",
       "L 288.992947 -50.577161 \n",
       "L 292.272289 -48.423375 \n",
       "L 295.551631 -48.471838 \n",
       "L 298.830954 -50.778929 \n",
       "L 302.110315 -55.350977 \n",
       "L 305.389638 -62.143036 \n",
       "L 308.66898 -71.055563 \n",
       "L 311.948322 -81.936523 \n",
       "L 315.227645 -94.581136 \n",
       "L 318.507007 -108.737428 \n",
       "L 321.78633 -124.109356 \n",
       "L 325.065672 -140.36501 \n",
       "L 328.345014 -157.144899 \n",
       "L 331.624356 -174.069697 \n",
       "L 334.903698 -190.752174 \n",
       "L 338.183021 -206.811441 \n",
       "L 341.462363 -221.831426 \n",
       "L 344.741705 -234.666164 \n",
       "L 348.021048 -246.248294 \n",
       "L 351.30039 -256.315717 \n",
       "L 354.579713 -264.596303 \n",
       "L 357.859055 -270.849195 \n",
       "L 361.138397 -274.834541 \n",
       "L 364.417739 -275.833126 \n",
       "L 367.697081 -274.404143 \n",
       "L 370.976423 -270.729162 \n",
       "L 374.255766 -264.959811 \n",
       "L 377.535088 -257.312973 \n",
       "L 380.814431 -248.064096 \n",
       "L 384.093773 -237.458798 \n",
       "L 384.093773 -237.537313 \n",
       "L 384.093773 -237.537313 \n",
       "L 380.814431 -249.276985 \n",
       "L 377.535088 -259.196897 \n",
       "L 374.255766 -267.026035 \n",
       "L 370.976423 -272.5897 \n",
       "L 367.697081 -275.779819 \n",
       "L 364.417739 -276.526391 \n",
       "L 361.138397 -274.913052 \n",
       "L 357.859055 -271.529991 \n",
       "L 354.579713 -265.811337 \n",
       "L 351.30039 -257.799216 \n",
       "L 348.021048 -247.652749 \n",
       "L 344.741705 -235.584397 \n",
       "L 341.462363 -221.909941 \n",
       "L 338.183021 -208.211334 \n",
       "L 334.903698 -194.037296 \n",
       "L 331.624356 -179.689053 \n",
       "L 328.345014 -165.513798 \n",
       "L 325.065672 -151.82872 \n",
       "L 321.78633 -138.934354 \n",
       "L 318.507007 -127.091555 \n",
       "L 315.227645 -116.518488 \n",
       "L 311.948322 -107.392793 \n",
       "L 308.66898 -99.839708 \n",
       "L 305.389638 -93.940846 \n",
       "L 302.110315 -89.726418 \n",
       "L 298.830954 -87.18467 \n",
       "L 295.551631 -86.258827 \n",
       "L 292.272289 -86.856644 \n",
       "L 288.992947 -88.854129 \n",
       "L 285.713605 -92.10217 \n",
       "L 282.434262 -96.43445 \n",
       "L 279.15494 -101.671627 \n",
       "L 275.875578 -107.629229 \n",
       "L 272.596255 -114.12574 \n",
       "L 269.316913 -120.983352 \n",
       "L 266.037571 -128.03811 \n",
       "L 262.758248 -135.14045 \n",
       "L 259.478887 -142.199512 \n",
       "L 256.199564 -156.290018 \n",
       "L 252.920222 -170.358436 \n",
       "L 249.640879 -184.163324 \n",
       "L 246.361537 -197.522754 \n",
       "L 243.082195 -210.277058 \n",
       "L 239.802872 -222.29008 \n",
       "L 236.523511 -233.449812 \n",
       "L 233.244188 -243.668535 \n",
       "L 229.964846 -252.882635 \n",
       "L 226.685504 -261.05158 \n",
       "L 223.406181 -268.156506 \n",
       "L 220.126829 -274.199221 \n",
       "L 216.847496 -279.199897 \n",
       "L 213.568154 -283.195705 \n",
       "L 210.288812 -286.238395 \n",
       "L 207.00948 -288.392441 \n",
       "L 203.730137 -289.732944 \n",
       "L 200.450795 -290.343375 \n",
       "L 197.171463 -290.313526 \n",
       "L 193.892121 -289.737441 \n",
       "L 190.612778 -288.711336 \n",
       "L 187.333446 -287.331592 \n",
       "L 184.054104 -285.692836 \n",
       "L 180.774762 -283.886152 \n",
       "L 177.495429 -281.997158 \n",
       "L 174.216087 -280.104479 \n",
       "L 170.936745 -278.278494 \n",
       "L 167.657412 -276.579379 \n",
       "L 164.37807 -275.056979 \n",
       "L 161.098728 -275.369794 \n",
       "L 157.819395 -278.903881 \n",
       "L 154.540053 -281.952554 \n",
       "L 151.260711 -284.445005 \n",
       "L 147.981379 -286.317732 \n",
       "L 144.702037 -287.517798 \n",
       "L 141.422694 -288.004188 \n",
       "L 138.143362 -287.749087 \n",
       "L 134.86402 -286.739432 \n",
       "L 131.584682 -284.977838 \n",
       "L 128.305345 -282.4822 \n",
       "L 125.026003 -279.287063 \n",
       "L 121.746666 -275.442135 \n",
       "L 118.467328 -271.902701 \n",
       "L 115.187986 -271.339599 \n",
       "L 111.908649 -270.421732 \n",
       "L 108.629311 -269.097713 \n",
       "L 105.349969 -267.330169 \n",
       "L 102.070632 -265.091254 \n",
       "L 98.791295 -262.365227 \n",
       "L 95.511955 -259.148945 \n",
       "L 92.232615 -255.451332 \n",
       "L 88.953278 -251.293912 \n",
       "L 85.673938 -246.709987 \n",
       "L 82.394598 -241.743926 \n",
       "L 79.115261 -236.450327 \n",
       "L 75.835921 -230.892195 \n",
       "L 72.556583 -225.138566 \n",
       "L 69.277244 -219.264248 \n",
       "L 65.997905 -213.346494 \n",
       "L 62.718566 -207.463875 \n",
       "L 59.439227 -201.733106 \n",
       "z\n",
       "\" style=\"stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p668037cc3d)\">\n",
       "     <use xlink:href=\"#m1f56934d3b\" x=\"0\" y=\"322.510875\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_2\">\n",
       "    <defs>\n",
       "     <path id=\"m0b5f8cc96a\" d=\"M 59.439227 -201.654591 \n",
       "L 59.439227 -201.654591 \n",
       "L 62.718566 -200.686785 \n",
       "L 65.997905 -200.491859 \n",
       "L 69.277244 -201.11431 \n",
       "L 72.556583 -202.544817 \n",
       "L 75.835921 -204.758638 \n",
       "L 79.115261 -207.716497 \n",
       "L 82.394598 -211.363998 \n",
       "L 85.673938 -215.633313 \n",
       "L 88.953278 -220.444276 \n",
       "L 92.232615 -225.705198 \n",
       "L 95.511955 -231.315391 \n",
       "L 98.791295 -237.166909 \n",
       "L 102.070632 -243.146753 \n",
       "L 105.349969 -249.14043 \n",
       "L 108.629311 -255.032909 \n",
       "L 111.908649 -260.711911 \n",
       "L 115.187986 -266.071293 \n",
       "L 118.467328 -271.008207 \n",
       "L 121.746666 -272.157755 \n",
       "L 125.026003 -272.174437 \n",
       "L 128.305345 -272.014724 \n",
       "L 131.584682 -271.745913 \n",
       "L 134.86402 -271.435201 \n",
       "L 138.143362 -271.146456 \n",
       "L 141.422694 -270.939715 \n",
       "L 144.702037 -270.868159 \n",
       "L 147.981379 -270.976638 \n",
       "L 151.260711 -271.30064 \n",
       "L 154.540053 -271.864509 \n",
       "L 157.819395 -272.680395 \n",
       "L 161.098728 -273.748591 \n",
       "L 164.37807 -271.426654 \n",
       "L 167.657412 -267.155635 \n",
       "L 170.936745 -262.637653 \n",
       "L 174.216087 -257.953238 \n",
       "L 177.495429 -253.178809 \n",
       "L 180.774762 -248.385425 \n",
       "L 184.054104 -243.636433 \n",
       "L 187.333446 -238.985846 \n",
       "L 190.612778 -234.477063 \n",
       "L 193.892121 -230.141629 \n",
       "L 197.171463 -225.998603 \n",
       "L 200.450795 -222.054159 \n",
       "L 203.730137 -218.301581 \n",
       "L 207.00948 -214.721706 \n",
       "L 210.288812 -211.283756 \n",
       "L 213.568154 -207.946362 \n",
       "L 216.847496 -204.659359 \n",
       "L 220.126829 -201.365542 \n",
       "L 223.406181 -198.002813 \n",
       "L 226.685504 -194.506928 \n",
       "L 229.964846 -190.813917 \n",
       "L 233.244188 -186.863357 \n",
       "L 236.523511 -182.601075 \n",
       "L 239.802872 -177.982165 \n",
       "L 243.082195 -172.974413 \n",
       "L 246.361537 -167.560532 \n",
       "L 249.640879 -161.741084 \n",
       "L 252.920222 -155.536228 \n",
       "L 256.199564 -148.987969 \n",
       "L 259.478887 -142.121006 \n",
       "L 262.758248 -128.18769 \n",
       "L 266.037571 -114.605873 \n",
       "L 269.316913 -101.656165 \n",
       "L 272.596255 -89.585261 \n",
       "L 275.875578 -78.637718 \n",
       "L 279.15494 -69.051433 \n",
       "L 282.434262 -61.048838 \n",
       "L 285.713605 -54.832489 \n",
       "L 288.992947 -50.577161 \n",
       "L 292.272289 -48.423375 \n",
       "L 295.551631 -48.471838 \n",
       "L 298.830954 -50.778929 \n",
       "L 302.110315 -55.350977 \n",
       "L 305.389638 -62.143036 \n",
       "L 308.66898 -71.055563 \n",
       "L 311.948322 -81.936523 \n",
       "L 315.227645 -94.581136 \n",
       "L 318.507007 -108.737428 \n",
       "L 321.78633 -124.109356 \n",
       "L 325.065672 -140.36501 \n",
       "L 328.345014 -157.144899 \n",
       "L 331.624356 -174.069697 \n",
       "L 334.903698 -190.752174 \n",
       "L 338.183021 -206.811441 \n",
       "L 341.462363 -221.831426 \n",
       "L 344.741705 -234.666164 \n",
       "L 348.021048 -246.248294 \n",
       "L 351.30039 -256.315717 \n",
       "L 354.579713 -264.596303 \n",
       "L 357.859055 -270.849195 \n",
       "L 361.138397 -274.834541 \n",
       "L 364.417739 -275.833126 \n",
       "L 367.697081 -274.404143 \n",
       "L 370.976423 -270.729162 \n",
       "L 374.255766 -264.959811 \n",
       "L 377.535088 -257.312973 \n",
       "L 380.814431 -248.064096 \n",
       "L 384.093773 -237.458798 \n",
       "L 384.093773 -237.458798 \n",
       "L 384.093773 -237.458798 \n",
       "L 380.814431 -248.064096 \n",
       "L 377.535088 -257.312973 \n",
       "L 374.255766 -264.959811 \n",
       "L 370.976423 -270.729162 \n",
       "L 367.697081 -274.404143 \n",
       "L 364.417739 -275.833126 \n",
       "L 361.138397 -274.834541 \n",
       "L 357.859055 -270.849195 \n",
       "L 354.579713 -264.596303 \n",
       "L 351.30039 -256.315717 \n",
       "L 348.021048 -246.248294 \n",
       "L 344.741705 -234.666164 \n",
       "L 341.462363 -221.831426 \n",
       "L 338.183021 -206.811441 \n",
       "L 334.903698 -190.752174 \n",
       "L 331.624356 -174.069697 \n",
       "L 328.345014 -157.144899 \n",
       "L 325.065672 -140.36501 \n",
       "L 321.78633 -124.109356 \n",
       "L 318.507007 -108.737428 \n",
       "L 315.227645 -94.581136 \n",
       "L 311.948322 -81.936523 \n",
       "L 308.66898 -71.055563 \n",
       "L 305.389638 -62.143036 \n",
       "L 302.110315 -55.350977 \n",
       "L 298.830954 -50.778929 \n",
       "L 295.551631 -48.471838 \n",
       "L 292.272289 -48.423375 \n",
       "L 288.992947 -50.577161 \n",
       "L 285.713605 -54.832489 \n",
       "L 282.434262 -61.048838 \n",
       "L 279.15494 -69.051433 \n",
       "L 275.875578 -78.637718 \n",
       "L 272.596255 -89.585261 \n",
       "L 269.316913 -101.656165 \n",
       "L 266.037571 -114.605873 \n",
       "L 262.758248 -128.18769 \n",
       "L 259.478887 -142.121006 \n",
       "L 256.199564 -148.987969 \n",
       "L 252.920222 -155.536228 \n",
       "L 249.640879 -161.741084 \n",
       "L 246.361537 -167.560532 \n",
       "L 243.082195 -172.974413 \n",
       "L 239.802872 -177.982165 \n",
       "L 236.523511 -182.601075 \n",
       "L 233.244188 -186.863357 \n",
       "L 229.964846 -190.813917 \n",
       "L 226.685504 -194.506928 \n",
       "L 223.406181 -198.002813 \n",
       "L 220.126829 -201.365542 \n",
       "L 216.847496 -204.659359 \n",
       "L 213.568154 -207.946362 \n",
       "L 210.288812 -211.283756 \n",
       "L 207.00948 -214.721706 \n",
       "L 203.730137 -218.301581 \n",
       "L 200.450795 -222.054159 \n",
       "L 197.171463 -225.998603 \n",
       "L 193.892121 -230.141629 \n",
       "L 190.612778 -234.477063 \n",
       "L 187.333446 -238.985846 \n",
       "L 184.054104 -243.636433 \n",
       "L 180.774762 -248.385425 \n",
       "L 177.495429 -253.178809 \n",
       "L 174.216087 -257.953238 \n",
       "L 170.936745 -262.637653 \n",
       "L 167.657412 -267.155635 \n",
       "L 164.37807 -271.426654 \n",
       "L 161.098728 -273.748591 \n",
       "L 157.819395 -272.680395 \n",
       "L 154.540053 -271.864509 \n",
       "L 151.260711 -271.30064 \n",
       "L 147.981379 -270.976638 \n",
       "L 144.702037 -270.868159 \n",
       "L 141.422694 -270.939715 \n",
       "L 138.143362 -271.146456 \n",
       "L 134.86402 -271.435201 \n",
       "L 131.584682 -271.745913 \n",
       "L 128.305345 -272.014724 \n",
       "L 125.026003 -272.174437 \n",
       "L 121.746666 -272.157755 \n",
       "L 118.467328 -271.008207 \n",
       "L 115.187986 -266.071293 \n",
       "L 111.908649 -260.711911 \n",
       "L 108.629311 -255.032909 \n",
       "L 105.349969 -249.14043 \n",
       "L 102.070632 -243.146753 \n",
       "L 98.791295 -237.166909 \n",
       "L 95.511955 -231.315391 \n",
       "L 92.232615 -225.705198 \n",
       "L 88.953278 -220.444276 \n",
       "L 85.673938 -215.633313 \n",
       "L 82.394598 -211.363998 \n",
       "L 79.115261 -207.716497 \n",
       "L 75.835921 -204.758638 \n",
       "L 72.556583 -202.544817 \n",
       "L 69.277244 -201.11431 \n",
       "L 65.997905 -200.491859 \n",
       "L 62.718566 -200.686785 \n",
       "L 59.439227 -201.654591 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p668037cc3d)\">\n",
       "     <use xlink:href=\"#m0b5f8cc96a\" x=\"0\" y=\"322.510875\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_3\">\n",
       "    <defs>\n",
       "     <path id=\"mfe2963e6e9\" d=\"M 59.439227 -201.733106 \n",
       "L 59.439227 -201.733106 \n",
       "L 62.718566 -207.463875 \n",
       "L 65.997905 -213.346494 \n",
       "L 69.277244 -219.264248 \n",
       "L 72.556583 -225.138566 \n",
       "L 75.835921 -230.892195 \n",
       "L 79.115261 -236.450327 \n",
       "L 82.394598 -241.743926 \n",
       "L 85.673938 -246.709987 \n",
       "L 88.953278 -251.293912 \n",
       "L 92.232615 -255.451332 \n",
       "L 95.511955 -259.148945 \n",
       "L 98.791295 -262.365227 \n",
       "L 102.070632 -265.091254 \n",
       "L 105.349969 -267.330169 \n",
       "L 108.629311 -269.097713 \n",
       "L 111.908649 -270.421732 \n",
       "L 115.187986 -271.339599 \n",
       "L 118.467328 -271.902701 \n",
       "L 121.746666 -275.442135 \n",
       "L 125.026003 -279.287063 \n",
       "L 128.305345 -282.4822 \n",
       "L 131.584682 -284.977838 \n",
       "L 134.86402 -286.739432 \n",
       "L 138.143362 -287.749087 \n",
       "L 141.422694 -288.004188 \n",
       "L 144.702037 -287.517798 \n",
       "L 147.981379 -286.317732 \n",
       "L 151.260711 -284.445005 \n",
       "L 154.540053 -281.952554 \n",
       "L 157.819395 -278.903881 \n",
       "L 161.098728 -275.369794 \n",
       "L 164.37807 -275.056979 \n",
       "L 167.657412 -276.579379 \n",
       "L 170.936745 -278.278494 \n",
       "L 174.216087 -280.104479 \n",
       "L 177.495429 -281.997158 \n",
       "L 180.774762 -283.886152 \n",
       "L 184.054104 -285.692836 \n",
       "L 187.333446 -287.331592 \n",
       "L 190.612778 -288.711336 \n",
       "L 193.892121 -289.737441 \n",
       "L 197.171463 -290.313526 \n",
       "L 200.450795 -290.343375 \n",
       "L 203.730137 -289.732944 \n",
       "L 207.00948 -288.392441 \n",
       "L 210.288812 -286.238395 \n",
       "L 213.568154 -283.195705 \n",
       "L 216.847496 -279.199897 \n",
       "L 220.126829 -274.199221 \n",
       "L 223.406181 -268.156506 \n",
       "L 226.685504 -261.05158 \n",
       "L 229.964846 -252.882635 \n",
       "L 233.244188 -243.668535 \n",
       "L 236.523511 -233.449812 \n",
       "L 239.802872 -222.29008 \n",
       "L 243.082195 -210.277058 \n",
       "L 246.361537 -197.522754 \n",
       "L 249.640879 -184.163324 \n",
       "L 252.920222 -170.358436 \n",
       "L 256.199564 -156.290018 \n",
       "L 259.478887 -142.199512 \n",
       "L 262.758248 -135.14045 \n",
       "L 266.037571 -128.03811 \n",
       "L 269.316913 -120.983352 \n",
       "L 272.596255 -114.12574 \n",
       "L 275.875578 -107.629229 \n",
       "L 279.15494 -101.671627 \n",
       "L 282.434262 -96.43445 \n",
       "L 285.713605 -92.10217 \n",
       "L 288.992947 -88.854129 \n",
       "L 292.272289 -86.856644 \n",
       "L 295.551631 -86.258827 \n",
       "L 298.830954 -87.18467 \n",
       "L 302.110315 -89.726418 \n",
       "L 305.389638 -93.940846 \n",
       "L 308.66898 -99.839708 \n",
       "L 311.948322 -107.392793 \n",
       "L 315.227645 -116.518488 \n",
       "L 318.507007 -127.091555 \n",
       "L 321.78633 -138.934354 \n",
       "L 325.065672 -151.82872 \n",
       "L 328.345014 -165.513798 \n",
       "L 331.624356 -179.689053 \n",
       "L 334.903698 -194.037296 \n",
       "L 338.183021 -208.211334 \n",
       "L 341.462363 -221.909941 \n",
       "L 344.741705 -235.584397 \n",
       "L 348.021048 -247.652749 \n",
       "L 351.30039 -257.799216 \n",
       "L 354.579713 -265.811337 \n",
       "L 357.859055 -271.529991 \n",
       "L 361.138397 -274.913052 \n",
       "L 364.417739 -276.526391 \n",
       "L 367.697081 -275.779819 \n",
       "L 370.976423 -272.5897 \n",
       "L 374.255766 -267.026035 \n",
       "L 377.535088 -259.196897 \n",
       "L 380.814431 -249.276985 \n",
       "L 384.093773 -237.537313 \n",
       "L 384.093773 -237.537313 \n",
       "L 384.093773 -237.537313 \n",
       "L 380.814431 -249.276985 \n",
       "L 377.535088 -259.196897 \n",
       "L 374.255766 -267.026035 \n",
       "L 370.976423 -272.5897 \n",
       "L 367.697081 -275.779819 \n",
       "L 364.417739 -276.526391 \n",
       "L 361.138397 -274.913052 \n",
       "L 357.859055 -271.529991 \n",
       "L 354.579713 -265.811337 \n",
       "L 351.30039 -257.799216 \n",
       "L 348.021048 -247.652749 \n",
       "L 344.741705 -235.584397 \n",
       "L 341.462363 -221.909941 \n",
       "L 338.183021 -208.211334 \n",
       "L 334.903698 -194.037296 \n",
       "L 331.624356 -179.689053 \n",
       "L 328.345014 -165.513798 \n",
       "L 325.065672 -151.82872 \n",
       "L 321.78633 -138.934354 \n",
       "L 318.507007 -127.091555 \n",
       "L 315.227645 -116.518488 \n",
       "L 311.948322 -107.392793 \n",
       "L 308.66898 -99.839708 \n",
       "L 305.389638 -93.940846 \n",
       "L 302.110315 -89.726418 \n",
       "L 298.830954 -87.18467 \n",
       "L 295.551631 -86.258827 \n",
       "L 292.272289 -86.856644 \n",
       "L 288.992947 -88.854129 \n",
       "L 285.713605 -92.10217 \n",
       "L 282.434262 -96.43445 \n",
       "L 279.15494 -101.671627 \n",
       "L 275.875578 -107.629229 \n",
       "L 272.596255 -114.12574 \n",
       "L 269.316913 -120.983352 \n",
       "L 266.037571 -128.03811 \n",
       "L 262.758248 -135.14045 \n",
       "L 259.478887 -142.199512 \n",
       "L 256.199564 -156.290018 \n",
       "L 252.920222 -170.358436 \n",
       "L 249.640879 -184.163324 \n",
       "L 246.361537 -197.522754 \n",
       "L 243.082195 -210.277058 \n",
       "L 239.802872 -222.29008 \n",
       "L 236.523511 -233.449812 \n",
       "L 233.244188 -243.668535 \n",
       "L 229.964846 -252.882635 \n",
       "L 226.685504 -261.05158 \n",
       "L 223.406181 -268.156506 \n",
       "L 220.126829 -274.199221 \n",
       "L 216.847496 -279.199897 \n",
       "L 213.568154 -283.195705 \n",
       "L 210.288812 -286.238395 \n",
       "L 207.00948 -288.392441 \n",
       "L 203.730137 -289.732944 \n",
       "L 200.450795 -290.343375 \n",
       "L 197.171463 -290.313526 \n",
       "L 193.892121 -289.737441 \n",
       "L 190.612778 -288.711336 \n",
       "L 187.333446 -287.331592 \n",
       "L 184.054104 -285.692836 \n",
       "L 180.774762 -283.886152 \n",
       "L 177.495429 -281.997158 \n",
       "L 174.216087 -280.104479 \n",
       "L 170.936745 -278.278494 \n",
       "L 167.657412 -276.579379 \n",
       "L 164.37807 -275.056979 \n",
       "L 161.098728 -275.369794 \n",
       "L 157.819395 -278.903881 \n",
       "L 154.540053 -281.952554 \n",
       "L 151.260711 -284.445005 \n",
       "L 147.981379 -286.317732 \n",
       "L 144.702037 -287.517798 \n",
       "L 141.422694 -288.004188 \n",
       "L 138.143362 -287.749087 \n",
       "L 134.86402 -286.739432 \n",
       "L 131.584682 -284.977838 \n",
       "L 128.305345 -282.4822 \n",
       "L 125.026003 -279.287063 \n",
       "L 121.746666 -275.442135 \n",
       "L 118.467328 -271.902701 \n",
       "L 115.187986 -271.339599 \n",
       "L 111.908649 -270.421732 \n",
       "L 108.629311 -269.097713 \n",
       "L 105.349969 -267.330169 \n",
       "L 102.070632 -265.091254 \n",
       "L 98.791295 -262.365227 \n",
       "L 95.511955 -259.148945 \n",
       "L 92.232615 -255.451332 \n",
       "L 88.953278 -251.293912 \n",
       "L 85.673938 -246.709987 \n",
       "L 82.394598 -241.743926 \n",
       "L 79.115261 -236.450327 \n",
       "L 75.835921 -230.892195 \n",
       "L 72.556583 -225.138566 \n",
       "L 69.277244 -219.264248 \n",
       "L 65.997905 -213.346494 \n",
       "L 62.718566 -207.463875 \n",
       "L 59.439227 -201.733106 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p668037cc3d)\">\n",
       "     <use xlink:href=\"#mfe2963e6e9\" x=\"0\" y=\"322.510875\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_14\">\n",
       "    <defs>\n",
       "     <path id=\"m1f2934d2e3\" d=\"M -5 5 \n",
       "L 5 -5 \n",
       "M -5 -5 \n",
       "L 5 5 \n",
       "\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p668037cc3d)\">\n",
       "     <use xlink:href=\"#m1f2934d2e3\" x=\"361.243318\" y=\"47.558156\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m1f2934d2e3\" x=\"162.151989\" y=\"48.367013\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m1f2934d2e3\" x=\"119.149308\" y=\"50.534081\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m1f2934d2e3\" x=\"259.478887\" y=\"180.350672\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m1f2934d2e3\" x=\"384.093773\" y=\"85.013357\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m1f2934d2e3\" x=\"341.462363\" y=\"100.640996\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m1f2934d2e3\" x=\"59.439227\" y=\"120.816989\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_15\">\n",
       "    <path d=\"M 59.439227 120.817027 \n",
       "L 62.718566 118.435547 \n",
       "L 65.997905 115.591699 \n",
       "L 69.277244 112.321594 \n",
       "L 72.556583 108.669184 \n",
       "L 75.835921 104.685459 \n",
       "L 79.115261 100.427463 \n",
       "L 82.394598 95.956913 \n",
       "L 85.673938 91.339225 \n",
       "L 88.953278 86.641781 \n",
       "L 92.232615 81.93261 \n",
       "L 95.511955 77.278706 \n",
       "L 98.791295 72.744807 \n",
       "L 102.070632 68.391871 \n",
       "L 105.349969 64.275576 \n",
       "L 108.629311 60.445563 \n",
       "L 111.908649 56.944054 \n",
       "L 115.187986 53.805429 \n",
       "L 118.467328 51.055421 \n",
       "L 121.746666 48.71093 \n",
       "L 125.026003 46.780125 \n",
       "L 128.305345 45.262413 \n",
       "L 131.584682 44.149 \n",
       "L 134.86402 43.423559 \n",
       "L 138.143362 43.063103 \n",
       "L 141.422694 43.038923 \n",
       "L 144.702037 43.317897 \n",
       "L 147.981379 43.86369 \n",
       "L 151.260711 44.638052 \n",
       "L 154.540053 45.602343 \n",
       "L 157.819395 46.718737 \n",
       "L 161.098728 47.951683 \n",
       "L 164.37807 49.269059 \n",
       "L 167.657412 50.643368 \n",
       "L 170.936745 52.052802 \n",
       "L 174.216087 53.482017 \n",
       "L 177.495429 54.922892 \n",
       "L 180.774762 56.375087 \n",
       "L 184.054104 57.846241 \n",
       "L 187.333446 59.352156 \n",
       "L 190.612778 60.916676 \n",
       "L 193.892121 62.571341 \n",
       "L 197.171463 64.354809 \n",
       "L 200.450795 66.312108 \n",
       "L 203.730137 68.493611 \n",
       "L 207.00948 70.953803 \n",
       "L 210.288812 73.7498 \n",
       "L 213.568154 76.939843 \n",
       "L 216.847496 80.581248 \n",
       "L 220.126829 84.728492 \n",
       "L 223.406181 89.431215 \n",
       "L 226.685504 94.731623 \n",
       "L 229.964846 100.662597 \n",
       "L 233.244188 107.244929 \n",
       "L 236.523511 114.485431 \n",
       "L 239.802872 122.374755 \n",
       "L 243.082195 130.885139 \n",
       "L 246.361537 139.969232 \n",
       "L 249.640879 149.558671 \n",
       "L 252.920222 159.563543 \n",
       "L 256.199564 169.871881 \n",
       "L 259.478887 180.350616 \n",
       "L 262.758248 190.846805 \n",
       "L 266.037571 201.188884 \n",
       "L 269.316913 211.191116 \n",
       "L 272.596255 220.655375 \n",
       "L 275.875578 229.377402 \n",
       "L 279.15494 237.149345 \n",
       "L 282.434262 243.769231 \n",
       "L 285.713605 249.043546 \n",
       "L 288.992947 252.79523 \n",
       "L 292.272289 254.870865 \n",
       "L 295.551631 255.145543 \n",
       "L 298.830954 253.529076 \n",
       "L 302.110315 249.972178 \n",
       "L 305.389638 244.468934 \n",
       "L 308.66898 237.063239 \n",
       "L 311.948322 227.846217 \n",
       "L 315.227645 216.961063 \n",
       "L 318.507007 204.596388 \n",
       "L 321.78633 190.98902 \n",
       "L 325.065672 176.41401 \n",
       "L 328.345014 161.181526 \n",
       "L 331.624356 145.6315 \n",
       "L 334.903698 130.11614 \n",
       "L 338.183021 114.999488 \n",
       "L 341.462363 100.640191 \n",
       "L 344.741705 87.385594 \n",
       "L 348.021048 75.560353 \n",
       "L 351.30039 65.453409 \n",
       "L 354.579713 57.307055 \n",
       "L 357.859055 51.321282 \n",
       "L 361.138397 47.637079 \n",
       "L 364.417739 46.331116 \n",
       "L 367.697081 47.418894 \n",
       "L 370.976423 50.851444 \n",
       "L 374.255766 56.517952 \n",
       "L 377.535088 64.25594 \n",
       "L 380.814431 73.840335 \n",
       "L 384.093773 85.012819 \n",
       "\" clip-path=\"url(#p668037cc3d)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_16\">\n",
       "    <path d=\"M 59.439227 120.816989 \n",
       "L 62.718566 116.027094 \n",
       "L 65.997905 111.254973 \n",
       "L 69.277244 106.518323 \n",
       "L 72.556583 101.834778 \n",
       "L 75.835921 97.221774 \n",
       "L 79.115261 92.696579 \n",
       "L 82.394598 88.276157 \n",
       "L 85.673938 83.977135 \n",
       "L 88.953278 79.815775 \n",
       "L 92.232615 75.807865 \n",
       "L 95.511955 71.968704 \n",
       "L 98.791295 68.313033 \n",
       "L 102.070632 64.854988 \n",
       "L 105.349969 61.608038 \n",
       "L 108.629311 58.584977 \n",
       "L 111.908649 55.797836 \n",
       "L 115.187986 53.257866 \n",
       "L 118.467328 50.975478 \n",
       "L 121.746666 48.960239 \n",
       "L 125.026003 47.220818 \n",
       "L 128.305345 45.764947 \n",
       "L 131.584682 44.599412 \n",
       "L 134.86402 43.73002 \n",
       "L 138.143362 43.161568 \n",
       "L 141.422694 42.897836 \n",
       "L 144.702037 42.941572 \n",
       "L 147.981379 43.294456 \n",
       "L 151.260711 43.95711 \n",
       "L 154.540053 44.92909 \n",
       "L 157.819395 46.20886 \n",
       "L 161.098728 47.793791 \n",
       "L 164.37807 49.680195 \n",
       "L 167.657412 51.863257 \n",
       "L 170.936745 54.337104 \n",
       "L 174.216087 57.094762 \n",
       "L 177.495429 60.128179 \n",
       "L 180.774762 63.428225 \n",
       "L 184.054104 66.984683 \n",
       "L 187.333446 70.786313 \n",
       "L 190.612778 74.820752 \n",
       "L 193.892121 79.074638 \n",
       "L 197.171463 83.533513 \n",
       "L 200.450795 88.181932 \n",
       "L 203.730137 93.003368 \n",
       "L 207.00948 97.980249 \n",
       "L 210.288812 103.093981 \n",
       "L 213.568154 108.324953 \n",
       "L 216.847496 113.652466 \n",
       "L 220.126829 119.054821 \n",
       "L 223.406181 124.50926 \n",
       "L 226.685504 129.991923 \n",
       "L 229.964846 135.477955 \n",
       "L 233.244188 140.941403 \n",
       "L 236.523511 146.355097 \n",
       "L 239.802872 151.691006 \n",
       "L 243.082195 156.919684 \n",
       "L 246.361537 162.0108 \n",
       "L 249.640879 166.932736 \n",
       "L 252.920222 171.652773 \n",
       "L 256.199564 176.137096 \n",
       "L 259.478887 180.350672 \n",
       "L 262.758248 184.257468 \n",
       "L 266.037571 187.820337 \n",
       "L 269.316913 191.001206 \n",
       "L 272.596255 193.761101 \n",
       "L 275.875578 196.060396 \n",
       "L 279.15494 197.858884 \n",
       "L 282.434262 199.116131 \n",
       "L 285.713605 199.791771 \n",
       "L 288.992947 199.845933 \n",
       "L 292.272289 199.239767 \n",
       "L 295.551631 197.936145 \n",
       "L 298.830954 195.900427 \n",
       "L 302.110315 193.101363 \n",
       "L 305.389638 189.512624 \n",
       "L 308.66898 185.113649 \n",
       "L 311.948322 179.891803 \n",
       "L 315.227645 173.844202 \n",
       "L 318.507007 166.979701 \n",
       "L 321.78633 159.321895 \n",
       "L 325.065672 150.911636 \n",
       "L 328.345014 141.810369 \n",
       "L 331.624356 132.103611 \n",
       "L 334.903698 121.90444 \n",
       "L 338.183021 111.35719 \n",
       "L 341.462363 100.640996 \n",
       "L 344.741705 89.972605 \n",
       "L 348.021048 79.608733 \n",
       "L 351.30039 69.846951 \n",
       "L 354.579713 61.024119 \n",
       "L 357.859055 53.512243 \n",
       "L 361.138397 47.710914 \n",
       "L 364.417739 44.033646 \n",
       "L 367.697081 42.888931 \n",
       "L 370.976423 44.653383 \n",
       "L 374.255766 49.636595 \n",
       "L 377.535088 58.037344 \n",
       "L 380.814431 69.891393 \n",
       "L 384.093773 85.013357 \n",
       "\" clip-path=\"url(#p668037cc3d)\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 43.2065 278.413098 \n",
       "L 43.2065 42.878051 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 59.439227 286.1835 \n",
       "L 384.093773 286.1835 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_16\">\n",
       "    <!-- N=3,  -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(210.16025 14.0715) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-4e\" d=\"M 488 0 \n",
       "L 488 4581 \n",
       "L 1109 4581 \n",
       "L 3516 984 \n",
       "L 3516 4581 \n",
       "L 4097 4581 \n",
       "L 4097 0 \n",
       "L 3475 0 \n",
       "L 1069 3600 \n",
       "L 1069 0 \n",
       "L 488 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-3d\" d=\"M 3381 2694 \n",
       "L 356 2694 \n",
       "L 356 3219 \n",
       "L 3381 3219 \n",
       "L 3381 2694 \n",
       "z\n",
       "M 3381 1303 \n",
       "L 356 1303 \n",
       "L 356 1828 \n",
       "L 3381 1828 \n",
       "L 3381 1303 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-33\" d=\"M 269 1209 \n",
       "L 831 1284 \n",
       "Q 928 806 1161 595 \n",
       "Q 1394 384 1728 384 \n",
       "Q 2125 384 2398 659 \n",
       "Q 2672 934 2672 1341 \n",
       "Q 2672 1728 2419 1979 \n",
       "Q 2166 2231 1775 2231 \n",
       "Q 1616 2231 1378 2169 \n",
       "L 1441 2663 \n",
       "Q 1497 2656 1531 2656 \n",
       "Q 1891 2656 2178 2843 \n",
       "Q 2466 3031 2466 3422 \n",
       "Q 2466 3731 2256 3934 \n",
       "Q 2047 4138 1716 4138 \n",
       "Q 1388 4138 1169 3931 \n",
       "Q 950 3725 888 3313 \n",
       "L 325 3413 \n",
       "Q 428 3978 793 4289 \n",
       "Q 1159 4600 1703 4600 \n",
       "Q 2078 4600 2393 4439 \n",
       "Q 2709 4278 2876 4000 \n",
       "Q 3044 3722 3044 3409 \n",
       "Q 3044 3113 2884 2869 \n",
       "Q 2725 2625 2413 2481 \n",
       "Q 2819 2388 3044 2092 \n",
       "Q 3269 1797 3269 1353 \n",
       "Q 3269 753 2831 336 \n",
       "Q 2394 -81 1725 -81 \n",
       "Q 1122 -81 723 278 \n",
       "Q 325 638 269 1209 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-2c\" d=\"M 569 0 \n",
       "L 569 641 \n",
       "L 1209 641 \n",
       "L 1209 0 \n",
       "Q 1209 -353 1084 -570 \n",
       "Q 959 -788 688 -906 \n",
       "L 531 -666 \n",
       "Q 709 -588 793 -436 \n",
       "Q 878 -284 888 0 \n",
       "L 569 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-4e\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"72.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-33\" x=\"130.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-2c\" x=\"186.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-20\" x=\"214.013672\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"legend_1\">\n",
       "    <g id=\"line2d_17\">\n",
       "     <g>\n",
       "      <use xlink:href=\"#m1f2934d2e3\" x=\"59.9265\" y=\"219.978625\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_17\">\n",
       "     <!-- Observations -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 223.058625) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4f\" d=\"M 309 2231 \n",
       "Q 309 3372 921 4017 \n",
       "Q 1534 4663 2503 4663 \n",
       "Q 3138 4663 3647 4359 \n",
       "Q 4156 4056 4423 3514 \n",
       "Q 4691 2972 4691 2284 \n",
       "Q 4691 1588 4409 1038 \n",
       "Q 4128 488 3612 205 \n",
       "Q 3097 -78 2500 -78 \n",
       "Q 1853 -78 1343 234 \n",
       "Q 834 547 571 1087 \n",
       "Q 309 1628 309 2231 \n",
       "z\n",
       "M 934 2222 \n",
       "Q 934 1394 1379 917 \n",
       "Q 1825 441 2497 441 \n",
       "Q 3181 441 3623 922 \n",
       "Q 4066 1403 4066 2288 \n",
       "Q 4066 2847 3877 3264 \n",
       "Q 3688 3681 3323 3911 \n",
       "Q 2959 4141 2506 4141 \n",
       "Q 1863 4141 1398 3698 \n",
       "Q 934 3256 934 2222 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-62\" d=\"M 941 0 \n",
       "L 419 0 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 2947 \n",
       "Q 1338 3394 1891 3394 \n",
       "Q 2197 3394 2470 3270 \n",
       "Q 2744 3147 2920 2923 \n",
       "Q 3097 2700 3197 2384 \n",
       "Q 3297 2069 3297 1709 \n",
       "Q 3297 856 2875 390 \n",
       "Q 2453 -75 1863 -75 \n",
       "Q 1275 -75 941 416 \n",
       "L 941 0 \n",
       "z\n",
       "M 934 1684 \n",
       "Q 934 1088 1097 822 \n",
       "Q 1363 388 1816 388 \n",
       "Q 2184 388 2453 708 \n",
       "Q 2722 1028 2722 1663 \n",
       "Q 2722 2313 2464 2622 \n",
       "Q 2206 2931 1841 2931 \n",
       "Q 1472 2931 1203 2611 \n",
       "Q 934 2291 934 1684 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-76\" d=\"M 1344 0 \n",
       "L 81 3319 \n",
       "L 675 3319 \n",
       "L 1388 1331 \n",
       "Q 1503 1009 1600 663 \n",
       "Q 1675 925 1809 1294 \n",
       "L 2547 3319 \n",
       "L 3125 3319 \n",
       "L 1869 0 \n",
       "L 1344 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4f\"/>\n",
       "      <use xlink:href=\"#ArialMT-62\" x=\"77.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"133.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"183.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"239.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"272.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"322.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"377.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"405.712891\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"427.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"483.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"539.160156\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_18\">\n",
       "     <path d=\"M 51.1265 232.562625 \n",
       "L 59.9265 232.562625 \n",
       "L 68.7265 232.562625 \n",
       "\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "    </g>\n",
       "    <g id=\"text_18\">\n",
       "     <!-- $m_n(x)$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 235.642625) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-6d\" d=\"M 5747 2113 \n",
       "L 5338 0 \n",
       "L 4763 0 \n",
       "L 5166 2094 \n",
       "Q 5191 2228 5203 2325 \n",
       "Q 5216 2422 5216 2491 \n",
       "Q 5216 2772 5059 2928 \n",
       "Q 4903 3084 4622 3084 \n",
       "Q 4203 3084 3875 2770 \n",
       "Q 3547 2456 3450 1953 \n",
       "L 3066 0 \n",
       "L 2491 0 \n",
       "L 2900 2094 \n",
       "Q 2925 2209 2937 2307 \n",
       "Q 2950 2406 2950 2484 \n",
       "Q 2950 2769 2794 2926 \n",
       "Q 2638 3084 2363 3084 \n",
       "Q 1938 3084 1609 2770 \n",
       "Q 1281 2456 1184 1953 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 909 3500 \n",
       "L 1484 3500 \n",
       "L 1375 2956 \n",
       "Q 1609 3263 1923 3423 \n",
       "Q 2238 3584 2597 3584 \n",
       "Q 2978 3584 3223 3384 \n",
       "Q 3469 3184 3519 2828 \n",
       "Q 3781 3197 4126 3390 \n",
       "Q 4472 3584 4856 3584 \n",
       "Q 5306 3584 5551 3325 \n",
       "Q 5797 3066 5797 2591 \n",
       "Q 5797 2488 5784 2364 \n",
       "Q 5772 2241 5747 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Oblique-6e\" d=\"M 3566 2113 \n",
       "L 3156 0 \n",
       "L 2578 0 \n",
       "L 2988 2091 \n",
       "Q 3016 2238 3031 2350 \n",
       "Q 3047 2463 3047 2528 \n",
       "Q 3047 2791 2881 2937 \n",
       "Q 2716 3084 2419 3084 \n",
       "Q 1956 3084 1622 2776 \n",
       "Q 1288 2469 1184 1941 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 903 3500 \n",
       "L 1478 3500 \n",
       "L 1363 2950 \n",
       "Q 1603 3253 1940 3418 \n",
       "Q 2278 3584 2650 3584 \n",
       "Q 3113 3584 3367 3334 \n",
       "Q 3622 3084 3622 2631 \n",
       "Q 3622 2519 3608 2391 \n",
       "Q 3594 2263 3566 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-28\" d=\"M 1984 4856 \n",
       "Q 1566 4138 1362 3434 \n",
       "Q 1159 2731 1159 2009 \n",
       "Q 1159 1288 1364 580 \n",
       "Q 1569 -128 1984 -844 \n",
       "L 1484 -844 \n",
       "Q 1016 -109 783 600 \n",
       "Q 550 1309 550 2009 \n",
       "Q 550 2706 781 3412 \n",
       "Q 1013 4119 1484 4856 \n",
       "L 1984 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-29\" d=\"M 513 4856 \n",
       "L 1013 4856 \n",
       "Q 1481 4119 1714 3412 \n",
       "Q 1947 2706 1947 2009 \n",
       "Q 1947 1309 1714 600 \n",
       "Q 1481 -109 1013 -844 \n",
       "L 513 -844 \n",
       "Q 928 -128 1133 580 \n",
       "Q 1338 1288 1338 2009 \n",
       "Q 1338 2731 1133 3434 \n",
       "Q 928 4138 513 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6d\" transform=\"translate(0 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6e\" transform=\"translate(97.412109 -16.28125) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(144.511719 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(183.525391 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(242.705078 0.125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_5\">\n",
       "     <path d=\"M 51.1265 249.799625 \n",
       "L 68.7265 249.799625 \n",
       "L 68.7265 243.639625 \n",
       "L 51.1265 243.639625 \n",
       "z\n",
       "\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_19\">\n",
       "     <!-- $f(\\mathbf{x}^*)$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 249.799625) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-66\" d=\"M 3059 4863 \n",
       "L 2969 4384 \n",
       "L 2419 4384 \n",
       "Q 2106 4384 1964 4261 \n",
       "Q 1822 4138 1753 3809 \n",
       "L 1691 3500 \n",
       "L 2638 3500 \n",
       "L 2553 3053 \n",
       "L 1606 3053 \n",
       "L 1013 0 \n",
       "L 434 0 \n",
       "L 1031 3053 \n",
       "L 481 3053 \n",
       "L 563 3500 \n",
       "L 1113 3500 \n",
       "L 1159 3744 \n",
       "Q 1278 4363 1576 4613 \n",
       "Q 1875 4863 2516 4863 \n",
       "L 3059 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Bold-78\" d=\"M 1422 1791 \n",
       "L 159 3500 \n",
       "L 1344 3500 \n",
       "L 2059 2463 \n",
       "L 2784 3500 \n",
       "L 3969 3500 \n",
       "L 2706 1797 \n",
       "L 4031 0 \n",
       "L 2847 0 \n",
       "L 2059 1106 \n",
       "L 1281 0 \n",
       "L 97 0 \n",
       "L 1422 1791 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-2a\" d=\"M 3009 3897 \n",
       "L 1888 3291 \n",
       "L 3009 2681 \n",
       "L 2828 2375 \n",
       "L 1778 3009 \n",
       "L 1778 1831 \n",
       "L 1422 1831 \n",
       "L 1422 3009 \n",
       "L 372 2375 \n",
       "L 191 2681 \n",
       "L 1313 3291 \n",
       "L 191 3897 \n",
       "L 372 4206 \n",
       "L 1422 3572 \n",
       "L 1422 4750 \n",
       "L 1778 4750 \n",
       "L 1778 3572 \n",
       "L 2828 4206 \n",
       "L 3009 3897 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-39\" d=\"M 350 1059 \n",
       "L 891 1109 \n",
       "Q 959 728 1153 556 \n",
       "Q 1347 384 1650 384 \n",
       "Q 1909 384 2104 503 \n",
       "Q 2300 622 2425 820 \n",
       "Q 2550 1019 2634 1356 \n",
       "Q 2719 1694 2719 2044 \n",
       "Q 2719 2081 2716 2156 \n",
       "Q 2547 1888 2255 1720 \n",
       "Q 1963 1553 1622 1553 \n",
       "Q 1053 1553 659 1965 \n",
       "Q 266 2378 266 3053 \n",
       "Q 266 3750 677 4175 \n",
       "Q 1088 4600 1706 4600 \n",
       "Q 2153 4600 2523 4359 \n",
       "Q 2894 4119 3086 3673 \n",
       "Q 3278 3228 3278 2384 \n",
       "Q 3278 1506 3087 986 \n",
       "Q 2897 466 2520 194 \n",
       "Q 2144 -78 1638 -78 \n",
       "Q 1100 -78 759 220 \n",
       "Q 419 519 350 1059 \n",
       "z\n",
       "M 2653 3081 \n",
       "Q 2653 3566 2395 3850 \n",
       "Q 2138 4134 1775 4134 \n",
       "Q 1400 4134 1122 3828 \n",
       "Q 844 3522 844 3034 \n",
       "Q 844 2597 1108 2323 \n",
       "Q 1372 2050 1759 2050 \n",
       "Q 2150 2050 2401 2323 \n",
       "Q 2653 2597 2653 3081 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-25\" d=\"M 372 3481 \n",
       "Q 372 3972 619 4315 \n",
       "Q 866 4659 1334 4659 \n",
       "Q 1766 4659 2048 4351 \n",
       "Q 2331 4044 2331 3447 \n",
       "Q 2331 2866 2045 2552 \n",
       "Q 1759 2238 1341 2238 \n",
       "Q 925 2238 648 2547 \n",
       "Q 372 2856 372 3481 \n",
       "z\n",
       "M 1350 4272 \n",
       "Q 1141 4272 1002 4090 \n",
       "Q 863 3909 863 3425 \n",
       "Q 863 2984 1003 2804 \n",
       "Q 1144 2625 1350 2625 \n",
       "Q 1563 2625 1702 2806 \n",
       "Q 1841 2988 1841 3469 \n",
       "Q 1841 3913 1700 4092 \n",
       "Q 1559 4272 1350 4272 \n",
       "z\n",
       "M 1353 -169 \n",
       "L 3859 4659 \n",
       "L 4316 4659 \n",
       "L 1819 -169 \n",
       "L 1353 -169 \n",
       "z\n",
       "M 3334 1075 \n",
       "Q 3334 1569 3581 1911 \n",
       "Q 3828 2253 4300 2253 \n",
       "Q 4731 2253 5014 1945 \n",
       "Q 5297 1638 5297 1041 \n",
       "Q 5297 459 5011 145 \n",
       "Q 4725 -169 4303 -169 \n",
       "Q 3888 -169 3611 142 \n",
       "Q 3334 453 3334 1075 \n",
       "z\n",
       "M 4316 1866 \n",
       "Q 4103 1866 3964 1684 \n",
       "Q 3825 1503 3825 1019 \n",
       "Q 3825 581 3965 400 \n",
       "Q 4106 219 4313 219 \n",
       "Q 4528 219 4667 400 \n",
       "Q 4806 581 4806 1063 \n",
       "Q 4806 1506 4665 1686 \n",
       "Q 4525 1866 4316 1866 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-66\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(35.205078 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Bold-78\" transform=\"translate(74.21875 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(153.31543 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(204.6875 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(243.701172 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(271.484375 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(327.099609 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(382.714844 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(471.630859 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(499.414062 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(555.029297 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(588.330078 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(643.945312 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(699.560547 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_6\">\n",
       "     <path d=\"M 51.1265 263.967625 \n",
       "L 68.7265 263.967625 \n",
       "L 68.7265 257.807625 \n",
       "L 51.1265 257.807625 \n",
       "z\n",
       "\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_20\">\n",
       "     <!-- $y^*$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 263.967625) scale(0.088 -0.088)\">\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(77.283529 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(128.655599 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(156.438802 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(212.054036 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(267.669271 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(356.585286 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(384.36849 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(439.983724 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(473.284505 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(528.89974 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(584.514974 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_19\">\n",
       "     <path d=\"M 51.1265 273.4345 \n",
       "L 59.9265 273.4345 \n",
       "L 68.7265 273.4345 \n",
       "\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "    </g>\n",
       "    <g id=\"text_21\">\n",
       "     <!-- True function -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 276.5145) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-54\" d=\"M 1659 0 \n",
       "L 1659 4041 \n",
       "L 150 4041 \n",
       "L 150 4581 \n",
       "L 3781 4581 \n",
       "L 3781 4041 \n",
       "L 2266 4041 \n",
       "L 2266 0 \n",
       "L 1659 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-66\" d=\"M 556 0 \n",
       "L 556 2881 \n",
       "L 59 2881 \n",
       "L 59 3319 \n",
       "L 556 3319 \n",
       "L 556 3672 \n",
       "Q 556 4006 616 4169 \n",
       "Q 697 4388 901 4523 \n",
       "Q 1106 4659 1475 4659 \n",
       "Q 1713 4659 2000 4603 \n",
       "L 1916 4113 \n",
       "Q 1741 4144 1584 4144 \n",
       "Q 1328 4144 1222 4034 \n",
       "Q 1116 3925 1116 3625 \n",
       "L 1116 3319 \n",
       "L 1763 3319 \n",
       "L 1763 2881 \n",
       "L 1116 2881 \n",
       "L 1116 0 \n",
       "L 556 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-54\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"57.333984\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"90.634766\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"146.25\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"201.865234\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"229.648438\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"257.431641\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"313.046875\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"368.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"418.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"446.445312\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"468.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"524.277344\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_20\">\n",
       "      <defs>\n",
       "       <path id=\"m8575009a89\" d=\"M 0 0 \n",
       "L 4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m8575009a89\" x=\"400.3265\" y=\"274.0875\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_22\">\n",
       "      <!-- 0.00 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 277.236937) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_9\">\n",
       "     <g id=\"line2d_21\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m8575009a89\" x=\"400.3265\" y=\"224.996282\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_23\">\n",
       "      <!-- 0.05 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 228.145719) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_10\">\n",
       "     <g id=\"line2d_22\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m8575009a89\" x=\"400.3265\" y=\"175.905064\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_24\">\n",
       "      <!-- 0.10 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 179.054501) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_11\">\n",
       "     <g id=\"line2d_23\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m8575009a89\" x=\"400.3265\" y=\"126.813846\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_25\">\n",
       "      <!-- 0.15 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 129.963283) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_12\">\n",
       "     <g id=\"line2d_24\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m8575009a89\" x=\"400.3265\" y=\"77.722628\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_26\">\n",
       "      <!-- 0.20 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 80.872065) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_13\">\n",
       "     <g id=\"line2d_25\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m8575009a89\" x=\"400.3265\" y=\"28.631409\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_27\">\n",
       "      <!-- 0.25 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 31.780847) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"139.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_28\">\n",
       "     <!-- Information Acquisition Function -->\n",
       "     <g style=\"fill: #ff7f0e\" transform=\"translate(436.740625 221.16075) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-49\" d=\"M 597 0 \n",
       "L 597 4581 \n",
       "L 1203 4581 \n",
       "L 1203 0 \n",
       "L 597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-41\" d=\"M -9 0 \n",
       "L 1750 4581 \n",
       "L 2403 4581 \n",
       "L 4278 0 \n",
       "L 3588 0 \n",
       "L 3053 1388 \n",
       "L 1138 1388 \n",
       "L 634 0 \n",
       "L -9 0 \n",
       "z\n",
       "M 1313 1881 \n",
       "L 2866 1881 \n",
       "L 2388 3150 \n",
       "Q 2169 3728 2063 4100 \n",
       "Q 1975 3659 1816 3225 \n",
       "L 1313 1881 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-71\" d=\"M 2538 -1272 \n",
       "L 2538 353 \n",
       "Q 2406 169 2170 47 \n",
       "Q 1934 -75 1669 -75 \n",
       "Q 1078 -75 651 397 \n",
       "Q 225 869 225 1691 \n",
       "Q 225 2191 398 2587 \n",
       "Q 572 2984 901 3189 \n",
       "Q 1231 3394 1625 3394 \n",
       "Q 2241 3394 2594 2875 \n",
       "L 2594 3319 \n",
       "L 3100 3319 \n",
       "L 3100 -1272 \n",
       "L 2538 -1272 \n",
       "z\n",
       "M 803 1669 \n",
       "Q 803 1028 1072 708 \n",
       "Q 1341 388 1716 388 \n",
       "Q 2075 388 2334 692 \n",
       "Q 2594 997 2594 1619 \n",
       "Q 2594 2281 2320 2615 \n",
       "Q 2047 2950 1678 2950 \n",
       "Q 1313 2950 1058 2639 \n",
       "Q 803 2328 803 1669 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-46\" d=\"M 525 0 \n",
       "L 525 4581 \n",
       "L 3616 4581 \n",
       "L 3616 4041 \n",
       "L 1131 4041 \n",
       "L 1131 2622 \n",
       "L 3281 2622 \n",
       "L 3281 2081 \n",
       "L 1131 2081 \n",
       "L 1131 0 \n",
       "L 525 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-49\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"27.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"83.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"111.181641\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"166.796875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6d\" x=\"200.097656\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"283.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"339.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"366.796875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"389.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"444.628906\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"500.244141\"/>\n",
       "      <use xlink:href=\"#ArialMT-41\" x=\"522.527344\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"589.226562\"/>\n",
       "      <use xlink:href=\"#ArialMT-71\" x=\"639.226562\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"694.841797\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"750.457031\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"772.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"822.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"844.890625\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"872.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"894.890625\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"950.505859\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"1006.121094\"/>\n",
       "      <use xlink:href=\"#ArialMT-46\" x=\"1033.904297\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"1094.988281\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"1150.603516\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"1206.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"1256.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"1284.001953\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"1306.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"1361.833984\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_26\">\n",
       "    <path d=\"M 59.439227 274.0875 \n",
       "L 62.718566 274.0875 \n",
       "L 65.997905 274.0875 \n",
       "L 69.277244 274.0875 \n",
       "L 72.556583 274.0875 \n",
       "L 75.835921 274.0875 \n",
       "L 79.115261 274.0875 \n",
       "L 82.394598 274.0875 \n",
       "L 85.673938 274.08748 \n",
       "L 88.953278 274.0875 \n",
       "L 92.232615 274.087377 \n",
       "L 95.511955 274.086768 \n",
       "L 98.791295 274.085265 \n",
       "L 102.070632 274.082812 \n",
       "L 105.349969 274.081011 \n",
       "L 108.629311 274.082248 \n",
       "L 111.908649 274.085961 \n",
       "L 115.187986 274.087484 \n",
       "L 118.467328 274.0875 \n",
       "L 121.746666 272.594487 \n",
       "L 125.026003 215.800092 \n",
       "L 128.305345 145.547442 \n",
       "L 131.584682 90.553374 \n",
       "L 134.86402 53.624068 \n",
       "L 138.143362 34.503568 \n",
       "L 141.422694 32.1675 \n",
       "L 144.702037 45.243849 \n",
       "L 147.981379 72.150578 \n",
       "L 151.260711 111.16311 \n",
       "L 154.540053 160.423437 \n",
       "L 157.819395 217.63187 \n",
       "L 161.098728 272.302842 \n",
       "L 164.37807 273.565912 \n",
       "L 167.657412 268.830133 \n",
       "L 170.936745 261.927202 \n",
       "L 174.216087 253.91287 \n",
       "L 177.495429 245.311326 \n",
       "L 180.774762 236.634758 \n",
       "L 184.054104 228.445698 \n",
       "L 187.333446 221.352157 \n",
       "L 190.612778 215.975345 \n",
       "L 193.892121 212.896049 \n",
       "L 197.171463 212.584402 \n",
       "L 200.450795 215.313527 \n",
       "L 203.730137 221.062001 \n",
       "L 207.00948 229.42236 \n",
       "L 210.288812 239.545007 \n",
       "L 213.568154 250.170309 \n",
       "L 216.847496 259.81619 \n",
       "L 220.126829 267.170382 \n",
       "L 223.406181 271.609412 \n",
       "L 226.685504 273.525935 \n",
       "L 229.964846 274.025946 \n",
       "L 233.244188 274.085466 \n",
       "L 236.523511 274.087457 \n",
       "L 239.802872 274.0875 \n",
       "L 243.082195 274.0875 \n",
       "L 246.361537 274.0875 \n",
       "L 249.640879 274.0875 \n",
       "L 252.920222 274.0875 \n",
       "L 256.199564 274.0875 \n",
       "L 259.478887 274.0875 \n",
       "L 262.758248 274.0875 \n",
       "L 266.037571 274.0875 \n",
       "L 269.316913 274.0875 \n",
       "L 272.596255 274.0875 \n",
       "L 275.875578 274.0875 \n",
       "L 279.15494 274.0875 \n",
       "L 282.434262 274.0875 \n",
       "L 285.713605 274.0875 \n",
       "L 288.992947 274.0875 \n",
       "L 292.272289 274.0875 \n",
       "L 295.551631 274.0875 \n",
       "L 298.830954 274.0875 \n",
       "L 302.110315 274.0875 \n",
       "L 305.389638 274.0875 \n",
       "L 308.66898 274.0875 \n",
       "L 311.948322 274.0875 \n",
       "L 315.227645 274.0875 \n",
       "L 318.507007 274.0875 \n",
       "L 321.78633 274.0875 \n",
       "L 325.065672 274.0875 \n",
       "L 328.345014 274.0875 \n",
       "L 331.624356 274.0875 \n",
       "L 334.903698 274.0875 \n",
       "L 338.183021 274.0875 \n",
       "L 341.462363 274.0875 \n",
       "L 344.741705 274.0875 \n",
       "L 348.021048 274.0875 \n",
       "L 351.30039 274.0875 \n",
       "L 354.579713 274.0875 \n",
       "L 357.859055 274.0875 \n",
       "L 361.138397 274.087494 \n",
       "L 364.417739 212.70873 \n",
       "L 367.697081 263.186143 \n",
       "L 370.976423 274.0875 \n",
       "L 374.255766 274.0875 \n",
       "L 377.535088 274.0875 \n",
       "L 380.814431 274.0875 \n",
       "L 384.093773 274.0875 \n",
       "\" clip-path=\"url(#p668037cc3d)\" style=\"fill: none; stroke: #ff7f0e; stroke-width: 1.2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_27\">\n",
       "    <path d=\"M 141.422694 274.0875 \n",
       "L 141.422694 271.643864 \n",
       "L 141.422694 269.200227 \n",
       "L 141.422694 266.756591 \n",
       "L 141.422694 264.312955 \n",
       "L 141.422694 261.869319 \n",
       "L 141.422694 259.425681 \n",
       "L 141.422694 256.982046 \n",
       "L 141.422694 254.538409 \n",
       "L 141.422694 252.094772 \n",
       "L 141.422694 249.651137 \n",
       "L 141.422694 247.2075 \n",
       "L 141.422694 244.763863 \n",
       "L 141.422694 242.320226 \n",
       "L 141.422694 239.876593 \n",
       "L 141.422694 237.432956 \n",
       "L 141.422694 234.989319 \n",
       "L 141.422694 232.545681 \n",
       "L 141.422694 230.102044 \n",
       "L 141.422694 227.658411 \n",
       "L 141.422694 225.214774 \n",
       "L 141.422694 222.771137 \n",
       "L 141.422694 220.3275 \n",
       "L 141.422694 217.883863 \n",
       "L 141.422694 215.440226 \n",
       "L 141.422694 212.996593 \n",
       "L 141.422694 210.552952 \n",
       "L 141.422694 208.109322 \n",
       "L 141.422694 205.665685 \n",
       "L 141.422694 203.222048 \n",
       "L 141.422694 200.778411 \n",
       "L 141.422694 198.334774 \n",
       "L 141.422694 195.891137 \n",
       "L 141.422694 193.4475 \n",
       "L 141.422694 191.003863 \n",
       "L 141.422694 188.560226 \n",
       "L 141.422694 186.116589 \n",
       "L 141.422694 183.672952 \n",
       "L 141.422694 181.229322 \n",
       "L 141.422694 178.785685 \n",
       "L 141.422694 176.342048 \n",
       "L 141.422694 173.898411 \n",
       "L 141.422694 171.454774 \n",
       "L 141.422694 169.011137 \n",
       "L 141.422694 166.5675 \n",
       "L 141.422694 164.123863 \n",
       "L 141.422694 161.680226 \n",
       "L 141.422694 159.236589 \n",
       "L 141.422694 156.792952 \n",
       "L 141.422694 154.349322 \n",
       "L 141.422694 151.905678 \n",
       "L 141.422694 149.462048 \n",
       "L 141.422694 147.018404 \n",
       "L 141.422694 144.574774 \n",
       "L 141.422694 142.131144 \n",
       "L 141.422694 139.6875 \n",
       "L 141.422694 137.243856 \n",
       "L 141.422694 134.800226 \n",
       "L 141.422694 132.356596 \n",
       "L 141.422694 129.912952 \n",
       "L 141.422694 127.469308 \n",
       "L 141.422694 125.025678 \n",
       "L 141.422694 122.582048 \n",
       "L 141.422694 120.138404 \n",
       "L 141.422694 117.694774 \n",
       "L 141.422694 115.251144 \n",
       "L 141.422694 112.8075 \n",
       "L 141.422694 110.363856 \n",
       "L 141.422694 107.920226 \n",
       "L 141.422694 105.476596 \n",
       "L 141.422694 103.032952 \n",
       "L 141.422694 100.589308 \n",
       "L 141.422694 98.145678 \n",
       "L 141.422694 95.702048 \n",
       "L 141.422694 93.258404 \n",
       "L 141.422694 90.814774 \n",
       "L 141.422694 88.371144 \n",
       "L 141.422694 85.9275 \n",
       "L 141.422694 83.483856 \n",
       "L 141.422694 81.040226 \n",
       "L 141.422694 78.596596 \n",
       "L 141.422694 76.152952 \n",
       "L 141.422694 73.709322 \n",
       "L 141.422694 71.265678 \n",
       "L 141.422694 68.822048 \n",
       "L 141.422694 66.378404 \n",
       "L 141.422694 63.934774 \n",
       "L 141.422694 61.491144 \n",
       "L 141.422694 59.0475 \n",
       "L 141.422694 56.603856 \n",
       "L 141.422694 54.160226 \n",
       "L 141.422694 51.716596 \n",
       "L 141.422694 49.272952 \n",
       "L 141.422694 46.829322 \n",
       "L 141.422694 44.385678 \n",
       "L 141.422694 41.942048 \n",
       "L 141.422694 39.498404 \n",
       "L 141.422694 37.054774 \n",
       "L 141.422694 34.61113 \n",
       "L 141.422694 32.1675 \n",
       "\" clip-path=\"url(#p668037cc3d)\" style=\"fill: none; stroke: #ff7f0e; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_7\">\n",
       "    <path d=\"M 43.2065 286.1835 \n",
       "L 43.2065 20.0715 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 400.3265 286.1835 \n",
       "L 400.3265 20.0715 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 43.2065 286.1835 \n",
       "L 400.3265 286.1835 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 43.2065 20.0715 \n",
       "L 400.3265 20.0715 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"p668037cc3d\">\n",
       "   <rect x=\"43.2065\" y=\"20.0715\" width=\"357.12\" height=\"266.112\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 640x480 with 2 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "image/svg+xml": [
       "<?xml version=\"1.0\" encoding=\"utf-8\" standalone=\"no\"?>\n",
       "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n",
       "  \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n",
       "<svg xmlns:xlink=\"http://www.w3.org/1999/xlink\" width=\"455.635875pt\" height=\"322.510875pt\" viewBox=\"0 0 455.635875 322.510875\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n",
       " <metadata>\n",
       "  <rdf:RDF xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:cc=\"http://creativecommons.org/ns#\" xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\">\n",
       "   <cc:Work>\n",
       "    <dc:type rdf:resource=\"http://purl.org/dc/dcmitype/StillImage\"/>\n",
       "    <dc:date>2023-10-23T15:18:58.604880</dc:date>\n",
       "    <dc:format>image/svg+xml</dc:format>\n",
       "    <dc:creator>\n",
       "     <cc:Agent>\n",
       "      <dc:title>Matplotlib v3.8.0, https://matplotlib.org/</dc:title>\n",
       "     </cc:Agent>\n",
       "    </dc:creator>\n",
       "   </cc:Work>\n",
       "  </rdf:RDF>\n",
       " </metadata>\n",
       " <defs>\n",
       "  <style type=\"text/css\">*{stroke-linejoin: round; stroke-linecap: butt}</style>\n",
       " </defs>\n",
       " <g id=\"figure_1\">\n",
       "  <g id=\"patch_1\">\n",
       "   <path d=\"M 0 322.510875 \n",
       "L 455.635875 322.510875 \n",
       "L 455.635875 0 \n",
       "L 0 0 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "  </g>\n",
       "  <g id=\"axes_1\">\n",
       "   <g id=\"patch_2\">\n",
       "    <path d=\"M 43.2065 286.1835 \n",
       "L 400.3265 286.1835 \n",
       "L 400.3265 20.0715 \n",
       "L 43.2065 20.0715 \n",
       "z\n",
       "\" style=\"fill: #ffffff\"/>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_1\">\n",
       "    <g id=\"xtick_1\">\n",
       "     <g id=\"line2d_1\">\n",
       "      <defs>\n",
       "       <path id=\"ma3c6f6dff3\" d=\"M 0 0 \n",
       "L 0 4.8 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma3c6f6dff3\" x=\"59.439227\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_1\">\n",
       "      <!-- 0.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(53.323227 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-30\" d=\"M 266 2259 \n",
       "Q 266 3072 433 3567 \n",
       "Q 600 4063 929 4331 \n",
       "Q 1259 4600 1759 4600 \n",
       "Q 2128 4600 2406 4451 \n",
       "Q 2684 4303 2865 4023 \n",
       "Q 3047 3744 3150 3342 \n",
       "Q 3253 2941 3253 2259 \n",
       "Q 3253 1453 3087 958 \n",
       "Q 2922 463 2592 192 \n",
       "Q 2263 -78 1759 -78 \n",
       "Q 1097 -78 719 397 \n",
       "Q 266 969 266 2259 \n",
       "z\n",
       "M 844 2259 \n",
       "Q 844 1131 1108 757 \n",
       "Q 1372 384 1759 384 \n",
       "Q 2147 384 2411 759 \n",
       "Q 2675 1134 2675 2259 \n",
       "Q 2675 3391 2411 3762 \n",
       "Q 2147 4134 1753 4134 \n",
       "Q 1366 4134 1134 3806 \n",
       "Q 844 3388 844 2259 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "        <path id=\"ArialMT-2e\" d=\"M 581 0 \n",
       "L 581 641 \n",
       "L 1222 641 \n",
       "L 1222 0 \n",
       "L 581 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_2\">\n",
       "     <g id=\"line2d_2\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma3c6f6dff3\" x=\"124.370136\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_2\">\n",
       "      <!-- 0.2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(118.254136 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-32\" d=\"M 3222 541 \n",
       "L 3222 0 \n",
       "L 194 0 \n",
       "Q 188 203 259 391 \n",
       "Q 375 700 629 1000 \n",
       "Q 884 1300 1366 1694 \n",
       "Q 2113 2306 2375 2664 \n",
       "Q 2638 3022 2638 3341 \n",
       "Q 2638 3675 2398 3904 \n",
       "Q 2159 4134 1775 4134 \n",
       "Q 1369 4134 1125 3890 \n",
       "Q 881 3647 878 3216 \n",
       "L 300 3275 \n",
       "Q 359 3922 746 4261 \n",
       "Q 1134 4600 1788 4600 \n",
       "Q 2447 4600 2831 4234 \n",
       "Q 3216 3869 3216 3328 \n",
       "Q 3216 3053 3103 2787 \n",
       "Q 2991 2522 2730 2228 \n",
       "Q 2469 1934 1863 1422 \n",
       "Q 1356 997 1212 845 \n",
       "Q 1069 694 975 541 \n",
       "L 3222 541 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_3\">\n",
       "     <g id=\"line2d_3\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma3c6f6dff3\" x=\"189.301045\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_3\">\n",
       "      <!-- 0.4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(183.185045 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-34\" d=\"M 2069 0 \n",
       "L 2069 1097 \n",
       "L 81 1097 \n",
       "L 81 1613 \n",
       "L 2172 4581 \n",
       "L 2631 4581 \n",
       "L 2631 1613 \n",
       "L 3250 1613 \n",
       "L 3250 1097 \n",
       "L 2631 1097 \n",
       "L 2631 0 \n",
       "L 2069 0 \n",
       "z\n",
       "M 2069 1613 \n",
       "L 2069 3678 \n",
       "L 634 1613 \n",
       "L 2069 1613 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_4\">\n",
       "     <g id=\"line2d_4\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma3c6f6dff3\" x=\"254.231955\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_4\">\n",
       "      <!-- 0.6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(248.115955 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-36\" d=\"M 3184 3459 \n",
       "L 2625 3416 \n",
       "Q 2550 3747 2413 3897 \n",
       "Q 2184 4138 1850 4138 \n",
       "Q 1581 4138 1378 3988 \n",
       "Q 1113 3794 959 3422 \n",
       "Q 806 3050 800 2363 \n",
       "Q 1003 2672 1297 2822 \n",
       "Q 1591 2972 1913 2972 \n",
       "Q 2475 2972 2870 2558 \n",
       "Q 3266 2144 3266 1488 \n",
       "Q 3266 1056 3080 686 \n",
       "Q 2894 316 2569 119 \n",
       "Q 2244 -78 1831 -78 \n",
       "Q 1128 -78 684 439 \n",
       "Q 241 956 241 2144 \n",
       "Q 241 3472 731 4075 \n",
       "Q 1159 4600 1884 4600 \n",
       "Q 2425 4600 2770 4297 \n",
       "Q 3116 3994 3184 3459 \n",
       "z\n",
       "M 888 1484 \n",
       "Q 888 1194 1011 928 \n",
       "Q 1134 663 1356 523 \n",
       "Q 1578 384 1822 384 \n",
       "Q 2178 384 2434 671 \n",
       "Q 2691 959 2691 1453 \n",
       "Q 2691 1928 2437 2201 \n",
       "Q 2184 2475 1800 2475 \n",
       "Q 1419 2475 1153 2201 \n",
       "Q 888 1928 888 1484 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_5\">\n",
       "     <g id=\"line2d_5\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma3c6f6dff3\" x=\"319.162864\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_5\">\n",
       "      <!-- 0.8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(313.046864 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-38\" d=\"M 1131 2484 \n",
       "Q 781 2613 612 2850 \n",
       "Q 444 3088 444 3419 \n",
       "Q 444 3919 803 4259 \n",
       "Q 1163 4600 1759 4600 \n",
       "Q 2359 4600 2725 4251 \n",
       "Q 3091 3903 3091 3403 \n",
       "Q 3091 3084 2923 2848 \n",
       "Q 2756 2613 2416 2484 \n",
       "Q 2838 2347 3058 2040 \n",
       "Q 3278 1734 3278 1309 \n",
       "Q 3278 722 2862 322 \n",
       "Q 2447 -78 1769 -78 \n",
       "Q 1091 -78 675 323 \n",
       "Q 259 725 259 1325 \n",
       "Q 259 1772 486 2073 \n",
       "Q 713 2375 1131 2484 \n",
       "z\n",
       "M 1019 3438 \n",
       "Q 1019 3113 1228 2906 \n",
       "Q 1438 2700 1772 2700 \n",
       "Q 2097 2700 2305 2904 \n",
       "Q 2513 3109 2513 3406 \n",
       "Q 2513 3716 2298 3927 \n",
       "Q 2084 4138 1766 4138 \n",
       "Q 1444 4138 1231 3931 \n",
       "Q 1019 3725 1019 3438 \n",
       "z\n",
       "M 838 1322 \n",
       "Q 838 1081 952 856 \n",
       "Q 1066 631 1291 507 \n",
       "Q 1516 384 1775 384 \n",
       "Q 2178 384 2440 643 \n",
       "Q 2703 903 2703 1303 \n",
       "Q 2703 1709 2433 1975 \n",
       "Q 2163 2241 1756 2241 \n",
       "Q 1359 2241 1098 1978 \n",
       "Q 838 1716 838 1322 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"xtick_6\">\n",
       "     <g id=\"line2d_6\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#ma3c6f6dff3\" x=\"384.093773\" y=\"286.1835\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_6\">\n",
       "      <!-- 1.0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(377.977773 300.782375) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-31\" d=\"M 2384 0 \n",
       "L 1822 0 \n",
       "L 1822 3584 \n",
       "Q 1619 3391 1289 3197 \n",
       "Q 959 3003 697 2906 \n",
       "L 697 3450 \n",
       "Q 1169 3672 1522 3987 \n",
       "Q 1875 4303 2022 4600 \n",
       "L 2384 4600 \n",
       "L 2384 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-31\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_7\">\n",
       "     <!-- $x$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(218.8865 313.402875) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-78\" d=\"M 3841 3500 \n",
       "L 2234 1784 \n",
       "L 3219 0 \n",
       "L 2559 0 \n",
       "L 1819 1388 \n",
       "L 531 0 \n",
       "L -166 0 \n",
       "L 1556 1844 \n",
       "L 641 3500 \n",
       "L 1300 3500 \n",
       "L 1972 2234 \n",
       "L 3144 3500 \n",
       "L 3841 3500 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"matplotlib.axis_2\">\n",
       "    <g id=\"ytick_1\">\n",
       "     <g id=\"line2d_7\">\n",
       "      <defs>\n",
       "       <path id=\"m8aab8893b0\" d=\"M 0 0 \n",
       "L -4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#m8aab8893b0\" x=\"43.2065\" y=\"279.638338\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_8\">\n",
       "      <!-- −12 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 282.787775) scale(0.088 -0.088)\">\n",
       "       <defs>\n",
       "        <path id=\"ArialMT-2212\" d=\"M 3381 1997 \n",
       "L 356 1997 \n",
       "L 356 2522 \n",
       "L 3381 2522 \n",
       "L 3381 1997 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       </defs>\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"114.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_2\">\n",
       "     <g id=\"line2d_8\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m8aab8893b0\" x=\"43.2065\" y=\"238.435227\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_9\">\n",
       "      <!-- −10 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(19.9795 241.584664) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"58.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"114.013672\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_3\">\n",
       "     <g id=\"line2d_9\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m8aab8893b0\" x=\"43.2065\" y=\"197.232116\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_10\">\n",
       "      <!-- −8 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 200.381554) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-38\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_4\">\n",
       "     <g id=\"line2d_10\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m8aab8893b0\" x=\"43.2065\" y=\"156.029005\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_11\">\n",
       "      <!-- −6 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 159.178443) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-36\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_5\">\n",
       "     <g id=\"line2d_11\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m8aab8893b0\" x=\"43.2065\" y=\"114.825895\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_12\">\n",
       "      <!-- −4 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 117.975332) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-34\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_6\">\n",
       "     <g id=\"line2d_12\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m8aab8893b0\" x=\"43.2065\" y=\"73.622784\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_13\">\n",
       "      <!-- −2 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(24.873125 76.772222) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-2212\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"58.398438\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_7\">\n",
       "     <g id=\"line2d_13\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#m8aab8893b0\" x=\"43.2065\" y=\"32.419673\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_14\">\n",
       "      <!-- 0 -->\n",
       "      <g style=\"fill: #262626\" transform=\"translate(30.012875 35.569111) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_15\">\n",
       "     <!-- $y$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(13.9635 156.0075) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-79\" d=\"M 1588 -325 \n",
       "Q 1188 -997 936 -1164 \n",
       "Q 684 -1331 294 -1331 \n",
       "L -159 -1331 \n",
       "L -63 -850 \n",
       "L 269 -850 \n",
       "Q 509 -850 678 -719 \n",
       "Q 847 -588 1056 -206 \n",
       "L 1234 128 \n",
       "L 459 3500 \n",
       "L 1069 3500 \n",
       "L 1650 819 \n",
       "L 3256 3500 \n",
       "L 3859 3500 \n",
       "L 1588 -325 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.3125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_1\">\n",
       "    <defs>\n",
       "     <path id=\"mc32ef127e8\" d=\"M 59.439227 -208.32733 \n",
       "L 59.439227 -208.24492 \n",
       "L 62.718566 -208.240509 \n",
       "L 65.997905 -209.085824 \n",
       "L 69.277244 -210.797672 \n",
       "L 72.556583 -213.333867 \n",
       "L 75.835921 -216.632662 \n",
       "L 79.115261 -220.616402 \n",
       "L 82.394598 -225.191241 \n",
       "L 85.673938 -230.250732 \n",
       "L 88.953278 -235.680111 \n",
       "L 92.232615 -241.355114 \n",
       "L 95.511955 -247.150112 \n",
       "L 98.791295 -252.93772 \n",
       "L 102.070632 -258.596106 \n",
       "L 105.349969 -264.011243 \n",
       "L 108.629311 -269.079367 \n",
       "L 111.908649 -273.710709 \n",
       "L 115.187986 -277.8341 \n",
       "L 118.467328 -281.379761 \n",
       "L 121.746666 -283.645532 \n",
       "L 125.026003 -285.420169 \n",
       "L 128.305345 -286.926537 \n",
       "L 131.584682 -288.156034 \n",
       "L 134.86402 -289.099267 \n",
       "L 138.143362 -289.738572 \n",
       "L 141.422694 -290.029236 \n",
       "L 144.702037 -289.470066 \n",
       "L 147.981379 -288.631711 \n",
       "L 151.260711 -287.641622 \n",
       "L 154.540053 -286.587267 \n",
       "L 157.819395 -285.548413 \n",
       "L 161.098728 -284.604828 \n",
       "L 164.37807 -282.894318 \n",
       "L 167.657412 -280.509553 \n",
       "L 170.936745 -277.815195 \n",
       "L 174.216087 -274.837296 \n",
       "L 177.495429 -271.603028 \n",
       "L 180.774762 -268.142086 \n",
       "L 184.054104 -264.487574 \n",
       "L 187.333446 -260.671685 \n",
       "L 190.612778 -256.72695 \n",
       "L 193.892121 -252.682044 \n",
       "L 197.171463 -248.562847 \n",
       "L 200.450795 -244.388986 \n",
       "L 203.730137 -240.173798 \n",
       "L 207.00948 -235.922705 \n",
       "L 210.288812 -231.633373 \n",
       "L 213.568154 -227.294874 \n",
       "L 216.847496 -222.888396 \n",
       "L 220.126829 -218.387562 \n",
       "L 223.406181 -213.759887 \n",
       "L 226.685504 -208.968599 \n",
       "L 229.964846 -203.974307 \n",
       "L 233.244188 -198.737971 \n",
       "L 236.523511 -193.223491 \n",
       "L 239.802872 -187.400491 \n",
       "L 243.082195 -181.247939 \n",
       "L 246.361537 -174.75669 \n",
       "L 249.640879 -167.932764 \n",
       "L 252.920222 -160.799445 \n",
       "L 256.199564 -153.400349 \n",
       "L 259.478887 -145.758168 \n",
       "L 262.758248 -131.533869 \n",
       "L 266.037571 -117.590427 \n",
       "L 269.316913 -104.230721 \n",
       "L 272.596255 -91.721719 \n",
       "L 275.875578 -80.328873 \n",
       "L 279.15494 -70.311074 \n",
       "L 282.434262 -61.910708 \n",
       "L 285.713605 -55.349004 \n",
       "L 288.992947 -50.817855 \n",
       "L 292.272289 -48.471766 \n",
       "L 295.551631 -48.423375 \n",
       "L 298.830954 -50.737596 \n",
       "L 302.110315 -55.426433 \n",
       "L 305.389638 -62.44631 \n",
       "L 308.66898 -71.696573 \n",
       "L 311.948322 -83.019789 \n",
       "L 315.227645 -96.203102 \n",
       "L 318.507007 -110.983357 \n",
       "L 321.78633 -127.050158 \n",
       "L 325.065672 -144.055976 \n",
       "L 328.345014 -161.621945 \n",
       "L 331.624356 -179.350228 \n",
       "L 334.903698 -196.832608 \n",
       "L 338.183021 -213.670315 \n",
       "L 341.462363 -229.420703 \n",
       "L 344.741705 -242.895998 \n",
       "L 348.021048 -255.055975 \n",
       "L 351.30039 -265.623014 \n",
       "L 354.579713 -274.313508 \n",
       "L 357.859055 -280.875092 \n",
       "L 361.138397 -285.055372 \n",
       "L 364.417739 -286.109035 \n",
       "L 367.697081 -284.610896 \n",
       "L 370.976423 -280.755187 \n",
       "L 374.255766 -274.699752 \n",
       "L 377.535088 -266.671249 \n",
       "L 380.814431 -256.959781 \n",
       "L 384.093773 -245.824129 \n",
       "L 384.093773 -245.906539 \n",
       "L 384.093773 -245.906539 \n",
       "L 380.814431 -258.227098 \n",
       "L 377.535088 -268.637951 \n",
       "L 374.255766 -276.85499 \n",
       "L 370.976423 -282.695054 \n",
       "L 367.697081 -286.044043 \n",
       "L 364.417739 -286.829062 \n",
       "L 361.138397 -285.137779 \n",
       "L 357.859055 -281.58336 \n",
       "L 354.579713 -275.577668 \n",
       "L 351.30039 -267.165376 \n",
       "L 348.021048 -256.515038 \n",
       "L 344.741705 -243.850418 \n",
       "L 341.462363 -229.503113 \n",
       "L 338.183021 -215.11285 \n",
       "L 334.903698 -200.221785 \n",
       "L 331.624356 -185.140781 \n",
       "L 328.345014 -170.234323 \n",
       "L 325.065672 -155.83481 \n",
       "L 321.78633 -142.256737 \n",
       "L 318.507007 -129.773836 \n",
       "L 315.227645 -118.613848 \n",
       "L 311.948322 -108.964787 \n",
       "L 308.66898 -100.95817 \n",
       "L 305.389638 -94.680721 \n",
       "L 302.110315 -90.166763 \n",
       "L 298.830954 -87.405392 \n",
       "L 295.551631 -86.341557 \n",
       "L 292.272289 -86.882267 \n",
       "L 288.992947 -88.902094 \n",
       "L 285.713605 -92.250719 \n",
       "L 282.434262 -96.760276 \n",
       "L 279.15494 -102.249677 \n",
       "L 275.875578 -108.533295 \n",
       "L 272.596255 -115.429139 \n",
       "L 269.316913 -122.759225 \n",
       "L 266.037571 -130.360068 \n",
       "L 262.758248 -138.083097 \n",
       "L 259.478887 -145.840568 \n",
       "L 256.199564 -160.136265 \n",
       "L 252.920222 -174.310748 \n",
       "L 249.640879 -188.107996 \n",
       "L 246.361537 -201.337764 \n",
       "L 243.082195 -213.83571 \n",
       "L 239.802872 -225.465894 \n",
       "L 236.523511 -236.121406 \n",
       "L 233.244188 -245.724675 \n",
       "L 229.964846 -254.227537 \n",
       "L 226.685504 -261.610042 \n",
       "L 223.406181 -267.878676 \n",
       "L 220.126829 -273.064941 \n",
       "L 216.847496 -277.222312 \n",
       "L 213.568154 -280.423935 \n",
       "L 210.288812 -282.759164 \n",
       "L 207.00948 -284.330405 \n",
       "L 203.730137 -285.249642 \n",
       "L 200.450795 -285.63469 \n",
       "L 197.171463 -285.605245 \n",
       "L 193.892121 -285.27982 \n",
       "L 190.612778 -284.771592 \n",
       "L 187.333446 -284.186248 \n",
       "L 184.054104 -283.616931 \n",
       "L 180.774762 -283.144178 \n",
       "L 177.495429 -282.830978 \n",
       "L 174.216087 -282.723969 \n",
       "L 170.936745 -282.84939 \n",
       "L 167.657412 -283.214629 \n",
       "L 164.37807 -283.810915 \n",
       "L 161.098728 -284.954471 \n",
       "L 157.819395 -286.677901 \n",
       "L 154.540053 -288.049623 \n",
       "L 151.260711 -289.073025 \n",
       "L 147.981379 -289.747219 \n",
       "L 144.702037 -290.077807 \n",
       "L 141.422694 -290.111643 \n",
       "L 138.143362 -290.343375 \n",
       "L 134.86402 -290.203046 \n",
       "L 131.584682 -289.586873 \n",
       "L 128.305345 -288.430584 \n",
       "L 125.026003 -286.692624 \n",
       "L 121.746666 -284.348197 \n",
       "L 118.467328 -281.621589 \n",
       "L 115.187986 -279.321265 \n",
       "L 111.908649 -276.78336 \n",
       "L 108.629311 -273.994718 \n",
       "L 105.349969 -270.958936 \n",
       "L 102.070632 -267.677079 \n",
       "L 98.791295 -264.151625 \n",
       "L 95.511955 -260.387037 \n",
       "L 92.232615 -256.390664 \n",
       "L 88.953278 -252.17179 \n",
       "L 85.673938 -247.745804 \n",
       "L 82.394598 -243.131135 \n",
       "L 79.115261 -238.353979 \n",
       "L 75.835921 -233.444287 \n",
       "L 72.556583 -228.436542 \n",
       "L 69.277244 -223.371314 \n",
       "L 65.997905 -218.292175 \n",
       "L 62.718566 -213.247316 \n",
       "L 59.439227 -208.32733 \n",
       "z\n",
       "\" style=\"stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p88c51600fc)\">\n",
       "     <use xlink:href=\"#mc32ef127e8\" x=\"0\" y=\"322.510875\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_2\">\n",
       "    <defs>\n",
       "     <path id=\"mb2a0caefcf\" d=\"M 59.439227 -208.24492 \n",
       "L 59.439227 -208.24492 \n",
       "L 62.718566 -208.240509 \n",
       "L 65.997905 -209.085824 \n",
       "L 69.277244 -210.797672 \n",
       "L 72.556583 -213.333867 \n",
       "L 75.835921 -216.632662 \n",
       "L 79.115261 -220.616402 \n",
       "L 82.394598 -225.191241 \n",
       "L 85.673938 -230.250732 \n",
       "L 88.953278 -235.680111 \n",
       "L 92.232615 -241.355114 \n",
       "L 95.511955 -247.150112 \n",
       "L 98.791295 -252.93772 \n",
       "L 102.070632 -258.596106 \n",
       "L 105.349969 -264.011243 \n",
       "L 108.629311 -269.079367 \n",
       "L 111.908649 -273.710709 \n",
       "L 115.187986 -277.8341 \n",
       "L 118.467328 -281.379761 \n",
       "L 121.746666 -283.645532 \n",
       "L 125.026003 -285.420169 \n",
       "L 128.305345 -286.926537 \n",
       "L 131.584682 -288.156034 \n",
       "L 134.86402 -289.099267 \n",
       "L 138.143362 -289.738572 \n",
       "L 141.422694 -290.029236 \n",
       "L 144.702037 -289.470066 \n",
       "L 147.981379 -288.631711 \n",
       "L 151.260711 -287.641622 \n",
       "L 154.540053 -286.587267 \n",
       "L 157.819395 -285.548413 \n",
       "L 161.098728 -284.604828 \n",
       "L 164.37807 -282.894318 \n",
       "L 167.657412 -280.509553 \n",
       "L 170.936745 -277.815195 \n",
       "L 174.216087 -274.837296 \n",
       "L 177.495429 -271.603028 \n",
       "L 180.774762 -268.142086 \n",
       "L 184.054104 -264.487574 \n",
       "L 187.333446 -260.671685 \n",
       "L 190.612778 -256.72695 \n",
       "L 193.892121 -252.682044 \n",
       "L 197.171463 -248.562847 \n",
       "L 200.450795 -244.388986 \n",
       "L 203.730137 -240.173798 \n",
       "L 207.00948 -235.922705 \n",
       "L 210.288812 -231.633373 \n",
       "L 213.568154 -227.294874 \n",
       "L 216.847496 -222.888396 \n",
       "L 220.126829 -218.387562 \n",
       "L 223.406181 -213.759887 \n",
       "L 226.685504 -208.968599 \n",
       "L 229.964846 -203.974307 \n",
       "L 233.244188 -198.737971 \n",
       "L 236.523511 -193.223491 \n",
       "L 239.802872 -187.400491 \n",
       "L 243.082195 -181.247939 \n",
       "L 246.361537 -174.75669 \n",
       "L 249.640879 -167.932764 \n",
       "L 252.920222 -160.799445 \n",
       "L 256.199564 -153.400349 \n",
       "L 259.478887 -145.758168 \n",
       "L 262.758248 -131.533869 \n",
       "L 266.037571 -117.590427 \n",
       "L 269.316913 -104.230721 \n",
       "L 272.596255 -91.721719 \n",
       "L 275.875578 -80.328873 \n",
       "L 279.15494 -70.311074 \n",
       "L 282.434262 -61.910708 \n",
       "L 285.713605 -55.349004 \n",
       "L 288.992947 -50.817855 \n",
       "L 292.272289 -48.471766 \n",
       "L 295.551631 -48.423375 \n",
       "L 298.830954 -50.737596 \n",
       "L 302.110315 -55.426433 \n",
       "L 305.389638 -62.44631 \n",
       "L 308.66898 -71.696573 \n",
       "L 311.948322 -83.019789 \n",
       "L 315.227645 -96.203102 \n",
       "L 318.507007 -110.983357 \n",
       "L 321.78633 -127.050158 \n",
       "L 325.065672 -144.055976 \n",
       "L 328.345014 -161.621945 \n",
       "L 331.624356 -179.350228 \n",
       "L 334.903698 -196.832608 \n",
       "L 338.183021 -213.670315 \n",
       "L 341.462363 -229.420703 \n",
       "L 344.741705 -242.895998 \n",
       "L 348.021048 -255.055975 \n",
       "L 351.30039 -265.623014 \n",
       "L 354.579713 -274.313508 \n",
       "L 357.859055 -280.875092 \n",
       "L 361.138397 -285.055372 \n",
       "L 364.417739 -286.109035 \n",
       "L 367.697081 -284.610896 \n",
       "L 370.976423 -280.755187 \n",
       "L 374.255766 -274.699752 \n",
       "L 377.535088 -266.671249 \n",
       "L 380.814431 -256.959781 \n",
       "L 384.093773 -245.824129 \n",
       "L 384.093773 -245.824129 \n",
       "L 384.093773 -245.824129 \n",
       "L 380.814431 -256.959781 \n",
       "L 377.535088 -266.671249 \n",
       "L 374.255766 -274.699752 \n",
       "L 370.976423 -280.755187 \n",
       "L 367.697081 -284.610896 \n",
       "L 364.417739 -286.109035 \n",
       "L 361.138397 -285.055372 \n",
       "L 357.859055 -280.875092 \n",
       "L 354.579713 -274.313508 \n",
       "L 351.30039 -265.623014 \n",
       "L 348.021048 -255.055975 \n",
       "L 344.741705 -242.895998 \n",
       "L 341.462363 -229.420703 \n",
       "L 338.183021 -213.670315 \n",
       "L 334.903698 -196.832608 \n",
       "L 331.624356 -179.350228 \n",
       "L 328.345014 -161.621945 \n",
       "L 325.065672 -144.055976 \n",
       "L 321.78633 -127.050158 \n",
       "L 318.507007 -110.983357 \n",
       "L 315.227645 -96.203102 \n",
       "L 311.948322 -83.019789 \n",
       "L 308.66898 -71.696573 \n",
       "L 305.389638 -62.44631 \n",
       "L 302.110315 -55.426433 \n",
       "L 298.830954 -50.737596 \n",
       "L 295.551631 -48.423375 \n",
       "L 292.272289 -48.471766 \n",
       "L 288.992947 -50.817855 \n",
       "L 285.713605 -55.349004 \n",
       "L 282.434262 -61.910708 \n",
       "L 279.15494 -70.311074 \n",
       "L 275.875578 -80.328873 \n",
       "L 272.596255 -91.721719 \n",
       "L 269.316913 -104.230721 \n",
       "L 266.037571 -117.590427 \n",
       "L 262.758248 -131.533869 \n",
       "L 259.478887 -145.758168 \n",
       "L 256.199564 -153.400349 \n",
       "L 252.920222 -160.799445 \n",
       "L 249.640879 -167.932764 \n",
       "L 246.361537 -174.75669 \n",
       "L 243.082195 -181.247939 \n",
       "L 239.802872 -187.400491 \n",
       "L 236.523511 -193.223491 \n",
       "L 233.244188 -198.737971 \n",
       "L 229.964846 -203.974307 \n",
       "L 226.685504 -208.968599 \n",
       "L 223.406181 -213.759887 \n",
       "L 220.126829 -218.387562 \n",
       "L 216.847496 -222.888396 \n",
       "L 213.568154 -227.294874 \n",
       "L 210.288812 -231.633373 \n",
       "L 207.00948 -235.922705 \n",
       "L 203.730137 -240.173798 \n",
       "L 200.450795 -244.388986 \n",
       "L 197.171463 -248.562847 \n",
       "L 193.892121 -252.682044 \n",
       "L 190.612778 -256.72695 \n",
       "L 187.333446 -260.671685 \n",
       "L 184.054104 -264.487574 \n",
       "L 180.774762 -268.142086 \n",
       "L 177.495429 -271.603028 \n",
       "L 174.216087 -274.837296 \n",
       "L 170.936745 -277.815195 \n",
       "L 167.657412 -280.509553 \n",
       "L 164.37807 -282.894318 \n",
       "L 161.098728 -284.604828 \n",
       "L 157.819395 -285.548413 \n",
       "L 154.540053 -286.587267 \n",
       "L 151.260711 -287.641622 \n",
       "L 147.981379 -288.631711 \n",
       "L 144.702037 -289.470066 \n",
       "L 141.422694 -290.029236 \n",
       "L 138.143362 -289.738572 \n",
       "L 134.86402 -289.099267 \n",
       "L 131.584682 -288.156034 \n",
       "L 128.305345 -286.926537 \n",
       "L 125.026003 -285.420169 \n",
       "L 121.746666 -283.645532 \n",
       "L 118.467328 -281.379761 \n",
       "L 115.187986 -277.8341 \n",
       "L 111.908649 -273.710709 \n",
       "L 108.629311 -269.079367 \n",
       "L 105.349969 -264.011243 \n",
       "L 102.070632 -258.596106 \n",
       "L 98.791295 -252.93772 \n",
       "L 95.511955 -247.150112 \n",
       "L 92.232615 -241.355114 \n",
       "L 88.953278 -235.680111 \n",
       "L 85.673938 -230.250732 \n",
       "L 82.394598 -225.191241 \n",
       "L 79.115261 -220.616402 \n",
       "L 75.835921 -216.632662 \n",
       "L 72.556583 -213.333867 \n",
       "L 69.277244 -210.797672 \n",
       "L 65.997905 -209.085824 \n",
       "L 62.718566 -208.240509 \n",
       "L 59.439227 -208.24492 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p88c51600fc)\">\n",
       "     <use xlink:href=\"#mb2a0caefcf\" x=\"0\" y=\"322.510875\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"PolyCollection_3\">\n",
       "    <defs>\n",
       "     <path id=\"md10ff89b5b\" d=\"M 59.439227 -208.32733 \n",
       "L 59.439227 -208.32733 \n",
       "L 62.718566 -213.247316 \n",
       "L 65.997905 -218.292175 \n",
       "L 69.277244 -223.371314 \n",
       "L 72.556583 -228.436542 \n",
       "L 75.835921 -233.444287 \n",
       "L 79.115261 -238.353979 \n",
       "L 82.394598 -243.131135 \n",
       "L 85.673938 -247.745804 \n",
       "L 88.953278 -252.17179 \n",
       "L 92.232615 -256.390664 \n",
       "L 95.511955 -260.387037 \n",
       "L 98.791295 -264.151625 \n",
       "L 102.070632 -267.677079 \n",
       "L 105.349969 -270.958936 \n",
       "L 108.629311 -273.994718 \n",
       "L 111.908649 -276.78336 \n",
       "L 115.187986 -279.321265 \n",
       "L 118.467328 -281.621589 \n",
       "L 121.746666 -284.348197 \n",
       "L 125.026003 -286.692624 \n",
       "L 128.305345 -288.430584 \n",
       "L 131.584682 -289.586873 \n",
       "L 134.86402 -290.203046 \n",
       "L 138.143362 -290.343375 \n",
       "L 141.422694 -290.111643 \n",
       "L 144.702037 -290.077807 \n",
       "L 147.981379 -289.747219 \n",
       "L 151.260711 -289.073025 \n",
       "L 154.540053 -288.049623 \n",
       "L 157.819395 -286.677901 \n",
       "L 161.098728 -284.954471 \n",
       "L 164.37807 -283.810915 \n",
       "L 167.657412 -283.214629 \n",
       "L 170.936745 -282.84939 \n",
       "L 174.216087 -282.723969 \n",
       "L 177.495429 -282.830978 \n",
       "L 180.774762 -283.144178 \n",
       "L 184.054104 -283.616931 \n",
       "L 187.333446 -284.186248 \n",
       "L 190.612778 -284.771592 \n",
       "L 193.892121 -285.27982 \n",
       "L 197.171463 -285.605245 \n",
       "L 200.450795 -285.63469 \n",
       "L 203.730137 -285.249642 \n",
       "L 207.00948 -284.330405 \n",
       "L 210.288812 -282.759164 \n",
       "L 213.568154 -280.423935 \n",
       "L 216.847496 -277.222312 \n",
       "L 220.126829 -273.064941 \n",
       "L 223.406181 -267.878676 \n",
       "L 226.685504 -261.610042 \n",
       "L 229.964846 -254.227537 \n",
       "L 233.244188 -245.724675 \n",
       "L 236.523511 -236.121406 \n",
       "L 239.802872 -225.465894 \n",
       "L 243.082195 -213.83571 \n",
       "L 246.361537 -201.337764 \n",
       "L 249.640879 -188.107996 \n",
       "L 252.920222 -174.310748 \n",
       "L 256.199564 -160.136265 \n",
       "L 259.478887 -145.840568 \n",
       "L 262.758248 -138.083097 \n",
       "L 266.037571 -130.360068 \n",
       "L 269.316913 -122.759225 \n",
       "L 272.596255 -115.429139 \n",
       "L 275.875578 -108.533295 \n",
       "L 279.15494 -102.249677 \n",
       "L 282.434262 -96.760276 \n",
       "L 285.713605 -92.250719 \n",
       "L 288.992947 -88.902094 \n",
       "L 292.272289 -86.882267 \n",
       "L 295.551631 -86.341557 \n",
       "L 298.830954 -87.405392 \n",
       "L 302.110315 -90.166763 \n",
       "L 305.389638 -94.680721 \n",
       "L 308.66898 -100.95817 \n",
       "L 311.948322 -108.964787 \n",
       "L 315.227645 -118.613848 \n",
       "L 318.507007 -129.773836 \n",
       "L 321.78633 -142.256737 \n",
       "L 325.065672 -155.83481 \n",
       "L 328.345014 -170.234323 \n",
       "L 331.624356 -185.140781 \n",
       "L 334.903698 -200.221785 \n",
       "L 338.183021 -215.11285 \n",
       "L 341.462363 -229.503113 \n",
       "L 344.741705 -243.850418 \n",
       "L 348.021048 -256.515038 \n",
       "L 351.30039 -267.165376 \n",
       "L 354.579713 -275.577668 \n",
       "L 357.859055 -281.58336 \n",
       "L 361.138397 -285.137779 \n",
       "L 364.417739 -286.829062 \n",
       "L 367.697081 -286.044043 \n",
       "L 370.976423 -282.695054 \n",
       "L 374.255766 -276.85499 \n",
       "L 377.535088 -268.637951 \n",
       "L 380.814431 -258.227098 \n",
       "L 384.093773 -245.906539 \n",
       "L 384.093773 -245.906539 \n",
       "L 384.093773 -245.906539 \n",
       "L 380.814431 -258.227098 \n",
       "L 377.535088 -268.637951 \n",
       "L 374.255766 -276.85499 \n",
       "L 370.976423 -282.695054 \n",
       "L 367.697081 -286.044043 \n",
       "L 364.417739 -286.829062 \n",
       "L 361.138397 -285.137779 \n",
       "L 357.859055 -281.58336 \n",
       "L 354.579713 -275.577668 \n",
       "L 351.30039 -267.165376 \n",
       "L 348.021048 -256.515038 \n",
       "L 344.741705 -243.850418 \n",
       "L 341.462363 -229.503113 \n",
       "L 338.183021 -215.11285 \n",
       "L 334.903698 -200.221785 \n",
       "L 331.624356 -185.140781 \n",
       "L 328.345014 -170.234323 \n",
       "L 325.065672 -155.83481 \n",
       "L 321.78633 -142.256737 \n",
       "L 318.507007 -129.773836 \n",
       "L 315.227645 -118.613848 \n",
       "L 311.948322 -108.964787 \n",
       "L 308.66898 -100.95817 \n",
       "L 305.389638 -94.680721 \n",
       "L 302.110315 -90.166763 \n",
       "L 298.830954 -87.405392 \n",
       "L 295.551631 -86.341557 \n",
       "L 292.272289 -86.882267 \n",
       "L 288.992947 -88.902094 \n",
       "L 285.713605 -92.250719 \n",
       "L 282.434262 -96.760276 \n",
       "L 279.15494 -102.249677 \n",
       "L 275.875578 -108.533295 \n",
       "L 272.596255 -115.429139 \n",
       "L 269.316913 -122.759225 \n",
       "L 266.037571 -130.360068 \n",
       "L 262.758248 -138.083097 \n",
       "L 259.478887 -145.840568 \n",
       "L 256.199564 -160.136265 \n",
       "L 252.920222 -174.310748 \n",
       "L 249.640879 -188.107996 \n",
       "L 246.361537 -201.337764 \n",
       "L 243.082195 -213.83571 \n",
       "L 239.802872 -225.465894 \n",
       "L 236.523511 -236.121406 \n",
       "L 233.244188 -245.724675 \n",
       "L 229.964846 -254.227537 \n",
       "L 226.685504 -261.610042 \n",
       "L 223.406181 -267.878676 \n",
       "L 220.126829 -273.064941 \n",
       "L 216.847496 -277.222312 \n",
       "L 213.568154 -280.423935 \n",
       "L 210.288812 -282.759164 \n",
       "L 207.00948 -284.330405 \n",
       "L 203.730137 -285.249642 \n",
       "L 200.450795 -285.63469 \n",
       "L 197.171463 -285.605245 \n",
       "L 193.892121 -285.27982 \n",
       "L 190.612778 -284.771592 \n",
       "L 187.333446 -284.186248 \n",
       "L 184.054104 -283.616931 \n",
       "L 180.774762 -283.144178 \n",
       "L 177.495429 -282.830978 \n",
       "L 174.216087 -282.723969 \n",
       "L 170.936745 -282.84939 \n",
       "L 167.657412 -283.214629 \n",
       "L 164.37807 -283.810915 \n",
       "L 161.098728 -284.954471 \n",
       "L 157.819395 -286.677901 \n",
       "L 154.540053 -288.049623 \n",
       "L 151.260711 -289.073025 \n",
       "L 147.981379 -289.747219 \n",
       "L 144.702037 -290.077807 \n",
       "L 141.422694 -290.111643 \n",
       "L 138.143362 -290.343375 \n",
       "L 134.86402 -290.203046 \n",
       "L 131.584682 -289.586873 \n",
       "L 128.305345 -288.430584 \n",
       "L 125.026003 -286.692624 \n",
       "L 121.746666 -284.348197 \n",
       "L 118.467328 -281.621589 \n",
       "L 115.187986 -279.321265 \n",
       "L 111.908649 -276.78336 \n",
       "L 108.629311 -273.994718 \n",
       "L 105.349969 -270.958936 \n",
       "L 102.070632 -267.677079 \n",
       "L 98.791295 -264.151625 \n",
       "L 95.511955 -260.387037 \n",
       "L 92.232615 -256.390664 \n",
       "L 88.953278 -252.17179 \n",
       "L 85.673938 -247.745804 \n",
       "L 82.394598 -243.131135 \n",
       "L 79.115261 -238.353979 \n",
       "L 75.835921 -233.444287 \n",
       "L 72.556583 -228.436542 \n",
       "L 69.277244 -223.371314 \n",
       "L 65.997905 -218.292175 \n",
       "L 62.718566 -213.247316 \n",
       "L 59.439227 -208.32733 \n",
       "z\n",
       "\" style=\"stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p88c51600fc)\">\n",
       "     <use xlink:href=\"#md10ff89b5b\" x=\"0\" y=\"322.510875\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_14\">\n",
       "    <defs>\n",
       "     <path id=\"m595f3cf7e7\" d=\"M -5 5 \n",
       "L 5 -5 \n",
       "M -5 -5 \n",
       "L 5 5 \n",
       "\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </defs>\n",
       "    <g clip-path=\"url(#p88c51600fc)\">\n",
       "     <use xlink:href=\"#m595f3cf7e7\" x=\"361.243318\" y=\"37.331933\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m595f3cf7e7\" x=\"162.151989\" y=\"38.180914\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m595f3cf7e7\" x=\"119.149308\" y=\"40.455478\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m595f3cf7e7\" x=\"259.478887\" y=\"176.711566\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m595f3cf7e7\" x=\"384.093773\" y=\"76.645084\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m595f3cf7e7\" x=\"341.462363\" y=\"93.047926\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m595f3cf7e7\" x=\"59.439227\" y=\"114.22474\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     <use xlink:href=\"#m595f3cf7e7\" x=\"141.422694\" y=\"32.44044\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_15\">\n",
       "    <path d=\"M 59.439227 114.22475 \n",
       "L 62.718566 111.766962 \n",
       "L 65.997905 108.821875 \n",
       "L 69.277244 105.426382 \n",
       "L 72.556583 101.625671 \n",
       "L 75.835921 97.4724 \n",
       "L 79.115261 93.025685 \n",
       "L 82.394598 88.349687 \n",
       "L 85.673938 83.512607 \n",
       "L 88.953278 78.584923 \n",
       "L 92.232615 73.637986 \n",
       "L 95.511955 68.742301 \n",
       "L 98.791295 63.966203 \n",
       "L 102.070632 59.374282 \n",
       "L 105.349969 55.025786 \n",
       "L 108.629311 50.973833 \n",
       "L 111.908649 47.26384 \n",
       "L 115.187986 43.933192 \n",
       "L 118.467328 41.0102 \n",
       "L 121.746666 38.514011 \n",
       "L 125.026003 36.454478 \n",
       "L 128.305345 34.832314 \n",
       "L 131.584682 33.639421 \n",
       "L 134.86402 32.859718 \n",
       "L 138.143362 32.469901 \n",
       "L 141.422694 32.440435 \n",
       "L 144.702037 32.736938 \n",
       "L 147.981379 33.32141 \n",
       "L 151.260711 34.153551 \n",
       "L 154.540053 35.19243 \n",
       "L 157.819395 36.397718 \n",
       "L 161.098728 37.731225 \n",
       "L 164.37807 39.158259 \n",
       "L 167.657412 40.648784 \n",
       "L 170.936745 42.178582 \n",
       "L 174.216087 43.730242 \n",
       "L 177.495429 45.293872 \n",
       "L 180.774762 46.867744 \n",
       "L 184.054104 48.458622 \n",
       "L 187.333446 50.081908 \n",
       "L 190.612778 51.761604 \n",
       "L 193.892121 53.529943 \n",
       "L 197.171463 55.426829 \n",
       "L 200.450795 57.499036 \n",
       "L 203.730137 59.799155 \n",
       "L 207.00948 62.38432 \n",
       "L 210.288812 65.314608 \n",
       "L 213.568154 68.651469 \n",
       "L 216.847496 72.455521 \n",
       "L 220.126829 76.784623 \n",
       "L 223.406181 81.691594 \n",
       "L 226.685504 87.221556 \n",
       "L 229.964846 93.409954 \n",
       "L 233.244188 100.279549 \n",
       "L 236.523511 107.838426 \n",
       "L 239.802872 116.077685 \n",
       "L 243.082195 124.969053 \n",
       "L 246.361537 134.463648 \n",
       "L 249.640879 144.490495 \n",
       "L 252.920222 154.955779 \n",
       "L 256.199564 165.742568 \n",
       "L 259.478887 176.711507 \n",
       "L 262.758248 187.702392 \n",
       "L 266.037571 198.535628 \n",
       "L 269.316913 209.015902 \n",
       "L 272.596255 218.935446 \n",
       "L 275.875578 228.079791 \n",
       "L 279.15494 236.2305 \n",
       "L 282.434262 243.175383 \n",
       "L 285.713605 248.711013 \n",
       "L 288.992947 252.6509 \n",
       "L 292.272289 254.833859 \n",
       "L 295.551631 255.128409 \n",
       "L 298.830954 253.439381 \n",
       "L 302.110315 249.714277 \n",
       "L 305.389638 243.947359 \n",
       "L 308.66898 236.183503 \n",
       "L 311.948322 226.518587 \n",
       "L 315.227645 215.1024 \n",
       "L 318.507007 202.132279 \n",
       "L 321.78633 187.857428 \n",
       "L 325.065672 172.565482 \n",
       "L 328.345014 156.582741 \n",
       "L 331.624356 140.26537 \n",
       "L 334.903698 123.983678 \n",
       "L 338.183021 108.119293 \n",
       "L 341.462363 93.048967 \n",
       "L 344.741705 79.137667 \n",
       "L 348.021048 66.725368 \n",
       "L 351.30039 56.11668 \n",
       "L 354.579713 47.565287 \n",
       "L 357.859055 41.281649 \n",
       "L 361.138397 37.414299 \n",
       "L 364.417739 36.041826 \n",
       "L 367.697081 37.183406 \n",
       "L 370.976423 40.785754 \n",
       "L 374.255766 46.733504 \n",
       "L 377.535088 54.856275 \n",
       "L 380.814431 64.917435 \n",
       "L 384.093773 76.645541 \n",
       "\" clip-path=\"url(#p88c51600fc)\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_16\">\n",
       "    <path d=\"M 59.439227 114.22474 \n",
       "L 62.718566 109.197245 \n",
       "L 65.997905 104.188404 \n",
       "L 69.277244 99.216794 \n",
       "L 72.556583 94.300924 \n",
       "L 75.835921 89.459094 \n",
       "L 79.115261 84.709429 \n",
       "L 82.394598 80.069734 \n",
       "L 85.673938 75.557461 \n",
       "L 88.953278 71.189678 \n",
       "L 92.232615 66.982958 \n",
       "L 95.511955 62.953357 \n",
       "L 98.791295 59.116347 \n",
       "L 102.070632 55.486767 \n",
       "L 105.349969 52.078754 \n",
       "L 108.629311 48.905735 \n",
       "L 111.908649 45.98034 \n",
       "L 115.187986 43.314375 \n",
       "L 118.467328 40.918771 \n",
       "L 121.746666 38.803566 \n",
       "L 125.026003 36.977862 \n",
       "L 128.305345 35.449774 \n",
       "L 131.584682 34.226423 \n",
       "L 134.86402 33.313905 \n",
       "L 138.143362 32.717254 \n",
       "L 141.422694 32.44044 \n",
       "L 144.702037 32.486346 \n",
       "L 147.981379 32.856735 \n",
       "L 151.260711 33.552259 \n",
       "L 154.540053 34.572453 \n",
       "L 157.819395 35.915706 \n",
       "L 161.098728 37.579257 \n",
       "L 164.37807 39.559235 \n",
       "L 167.657412 41.850587 \n",
       "L 170.936745 44.447148 \n",
       "L 174.216087 47.341599 \n",
       "L 177.495429 50.525487 \n",
       "L 180.774762 53.98923 \n",
       "L 184.054104 57.722105 \n",
       "L 187.333446 61.712313 \n",
       "L 190.612778 65.946879 \n",
       "L 193.892121 70.411778 \n",
       "L 197.171463 75.091833 \n",
       "L 200.450795 79.970835 \n",
       "L 203.730137 85.031436 \n",
       "L 207.00948 90.255193 \n",
       "L 210.288812 95.622589 \n",
       "L 213.568154 101.113041 \n",
       "L 216.847496 106.704824 \n",
       "L 220.126829 112.37516 \n",
       "L 223.406181 118.100165 \n",
       "L 226.685504 123.854793 \n",
       "L 229.964846 129.612957 \n",
       "L 233.244188 135.347417 \n",
       "L 236.523511 141.029655 \n",
       "L 239.802872 146.630249 \n",
       "L 243.082195 152.118294 \n",
       "L 246.361537 157.461952 \n",
       "L 249.640879 162.628039 \n",
       "L 252.920222 167.582212 \n",
       "L 256.199564 172.288977 \n",
       "L 259.478887 176.711566 \n",
       "L 262.758248 180.812157 \n",
       "L 266.037571 184.551761 \n",
       "L 269.316913 187.890415 \n",
       "L 272.596255 190.787214 \n",
       "L 275.875578 193.200565 \n",
       "L 279.15494 195.088266 \n",
       "L 282.434262 196.407878 \n",
       "L 285.713605 197.117033 \n",
       "L 288.992947 197.173882 \n",
       "L 292.272289 196.537647 \n",
       "L 295.551631 195.169359 \n",
       "L 298.830954 193.03266 \n",
       "L 302.110315 190.09475 \n",
       "L 305.389638 186.327993 \n",
       "L 308.66898 181.710809 \n",
       "L 311.948322 176.229935 \n",
       "L 315.227645 169.882346 \n",
       "L 318.507007 162.677334 \n",
       "L 321.78633 154.639665 \n",
       "L 325.065672 145.812219 \n",
       "L 328.345014 136.259488 \n",
       "L 331.624356 126.07123 \n",
       "L 334.903698 115.366133 \n",
       "L 338.183021 104.295692 \n",
       "L 341.462363 93.047926 \n",
       "L 344.741705 81.850333 \n",
       "L 348.021048 70.972365 \n",
       "L 351.30039 60.726354 \n",
       "L 354.579713 51.46587 \n",
       "L 357.859055 43.581371 \n",
       "L 361.138397 37.492269 \n",
       "L 364.417739 33.632592 \n",
       "L 367.697081 32.431093 \n",
       "L 370.976423 34.28307 \n",
       "L 374.255766 39.513472 \n",
       "L 377.535088 48.330937 \n",
       "L 380.814431 60.773002 \n",
       "L 384.093773 76.645084 \n",
       "\" clip-path=\"url(#p88c51600fc)\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_3\">\n",
       "    <path d=\"M 43.2065 279.638338 \n",
       "L 43.2065 32.419673 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_4\">\n",
       "    <path d=\"M 59.439227 286.1835 \n",
       "L 384.093773 286.1835 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"text_16\">\n",
       "    <!-- N=4,  -->\n",
       "    <g style=\"fill: #262626\" transform=\"translate(210.16025 14.0715) scale(0.096 -0.096)\">\n",
       "     <defs>\n",
       "      <path id=\"ArialMT-4e\" d=\"M 488 0 \n",
       "L 488 4581 \n",
       "L 1109 4581 \n",
       "L 3516 984 \n",
       "L 3516 4581 \n",
       "L 4097 4581 \n",
       "L 4097 0 \n",
       "L 3475 0 \n",
       "L 1069 3600 \n",
       "L 1069 0 \n",
       "L 488 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-3d\" d=\"M 3381 2694 \n",
       "L 356 2694 \n",
       "L 356 3219 \n",
       "L 3381 3219 \n",
       "L 3381 2694 \n",
       "z\n",
       "M 3381 1303 \n",
       "L 356 1303 \n",
       "L 356 1828 \n",
       "L 3381 1828 \n",
       "L 3381 1303 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-2c\" d=\"M 569 0 \n",
       "L 569 641 \n",
       "L 1209 641 \n",
       "L 1209 0 \n",
       "Q 1209 -353 1084 -570 \n",
       "Q 959 -788 688 -906 \n",
       "L 531 -666 \n",
       "Q 709 -588 793 -436 \n",
       "Q 878 -284 888 0 \n",
       "L 569 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      <path id=\"ArialMT-20\" transform=\"scale(0.015625)\"/>\n",
       "     </defs>\n",
       "     <use xlink:href=\"#ArialMT-4e\"/>\n",
       "     <use xlink:href=\"#ArialMT-3d\" x=\"72.216797\"/>\n",
       "     <use xlink:href=\"#ArialMT-34\" x=\"130.615234\"/>\n",
       "     <use xlink:href=\"#ArialMT-2c\" x=\"186.230469\"/>\n",
       "     <use xlink:href=\"#ArialMT-20\" x=\"214.013672\"/>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"legend_1\">\n",
       "    <g id=\"line2d_17\">\n",
       "     <g>\n",
       "      <use xlink:href=\"#m595f3cf7e7\" x=\"59.9265\" y=\"219.978625\" style=\"stroke: #000000; stroke-width: 2\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_17\">\n",
       "     <!-- Observations -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 223.058625) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-4f\" d=\"M 309 2231 \n",
       "Q 309 3372 921 4017 \n",
       "Q 1534 4663 2503 4663 \n",
       "Q 3138 4663 3647 4359 \n",
       "Q 4156 4056 4423 3514 \n",
       "Q 4691 2972 4691 2284 \n",
       "Q 4691 1588 4409 1038 \n",
       "Q 4128 488 3612 205 \n",
       "Q 3097 -78 2500 -78 \n",
       "Q 1853 -78 1343 234 \n",
       "Q 834 547 571 1087 \n",
       "Q 309 1628 309 2231 \n",
       "z\n",
       "M 934 2222 \n",
       "Q 934 1394 1379 917 \n",
       "Q 1825 441 2497 441 \n",
       "Q 3181 441 3623 922 \n",
       "Q 4066 1403 4066 2288 \n",
       "Q 4066 2847 3877 3264 \n",
       "Q 3688 3681 3323 3911 \n",
       "Q 2959 4141 2506 4141 \n",
       "Q 1863 4141 1398 3698 \n",
       "Q 934 3256 934 2222 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-62\" d=\"M 941 0 \n",
       "L 419 0 \n",
       "L 419 4581 \n",
       "L 981 4581 \n",
       "L 981 2947 \n",
       "Q 1338 3394 1891 3394 \n",
       "Q 2197 3394 2470 3270 \n",
       "Q 2744 3147 2920 2923 \n",
       "Q 3097 2700 3197 2384 \n",
       "Q 3297 2069 3297 1709 \n",
       "Q 3297 856 2875 390 \n",
       "Q 2453 -75 1863 -75 \n",
       "Q 1275 -75 941 416 \n",
       "L 941 0 \n",
       "z\n",
       "M 934 1684 \n",
       "Q 934 1088 1097 822 \n",
       "Q 1363 388 1816 388 \n",
       "Q 2184 388 2453 708 \n",
       "Q 2722 1028 2722 1663 \n",
       "Q 2722 2313 2464 2622 \n",
       "Q 2206 2931 1841 2931 \n",
       "Q 1472 2931 1203 2611 \n",
       "Q 934 2291 934 1684 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-73\" d=\"M 197 991 \n",
       "L 753 1078 \n",
       "Q 800 744 1014 566 \n",
       "Q 1228 388 1613 388 \n",
       "Q 2000 388 2187 545 \n",
       "Q 2375 703 2375 916 \n",
       "Q 2375 1106 2209 1216 \n",
       "Q 2094 1291 1634 1406 \n",
       "Q 1016 1563 777 1677 \n",
       "Q 538 1791 414 1992 \n",
       "Q 291 2194 291 2438 \n",
       "Q 291 2659 392 2848 \n",
       "Q 494 3038 669 3163 \n",
       "Q 800 3259 1026 3326 \n",
       "Q 1253 3394 1513 3394 \n",
       "Q 1903 3394 2198 3281 \n",
       "Q 2494 3169 2634 2976 \n",
       "Q 2775 2784 2828 2463 \n",
       "L 2278 2388 \n",
       "Q 2241 2644 2061 2787 \n",
       "Q 1881 2931 1553 2931 \n",
       "Q 1166 2931 1000 2803 \n",
       "Q 834 2675 834 2503 \n",
       "Q 834 2394 903 2306 \n",
       "Q 972 2216 1119 2156 \n",
       "Q 1203 2125 1616 2013 \n",
       "Q 2213 1853 2448 1751 \n",
       "Q 2684 1650 2818 1456 \n",
       "Q 2953 1263 2953 975 \n",
       "Q 2953 694 2789 445 \n",
       "Q 2625 197 2315 61 \n",
       "Q 2006 -75 1616 -75 \n",
       "Q 969 -75 630 194 \n",
       "Q 291 463 197 991 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-65\" d=\"M 2694 1069 \n",
       "L 3275 997 \n",
       "Q 3138 488 2766 206 \n",
       "Q 2394 -75 1816 -75 \n",
       "Q 1088 -75 661 373 \n",
       "Q 234 822 234 1631 \n",
       "Q 234 2469 665 2931 \n",
       "Q 1097 3394 1784 3394 \n",
       "Q 2450 3394 2872 2941 \n",
       "Q 3294 2488 3294 1666 \n",
       "Q 3294 1616 3291 1516 \n",
       "L 816 1516 \n",
       "Q 847 969 1125 678 \n",
       "Q 1403 388 1819 388 \n",
       "Q 2128 388 2347 550 \n",
       "Q 2566 713 2694 1069 \n",
       "z\n",
       "M 847 1978 \n",
       "L 2700 1978 \n",
       "Q 2663 2397 2488 2606 \n",
       "Q 2219 2931 1791 2931 \n",
       "Q 1403 2931 1139 2672 \n",
       "Q 875 2413 847 1978 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-72\" d=\"M 416 0 \n",
       "L 416 3319 \n",
       "L 922 3319 \n",
       "L 922 2816 \n",
       "Q 1116 3169 1280 3281 \n",
       "Q 1444 3394 1641 3394 \n",
       "Q 1925 3394 2219 3213 \n",
       "L 2025 2691 \n",
       "Q 1819 2813 1613 2813 \n",
       "Q 1428 2813 1281 2702 \n",
       "Q 1134 2591 1072 2394 \n",
       "Q 978 2094 978 1738 \n",
       "L 978 0 \n",
       "L 416 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-76\" d=\"M 1344 0 \n",
       "L 81 3319 \n",
       "L 675 3319 \n",
       "L 1388 1331 \n",
       "Q 1503 1009 1600 663 \n",
       "Q 1675 925 1809 1294 \n",
       "L 2547 3319 \n",
       "L 3125 3319 \n",
       "L 1869 0 \n",
       "L 1344 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-61\" d=\"M 2588 409 \n",
       "Q 2275 144 1986 34 \n",
       "Q 1697 -75 1366 -75 \n",
       "Q 819 -75 525 192 \n",
       "Q 231 459 231 875 \n",
       "Q 231 1119 342 1320 \n",
       "Q 453 1522 633 1644 \n",
       "Q 813 1766 1038 1828 \n",
       "Q 1203 1872 1538 1913 \n",
       "Q 2219 1994 2541 2106 \n",
       "Q 2544 2222 2544 2253 \n",
       "Q 2544 2597 2384 2738 \n",
       "Q 2169 2928 1744 2928 \n",
       "Q 1347 2928 1158 2789 \n",
       "Q 969 2650 878 2297 \n",
       "L 328 2372 \n",
       "Q 403 2725 575 2942 \n",
       "Q 747 3159 1072 3276 \n",
       "Q 1397 3394 1825 3394 \n",
       "Q 2250 3394 2515 3294 \n",
       "Q 2781 3194 2906 3042 \n",
       "Q 3031 2891 3081 2659 \n",
       "Q 3109 2516 3109 2141 \n",
       "L 3109 1391 \n",
       "Q 3109 606 3145 398 \n",
       "Q 3181 191 3288 0 \n",
       "L 2700 0 \n",
       "Q 2613 175 2588 409 \n",
       "z\n",
       "M 2541 1666 \n",
       "Q 2234 1541 1622 1453 \n",
       "Q 1275 1403 1131 1340 \n",
       "Q 988 1278 909 1158 \n",
       "Q 831 1038 831 891 \n",
       "Q 831 666 1001 516 \n",
       "Q 1172 366 1500 366 \n",
       "Q 1825 366 2078 508 \n",
       "Q 2331 650 2450 897 \n",
       "Q 2541 1088 2541 1459 \n",
       "L 2541 1666 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-74\" d=\"M 1650 503 \n",
       "L 1731 6 \n",
       "Q 1494 -44 1306 -44 \n",
       "Q 1000 -44 831 53 \n",
       "Q 663 150 594 308 \n",
       "Q 525 466 525 972 \n",
       "L 525 2881 \n",
       "L 113 2881 \n",
       "L 113 3319 \n",
       "L 525 3319 \n",
       "L 525 4141 \n",
       "L 1084 4478 \n",
       "L 1084 3319 \n",
       "L 1650 3319 \n",
       "L 1650 2881 \n",
       "L 1084 2881 \n",
       "L 1084 941 \n",
       "Q 1084 700 1114 631 \n",
       "Q 1144 563 1211 522 \n",
       "Q 1278 481 1403 481 \n",
       "Q 1497 481 1650 503 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-69\" d=\"M 425 3934 \n",
       "L 425 4581 \n",
       "L 988 4581 \n",
       "L 988 3934 \n",
       "L 425 3934 \n",
       "z\n",
       "M 425 0 \n",
       "L 425 3319 \n",
       "L 988 3319 \n",
       "L 988 0 \n",
       "L 425 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6f\" d=\"M 213 1659 \n",
       "Q 213 2581 725 3025 \n",
       "Q 1153 3394 1769 3394 \n",
       "Q 2453 3394 2887 2945 \n",
       "Q 3322 2497 3322 1706 \n",
       "Q 3322 1066 3130 698 \n",
       "Q 2938 331 2570 128 \n",
       "Q 2203 -75 1769 -75 \n",
       "Q 1072 -75 642 372 \n",
       "Q 213 819 213 1659 \n",
       "z\n",
       "M 791 1659 \n",
       "Q 791 1022 1069 705 \n",
       "Q 1347 388 1769 388 \n",
       "Q 2188 388 2466 706 \n",
       "Q 2744 1025 2744 1678 \n",
       "Q 2744 2294 2464 2611 \n",
       "Q 2184 2928 1769 2928 \n",
       "Q 1347 2928 1069 2612 \n",
       "Q 791 2297 791 1659 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6e\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 928 3319 \n",
       "L 928 2847 \n",
       "Q 1294 3394 1984 3394 \n",
       "Q 2284 3394 2536 3286 \n",
       "Q 2788 3178 2913 3003 \n",
       "Q 3038 2828 3088 2588 \n",
       "Q 3119 2431 3119 2041 \n",
       "L 3119 0 \n",
       "L 2556 0 \n",
       "L 2556 2019 \n",
       "Q 2556 2363 2490 2533 \n",
       "Q 2425 2703 2258 2804 \n",
       "Q 2091 2906 1866 2906 \n",
       "Q 1506 2906 1245 2678 \n",
       "Q 984 2450 984 1813 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-4f\"/>\n",
       "      <use xlink:href=\"#ArialMT-62\" x=\"77.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"133.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"183.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"239.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-76\" x=\"272.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"322.314453\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"377.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"405.712891\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"427.929688\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"483.544922\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"539.160156\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_18\">\n",
       "     <path d=\"M 51.1265 232.562625 \n",
       "L 59.9265 232.562625 \n",
       "L 68.7265 232.562625 \n",
       "\" style=\"fill: none; stroke: #1f77b4; stroke-width: 2; stroke-linecap: round\"/>\n",
       "    </g>\n",
       "    <g id=\"text_18\">\n",
       "     <!-- $m_n(x)$ -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 235.642625) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-6d\" d=\"M 5747 2113 \n",
       "L 5338 0 \n",
       "L 4763 0 \n",
       "L 5166 2094 \n",
       "Q 5191 2228 5203 2325 \n",
       "Q 5216 2422 5216 2491 \n",
       "Q 5216 2772 5059 2928 \n",
       "Q 4903 3084 4622 3084 \n",
       "Q 4203 3084 3875 2770 \n",
       "Q 3547 2456 3450 1953 \n",
       "L 3066 0 \n",
       "L 2491 0 \n",
       "L 2900 2094 \n",
       "Q 2925 2209 2937 2307 \n",
       "Q 2950 2406 2950 2484 \n",
       "Q 2950 2769 2794 2926 \n",
       "Q 2638 3084 2363 3084 \n",
       "Q 1938 3084 1609 2770 \n",
       "Q 1281 2456 1184 1953 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 909 3500 \n",
       "L 1484 3500 \n",
       "L 1375 2956 \n",
       "Q 1609 3263 1923 3423 \n",
       "Q 2238 3584 2597 3584 \n",
       "Q 2978 3584 3223 3384 \n",
       "Q 3469 3184 3519 2828 \n",
       "Q 3781 3197 4126 3390 \n",
       "Q 4472 3584 4856 3584 \n",
       "Q 5306 3584 5551 3325 \n",
       "Q 5797 3066 5797 2591 \n",
       "Q 5797 2488 5784 2364 \n",
       "Q 5772 2241 5747 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Oblique-6e\" d=\"M 3566 2113 \n",
       "L 3156 0 \n",
       "L 2578 0 \n",
       "L 2988 2091 \n",
       "Q 3016 2238 3031 2350 \n",
       "Q 3047 2463 3047 2528 \n",
       "Q 3047 2791 2881 2937 \n",
       "Q 2716 3084 2419 3084 \n",
       "Q 1956 3084 1622 2776 \n",
       "Q 1288 2469 1184 1941 \n",
       "L 800 0 \n",
       "L 225 0 \n",
       "L 903 3500 \n",
       "L 1478 3500 \n",
       "L 1363 2950 \n",
       "Q 1603 3253 1940 3418 \n",
       "Q 2278 3584 2650 3584 \n",
       "Q 3113 3584 3367 3334 \n",
       "Q 3622 3084 3622 2631 \n",
       "Q 3622 2519 3608 2391 \n",
       "Q 3594 2263 3566 2113 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-28\" d=\"M 1984 4856 \n",
       "Q 1566 4138 1362 3434 \n",
       "Q 1159 2731 1159 2009 \n",
       "Q 1159 1288 1364 580 \n",
       "Q 1569 -128 1984 -844 \n",
       "L 1484 -844 \n",
       "Q 1016 -109 783 600 \n",
       "Q 550 1309 550 2009 \n",
       "Q 550 2706 781 3412 \n",
       "Q 1013 4119 1484 4856 \n",
       "L 1984 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-29\" d=\"M 513 4856 \n",
       "L 1013 4856 \n",
       "Q 1481 4119 1714 3412 \n",
       "Q 1947 2706 1947 2009 \n",
       "Q 1947 1309 1714 600 \n",
       "Q 1481 -109 1013 -844 \n",
       "L 513 -844 \n",
       "Q 928 -128 1133 580 \n",
       "Q 1338 1288 1338 2009 \n",
       "Q 1338 2731 1133 3434 \n",
       "Q 928 4138 513 4856 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6d\" transform=\"translate(0 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-6e\" transform=\"translate(97.412109 -16.28125) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(144.511719 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-78\" transform=\"translate(183.525391 0.125)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(242.705078 0.125)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_5\">\n",
       "     <path d=\"M 51.1265 249.799625 \n",
       "L 68.7265 249.799625 \n",
       "L 68.7265 243.639625 \n",
       "L 51.1265 243.639625 \n",
       "z\n",
       "\" style=\"fill: #1f77b4; fill-opacity: 0.5; stroke: #1f77b4; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_19\">\n",
       "     <!-- $f(\\mathbf{x}^*)$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 249.799625) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"DejaVuSans-Oblique-66\" d=\"M 3059 4863 \n",
       "L 2969 4384 \n",
       "L 2419 4384 \n",
       "Q 2106 4384 1964 4261 \n",
       "Q 1822 4138 1753 3809 \n",
       "L 1691 3500 \n",
       "L 2638 3500 \n",
       "L 2553 3053 \n",
       "L 1606 3053 \n",
       "L 1013 0 \n",
       "L 434 0 \n",
       "L 1031 3053 \n",
       "L 481 3053 \n",
       "L 563 3500 \n",
       "L 1113 3500 \n",
       "L 1159 3744 \n",
       "Q 1278 4363 1576 4613 \n",
       "Q 1875 4863 2516 4863 \n",
       "L 3059 4863 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-Bold-78\" d=\"M 1422 1791 \n",
       "L 159 3500 \n",
       "L 1344 3500 \n",
       "L 2059 2463 \n",
       "L 2784 3500 \n",
       "L 3969 3500 \n",
       "L 2706 1797 \n",
       "L 4031 0 \n",
       "L 2847 0 \n",
       "L 2059 1106 \n",
       "L 1281 0 \n",
       "L 97 0 \n",
       "L 1422 1791 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"DejaVuSans-2a\" d=\"M 3009 3897 \n",
       "L 1888 3291 \n",
       "L 3009 2681 \n",
       "L 2828 2375 \n",
       "L 1778 3009 \n",
       "L 1778 1831 \n",
       "L 1422 1831 \n",
       "L 1422 3009 \n",
       "L 372 2375 \n",
       "L 191 2681 \n",
       "L 1313 3291 \n",
       "L 191 3897 \n",
       "L 372 4206 \n",
       "L 1422 3572 \n",
       "L 1422 4750 \n",
       "L 1778 4750 \n",
       "L 1778 3572 \n",
       "L 2828 4206 \n",
       "L 3009 3897 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-39\" d=\"M 350 1059 \n",
       "L 891 1109 \n",
       "Q 959 728 1153 556 \n",
       "Q 1347 384 1650 384 \n",
       "Q 1909 384 2104 503 \n",
       "Q 2300 622 2425 820 \n",
       "Q 2550 1019 2634 1356 \n",
       "Q 2719 1694 2719 2044 \n",
       "Q 2719 2081 2716 2156 \n",
       "Q 2547 1888 2255 1720 \n",
       "Q 1963 1553 1622 1553 \n",
       "Q 1053 1553 659 1965 \n",
       "Q 266 2378 266 3053 \n",
       "Q 266 3750 677 4175 \n",
       "Q 1088 4600 1706 4600 \n",
       "Q 2153 4600 2523 4359 \n",
       "Q 2894 4119 3086 3673 \n",
       "Q 3278 3228 3278 2384 \n",
       "Q 3278 1506 3087 986 \n",
       "Q 2897 466 2520 194 \n",
       "Q 2144 -78 1638 -78 \n",
       "Q 1100 -78 759 220 \n",
       "Q 419 519 350 1059 \n",
       "z\n",
       "M 2653 3081 \n",
       "Q 2653 3566 2395 3850 \n",
       "Q 2138 4134 1775 4134 \n",
       "Q 1400 4134 1122 3828 \n",
       "Q 844 3522 844 3034 \n",
       "Q 844 2597 1108 2323 \n",
       "Q 1372 2050 1759 2050 \n",
       "Q 2150 2050 2401 2323 \n",
       "Q 2653 2597 2653 3081 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-35\" d=\"M 266 1200 \n",
       "L 856 1250 \n",
       "Q 922 819 1161 601 \n",
       "Q 1400 384 1738 384 \n",
       "Q 2144 384 2425 690 \n",
       "Q 2706 997 2706 1503 \n",
       "Q 2706 1984 2436 2262 \n",
       "Q 2166 2541 1728 2541 \n",
       "Q 1456 2541 1237 2417 \n",
       "Q 1019 2294 894 2097 \n",
       "L 366 2166 \n",
       "L 809 4519 \n",
       "L 3088 4519 \n",
       "L 3088 3981 \n",
       "L 1259 3981 \n",
       "L 1013 2750 \n",
       "Q 1425 3038 1878 3038 \n",
       "Q 2478 3038 2890 2622 \n",
       "Q 3303 2206 3303 1553 \n",
       "Q 3303 931 2941 478 \n",
       "Q 2500 -78 1738 -78 \n",
       "Q 1113 -78 717 272 \n",
       "Q 322 622 266 1200 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-25\" d=\"M 372 3481 \n",
       "Q 372 3972 619 4315 \n",
       "Q 866 4659 1334 4659 \n",
       "Q 1766 4659 2048 4351 \n",
       "Q 2331 4044 2331 3447 \n",
       "Q 2331 2866 2045 2552 \n",
       "Q 1759 2238 1341 2238 \n",
       "Q 925 2238 648 2547 \n",
       "Q 372 2856 372 3481 \n",
       "z\n",
       "M 1350 4272 \n",
       "Q 1141 4272 1002 4090 \n",
       "Q 863 3909 863 3425 \n",
       "Q 863 2984 1003 2804 \n",
       "Q 1144 2625 1350 2625 \n",
       "Q 1563 2625 1702 2806 \n",
       "Q 1841 2988 1841 3469 \n",
       "Q 1841 3913 1700 4092 \n",
       "Q 1559 4272 1350 4272 \n",
       "z\n",
       "M 1353 -169 \n",
       "L 3859 4659 \n",
       "L 4316 4659 \n",
       "L 1819 -169 \n",
       "L 1353 -169 \n",
       "z\n",
       "M 3334 1075 \n",
       "Q 3334 1569 3581 1911 \n",
       "Q 3828 2253 4300 2253 \n",
       "Q 4731 2253 5014 1945 \n",
       "Q 5297 1638 5297 1041 \n",
       "Q 5297 459 5011 145 \n",
       "Q 4725 -169 4303 -169 \n",
       "Q 3888 -169 3611 142 \n",
       "Q 3334 453 3334 1075 \n",
       "z\n",
       "M 4316 1866 \n",
       "Q 4103 1866 3964 1684 \n",
       "Q 3825 1503 3825 1019 \n",
       "Q 3825 581 3965 400 \n",
       "Q 4106 219 4313 219 \n",
       "Q 4528 219 4667 400 \n",
       "Q 4806 581 4806 1063 \n",
       "Q 4806 1506 4665 1686 \n",
       "Q 4525 1866 4316 1866 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-70\" d=\"M 422 -1272 \n",
       "L 422 3319 \n",
       "L 934 3319 \n",
       "L 934 2888 \n",
       "Q 1116 3141 1344 3267 \n",
       "Q 1572 3394 1897 3394 \n",
       "Q 2322 3394 2647 3175 \n",
       "Q 2972 2956 3137 2557 \n",
       "Q 3303 2159 3303 1684 \n",
       "Q 3303 1175 3120 767 \n",
       "Q 2938 359 2589 142 \n",
       "Q 2241 -75 1856 -75 \n",
       "Q 1575 -75 1351 44 \n",
       "Q 1128 163 984 344 \n",
       "L 984 -1272 \n",
       "L 422 -1272 \n",
       "z\n",
       "M 931 1641 \n",
       "Q 931 1000 1190 694 \n",
       "Q 1450 388 1819 388 \n",
       "Q 2194 388 2461 705 \n",
       "Q 2728 1022 2728 1688 \n",
       "Q 2728 2322 2467 2637 \n",
       "Q 2206 2953 1844 2953 \n",
       "Q 1484 2953 1207 2617 \n",
       "Q 931 2281 931 1641 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-64\" d=\"M 2575 0 \n",
       "L 2575 419 \n",
       "Q 2259 -75 1647 -75 \n",
       "Q 1250 -75 917 144 \n",
       "Q 584 363 401 755 \n",
       "Q 219 1147 219 1656 \n",
       "Q 219 2153 384 2558 \n",
       "Q 550 2963 881 3178 \n",
       "Q 1213 3394 1622 3394 \n",
       "Q 1922 3394 2156 3267 \n",
       "Q 2391 3141 2538 2938 \n",
       "L 2538 4581 \n",
       "L 3097 4581 \n",
       "L 3097 0 \n",
       "L 2575 0 \n",
       "z\n",
       "M 797 1656 \n",
       "Q 797 1019 1065 703 \n",
       "Q 1334 388 1700 388 \n",
       "Q 2069 388 2326 689 \n",
       "Q 2584 991 2584 1609 \n",
       "Q 2584 2291 2321 2609 \n",
       "Q 2059 2928 1675 2928 \n",
       "Q 1300 2928 1048 2622 \n",
       "Q 797 2316 797 1656 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-66\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-28\" transform=\"translate(35.205078 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-Bold-78\" transform=\"translate(74.21875 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(153.31543 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-29\" transform=\"translate(204.6875 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(243.701172 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(271.484375 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(327.099609 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(382.714844 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(471.630859 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(499.414062 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(555.029297 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(588.330078 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(643.945312 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(699.560547 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"patch_6\">\n",
       "     <path d=\"M 51.1265 263.967625 \n",
       "L 68.7265 263.967625 \n",
       "L 68.7265 257.807625 \n",
       "L 51.1265 257.807625 \n",
       "z\n",
       "\" style=\"fill: #ff7f0e; fill-opacity: 0.5; stroke: #ff7f0e; stroke-opacity: 0.5; stroke-width: 0.8; stroke-linejoin: miter\"/>\n",
       "    </g>\n",
       "    <g id=\"text_20\">\n",
       "     <!-- $y^*$ 95% pred. -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 263.967625) scale(0.088 -0.088)\">\n",
       "      <use xlink:href=\"#DejaVuSans-Oblique-79\" transform=\"translate(0 0.765625)\"/>\n",
       "      <use xlink:href=\"#DejaVuSans-2a\" transform=\"translate(77.283529 39.046875) scale(0.7)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(128.655599 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-39\" transform=\"translate(156.438802 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-35\" transform=\"translate(212.054036 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-25\" transform=\"translate(267.669271 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" transform=\"translate(356.585286 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-70\" transform=\"translate(384.36849 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" transform=\"translate(439.983724 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" transform=\"translate(473.284505 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-64\" transform=\"translate(528.89974 0.765625)\"/>\n",
       "      <use xlink:href=\"#ArialMT-2e\" transform=\"translate(584.514974 0.765625)\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"line2d_19\">\n",
       "     <path d=\"M 51.1265 273.4345 \n",
       "L 59.9265 273.4345 \n",
       "L 68.7265 273.4345 \n",
       "\" style=\"fill: none; stroke-dasharray: 7.68,1.92,1.2,1.92; stroke-dashoffset: 0; stroke: #bf00bf; stroke-width: 1.2\"/>\n",
       "    </g>\n",
       "    <g id=\"text_21\">\n",
       "     <!-- True function -->\n",
       "     <g style=\"fill: #262626\" transform=\"translate(75.7665 276.5145) scale(0.088 -0.088)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-54\" d=\"M 1659 0 \n",
       "L 1659 4041 \n",
       "L 150 4041 \n",
       "L 150 4581 \n",
       "L 3781 4581 \n",
       "L 3781 4041 \n",
       "L 2266 4041 \n",
       "L 2266 0 \n",
       "L 1659 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-75\" d=\"M 2597 0 \n",
       "L 2597 488 \n",
       "Q 2209 -75 1544 -75 \n",
       "Q 1250 -75 995 37 \n",
       "Q 741 150 617 320 \n",
       "Q 494 491 444 738 \n",
       "Q 409 903 409 1263 \n",
       "L 409 3319 \n",
       "L 972 3319 \n",
       "L 972 1478 \n",
       "Q 972 1038 1006 884 \n",
       "Q 1059 663 1231 536 \n",
       "Q 1403 409 1656 409 \n",
       "Q 1909 409 2131 539 \n",
       "Q 2353 669 2445 892 \n",
       "Q 2538 1116 2538 1541 \n",
       "L 2538 3319 \n",
       "L 3100 3319 \n",
       "L 3100 0 \n",
       "L 2597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-66\" d=\"M 556 0 \n",
       "L 556 2881 \n",
       "L 59 2881 \n",
       "L 59 3319 \n",
       "L 556 3319 \n",
       "L 556 3672 \n",
       "Q 556 4006 616 4169 \n",
       "Q 697 4388 901 4523 \n",
       "Q 1106 4659 1475 4659 \n",
       "Q 1713 4659 2000 4603 \n",
       "L 1916 4113 \n",
       "Q 1741 4144 1584 4144 \n",
       "Q 1328 4144 1222 4034 \n",
       "Q 1116 3925 1116 3625 \n",
       "L 1116 3319 \n",
       "L 1763 3319 \n",
       "L 1763 2881 \n",
       "L 1116 2881 \n",
       "L 1116 0 \n",
       "L 556 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-63\" d=\"M 2588 1216 \n",
       "L 3141 1144 \n",
       "Q 3050 572 2676 248 \n",
       "Q 2303 -75 1759 -75 \n",
       "Q 1078 -75 664 370 \n",
       "Q 250 816 250 1647 \n",
       "Q 250 2184 428 2587 \n",
       "Q 606 2991 970 3192 \n",
       "Q 1334 3394 1763 3394 \n",
       "Q 2303 3394 2647 3120 \n",
       "Q 2991 2847 3088 2344 \n",
       "L 2541 2259 \n",
       "Q 2463 2594 2264 2762 \n",
       "Q 2066 2931 1784 2931 \n",
       "Q 1359 2931 1093 2626 \n",
       "Q 828 2322 828 1663 \n",
       "Q 828 994 1084 691 \n",
       "Q 1341 388 1753 388 \n",
       "Q 2084 388 2306 591 \n",
       "Q 2528 794 2588 1216 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-54\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"57.333984\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"90.634766\"/>\n",
       "      <use xlink:href=\"#ArialMT-65\" x=\"146.25\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"201.865234\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"229.648438\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"257.431641\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"313.046875\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"368.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"418.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"446.445312\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"468.662109\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"524.277344\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "  </g>\n",
       "  <g id=\"axes_2\">\n",
       "   <g id=\"matplotlib.axis_3\">\n",
       "    <g id=\"ytick_8\">\n",
       "     <g id=\"line2d_20\">\n",
       "      <defs>\n",
       "       <path id=\"mb7ac659c85\" d=\"M 0 0 \n",
       "L 4.8 0 \n",
       "\" style=\"stroke: #262626\"/>\n",
       "      </defs>\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb7ac659c85\" x=\"400.3265\" y=\"274.0875\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_22\">\n",
       "      <!-- 0.0000 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 277.236937) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"194.628906\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"250.244141\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_9\">\n",
       "     <g id=\"line2d_21\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb7ac659c85\" x=\"400.3265\" y=\"220.762116\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_23\">\n",
       "      <!-- 0.0005 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 223.911554) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"194.628906\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"250.244141\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_10\">\n",
       "     <g id=\"line2d_22\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb7ac659c85\" x=\"400.3265\" y=\"167.436733\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_24\">\n",
       "      <!-- 0.0010 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 170.58617) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"194.628906\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"250.244141\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_11\">\n",
       "     <g id=\"line2d_23\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb7ac659c85\" x=\"400.3265\" y=\"114.111349\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_25\">\n",
       "      <!-- 0.0015 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 117.260787) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-31\" x=\"194.628906\"/>\n",
       "       <use xlink:href=\"#ArialMT-35\" x=\"250.244141\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"ytick_12\">\n",
       "     <g id=\"line2d_24\">\n",
       "      <g>\n",
       "       <use xlink:href=\"#mb7ac659c85\" x=\"400.3265\" y=\"60.785965\" style=\"fill: #262626; stroke: #262626\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "     <g id=\"text_26\">\n",
       "      <!-- 0.0020 -->\n",
       "      <g style=\"fill: #ff7f0e\" transform=\"translate(408.6265 63.935403) scale(0.088 -0.088)\">\n",
       "       <use xlink:href=\"#ArialMT-30\"/>\n",
       "       <use xlink:href=\"#ArialMT-2e\" x=\"55.615234\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"83.398438\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"139.013672\"/>\n",
       "       <use xlink:href=\"#ArialMT-32\" x=\"194.628906\"/>\n",
       "       <use xlink:href=\"#ArialMT-30\" x=\"250.244141\"/>\n",
       "      </g>\n",
       "     </g>\n",
       "    </g>\n",
       "    <g id=\"text_27\">\n",
       "     <!-- Information Acquisition Function -->\n",
       "     <g style=\"fill: #ff7f0e\" transform=\"translate(446.527875 221.16075) rotate(-90) scale(0.096 -0.096)\">\n",
       "      <defs>\n",
       "       <path id=\"ArialMT-49\" d=\"M 597 0 \n",
       "L 597 4581 \n",
       "L 1203 4581 \n",
       "L 1203 0 \n",
       "L 597 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-6d\" d=\"M 422 0 \n",
       "L 422 3319 \n",
       "L 925 3319 \n",
       "L 925 2853 \n",
       "Q 1081 3097 1340 3245 \n",
       "Q 1600 3394 1931 3394 \n",
       "Q 2300 3394 2536 3241 \n",
       "Q 2772 3088 2869 2813 \n",
       "Q 3263 3394 3894 3394 \n",
       "Q 4388 3394 4653 3120 \n",
       "Q 4919 2847 4919 2278 \n",
       "L 4919 0 \n",
       "L 4359 0 \n",
       "L 4359 2091 \n",
       "Q 4359 2428 4304 2576 \n",
       "Q 4250 2725 4106 2815 \n",
       "Q 3963 2906 3769 2906 \n",
       "Q 3419 2906 3187 2673 \n",
       "Q 2956 2441 2956 1928 \n",
       "L 2956 0 \n",
       "L 2394 0 \n",
       "L 2394 2156 \n",
       "Q 2394 2531 2256 2718 \n",
       "Q 2119 2906 1806 2906 \n",
       "Q 1569 2906 1367 2781 \n",
       "Q 1166 2656 1075 2415 \n",
       "Q 984 2175 984 1722 \n",
       "L 984 0 \n",
       "L 422 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-41\" d=\"M -9 0 \n",
       "L 1750 4581 \n",
       "L 2403 4581 \n",
       "L 4278 0 \n",
       "L 3588 0 \n",
       "L 3053 1388 \n",
       "L 1138 1388 \n",
       "L 634 0 \n",
       "L -9 0 \n",
       "z\n",
       "M 1313 1881 \n",
       "L 2866 1881 \n",
       "L 2388 3150 \n",
       "Q 2169 3728 2063 4100 \n",
       "Q 1975 3659 1816 3225 \n",
       "L 1313 1881 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-71\" d=\"M 2538 -1272 \n",
       "L 2538 353 \n",
       "Q 2406 169 2170 47 \n",
       "Q 1934 -75 1669 -75 \n",
       "Q 1078 -75 651 397 \n",
       "Q 225 869 225 1691 \n",
       "Q 225 2191 398 2587 \n",
       "Q 572 2984 901 3189 \n",
       "Q 1231 3394 1625 3394 \n",
       "Q 2241 3394 2594 2875 \n",
       "L 2594 3319 \n",
       "L 3100 3319 \n",
       "L 3100 -1272 \n",
       "L 2538 -1272 \n",
       "z\n",
       "M 803 1669 \n",
       "Q 803 1028 1072 708 \n",
       "Q 1341 388 1716 388 \n",
       "Q 2075 388 2334 692 \n",
       "Q 2594 997 2594 1619 \n",
       "Q 2594 2281 2320 2615 \n",
       "Q 2047 2950 1678 2950 \n",
       "Q 1313 2950 1058 2639 \n",
       "Q 803 2328 803 1669 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "       <path id=\"ArialMT-46\" d=\"M 525 0 \n",
       "L 525 4581 \n",
       "L 3616 4581 \n",
       "L 3616 4041 \n",
       "L 1131 4041 \n",
       "L 1131 2622 \n",
       "L 3281 2622 \n",
       "L 3281 2081 \n",
       "L 1131 2081 \n",
       "L 1131 0 \n",
       "L 525 0 \n",
       "z\n",
       "\" transform=\"scale(0.015625)\"/>\n",
       "      </defs>\n",
       "      <use xlink:href=\"#ArialMT-49\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"27.783203\"/>\n",
       "      <use xlink:href=\"#ArialMT-66\" x=\"83.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"111.181641\"/>\n",
       "      <use xlink:href=\"#ArialMT-72\" x=\"166.796875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6d\" x=\"200.097656\"/>\n",
       "      <use xlink:href=\"#ArialMT-61\" x=\"283.398438\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"339.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"366.796875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"389.013672\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"444.628906\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"500.244141\"/>\n",
       "      <use xlink:href=\"#ArialMT-41\" x=\"522.527344\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"589.226562\"/>\n",
       "      <use xlink:href=\"#ArialMT-71\" x=\"639.226562\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"694.841797\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"750.457031\"/>\n",
       "      <use xlink:href=\"#ArialMT-73\" x=\"772.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"822.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"844.890625\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"872.673828\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"894.890625\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"950.505859\"/>\n",
       "      <use xlink:href=\"#ArialMT-20\" x=\"1006.121094\"/>\n",
       "      <use xlink:href=\"#ArialMT-46\" x=\"1033.904297\"/>\n",
       "      <use xlink:href=\"#ArialMT-75\" x=\"1094.988281\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"1150.603516\"/>\n",
       "      <use xlink:href=\"#ArialMT-63\" x=\"1206.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-74\" x=\"1256.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-69\" x=\"1284.001953\"/>\n",
       "      <use xlink:href=\"#ArialMT-6f\" x=\"1306.21875\"/>\n",
       "      <use xlink:href=\"#ArialMT-6e\" x=\"1361.833984\"/>\n",
       "     </g>\n",
       "    </g>\n",
       "   </g>\n",
       "   <g id=\"line2d_25\">\n",
       "    <path d=\"M 59.439227 274.0875 \n",
       "L 62.718566 274.0875 \n",
       "L 65.997905 274.0875 \n",
       "L 69.277244 274.0875 \n",
       "L 72.556583 274.0875 \n",
       "L 75.835921 274.0875 \n",
       "L 79.115261 274.0875 \n",
       "L 82.394598 274.0875 \n",
       "L 85.673938 274.0875 \n",
       "L 88.953278 274.0875 \n",
       "L 92.232615 274.0875 \n",
       "L 95.511955 274.0875 \n",
       "L 98.791295 274.0875 \n",
       "L 102.070632 274.0875 \n",
       "L 105.349969 274.0875 \n",
       "L 108.629311 274.0875 \n",
       "L 111.908649 274.0875 \n",
       "L 115.187986 274.0875 \n",
       "L 118.467328 274.0875 \n",
       "L 121.746666 274.0875 \n",
       "L 125.026003 274.0875 \n",
       "L 128.305345 274.087499 \n",
       "L 131.584682 273.894558 \n",
       "L 134.86402 234.041682 \n",
       "L 138.143362 32.1675 \n",
       "L 141.422694 231.527281 \n",
       "L 144.702037 266.489084 \n",
       "L 147.981379 273.776584 \n",
       "L 151.260711 274.087098 \n",
       "L 154.540053 274.0875 \n",
       "L 157.819395 274.0875 \n",
       "L 161.098728 274.0875 \n",
       "L 164.37807 274.0875 \n",
       "L 167.657412 274.0875 \n",
       "L 170.936745 274.0875 \n",
       "L 174.216087 274.087191 \n",
       "L 177.495429 274.079971 \n",
       "L 180.774762 273.818569 \n",
       "L 184.054104 271.483684 \n",
       "L 187.333446 262.501724 \n",
       "L 190.612778 242.075414 \n",
       "L 193.892121 209.897652 \n",
       "L 197.171463 172.565924 \n",
       "L 200.450795 141.542755 \n",
       "L 203.730137 128.180789 \n",
       "L 207.00948 138.162582 \n",
       "L 210.288812 168.240165 \n",
       "L 213.568154 207.226669 \n",
       "L 216.847496 241.60786 \n",
       "L 220.126829 262.978304 \n",
       "L 223.406181 271.77019 \n",
       "L 226.685504 273.854223 \n",
       "L 229.964846 274.076127 \n",
       "L 233.244188 274.086112 \n",
       "L 236.523511 274.0875 \n",
       "L 239.802872 274.0875 \n",
       "L 243.082195 274.0875 \n",
       "L 246.361537 274.0875 \n",
       "L 249.640879 274.0875 \n",
       "L 252.920222 274.0875 \n",
       "L 256.199564 274.0875 \n",
       "L 259.478887 274.0875 \n",
       "L 262.758248 274.0875 \n",
       "L 266.037571 274.0875 \n",
       "L 269.316913 274.0875 \n",
       "L 272.596255 274.0875 \n",
       "L 275.875578 274.0875 \n",
       "L 279.15494 274.0875 \n",
       "L 282.434262 274.0875 \n",
       "L 285.713605 274.0875 \n",
       "L 288.992947 274.0875 \n",
       "L 292.272289 274.0875 \n",
       "L 295.551631 274.0875 \n",
       "L 298.830954 274.0875 \n",
       "L 302.110315 274.0875 \n",
       "L 305.389638 274.0875 \n",
       "L 308.66898 274.0875 \n",
       "L 311.948322 274.0875 \n",
       "L 315.227645 274.0875 \n",
       "L 318.507007 274.0875 \n",
       "L 321.78633 274.0875 \n",
       "L 325.065672 274.0875 \n",
       "L 328.345014 274.0875 \n",
       "L 331.624356 274.0875 \n",
       "L 334.903698 274.0875 \n",
       "L 338.183021 274.0875 \n",
       "L 341.462363 274.0875 \n",
       "L 344.741705 274.0875 \n",
       "L 348.021048 274.0875 \n",
       "L 351.30039 274.0875 \n",
       "L 354.579713 274.0875 \n",
       "L 357.859055 274.0875 \n",
       "L 361.138397 274.0875 \n",
       "L 364.417739 274.0875 \n",
       "L 367.697081 274.0875 \n",
       "L 370.976423 274.0875 \n",
       "L 374.255766 274.0875 \n",
       "L 377.535088 274.0875 \n",
       "L 380.814431 274.0875 \n",
       "L 384.093773 274.0875 \n",
       "\" clip-path=\"url(#p88c51600fc)\" style=\"fill: none; stroke: #ff7f0e; stroke-width: 1.2; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"line2d_26\">\n",
       "    <path d=\"M 138.143362 274.0875 \n",
       "L 138.143362 271.643864 \n",
       "L 138.143362 269.200227 \n",
       "L 138.143362 266.756591 \n",
       "L 138.143362 264.312955 \n",
       "L 138.143362 261.869318 \n",
       "L 138.143362 259.425683 \n",
       "L 138.143362 256.982046 \n",
       "L 138.143362 254.53841 \n",
       "L 138.143362 252.094774 \n",
       "L 138.143362 249.651137 \n",
       "L 138.143362 247.2075 \n",
       "L 138.143362 244.763866 \n",
       "L 138.143362 242.320228 \n",
       "L 138.143362 239.876591 \n",
       "L 138.143362 237.432957 \n",
       "L 138.143362 234.98932 \n",
       "L 138.143362 232.545682 \n",
       "L 138.143362 230.102048 \n",
       "L 138.143362 227.658411 \n",
       "L 138.143362 225.214774 \n",
       "L 138.143362 222.77114 \n",
       "L 138.143362 220.327499 \n",
       "L 138.143362 217.883868 \n",
       "L 138.143362 215.440231 \n",
       "L 138.143362 212.996594 \n",
       "L 138.143362 210.552957 \n",
       "L 138.143362 208.109319 \n",
       "L 138.143362 205.665682 \n",
       "L 138.143362 203.222051 \n",
       "L 138.143362 200.778414 \n",
       "L 138.143362 198.334777 \n",
       "L 138.143362 195.891139 \n",
       "L 138.143362 193.447502 \n",
       "L 138.143362 191.003865 \n",
       "L 138.143362 188.560228 \n",
       "L 138.143362 186.116597 \n",
       "L 138.143362 183.672959 \n",
       "L 138.143362 181.229322 \n",
       "L 138.143362 178.785685 \n",
       "L 138.143362 176.342048 \n",
       "L 138.143362 173.89841 \n",
       "L 138.143362 171.454779 \n",
       "L 138.143362 169.011136 \n",
       "L 138.143362 166.567499 \n",
       "L 138.143362 164.123874 \n",
       "L 138.143362 161.680237 \n",
       "L 138.143362 159.236599 \n",
       "L 138.143362 156.792962 \n",
       "L 138.143362 154.349325 \n",
       "L 138.143362 151.905675 \n",
       "L 138.143362 149.462038 \n",
       "L 138.143362 147.018401 \n",
       "L 138.143362 144.574763 \n",
       "L 138.143362 142.131126 \n",
       "L 138.143362 139.687501 \n",
       "L 138.143362 137.243864 \n",
       "L 138.143362 134.800214 \n",
       "L 138.143362 132.35659 \n",
       "L 138.143362 129.912952 \n",
       "L 138.143362 127.469315 \n",
       "L 138.143362 125.025678 \n",
       "L 138.143362 122.582041 \n",
       "L 138.143362 120.138403 \n",
       "L 138.143362 117.694766 \n",
       "L 138.143362 115.251141 \n",
       "L 138.143362 112.807492 \n",
       "L 138.143362 110.363867 \n",
       "L 138.143362 107.920217 \n",
       "L 138.143362 105.476592 \n",
       "L 138.143362 103.032943 \n",
       "L 138.143362 100.589318 \n",
       "L 138.143362 98.145681 \n",
       "L 138.143362 95.702043 \n",
       "L 138.143362 93.258406 \n",
       "L 138.143362 90.814769 \n",
       "L 138.143362 88.371132 \n",
       "L 138.143362 85.927494 \n",
       "L 138.143362 83.483857 \n",
       "L 138.143362 81.04022 \n",
       "L 138.143362 78.596595 \n",
       "L 138.143362 76.152946 \n",
       "L 138.143362 73.709321 \n",
       "L 138.143362 71.265683 \n",
       "L 138.143362 68.822046 \n",
       "L 138.143362 66.378409 \n",
       "L 138.143362 63.934772 \n",
       "L 138.143362 61.491147 \n",
       "L 138.143362 59.047497 \n",
       "L 138.143362 56.603872 \n",
       "L 138.143362 54.160223 \n",
       "L 138.143362 51.716598 \n",
       "L 138.143362 49.272948 \n",
       "L 138.143362 46.829323 \n",
       "L 138.143362 44.385674 \n",
       "L 138.143362 41.942049 \n",
       "L 138.143362 39.498399 \n",
       "L 138.143362 37.054774 \n",
       "L 138.143362 34.611125 \n",
       "L 138.143362 32.1675 \n",
       "\" clip-path=\"url(#p88c51600fc)\" style=\"fill: none; stroke: #ff7f0e; stroke-linecap: round\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_7\">\n",
       "    <path d=\"M 43.2065 286.1835 \n",
       "L 43.2065 20.0715 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_8\">\n",
       "    <path d=\"M 400.3265 286.1835 \n",
       "L 400.3265 20.0715 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_9\">\n",
       "    <path d=\"M 43.2065 286.1835 \n",
       "L 400.3265 286.1835 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "   <g id=\"patch_10\">\n",
       "    <path d=\"M 43.2065 20.0715 \n",
       "L 400.3265 20.0715 \n",
       "\" style=\"fill: none; stroke: #262626; stroke-linejoin: miter; stroke-linecap: square\"/>\n",
       "   </g>\n",
       "  </g>\n",
       " </g>\n",
       " <defs>\n",
       "  <clipPath id=\"p88c51600fc\">\n",
       "   <rect x=\"43.2065\" y=\"20.0715\" width=\"357.12\" height=\"266.112\"/>\n",
       "  </clipPath>\n",
       " </defs>\n",
       "</svg>\n"
      ],
      "text/plain": [
       "<Figure size 640x480 with 2 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "train_x = torch.from_numpy(X).float()\n",
    "train_y = torch.from_numpy(Y).float()\n",
    "model = ExactGP(train_x, train_y)\n",
    "\n",
    "# It is not a good idea to train the model when we don't have enough data\n",
    "# So we fix the hyperparameters to something reasonable\n",
    "model.covar_module.base_kernel.lengthscale = 0.15\n",
    "model.covar_module.outputscale = 4.0\n",
    "model.likelihood.noise = 0.0\n",
    "model.eval()\n",
    "\n",
    "# Run the algorithm\n",
    "X_design = torch.linspace(0, 1, 100)\n",
    "af_all = maximize(\n",
    "    f,\n",
    "    model,\n",
    "    X_design,\n",
    "    ei,\n",
    "    max_it=5,\n",
    "    plot=1\n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Questions\n",
    "\n",
    "+ Rerun the main algorithm for EI by optimizing the hyper-parameters. Hint: Go through the code of ``maximize``."
   ]
  }
 ],
 "metadata": {
  "celltoolbar": "Tags",
  "kernelspec": {
   "display_name": "Python 3 (ipykernel)",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.11.6"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 4
}
